#!/usr/bin/env node
// 指定脚本的执行程序

// 引入依赖
const program = require("commander");
const path = require("path");
const inquirer = require("inquirer");
const packages = require("../package.json");
const shell = require("shelljs");
const consoleBook = require("./consoleBook.js");
const questions = require("./questions.js");
const readline = require("readline");

const rl = readline.createInterface({
  input: process.stdin,
  output: process.stdout
});

// 定义版本号以及命令选项
program
  .version(packages.version)
  .option("-v --version", "output the version number")
  .option("-i --init", "init a project");

program.parse(process.argv);

if (program.init) {
  consoleBook.hello();

  inquirer.prompt(questions).then(answers => {
    const { name, git, gitBranch, type, history, distPath, install } = answers;
    const productPath = path.join(__dirname, "../");
    const query = {
      name,
      git,
      gitBranch,
      distPath,
      cwd: process.cwd(),
      gulpfile: path.join(productPath, "gulpfile.js"),
      history,
      install
    };
    const queryStr = Object.entries(query)
      .map(([key, val]) => {
        return val ? ` --${key} ${val}` : "";
      })
      .join("");

    const gulpShell = `${productPath}/node_modules/.bin/gulp ${type} ${queryStr}`;

    shell.exec(gulpShell);

    console.log("结果为:", answers);
  });
}
