module.exports = {
  parser: 'babel-eslint',
  extends: ['airbnb', 'prettier', 'plugin:compat/recommended'],
  env: {
    browser: true,
    node: true,
    es6: true,
    mocha: true,
    jest: true,
    jasmine: true,
  },
  globals: {
    APP_TYPE: true,
    NO_CACHE: true,
    MOCK: true,
    BMap: true,
    page: true,
  },
  rules: {
    /*
            "off"或者0    //关闭规则关闭
            "warn"或者1    //在打开的规则作为警告（不影响退出代码）
            "error"或者2    //把规则作为一个错误（退出代码触发时为1）
        */
    'react/jsx-filename-extension': [1, { extensions: ['.js'] }],
    'react/jsx-wrap-multilines': 0,
    'react/prop-types': 0,
    'react/forbid-prop-types': 0,
    'react/jsx-one-expression-per-line': 0,
    'react/jsx-indent': [0, 'tab'],
    'import/no-unresolved': [2, { ignore: ['^@/', '^umi/'] }],
    'import/no-extraneous-dependencies': [
      2,
      {
        optionalDependencies: true,
        devDependencies: ['**/tests/**.js', '/mock/**.js', '**/**.test.js'],
      },
    ],
    'jsx-a11y/no-noninteractive-element-interactions': 0,
    'jsx-a11y/click-events-have-key-events': 0,
    'jsx-a11y/no-static-element-interactions': 0,
    'jsx-a11y/anchor-is-valid': 0,
    'no-alert': 2,
    //如下新增
    'no-unused-vars': 0, //error 'parse' is defined but never used  已定义未使用。建议打开
    'react/destructuring-assignment': 0, //强制将props,state,context解构赋值。 强制在组件内部使用解构赋值  建议打开
    'prefer-const': 0, //不强制const
    'no-undef': 0, //未定义变量  建议打开
    'no-param-reassign': 1, //禁止给参数重新赋值
    'no-underscore-dangle': 0, //变量名不能带下划线前缀，防止与lodash误会
    camelcase: 0, //不强制使用驼峰
    'prefer-destructuring': 0,
    'no-unused-expressions': 0, //三目 短路
    'import/prefer-default-export': 0, //文件只export一个对象    建议直接用export default
    'react/no-array-index-key': 0,
    'no-script-url': 0, //  location.href = "javascript:void(0)"; error  基于eval安全考虑
    'react/sort-comp': 0,
    'func-names': 0, //不推荐匿名函数
    'import/no-mutable-exports': 0,
    'react/no-access-state-in-setstate': 0,
    'class-methods-use-this': 0, // 必须调用this
    'consistent-return': 0, // return 后面是否允许省略
    'no-plusplus': 0, // 禁止使用++，--
    'react/no-multi-comp': 1,
    'no-useless-constructor': 1,
    'react/prefer-stateless-function': 1,
    'react/no-unused-state': 1,
    'no-continue': 1,
    //。。。。。。。
    // 'array-callback-return': 0,
    // 'no-shadow': 0,
    // 'react/react-in-jsx-scope': 0,
    // 'no-dupe-keys': 0,
    // 'no-nested-ternary': 0,
    // 'no-useless-constructor': 0,
    // 'no-empty': 0,
    // 'react/no-unus': 0,
    // 'react/jsx-no-duplicate-props': 0,
    // 'react/no-unused-state': 0,
    // 'react/no-string-r': 0,
    // 'react/no-array-in': 0,
    // 'no-unreachable': 0,
    // 'no-useless-escape': 0,
    // 'import/extensions': 0,
    // 'no-void': 0,
    // 'no-prototype-builtins': 0,
    // 'react/no-string-refs': 0,
    // 'sx-a11y/label-has-for': 0,
    // 'no-multi-assign': 0,
    // 'jsx-a11y/label-has-associated-control': 0,
    // 'jsx-a11y/label-has-for': 0,
    // 'react/prefer-stateless-function': 0,
    // 'no-sequences': 0,
    // 'no-return-assign': 0,
    // 'default-case': 0,
    // 'no-use-before-define': 0,
    // 'global-require': 0,
    // 'import/no-extraneous-dependencies': 0,
    'jsx-a11y/alt-text': 0,
    // eqeqeq: 0, //三等
    // 'no-useless-concat': 0,
    indent: ['off', 2],
  },
  settings: {
    polyfills: ['fetch', 'promises', 'url'],
  },
  parserOptions: {
    // Parsing error: Using the export keyword between a decorator and a class is not allowed. Please use export @dec class instead.
    ecmaFeatures: {
      legacyDecorators: true,
    },
  },
};
