// https://umijs.org/config/
import os from 'os';
import slash from 'slash2';
import pageRoutes from './router.config';
// import webpackplugin from './plugin.config';
import defaultSettings from '../src/defaultSettings';

const APP_TYPE = process.env.APP_TYPE || 'dev';
// let PROXY_URL = `http://backend-crs-biz-service.${APP_TYPE}.ahotels.tech`;
let PROXY_URL = `https://crsx-${APP_TYPE}.oyohotels.cn`;

if (APP_TYPE === 'uat') {
  PROXY_URL = `http://ali.uat.ahotels.tech/crs-biz-service`;
}

export default {
  // add for transfer to umi
  plugins: [
    [
      'umi-plugin-react',
      {
        antd: true,
        dva: {
          hmr: true,
        },
        locale: {
          enable: true,
          default: 'zh-CN',
          baseNavigator: true,
          antd: true,
        },
        dynamicImport: {
          loadingComponent: './components/PageLoading/index',
        },
        // pwa 导致了线上申诉列表导出失败，具体原因的话可以找李翼和继祥沟通哈哈，先了解一下server-work pwa
        // pwa: {
        //   workboxPluginMode: 'InjectManifest',
        //   workboxOptions: {
        //     importWorkboxFrom: 'local',
        //   },
        // },
        ...(!process.env.TEST && os.platform() === 'darwin'
          ? {
              // 通过 webpack 的 dll 插件预打包一份 dll 文件来达到二次启动提速的目的。
              dll: {
                include: ['dva', 'dva/router', 'dva/saga', 'dva/fetch'],
                exclude: ['@babel/runtime'],
              },
              // 通过 hard-source-webpack-plugin 开启 webpack 缓存，二次启动时间减少 80%。推荐非 windows 电脑使用，windows 下由于大文件 IO 比较慢，可自行决定是否启用。
              hardSource: false,
            }
          : {}),
      },
    ],
  ],
  define: {
    APP_TYPE: process.env.APP_TYPE || '',
    NO_CACHE: process.env.NO_CACHE || '',
    MOCK: process.env.MOCK || '',
  },
  // 开启 tree-shaking之后，gzip后的尺寸能减少 10K
  treeShaking: true,
  targets: {
    ie: 11,
  },
  publicPath: './',
  history: 'hash',
  // 路由配置:如果配置了routes，则约定式路由会不生效。
  routes: pageRoutes,
  // Theme for antd
  // https://ant.design/docs/react/customize-theme-cn
  theme: {
    '@primary-color': defaultSettings.primaryColor,
  },
  externals: {
    '@antv/data-set': 'DataSet',
  },
  hash: true,
  ignoreMomentLocale: true,
  lessLoaderOptions: {
    javascriptEnabled: true,
  },
  cssLoaderOptions: {
    modules: true,
    getLocalIdent: (context, localIdentName, localName) => {
      if (
        context.resourcePath.includes('node_modules') ||
        context.resourcePath.includes('ant.design.pro.less') ||
        context.resourcePath.includes('global.less')
      ) {
        return localName;
      }
      const match = context.resourcePath.match(/src(.*)/);
      if (match && match[1]) {
        const antdProPath = match[1].replace('.less', '');
        const arr = slash(antdProPath)
          .split('/')
          .map(a => a.replace(/([A-Z])/g, '-$1'))
          .map(a => a.toLowerCase());
        return `antd-pro${arr.join('-')}-${localName}`.replace(/--/g, '-');
      }
      return localName;
    },
  },
  manifest: {
    basePath: '/',
  },
  cssnano: {
    mergeRules: false,
  },
  proxy: {
    '/api/crs/': {
      target: PROXY_URL,
      changeOrigin: true,
      // pathRewrite: { '^/v1/': '' },
    },
  },
  // chainWebpack: webpackplugin,
};
