import { parse } from 'url';

const RES = {
  rateCodeId: 12455, // 价格策略ID
  name: '你好吗', // 价格策略名称
  description: '', // 价格策略概述
  status: 1, // 是否有效 0无效 1有效
  checkinType: 1, // 入住类型 0时租房 1全天房
  rules: {
    reservationDateRule: {
      // 预定时间规则
      name: 'reservationDateRule',
      customizable: 0, // 是否可定制 0 不可 1 可制定
      type: '0', // 入住类型 '0'长期 '1'固定
      isUseWeekly: false, // 按每周
      isUseExceptDate: false, // 排除每月几号
      isUseTimeLimit: false, // 限制时间段
      regularDate: {
        // 固定日期
        startDate: 20180811, // 开始日期
        endDate: 20180918, // 结束日期
      },
      weekly: [2, 9], // 按每周：周信息 1,2,3,4,5,6,0（星期一到星期天)
      exceptDate: [1, 8, 22], // 排除每月几号，日期信息
      timeLimit: {
        // 限制时间段信息
        startDate: '', // 开始日期
        endDate: '', // 结束日期
      },
    },
    applyDateRule: {
      // 入住时间规则
      name: 'applyDateRule',
      customizable: 0, // 是否可定制 0 不可 1 可制定
      type: '0', // 入住类型 '0'长期 '1'固定
      isUseWeekly: false, // 按每周
      isUseExceptDate: false, // 排除每月几号
      isUseTimeLimit: false, // 限制时间段
      regularDate: {
        startDate: 20180811, // 开始日期
        endDate: 20180939, // 结束日期
      },
      weekly: [], // 按每周：周信息 1,2,3,4,5,6,0（星期一到星期天)
      exceptDate: [1], // 排除每月几号，日期信息
      timeLimit: {
        // 限制时间段信息
        startDate: '', // 开始日期
        endDate: '', // 结束日期
      },
    },
    changePriceRule: {
      isUseChangePrice: true, // 是否使用
      customizable: 0, // 是否可定制 0可定制 1不可定制
      type: '0', // 变价类型 0固定 1动态 2开启自定
      dynamicPriceType: '', // 0加价 1减价 2加价（百分比） 3打折
      stablePrice: '', // 固定价格
      dynamicPriceValue: '',
    },
    guestSourceRule: {
      // 客源类型规则
      guestSource: ['1', '2'], // 客源类型数组 0全部 1非会员 2会员
      customizable: 0, // 是否可定制 0 不可定制 1可定制
    },
    leastReservationRule: {
      // 可使用起订规则
      type: '1', // 起订类型 1多间预订 2连住预定 3提前预定
      continuousRoom: 0, // 房间数
      continuousDay: 12, // 连住天数
      inAdvanceDay: 0, // 提前预定天数
      customizable: 0, // 是否可定制
    },
    payRule: {
      // 支付规则
      type: '1', // 0预付 1现付
      customizable: 0, // 是否可定制
    },
    cancelRule: {
      // 取消规则
      type: '1', // 取消类型 1不可取消 2可取消
      customizable: 0, // 是否可定制
    },
    inventoryRule: {
      // 库存规则
      type: '1', // 共享库存规则 1共享正常库存
      shareInventoryRate: '32.5', // 共享库存百分比
      customizable: 0, // 是否可定制
    },
    guaranteeRule: {
      type: '1', // 1无担保 2全天首晚担保 3全天全额担保
      customizable: 0, // 是否可定制
    },
  },
};

function getRateCodeDetail(req, res, u, b) {
  let url = u;
  if (!url || Object.prototype.toString.call(url) !== '[object String]') {
    url = req.url; // eslint-disable-line
  }

  const body = (b && b.body) || req.body;
  // const { method, name, desc, key } = body;

  return res.json(RES);
}

const queryPriceStrategyList = (req, res) => {
  console.log(req);
  return {
    code: '000',
    msg: '成功',
    data: {
      pageNum: 0,
      pageSize: 10,
      totalPages: 1,
      totalCount: 4,
      result: [
        {
          rateCodeId: 2,
          rateCodeName: '国庆打折',
          rateCodeDescription: '国庆节打骨折，爽',
          channel: [2, 3, 1, 4],
          guestSourceType: '全部、非会员',
          status: '有效',
        },
        {
          rateCodeId: 4,
          rateCodeName: '会员专享',
          rateCodeDescription: '会员专用价格策略',
          channel: [],
          guestSourceType: '会员',
          status: '有效',
        },
        {
          rateCodeId: 7,
          rateCodeName: '测试新建价格策略',
          rateCodeDescription: '测试新建价格策略',
          channel: [],
          guestSourceType: '全部、非会员',
          status: '有效',
        },
        {
          rateCodeId: 3,
          rateCodeName: '情人节打折',
          rateCodeDescription: '情人节打骨折，爽',
          channel: [8, 7, 5, 1, 6, 2],
          guestSourceType: '全部',
          status: '有效',
        },
      ],
    },
  };
};

export default {
  'GET /api/crs/v1/rateCode/searchRateCodeList': queryPriceStrategyList,
  'GET /api/crs/v1/rateCode/getRateCodeDetail': getRateCodeDetail,
};
