import qs from 'qs';
import hotelType from './hotelType';
import user from './user';
import hotel from './hotel';
import permission from './permission';
import hotelList from './hotelList';
import hotelFacilities from './hotelFacilities';
import housePriceChannel from './housePriceChannel';
import hotelChange from './hotelChange';

const MOCK_LIST = [
  hotel,
  hotelType,
  hotelList,
  hotelFacilities,
  user,
  permission,
  housePriceChannel,
  hotelChange,
];

const ALL_DATA = {
  POST_DATA: [],
  GET_DATA: [],
  PUT_DATA: [],
};

const DefaultIndex = 40;

MOCK_LIST.forEach((item, index) => {
  Object.entries(item).forEach(([key, value]) => {
    let [method, url] = key.split(/\s+/);
    let { mockType = DefaultIndex } = value;
    let dataName = `${method}_DATA`;

    if (ALL_DATA[dataName][mockType] === undefined) ALL_DATA[dataName][mockType] = {};

    ALL_DATA[dataName][mockType][url] = value;
  });
});
console.log(ALL_DATA);

function getData(methData, type, url) {
  let data = ALL_DATA[methData][type];
  let returnData;
  let noMock = {
    msg: '请填写mock数据',
  };

  if (!data) {
    data = ALL_DATA[methData][DefaultIndex] || {};

    returnData = data[url] || noMock;
  } else if (data[url]) {
    returnData = data[url];
  } else if (ALL_DATA[methData][DefaultIndex]) {
    returnData = ALL_DATA[methData][DefaultIndex][url] || noMock;
  } else {
    returnData = noMock;
  }

  return returnData;
}

function transferMockGet(req, res) {
  let { map, type = DefaultIndex, url } = req.query;
  let data = getData('GET_DATA', type, url);

  if (typeof data === 'function') {
    data(req, res);
  } else {
    res.json(data);
  }
}

function transferMockPost(req, res) {
  let reqUrl = req.url;
  let search = reqUrl.match(/\?(.+)$/);

  if (search) {
    let { type, url } = qs.parse(search[1]);

    let data = getData('POST_DATA', type, url);

    if (typeof data === 'function') {
      data(req, res);
    } else {
      res.json(data);
    }
  }
}

export default {
  'GET /api/crs/v1/common/transfer/get/token': transferMockGet,
  'GET /api/crs/v1/common/transfer/get': transferMockGet,
  'POST /api/crs/v1/common/transfer/post/token': transferMockPost,
  'POST /api/crs/v1/common/transfer/post': {
    code: '000',
    data: {
      isForceUpdatePwd: 0,
      accountId: 1,
      role: 'CRS',
      expire: 10800,
      hotelsId: [],
      hotelId: 1,
      userName: 'admin',
      token: 'ec0-9a4f-33dc21ecb6a-545f-4479-af69-a2522f6fefc6',
    },
    msg: '成功',
  },
};
