/* eslint-disable no-param-reassign */
const httpProxyMiddleware = require('http-proxy-middleware');
const koaConnect = require('koa2-connect');
const getProxyConfig = require('../constants/ProxyConfig');
const logger = require('./logger');
const ENV = require('../constants/ENV');
const parseData = require('./easyBodyParse');

// 处理非200状态码
const getErrHandler = ctx => async (proxyRes, req) => {
  try {
    // 处理非200status的请求 记录下相关上行的参数
    if (proxyRes.statusCode !== 200) {
      const errData = {
        code: proxyRes.statusCode,
        url: ctx.url,
        headers: ctx.request.headers,
        query: ctx.query,
        method: req.method,
      };

      if (req.method.toUpperCase() === 'POST') {
        errData.reqData = ctx.reqData || {};
      }

      logger.error(JSON.stringify(errData));
    }
  } catch (e) {
    console.log(e);
  }
};

// 代理兼容封装
// eslint-disable-next-line func-names
const proxy = function(context, options) {
  if (typeof options === 'string') {
    options = {
      target: options,
    };
  }

  // eslint-disable-next-line func-names
  return async function(ctx, next) {
    await koaConnect(
      httpProxyMiddleware(context, {
        ...options,
        onProxyRes: getErrHandler(ctx, next),
        // 记录请求的参数
        onProxyReq: async () => {
          try {
            if (ctx.method.toUpperCase() === 'POST' || ctx.method.toUpperCase() === 'PUT') {
              ctx.reqData = await parseData(ctx);
            }
          } catch (e) {
            ctx.reqData = {
              data: `日志记录失败, 原因: ${e}`,
            };
          }
        },
      })
    )(ctx, next);
  };
};

// 代理配置
const proxyTable = getProxyConfig(ENV.SERVICE_ENV);

function createProxy(app) {
  Object.keys(proxyTable).forEach(context => {
    const options = proxyTable[context];
    // 使用代理
    app.use(proxy(context, options));
  });
}

module.exports = createProxy;
