import React, { PureComponent } from 'react';
import { message } from 'antd';
import { debounce } from '@/utils/decorator';
import { preLoadingMap } from '@/utils/preLoading';
import styles from './index.less';

class BaiduMapSearch extends PureComponent {
  constructor() {
    super();
    this.state = {
      value: '',
      map: null,
      lastSuccessVal: '',
    };
  }

  componentDidMount() {
    this.handlerBMap();
  }

  async handlerBMap() {
    await preLoadingMap();

    const map = new BMap.Map('b-map-search-component');

    const ac = new BMap.Autocomplete({
      input: 'suggestId',
      location: map,
    });

    this.setState({
      map,
    });

    ac.addEventListener('onconfirm', e => {
      const val = e.item.value;
      const value = val.province + val.city + val.district + val.street + val.business;

      this.setState({
        value,
      });

      this.dispatchPoint(value);
    });
  }

  dispatchPoint = value => {
    const { onChange } = this.props;
    const { map, lastSuccessVal } = this.state;

    if (lastSuccessVal === value || !value) return;

    const local = new BMap.LocalSearch(map, {
      onSearchComplete: () => {
        try {
          const pointer = local.getResults().getPoi(0).point;

          this.setState({
            lastSuccessVal: value,
          });

          onChange &&
            onChange({
              lat: pointer.lat,
              lng: pointer.lng,
            });
        } catch (e) {
          console.log(e);
          onChange && onChange({});
          message.error('未搜索到该地址');
        }
      },
    });

    local.search(value);
  };

  handlerVal = e => {
    this.setState({
      value: e.target.value,
    });
  };

  handlerBlur = e => {
    e.stopPropagation();
  };

  reset = () => {
    this.setState({ value: '' });
  };

  getValue = () => {
    return this.state.value;
  };

  setValue = value => {
    this.setState({ value });
  };

  render() {
    const { disabled, style, placeholder } = this.props;
    const { value } = this.state;

    return (
      <>
        <div id="b-map-search-component" style={{ display: 'none' }} />
        <input
          style={style}
          disabled={disabled}
          id="suggestId"
          placeholder={placeholder}
          onBlur={this.handlerBlur}
          onChange={this.handlerVal}
          value={value}
        />
      </>
    );
  }
}

export default BaiduMapSearch;
