import React, { PureComponent } from 'react';

import { Modal } from 'antd';
import styles from './index.less';

const confirm = Modal.confirm;

/**
 * 转换日期
 * eg: 80000 => 8; 200000 => 20; 201522 => 20
 * @param  {String} time
 * @return {Number}      返回整点 数字类型
 */
function transTime(timeParam: string = ''): number {
  const time: time = timeParam.startsWith('0') ? timeParam.substring(1) : timeParam;
  const subIndex: number = time.length === 5 ? 1 : 2;

  return Number(`${time}`.substring(0, subIndex));
}

/**
 * 转换时间列表
 * [0,1,2,21,22] => [0,1,2,21,22]; [{startTime:'000000', endTime: '20000‘}, {startTime:'210000', endTime: '220000‘}] => [0,1,2,21,22]
 * @param  {Array} list
 * @return {Array}      返回存在的时间段
 */
function transTimeLimit(
  list: BlockSelectType.props.value = [],
  count: number
): BlockSelectType.state.easyList {
  if (list.length === 0 || typeof list[0] === 'number') {
    return list as BlockSelectType.state.easyList;
  }

  if (typeof list[0] === 'object') {
    const newList: BlockSelectType.state.easyList = [];
    let rangeList: BlockSelectType.rangeList = [];

    list.forEach(
      ({ startTime = '', endTime = '' }: BlockSelectType.props.businessData): void => {
        const st: number = transTime(startTime);
        const end: number = transTime(endTime);
        const pushList: BlockSelectType.range = [st, end];

        if (st > end) {
          rangeList.push([0, pushList[1]], [pushList[0], count]);
        } else {
          rangeList.push(pushList);
        }
        // const insertIndex: number = rangeList.findIndex(
        //   (item: BlockSelectType.range): boolean => end < item[0]
        // );

        // if (insertIndex === -1) {
        //   rangeList.push(pushList);
        // } else {
        //   rangeList.splice(insertIndex, 0, pushList);
        // }
      }
    );

    rangeList.sort((arr1, arr2) => arr1[0] - arr2[0]);

    for (let i = 0; i < rangeList[rangeList.length - 1][1]; i++) {
      if (rangeList.some((item: BlockSelectType.range): boolean => i >= item[0] && i < item[1])) {
        newList.push(i);
      }
    }

    return newList;
  }

  return list as BlockSelectType.state.easyList;
}

function getUpdateList(
  st: number,
  count: number,
  mainValueList: BlockSelectType.state.easyList
): BlockSelectType.state.list {
  const list: BlockSelectType.state.list = [];

  for (let i = st; i < count; i++) {
    const params: BlockSelectType.state.listData = {
      text: i,
      isSelect: mainValueList.includes(i),
      isPreSelect: false,
    };

    list.push(params);
  }

  return list;
}

export default class BlockSelect extends PureComponent<BlockSelectType.props.data, any> {
  // private selectRow;
  protected static getDerivedStateFromProps(
    props: BlockSelectType.props.data,
    state: BlockSelectType.state.data
  ): any {
    if (!state.isInit) {
      const { count = 24, st = 0, value, defalutValue = [] } = props;

      let mainValueList: BlockSelectType.state.easyList = [];
      let isControl: boolean = false;

      if (value && Array.isArray(value)) {
        mainValueList = transTimeLimit(value, count);
        isControl = true;
      } else {
        mainValueList = transTimeLimit(defalutValue, count);
      }

      const list: BlockSelectType.state.list = getUpdateList(st, count, mainValueList);

      return {
        list,
        lastList: list,
        isInit: true,
        isControl,
      };
    }

    if (props.value !== state.value && state.isControl) {
      const { count = 24, st = 0 } = props;
      const mainValueList: BlockSelectType.state.easyList = transTimeLimit(props.value, count);
      const list: BlockSelectType.state.list = getUpdateList(st, count, mainValueList);

      return {
        list,
        lastList: list,
        value: props.value,
      };
    }

    return null;
  }

  public state: BlockSelectType.state.data = {
    list: [],
    lastList: [],
    isInit: false,
    wrapperStyle: {
      height: 70,
    },
    blockStyle: {},
    lastSelectIndex: 0,
    clickSwitch: false,
    value: [],
    isControl: false,
  };

  public readonly changeBlockStyle: any;

  protected selectRow: HTMLDivElement;

  constructor(props) {
    super(props);

    this.changeBlockStyle = (): void => {
      if (!this.selectRow) {
        return;
      }

      const width: number = this.selectRow.offsetWidth;
      const { list } = this.state;
      const singleWidth: number = Math.floor((width - 12 - list.length - 1) / list.length);

      this.setState({
        blockStyle: {
          width: singleWidth,
          height: singleWidth,
          pTop: singleWidth + 10,
        },
        wrapperStyle: {
          height: singleWidth + 15,
        },
      });
    };
  }

  public componentDidMount() {
    this.changeBlockStyle();

    window.addEventListener('resize', this.changeBlockStyle);
  }

  public componentWillUnmount() {
    window.removeEventListener('resize', this.changeBlockStyle);
  }

  public render() {
    const { list, blockStyle, wrapperStyle } = this.state;

    return (
      <div
        className={styles.blockSelect}
        style={wrapperStyle}
        ref={ref => {
          this.selectRow = ref;
        }}
      >
        {list.map((item, index) => (
          <div
            className={this.getBlockClass(item)}
            key={index}
            style={{ width: blockStyle.width, height: blockStyle.height }}
            onClick={() => this.openSwitch(index)}
            onMouseEnter={() => this.selectBlock(index)}
          >
            <p style={{ transform: `translate3d(-5px, ${blockStyle.pTop}px, 0)` }}>{item.text}</p>
            {index === list.length - 1 ? (
              <p
                className={styles.lastText}
                style={{ transform: `translate3d(5px, ${blockStyle.pTop}px, 0)` }}
              >
                {Number(list[list.length - 1].text) + 1}
              </p>
            ) : null}
          </div>
        ))}
      </div>
    );
  }

  protected getBlockClass = (item: BlockSelectType.state.listData): string => {
    let addClass: string = '';

    if (item.isPreSelect) {
      addClass = ` ${styles.preActive}`;
    }

    if (item.isSelect) {
      addClass = ` ${styles.active}`;
    }

    return `${styles.blocks}${addClass}`;
  };

  protected getBlockState = (
    lastItem: BlockSelectType.state.listData
  ): BlockSelectType.state.listData => {
    if (!lastItem.isSelect) {
      return {
        ...lastItem,
        isPreSelect: true,
      };
    }

    return lastItem;
  };

  protected getCloseBlockState = (
    item: BlockSelectType.state.listData
  ): BlockSelectType.state.listData => {
    if (item.isPreSelect) {
      return {
        ...item,
        isSelect: true,
        isPreSelect: false,
      };
    }

    return item;
  };

  protected openSwitch = (index: number) => {
    const { clickSwitch, list } = this.state;

    // 第1次点击或清除时间段
    if (!clickSwitch) {
      const newList: BlockSelectType.state.list = list.slice();
      const lastItem: BlockSelectType.state.listData = list[index];

      if (!lastItem.isSelect) {
        // 第1次点击
        newList[index] = this.getBlockState(lastItem);

        this.setState({
          list: newList,
          clickSwitch: true,
          lastList: list,
          lastSelectIndex: index,
        });
      } else {
        this.cancelListRang(index); // 清除时间段
      }
    } else {
      const newList: BlockSelectType.state.list = list.map(
        (item: BlockSelectType.state.listData): BlockSelectType.state.listData =>
          this.getCloseBlockState(item)
      );

      const params: any = {
        clickSwitch: false,
      };

      if (!this.state.isControl) {
        params.list = newList;
        params.lastList = newList;
      } else {
        params.list = this.state.lastList;
      }

      this.setState(params);

      this.handlerChangeEvent(newList);
    }
  };

  protected selectBlock = (index: number): void => {
    const { clickSwitch, list, lastList, lastSelectIndex } = this.state;
    const rangeIndex: number[] = [index, lastSelectIndex].sort((a, b) => a - b);

    if (!clickSwitch) {
      return;
    }

    const newList: BlockSelectType.state.list = list.map(
      (item, i): BlockSelectType.state.listData => {
        if (i >= rangeIndex[0] && i <= rangeIndex[1]) {
          return this.getBlockState(lastList[i]);
        }

        return lastList[i];
      }
    );

    this.setState({
      list: newList,
    });
  };

  protected cancelListRang = (num: number): void => {
    confirm({
      title: '确定是否需要清空该时间段',
      okText: '确定',
      cancelText: '取消',
      onOk: () => {
        let { lastList } = this.state;
        const newList: BlockSelectType.state.list = new Array(lastList.length);
        const count = lastList.length;
        let ltSwitch: boolean = true;
        let rgSwitch: boolean = true;
        let cycleNumber: number = -1;

        function cancel(index: number): void {
          for (let i = index; i >= 0; i--) {
            if (lastList[i].isSelect && ltSwitch) {
              if (i === 0 && lastList[count - 1].isSelect) {
                cycleNumber = count - 1;
              }
              if (i === count - 1 && lastList[0].isSelect) {
                cycleNumber = 0;
              }
              newList[i] = {
                ...lastList[i],
                isSelect: false,
              };
            } else {
              newList[i] = {
                ...lastList[i],
              };
              ltSwitch = false;
            }
          }

          for (let i = index + 1; i < lastList.length; i++) {
            if (!lastList[i]) {
              break;
            }

            if (lastList[i].isSelect && rgSwitch) {
              if (i === count - 1 && lastList[0].isSelect) {
                cycleNumber = 0;
              }
              newList[i] = {
                ...lastList[i],
                isSelect: false,
              };
            } else {
              newList[i] = {
                ...lastList[i],
              };
              rgSwitch = false;
            }
          }
        }

        cancel(num);

        if (cycleNumber !== -1) {
          ltSwitch = true;
          rgSwitch = true;
          lastList = newList;
          cancel(cycleNumber);
        }

        const params: any = {};

        if (!this.state.isControl) {
          params.list = newList;
          params.lastList = newList;
        } else {
          params.list = this.state.lastList;
        }

        this.setState(params);

        this.handlerChangeEvent(newList);
      },
    });
  };

  protected handlerChangeEvent = (newList: BlockSelectType.state.list): void => {
    const { onChange } = this.props;
    const rangeList: BlockSelectType.state.easyList = [];
    const timeLimitList: BlockSelectType.props.businessValueList = [];

    let lastIndex: number = -1;
    let differenceCount: number = 0;

    newList.forEach(
      (item, i): void => {
        if (item.isSelect) {
          rangeList.push(i);
        }

        if (i === 0) {
          if (item.isSelect) {
            differenceCount++;
            lastIndex = 0;
          }
        } else if (item.isSelect !== newList[i - 1].isSelect) {
          if (differenceCount % 2) {
            const params: BlockSelectType.props.businessData = this.getTimeLimit(lastIndex, i);

            timeLimitList.push(params);
          } else {
            lastIndex = i;
          }

          differenceCount++;
        }

        if (i === newList.length - 1 && item.isSelect) {
          const params: BlockSelectType.props.businessData = this.getTimeLimit(lastIndex, i + 1);

          timeLimitList.push(params);
        }
      }
    );

    const count: number = this.props.count || 24;
    const isCycleTime: blooean =
      rangeList.length !== count && (rangeList.includes(0) && rangeList.includes(count - 1));

    if (isCycleTime) {
      const lastData: BlockSelectType.props.businessData = timeLimitList.pop();

      timeLimitList[0] = {
        startTime: lastData.startTime,
        endTime: timeLimitList[0].endTime,
      };
    }

    if (onChange) {
      onChange(rangeList, timeLimitList);
    }
  };

  protected getTimeLimit = (
    lastIndex: number,
    nowIndex: number
  ): BlockSelectType.props.businessData => ({
    startTime: `${lastIndex < 10 ? '0' : ''}${lastIndex}${'0'.repeat(4)}`,
    endTime: `${nowIndex < 10 ? '0' : ''}${nowIndex}${'0'.repeat(4)}`,
  });
}
