import React, {
  Children,
  Component,
  useState,
  useEffect,
  useImperativeHandle,
  useRef,
  forwardRef,
} from 'react';
import { Button } from 'antd';
import ButtonAuthorized from '@/components/ButtonAuthorized';
/**
 *
 * @param {intervalTime:'间隔时间：秒',timeText: 计时文本$$（默认值：倒计时$$）}
 *
 */

const ComponentAuthorizedTimer = function(props, ref) {
  let {
    intervalTime = 0,
    timeText = '倒计时$<time>',
    children,
    myDisabled,
    isNeedAuth,
    ...rest
  } = props;

  const countNum = parseInt(intervalTime, 10);
  const [isStart, setIsStart] = useState(false);
  const [newChild, setNewChild] = useState(children);

  useEffect(() => {
    if (!isStart) return;
    let num = countNum;

    if (num !== 0) {
      let timeId = setInterval(() => {
        if (num <= 0) {
          setIsStart(false);
          setNewChild(children);
          clearInterval(timeId);
        } else {
          setNewChild(timeText.replace('$<time>', num));
          num--;
        }
      }, 1000);

      return () => {
        clearInterval(timeId);
      };
    }
  }, [isStart]);

  const domRef = useRef();
  useImperativeHandle(ref, () => ({
    // 开始倒计时
    setStartTime: () => {
      if (countNum) {
        setIsStart(true);
      }
    },
  }));

  return isNeedAuth ? (
    <ButtonAuthorized myDisabled={myDisabled || isStart} {...rest}>
      {newChild}
    </ButtonAuthorized>
  ) : (
    <Button disabled={myDisabled || isStart} {...rest}>
      {newChild}
    </Button>
  );
};
export default forwardRef(ComponentAuthorizedTimer);
