import React, { PureComponent } from 'react';
import { Icon, message } from 'antd';
import CowImageMasker from './CowImageMasker';
// import request from '@/utils/request';
// import { debounce } from '@/utils/decorator';
import styles from './cowImage.less';

class CowImage extends PureComponent {
  constructor() {
    super();
    this.state = {
      isShow: false,
      isLoading: true,
      isActive: false,
      containerStyle: {},
      picStyle: {},
    };
  }

  render() {
    let { isShow, isLoading, containerStyle, isActive } = this.state;
    let { src, largeSrc } = this.props;

    return (
      <div className={styles.cowImageWrapper}>
        <img src={src} onClick={this.handlerLarge} />
        {isShow ? (
          <CowImageMasker>
            <div
              className={styles.cowImageMasker + (isActive ? ` ${styles.active}` : '')}
              onClick={this.maskerClick}
            >
              <Icon className={styles.close} type="close" onClick={this.hiden} />
              {isLoading ? (
                <Icon className={styles.loading} type="loading" />
              ) : (
                <div
                  className={styles.imgContainer}
                  style={containerStyle}
                  onClick={e => {
                    e.stopPropagation();
                  }}
                >
                  <img src={largeSrc} />
                </div>
              )}
            </div>
          </CowImageMasker>
        ) : null}
      </div>
    );
  }

  handlerLarge = () => {
    let { largeSrc, src } = this.props;
    let _self = this;

    largeSrc = largeSrc || src;

    this.setState({
      isShow: true,
    });

    setTimeout(() => {
      this.setState({
        isActive: true,
      });
    }, 100);

    let img = new Image();

    img.src = largeSrc;

    img.onload = function() {
      let containerStyle = _self.getStytle(this.width, this.height);

      _self.registerEvent();

      _self.setState({
        isShow: true,
        isLoading: false,
        containerStyle,
        picStyle: {
          width: this.width,
          height: this.height,
        },
        isActive: true,
      });
    };

    img.onerror = function() {
      message.error('图片链接有问题');

      this.setState({
        isShow: false,
        isLoading: false,
      });
    };
  };

  registerEvent() {
    window.addEventListener('resize', this.resize);
  }

  resize = () => {
    let containerStyle = this.getStytle();

    this.setState({
      containerStyle,
    });
  };

  maskerClick = () => {
    if (this.props.wrapperClose === false) return;

    this.hiden();
  };

  hiden = () => {
    window.removeEventListener('resize', this.resize);

    this.setState({
      isActive: false,
    });

    setTimeout(() => {
      this.setState({
        isShow: false,
      });
    }, 300);
  };

  getStytle(picWidth = this.state.picStyle.width, picHeight = this.state.picStyle.height) {
    let windowWidth = document.documentElement.offsetWidth;
    let windowHeight = document.documentElement.offsetHeight;

    let picProp = picWidth / picHeight;
    // let screenProp = windowWidth / windowHeight;

    let width = 0;
    let height = 0;

    if (picProp > 1) {
      width = windowWidth * 0.9;
      height = width / picProp;

      if (height > windowHeight * 0.9) {
        height = windowHeight * 0.9;
        width = height * picProp;
      }
    } else {
      height = windowHeight * 0.9;
      width = height * picProp;

      if (width > windowWidth * 0.9) {
        width = windowWidth * 0.9;
        height = width / picProp;
      }
    }

    return {
      width,
      height,
    };
  }
}

export default CowImage;
