import React, { PureComponent } from 'react';
import { Input, Select, Icon, AutoComplete, message } from 'antd';
import request from '@/utils/request';
import { debounce } from '@/utils/decorator';
import styles from './HotelInput.less';

const Option = Select.Option;

/**
 * 用于酒店
 * @extends PureComponent
 */
class HotelInput extends PureComponent {
  constructor() {
    super();
    this.state = {
      type: '0',
      nameInput: '',
      idInput: '',
      oyoIdInput: '',
      isFixedType: false,
    };
  }

  componentWillMount() {
    let { defaultValue, type } = this.props;

    let newState = {};

    type = `${type}`;

    if (type === '0' || type === '1' || type === '2') {
      newState.type = type;
      newState.isFixedType = true;
    }

    if (type === '0') {
      newState.nameInput = defaultValue;
    } else if (type === '1') {
      newState.idInput = defaultValue;
    } else if (type === '2') {
      newState.oyoIdInput = defaultValue;
    } else {
      newState.nameInput = defaultValue;
    }

    this.setState(newState);
  }

  searchInput(type) {
    const { idInput, oyoIdInput, nameInput, isFixedType, searchList } = this.state;

    if (type === '1') {
      return (
        <Input
          placeholder="请输入酒店ID"
          value={idInput}
          onChange={e => this.onSearchId(e)}
          key="id"
          ref={ref => {
            this.idInput = ref;
          }}
        />
      );
    }

    if (type === '2') {
      return (
        <Input
          placeholder="请输入OYO ID"
          value={oyoIdInput}
          onChange={e => this.onSearchOYOId(e)}
          key="oyoId"
          ref={ref => {
            this.oyoIdInput = ref;
          }}
        />
      );
    }

    return (
      <Input
        value={nameInput}
        onChange={e => this.onSearchName(e)}
        placeholder="请输入酒店名称"
        ref={ref => {
          this.AutoComplete = ref;
        }}
      />
    );
  }

  render() {
    const { type, idInput, searchList, nameInput, isFixedType } = this.state;

    return (
      <div className={`${styles.searchGroup} ${isFixedType ? styles.fixed : ''}`}>
        {!isFixedType && (
          <Select defaultValue="0" style={{ width: 160 }} onChange={val => this.onSearchState(val)}>
            <Option value="0">酒店名称查询</Option>
            <Option value="2">OYO ID查询</Option>
            <Option value="1">酒店ID查询</Option>
          </Select>
        )}
        {this.searchInput(type)}
      </div>
    );
  }

  resetVal() {
    this.setState({
      nameInput: '',
      idInput: '',
      oyoIdInput: '',
    });
  }

  onSearchState(val) {
    if (val === this.state.type) return;

    const { onChange } = this.props;

    this.setState({
      type: val,
    });

    this.resetVal();

    onChange &&
      onChange({
        type: val,
      });
  }

  onSearchId(e) {
    const val = e.target.value;
    const { onChange } = this.props;

    if (Number.isNaN(Number(val))) {
      return message.error('请输入数字');
    }

    this.setState({
      idInput: val,
    });

    onChange &&
      onChange({
        type: this.state.type,
        val,
      });
  }

  onSearchName(e) {
    const val = e.target.value;
    const { onChange } = this.props;

    this.setState({
      nameInput: val,
    });

    onChange &&
      onChange({
        type: this.state.type,
        val,
      });
  }

  onSearchOYOId(e) {
    const val = e.target.value;
    const { onChange } = this.props;

    if (val !== '' && !/^[a-zA-Z0-9_\s]+$/.test(val)) {
      return message.error('请输入数字、英文字母和下划线');
    }

    this.setState({
      oyoIdInput: val,
    });

    onChange &&
      onChange({
        type: this.state.type,
        val,
      });
  }
}

export default HotelInput;
