import React, { PureComponent } from 'react';
import { Input, Select, Icon, AutoComplete, message } from 'antd';
import { authFetch } from '@/utils/fetch';
import { debounce } from '@/utils/decorator';
import styles from './HotelSearch.less';

const Option = Select.Option;

// 修改key名字
function getItemOp({ city_id, city_name, hotel_name, id }) {
  return {
    hotelName: hotel_name,
    hotelId: id,
    cityId: city_id,
    cityName: city_name,
  };
}

/**
 * 用于酒店
 * @extends PureComponent
 */
class HotelSearch extends PureComponent {
  constructor() {
    super();
    this.state = {
      isInForm: false, // 是否在form表单中被支配
      isHasInitialValue: false,
      type: '0',
      idInput: '',
      nameInput: '',
      selected: {}, // 已被选择的
      searchList: [],
      isFixedType: false,
      value: {},
      cityId: '',
      initSwitch: true,
      isBeChange: false, // 被操作 不会在根据默认值变化
      isControlComponent: false, // 是否是受控组件
    };
  }

  // static getDerivedStateFromProps(nextProps, prevState) {
  //   const { onSearch } = nextProps;
  //   const { isHasInitialValue, initSwitch, isInForm, isBeChange } = prevState;
  //   console.log('nextProps', nextProps);

  //   // 有初始值的时候
  //   if (isHasInitialValue && initSwitch && !isBeChange) {
  //     const lastDefaultValue = isInForm
  //       ? this.props['data-__meta'].initialValue || {}
  //       : this.props.defaultValue || {};

  //     const defaultValue = isInForm
  //       ? nextProps['data-__meta'].initialValue || {}
  //       : nextProps.defaultValue || {};

  //     if (lastDefaultValue !== defaultValue) {
  //       if (!lastDefaultValue || Object.keys(lastDefaultValue) === 0) {
  //         return {
  //           selected: {
  //             hotelName: defaultValue.val,
  //           },
  //           value: defaultValue,
  //           nameInput: defaultValue.val,
  //           idInput: defaultValue.val,
  //           initSwitch: false,
  //         };
  //       }
  //     }
  //   }

  //   // 搜索条件在收到城市限制时候有用
  //   if (prevState.cityId !== nextProps.cityId && nextProps.cityId) {
  //     onSearch && onSearch({});

  //     return {
  //       selected: {},
  //       searchList: [],
  //       nameInput: '',
  //       cityId: nextProps.cityId,
  //     };
  //   }

  //   if (prevState.value !== nextProps.value) {
  //     let val = '';

  //     if (!nextProps.value) {
  //       val = '';
  //     } else {
  //       val = nextProps.value.val;
  //     }

  //     if (prevState.type === '0') {
  //       onSearch && onSearch({});

  //       return {
  //         nameInput: val,
  //         value: nextProps.value,
  //       };
  //     } else {
  //       return {
  //         idInput: val,
  //         value: nextProps.value,
  //       };
  //     }
  //   }
  // }

  componentWillMount() {
    let { defaultValue = {}, type } = this.props;
    const hasOwnProperty = Object.prototype.hasOwnProperty;
    const isInForm = hasOwnProperty.call(this.props, 'data-__meta'); // 是否内嵌在antd Form组件中
    const isHasFormInitialValue = isInForm && this.props['data-__meta'].initialValue; // Form组件中props是否有initialValue
    const isControlComponent = !isInForm && !!this.props.value;

    if (isHasFormInitialValue) {
      defaultValue = this.props['data-__meta'].initialValue || {};
    }

    if (isControlComponent) {
      defaultValue = this.props.value;
    }

    // 入关传的不是对象 丢进对象
    if (!(defaultValue instanceof Object)) {
      defaultValue = {
        val: defaultValue,
      };
    }

    let newState = {
      nameInput: defaultValue.val,
      selected: {
        hotelName: defaultValue.val,
      },
      value: defaultValue,
      isInForm,
      isControlComponent,
      isHasInitialValue: isHasFormInitialValue || !!defaultValue,
    };

    type = `${type}`;

    if (type === '0' || type === '1') {
      newState.type = type;
      newState.isFixedType = true;
    }

    if (type === '1') {
      if (/^\d+$/.test(`${defaultValue.val}`)) {
        newState.idInput = defaultValue.val;
      }
    } else {
      newState.nameInput = defaultValue.val;
      newState.selected = {
        hotelName: defaultValue.val,
      };
    }

    // 不在form中 并且有value 则不在因为接口反回值更新defaulValue
    if (isControlComponent) {
      newState.initSwitch = false;
    }

    this.setState(newState);
  }

  componentWillReceiveProps(nextProps) {
    const { onSearch } = nextProps;
    const { isHasInitialValue, initSwitch, isInForm, isBeChange } = this.state;

    // 有初始值的时候
    if (isHasInitialValue && initSwitch && !isBeChange) {
      const lastDefaultValue = isInForm
        ? this.props['data-__meta'].initialValue || {}
        : this.props.defaultValue || {};

      const defaultValue = isInForm
        ? nextProps['data-__meta'].initialValue || {}
        : nextProps.defaultValue || {};

      if (defaultValue.val && !lastDefaultValue.val) {
        this.setState({
          selected: {
            hotelName: defaultValue.val,
          },
          value: defaultValue,
          nameInput: defaultValue.val,
          idInput: defaultValue.val,
          initSwitch: false,
        });
      }
    }

    // 搜索条件在收到城市限制时候有用
    if (this.props.cityId !== nextProps.cityId && nextProps.cityId) {
      this.setState({
        selected: {},
        searchList: [],
        nameInput: '',
      });

      onSearch && onSearch({});
    }

    if (this.props.value !== nextProps.value) {
      let val = '';

      if (!nextProps.value) {
        val = '';
      } else {
        val = nextProps.value.val;
      }

      if (this.state.type === '0') {
        this.setState({
          nameInput: val,
          value: nextProps.value,
        });

        onSearch && onSearch({});
      } else {
        this.setState({
          idInput: val,
          value: nextProps.value,
        });
      }
    }

    // this.setState({
    //   idInput
    //   nameInput: nextProps.value,
    // });
  }

  render() {
    const { type, idInput, searchList, nameInput, isFixedType } = this.state;

    return (
      <div
        style={{ marginTop: 3 }}
        className={`${styles.searchGroup} ${type === '0' ? styles.searchName : styles.searchId} ${
          isFixedType ? styles.fixed : ''
        }`}
      >
        {!isFixedType && (
          <Select defaultValue="0" style={{ width: 160 }} onChange={val => this.onSearchState(val)}>
            <Option value="0">酒店名称查询</Option>
            <Option value="1">酒店ID查询</Option>
          </Select>
        )}
        {this.state.type === '0' ? (
          <AutoComplete
            dataSource={searchList.map(item => ({
              value: item.id,
              text: item.hotel_name,
            }))}
            value={nameInput}
            onFocus={() => this.requestSearch()}
            onSearch={val => this.handleSearchName(val)}
            onSelect={val => this.handlerSelect(val)}
            onBlur={val => this.handleSearchBlur(val)}
            className={isFixedType ? styles.round : styles.halfRound}
            placeholder="请输入酒店名称"
            ref={ref => {
              this.AutoComplete = ref;
            }}
          />
        ) : (
          <Input
            placeholder="请输入酒店ID"
            value={idInput}
            onChange={e => this.onSearchId(e)}
            key="id"
            ref={ref => {
              this.idInput = ref;
            }}
          />
        )}
        {this.state.type === '0' ? null : (
          <div className={styles.btn} onClick={() => this.handlerIdSearch()}>
            <Icon type="search" theme="outlined" />
          </div>
        )}
      </div>
    );
  }

  /**
   * 搜索酒店接口
   * @param  {[type]}  params [description]
   * @return {Promise}        [description]
   */
  async suggestHotel(params) {
    try {
      const response = await authFetch(`/api/crs/v1/common/suggestHotel`, {
        method: 'POST',
        params: {
          ...params,
        },
      });

      return Promise.resolve({
        statue: true,
        ...response,
      });
    } catch (err) {
      return Promise.resolve({
        statue: false,
        ...err.response,
      });
    }
  }

  handlerSelect(val) {
    const { onSearch, onChange } = this.props;
    const item = getItemOp(this.getSelectItem(val)); // 获取已经选择的

    if (item) {
      const newState = {
        selected: item,
        nameInput: item.hotelName,
      };

      this.setState(newState);

      onSearch && onSearch(item);

      onChange &&
        onChange({
          val: item.hotelName,
          ...item,
        });
    }
  }

  // 酒店名字搜索(绑定debounce避免过多请求)
  handleSearchName(val) {
    const { isControlComponent } = this.state;
    let { onChange } = this.props;

    if (!isControlComponent) {
      this.setState({
        isBeChange: true, // 被操作 不会在根据默认值变化
      });

      onChange &&
        onChange({
          val,
        });

      this.setState(
        {
          nameInput: val, // 被操作 不会在根据默认值变化
        },
        this.requestSearch
      );
    }
  }

  @debounce(400)
  async requestSearch(val = this.state.nameInput) {
    if (!val) return;

    const { cityId } = this.props;
    const payload = {
      hotelName: val,
      searchType: 'hotelNameSearch',
    };

    // 传入城市id的时候增加城市id的搜索
    if (cityId) {
      payload.cityId = cityId;
    }

    const res = await this.suggestHotel(payload); // 获取酒店数据

    if (res.statue && res.data && res.data.hotels) {
      this.setState({
        searchList: res.data.hotels, // 设置搜索表单
      });
    } else {
      this.setState({
        searchList: [],
      });
    }

    // 全数字是因为AutoComplete组件选择了 option下拉框
    // if (!/^\d+$/.test(val)) {
    //   const res = await this.suggestHotel(payload); // 获取酒店数据

    //   if (res.statue && res.data && res.data.hotels) {
    //     this.setState({
    //       searchList: res.data.hotels, // 设置搜索表单
    //     });
    //   } else {
    //     this.setState({
    //       searchList: [],
    //     });
    //   }
    // } else {
    //   const item = this.getSelectItem(val); // 获取已经选择的

    //   if (item) {
    //     this.setState({
    //       selected: item,
    //     });

    //     onSearch && onSearch(item);
    //   }
    // }
  }

  onSearchState(val) {
    if (val === this.state.type) return;

    const { onSearch, onChange } = this.props;

    this.setState({
      selected: {},
      type: val,
      idInput: '',
      nameInput: '',
      isBeChange: true, // 被操作 不会在根据默认值变化
    });

    onSearch && onSearch({});
    onChange && onChange({});
  }

  handleSearchBlur(val) {
    const { onSearch } = this.props;
    const item = this.getSelectItem(val);

    if (item) {
      this.setState({
        selected: item,
      });

      onSearch && onSearch(item);
      onChange &&
        onChange({
          ...this.state.value,
          ...item,
        });
    }
  }

  // 根据变化的值
  getSelectItem(val) {
    const { searchList, selected } = this.state;

    // 全数字是因为AutoComplete组件选择了 option下拉框
    if (/^\d+$/.test(val)) {
      return searchList.find(item => item.id === val);
    }
    if (selected.hotelName === val) return false;

    return searchList.find(item => item.hotel_name === val);
  }

  async handlerIdSearch() {
    const { idInput } = this.state;
    const { onSearch, onChange } = this.props;
    const payload = {
      hotelIds: [idInput],
      searchType: 'hotelIdSearch',
    };

    const res = await this.suggestHotel(payload); // 获取酒店数据

    if (res.statue && res.data) {
      let item = res.data.hotels;

      if (item && item.length) {
        item = getItemOp(item[0]);

        this.setState({
          selected: item,
        });
        message.success(`搜索到酒店${item.hotelName}`);

        onSearch && onSearch(item);
        onChange &&
          onChange({
            ...this.state.value,
            ...item,
          });
      }
    } else {
      this.setState({
        selected: {},
      });
      onSearch && onSearch({});
      onChange &&
        onChange({
          val: this.state.value.val,
        });
      message.error('不存在该id的酒店');
    }
  }

  onSearchId(e) {
    const { onChange } = this.props;
    const val = e.target.value;

    if (Number.isNaN(Number(val))) return false;

    this.setState({
      idInput: val,
      isBeChange: true, // 被操作 不会在根据默认值变化
    });

    onChange &&
      onChange({
        val,
      });
  }

  // 非在form表单中时可以手动清空组件
  reset() {
    this.setState({
      idInput: '',
      nameInput: '',
      selected: {},
      isBeChange: true,
    });
  }

  focus() {
    if (this.state.type === '0') {
      this.AutoComplete.focus();
    } else {
      this.idInput.focus();
    }
  }
}

export default HotelSearch;
