import React, { PureComponent } from 'react';
import './MultiSelection.less';

/**
 * 多项选择器
 * @type {Object}
 * 用于多项选择的组件 exp: @/pages/Price/components/DateRules.js
 */
export default class MultiSelection extends PureComponent {
  constructor() {
    super();
    this.state = {
      select: [], // 被选择的
      isHasInitialValue: false,
      isControlComponent: false,
      isBeChange: false,
      initSwitch: true,
    };
  }

  componentWillMount() {
    const hasOwnProperty = Object.prototype.hasOwnProperty;

    this.initSelect(); // 初始化选择

    // 拥有value这个字段设为受控组件
    if (hasOwnProperty.call(this.props, 'value')) {
      this.setState({
        isControlComponent: true,
      });
    }

    // 拥有value这个字段设为受控组件
    if (hasOwnProperty.call(this.props, 'defaultValue')) {
      this.setState({
        isControlComponent: true,
      });
    }
  }

  /**
   * 用于请求后传入数据后初始化
   * @param  {Object} nextProps 改变的props
   */
  componentWillReceiveProps(nextProps) {
    const { isHasInitialValue, initSwitch, isControlComponent, isBeChange } = this.state;

    if (isHasInitialValue && initSwitch && !isBeChange) {
      if (this.props.defaultValue !== nextProps.defaultValue) {
        this.setValue(nextProps.defaultValue);
      }
    }

    if (isControlComponent && this.props.value !== nextProps.value) {
      this.setValue(nextProps.value);
    }

    if (this.props.disableList !== nextProps.disableList) {
      this.setDisabledValue(nextProps.disableList);
    }
  }

  setDisabledValue = listValue => {
    const select = this.state.select.slice();

    select.forEach(item => {
      const isInclude = listValue.includes(item.index);

      if (isInclude) {
        item.isActive = false;
        item.disabled = true;
      } else {
        item.disabled = false;
      }
    });

    this.setState({
      select,
    });
  };

  setValue = listValue => {
    const select = this.state.select.slice();

    select.forEach(item => {
      item.isActive = listValue.includes(item.index);
    });

    this.setState({
      select,
      isBeChange: true,
      initSwitch: false,
    });
  };

  // 非请求数据的初始化被选择项
  initSelect() {
    const select = this.props.list.map((item, index) => ({
      item,
      index,
      isActive: false,
      disabled: false,
    }));

    this.setState(
      {
        select,
      },
      () => {
        if (Array.isArray(this.props.disableList)) {
          this.setDisabledValue(this.props.disableList);
        }
      }
    );
  }

  // 设置禁用
  setDisabled = arr => {
    let { select } = this.state;

    select.forEach(item => {
      item.disabled = arr.includes(item.index);
    });

    this.setState({
      select,
    });
  };

  render() {
    const { select } = this.state;

    return (
      <ul className="multiSelection-box">
        {select.map(item => (
          <li
            className={`${item.isActive ? 'active' : ''} ${item.disabled ? 'disabled' : ''}`}
            key={item.index}
            onClick={() => this.handlerSelect(item)}
          >
            {item.item}
          </li>
        ))}
      </ul>
    );
  }

  /**
   * 点击事件
   * @param  {Object} item 被选择的数据 exp: {item: "周五", index: 4, isActive: false}
   */
  handlerSelect(item) {
    const { isControlComponent } = this.state;
    const select = this.state.select.slice();
    const onChange = this.props.onChange;

    item = Object.assign({}, item);

    if (item.disabled) {
      return;
    }

    item.isActive = !item.isActive; // 是否被选中
    select[item.index] = item;

    if (isControlComponent) {
      this.setState({
        isBeChange: true,
      });
    } else {
      this.setState({
        select,
        isBeChange: true,
      });
    }

    // 获取选择的index exp: [0, 2, 4]
    const selectIndex = select.filter(i => i.isActive).map(it => it.index);

    onChange && onChange(select, selectIndex);
  }
}
