import React, { useState } from 'react';
import styles from './index.less';

export const OYOCheckLabelColor = {
  green: '#00D7A5',
  sellable: '#0288D1',
  modified: '#8999AC',
  notSellable: '#323233',
};

const hex2rgb = (color, opacity = 1) => {
  if (/^#([0-9a-fA-F]{6}|[0-9a-fA-F]{3})$/.test(color)) {
    let str = color.substr(1); // #ccddee or #cde to ccddee or cde
    if (str.length === 3) {
      // cde to ccddee
      str = str
        .split('')
        .map(value => value.repeat(2))
        .join('');
    }
    const resArr = [];
    for (let i = 0; i < 3; i++) {
      // ccddee每次取cc、dd、ee，后面16是进制
      resArr[i] = Number.parseInt(str.substr(i * 2, 2), 16);
    }
    return `rgba(${resArr.toString()},${opacity})`;
  }

  console.error('color should be hex color value like #fff or #ffffff');
  return color;
};

export default function OYOCheckLabel(props) {
  const {
    onChange,
    children,
    valueName, // 如果有多个OYOCheckLabel共用一个onChange，可用此识别某个实例
    style = {},
    defaultChecked = false,
    disabled = false,
    color = OYOCheckLabelColor.green,
  } = props;

  // 自管理
  const [state, setState] = useState({ checked: defaultChecked });
  // 真实值取决于外部传入
  const checked = 'checked' in props ? props.checked : state.checked;

  // 这里样式不用classnames的想法：小组件在复用性高的情况下不该有太多依赖
  const [checkedStyle, disabledStyle] = [{}, {}];
  if (checked) {
    checkedStyle.borderColor = hex2rgb(color);
    checkedStyle.backgroundColor = hex2rgb(color, 0.1);
  }
  if (disabled) {
    disabledStyle.opacity = 0.3;
    disabledStyle.cursor = 'not-allowed';
  }

  return (
    <div
      onClick={e => {
        if (disabled) return;
        setState({ checked: !checked });
        typeof onChange === 'function' && onChange(!checked, valueName);
      }}
      className={styles.wrap}
      style={{
        cursor: 'pointer',
        ...checkedStyle,
        ...disabledStyle,
        ...style,
      }}
    >
      <span className={styles.colorBlock} style={{ background: color }} />
      <div className={styles.word}>{children}</div>
    </div>
  );
}
