import { Badge, Button, Card, Icon, Spin, Timeline, Upload, Input, message } from 'antd';
import { connect } from 'dva';
import React, { PureComponent } from 'react';
import { initialProps, IProps, xlsx } from './index.type';

const { TextArea } = Input;
@connect(({ global, user }) => ({
  global,
  user,
}))
export default class BatchAdd extends PureComponent<IProps, object> {
  public static defaultProps = { ...initialProps };

  public state = {
    res: null,
    loading: false,
  };

  constructor(props) {
    super(props);
  }

  public componentDidMount() {}

  public customRequest = file => {
    const { shouldFileUpload, uploadFile } = this.props;
    const formData: FormData = new FormData();

    let shouldContinue = shouldFileUpload ? shouldFileUpload() : true;
    if (!shouldContinue) {
      return;
    }

    formData.append('files', file.file);
    this.setState({
      loading: true,
      res: null,
    });

    uploadFile({ formData })
      .then(res => {
        this.setState({
          res,
          loading: false,
        });
      })
      .catch(er => {
        this.setState({
          loading: false,
        });
      });
  };

  public down = (): void => {
    const { downloadUrl } = this.props;

    if (downloadUrl) {
      window.open(downloadUrl);
    }
  };

  public renderRes = ({ success, dom }) => {
    console.log('success', success);
    return (
      <>
        <div>
          {success ? (
            <Icon type="check-circle" style={{ fontSize: 60, color: 'green' }} />
          ) : (
            <Icon type="close-circle" style={{ fontSize: 60, color: '#F5222D' }} />
          )}
        </div>
        <div style={{ marginTop: 20 }} />
        {dom}
      </>
    );
  };

  public render() {
    const { res, loading } = this.state;
    const { stepList, xlsx: xlsxP, isNeedTag } = this.props;
    return (
      <Card>
        <Timeline>
          <Timeline.Item dot={<Badge count={1} />}>
            <Button
              type="primary"
              style={{ marginLeft: 10 }}
              onClick={this.down}
              disabled={stepList[0].disabled}
            >
              {`${stepList[0].buttonTitle}`}
            </Button>{' '}
            {stepList[0].comments ? `(${stepList[0].comments})` : null}
          </Timeline.Item>
          <Timeline.Item dot={<Badge count={2} />}>
            {isNeedTag ? (
              <div dangerouslySetInnerHTML={{ __html: `${stepList[1].comments}` }} />
            ) : (
              <TextArea
                autosize
                disabled
                style={{
                  padding: 0,
                  border: 'none',
                  color: 'rgba(0, 0, 0, 0.65)',
                  backgroundColor: '#fff',
                  resize: 'none',
                }}
                defaultValue={`${stepList[1].comments}`}
              />
            )}
            {/* <div dangerouslySetInnerHTML={{ __html: `${stepList[1].comments}` }}></div> */}
          </Timeline.Item>
          <Timeline.Item dot={<Badge count={3} />}>
            <Upload
              showUploadList={false}
              customRequest={this.customRequest}
              accept={xlsxP || xlsx}
            >
              <Button type="primary" style={{ marginLeft: 10 }} disabled={stepList[2].disabled}>
                {`${stepList[2].buttonTitle}`}
              </Button>
            </Upload>{' '}
            {stepList[2].comments ? `(${stepList[2].comments})` : null}
          </Timeline.Item>
        </Timeline>
        {res ? this.renderRes(res) : null}
        {loading ? <Spin /> : null}
      </Card>
    );
  }
}
