import React, { PureComponent } from 'react';
import { Card, Form, Row, Col, Button, DatePicker, Input } from 'antd';

import styles from './SearchForm.less';

const FormItem = Form.Item;

const formLayout = { horizontal: 'horizontal' };
const getFormItemLayoutProps = column => {
  let columnParam = column;
  // 判断注释：column不等于整数，或者不在1到4区间到入参，默认设置3
  if (!Number.isInteger(column) || (column < 1 || column > 4)) columnParam = 3;
  const formItemLayout = {
    labelCol: {
      span: (columnParam + 1) * 2,
    },
    wrapperCol: {
      span: 24 - (columnParam + 1) * 2,
    },
  };

  return formItemLayout;
};

const getColProps = column => {
  // 判断注释：column不等于整数，或者不在1到4区间到入参，默认设置3
  let columnParam = column;
  if (!Number.isInteger(column) || (column < 1 || column > 4)) columnParam = 3;
  return { span: 24 / columnParam };
};
const rowProps = { gutter: 8, type: 'flex', justify: 'start' };

const widthStyle = { width: '100%' };

@Form.create()
class OYOForm extends PureComponent {
  static defaultProps = {
    fields: [],
  };

  constructor(props) {
    super(props);
    let { column } = this.props;
    // 判断注释：column不等于整数，或者不在1到4区间到入参，默认设置3
    if (!Number.isInteger(column) || (column < 1 || column > 4)) column = 3;

    const formItemLayoutProps = getFormItemLayoutProps(column);
    const colProps = getColProps(column);
    this.state = {
      formItemLayoutProps,
      colProps,
      ...props,
      initSwitch: true,
    };
  }

  handleFormSearch = e => {
    e.preventDefault();
    const { form, onSearch } = this.props;
    const params = form.getFieldsValue();
    typeof onSearch === 'function' && onSearch(params);
  };

  handleFormReset = () => {
    const { form, onReset } = this.props;
    form.resetFields();
    typeof onReset === 'function' && onReset();
  };

  renderForm = () => {
    const { form, fields } = this.props;
    const { formItemLayoutProps, colProps } = this.state;
    const { getFieldDecorator } = form;
    let fieldsList = [];

    if (fields.length) {
      fieldsList = fields.map((field, key) => (
        <Col {...colProps} key={`Search-Col-${key}`}>
          <FormItem label={field.label} {...formItemLayoutProps} style={widthStyle}>
            {getFieldDecorator(field.type, field.options)(
              field.render ? field.render() : field.component
            )}
          </FormItem>
        </Col>
      ));
      return fieldsList;
    }
    return null;
  };

  componentDidMount() {
    this.init();
  }

  componentWillReceiveProps(nextProps) {
    this.init(nextProps);
  }

  init(props = this.props) {
    if (!this.state.initSwitch) return;

    const { initialData } = props;
    // console.log(initialData);
    if (initialData && Object.keys(initialData).length) {
      this.props.form.setFieldsValue(initialData);
      this.setState({
        initSwitch: false,
      });
    }
  }

  render() {
    const {
      noSubmit,
      form: { getFieldDecorator },
    } = this.props;
    const { colProps } = this.state;
    return (
      <div className={styles.searchForm}>
        <Form onSubmit={this.handleFormSearch} layout="inline">
          <Row {...rowProps}>{this.renderForm()}</Row>
          {!noSubmit && (
            <Row {...rowProps}>
              <Col {...getColProps(1)} style={{ textAlign: 'center' }}>
                <Button type="primary" htmlType="submit">
                  查询
                </Button>
                <Button style={{ marginLeft: 20 }} onClick={this.handleFormReset}>
                  重置
                </Button>
              </Col>
            </Row>
          )}
        </Form>
      </div>
    );
  }
}

export default OYOForm;
