import React, { PureComponent } from 'react';
import { Table, Modal } from 'antd';
import OYONestedTable from '@/components/OyoTable/OyoNestedTable';

class OYOLogTableModal extends PureComponent {
  constructor(props) {
    super(props);
    const { dataSource, columns, title, rowKey, visible, pagination } = props;
    this.state = {
      visible,
      columns: columns || [],
      title: title || '',
      rowKey: rowKey || 'id',
    };
  }

  static getDerivedStateFromProps(nextProps, prevState) {
    const { visible } = nextProps;
    if (visible !== prevState.visible) {
      return { ...nextProps };
    }
    return null;
  }

  handleOk = () => {
    const { onOK } = this.props;
    const visible = false;
    this.setState({
      visible,
    });
    typeof onOK === 'function' && onOK(visible);
  };

  handleCancel = () => {
    const visible = false;
    const { onCancel } = this.props;
    this.setState({
      visible,
    });
    typeof onCancel === 'function' && onCancel(visible);
  };

  render() {
    const { visible, title, columns, rowKey } = this.state;
    const { getLogList, dataSource, pagination } = this.props;
    return (
      <Modal
        width={800}
        visible={visible}
        title={title || ''}
        footer={null}
        onOk={this.handleOk}
        onCancel={this.handleCancel}
        destroyOnClose
      >
        <OYONestedTable
          rowKey={rowKey}
          columns={columns}
          dataSource={dataSource}
          pagination={pagination && pagination.total > 10 ? pagination : false}
          getLogList={getLogList}
        />
      </Modal>
    );
  }
}

export default OYOLogTableModal;
