import React, { Component, PureComponent } from 'react';
import PropTypes from 'prop-types';
import { Button, Form, Row, Col, Input, Table } from 'antd';

class OyoTable extends PureComponent {
  constructor(props) {
    super(props);
    this.state = {
      loading: false,
      pagination: {
        showSizeChanger: true,
        current: 1,
        pageSize: 10,
        total: '',
      },
      dataSource: [],
    };
  }

  componentDidMount() {
    this.getPageList();
  }

  handlePageChange = ({ current, pageSize }) => {
    this.getPageList({
      current,
      pageSize,
    });
  };

  getPageList = ({ current = 1, pageSize = 10 } = {}) => {
    let { params, getList, pageParams, type } = this.props;

    params = {
      ...params,
      [pageParams[0]]: type === 'normal' ? current : (current - 1) * pageSize,
      [pageParams[1]]: pageSize,
    };
    this.setState({
      loading: true,
    });

    getList(params)
      .then(({ data, total } = {}) => {
        if (!data) {
          return;
        }
        this.setState({
          pagination: {
            ...this.state.pagination,
            current,
            pageSize,
            total,
          },
          dataSource: data,
        });
      })
      .catch(er => {
        console.log(er);
      })
      .finally(() => {
        this.setState({
          loading: false,
        });
      });
  };

  reset = () => {
    this.getPageList();
  };

  render() {
    let { props } = this;
    let { pagination, loading, dataSource } = this.state;
    let { columns, getList } = props;
    if (!columns || !getList) {
      return '请传入columns与getList';
    }

    return (
      <Table
        {...props}
        pagination={pagination}
        onChange={this.handlePageChange}
        onShowSizeChange={this.handlePageChange}
        loading={loading}
        dataSource={dataSource}
      />
    );
  }
}

OyoTable.defaultProps = {
  type: 'normal', // stupid
  getList() {
    return Promise.resolve({
      data: [],
      total: 0,
    });
  },
  params: {},
  pageParams: ['pageNum', 'pageSize'],
};

export default OyoTable;
