import React, { PureComponent } from 'react';
import { Table } from 'antd';
import getUUID from '@/utils/uuid';

interface IFormatData {
  data: Object[];
  total: Number;
}
export type Type = 'normal' | 'stupid';

class OyoTable extends PureComponent<any, any> {
  constructor(props) {
    super(props);
    this.state = {
      loading: false,
      pagination: {
        showSizeChanger: true,
        current: props.type == 'normal' ? 1 : 0,
        pageSize: 10,
        total: '',
        showTotal: total =>
          total === 1000 ? `查询结果最多只显示1000条` : `当前条件下，共${total}条结果`,
        // showQuickJumper: true,
      },
      dataSource: [],
    };
  }

  getCurrentPagination() {
    const { current, pageSize } = this.state.pagination;

    return { current, pageSize };
  }

  static defaultProps = {
    type: 'normal', // stupid
    getList(): Promise<IFormatData> {
      return Promise.resolve({
        data: [],
        total: 0,
      });
    },
    params: {},
    pageParams: ['pageNum', 'pageSize'],
  };

  componentDidMount() {
    const { preventGetList } = this.props;
    // 阻止一进入页面就请求数据，后面由李翼统一去修改
    if (preventGetList) {
      return;
    }
    this.getPageList();
  }

  handlePageChange = ({ current, pageSize }) => {
    let { pagination } = this.state;
    let { type } = this.props;
    if (pageSize !== pagination.pageSize) {
      // pageSize的变化 初始化current
      this.getPageList({
        current: type == 'normal' ? 1 : 0,
        pageSize,
      });
    } else {
      this.getPageList({ current, pageSize });
    }
  };
  /*  tslint-disable  */
  getPageList = ({ current, pageSize = 10 } = {}) => {
    let { params, getList, pageParams, type, withUUID } = this.props;
    current = current || (type === 'normal' ? 1 : 0);

    params = {
      ...params,
      [pageParams[0]]: type === 'normal' ? current : (current - 1) * pageSize,
      [pageParams[1]]: pageSize,
    };
    this.setState({
      loading: true,
    });
    getList(params)
      .then(({ data = null, total = 0 } = {}) => {
        if (!data) {
          return;
        }
        withUUID && this.injectUUID(data);
        this.setState({
          pagination: {
            ...this.state.pagination,
            current,
            pageSize,
            total,
          },
          dataSource: data,
        });
      })
      .catch(er => {
        console.log(er);
      })
      .finally(() => {
        this.setState({
          loading: false,
        });
      });
  };

  /**
   * 给数组内的元素注入uuid
   * @param {Array} data 需要注入uuid的数据列表
   */
  injectUUID = data => {
    Array.isArray(data) && data.forEach(v => (v.uuid = getUUID()));
  };

  reset = () => {
    this.getPageList();
  };

  setData = dataSource => {
    // debugger;
    this.setState({
      dataSource,
    });
  };

  clearTable = () => {
    this.setState({
      pagination: {
        ...this.state.pagination,
        current: 1,
        pageSize: 20,
        total: 0,
      },
      dataSource: [],
    });
  };

  render() {
    let { props } = this;
    let { pagination, loading, dataSource } = this.state;
    let { columns, getList, withUUID } = props;
    const customProps = {};
    withUUID && (customProps.rowKey = 'uuid');

    if (!columns || !getList) {
      return '请传入columns与getList';
    }

    return (
      <Table
        {...customProps}
        {...props}
        pagination={pagination}
        onChange={this.handlePageChange}
        loading={loading}
        dataSource={dataSource}
      />
    );
  }
}

export default OyoTable;
