import { message } from 'antd';
import { getHotelList, getHotelLogList } from '@/services/hotelList';

export default {
  namespace: 'hotelLists',
  state: {
    list: [],
    pagination: {
      showSizeChanger: true,
      current: 1,
      pageSize: 10,
      total: '',
    },
    loading: false,
    logListData: {},
  },
  effects: {
    *transHotelSearchGetList({ payload }, { call, put }) {
      const { searchHotelType, searchCityId = [], start, hits } = payload;
      const transPayload = {
        start: start * hits,
        hits,
        oyoId:
          searchHotelType.type === '2' && searchHotelType.val ? searchHotelType.val.trim() : null,
        hotelId:
          searchHotelType.type === '1' && searchHotelType.val ? searchHotelType.val.trim() : null,
        hotelName:
          searchHotelType.type === '0' && searchHotelType.val ? searchHotelType.val.trim() : null,
        status: '3',
        stateId: searchCityId[0] || null,
        cityId: searchCityId[1] || null,
        clusterId: searchCityId[2] || null,
        uniqueCode: null,
        type: null,
      };

      yield put({
        type: 'getList',
        payload: transPayload,
      });
    },
    *getList({ payload }, { call, put }) {
      try {
        yield put({
          type: 'changeMainVal',
          payload: {
            loading: true,
          },
        });

        let res = yield call(getHotelList, payload);

        if (!res || !res.data) return;

        let list = res.data.hotels || [];
        let total = res.data.count;
        let { start, hits } = payload;

        if (list.length === 0) {
          message.error('您的搜索无匹配酒店，请重试！');
        }

        list.forEach((item, index) => {
          item.index = index + 1;
        });

        if (res.data.hotels) {
          yield put({
            type: 'changeList',
            payload: {
              list,
              total,
              start: start / hits,
              hits,
              loading: false,
            },
          });
        }
      } catch (error) {
        console.log(error);
      }
    },
    *getLogList({ payload }, { call, put }) {
      try {
        const response = yield call(getHotelLogList, payload);
        yield put({
          type: 'setHotelLogList',
          payload: response,
        });
        return response;
      } catch (e) {
        console.log(e);
      }
    },
  },
  reducers: {
    changeMainVal(state, { payload }) {
      return {
        ...state,
        ...payload,
      };
    },
    resetList(state, { payload }) {
      return {
        ...state,
        list: [],
        pagination: {
          showSizeChanger: true,
          current: 1,
          pageSize: 10,
          total: '',
        },
      };
    },
    changeList(state, { payload }) {
      // debugger
      let { list, start, hits, total, loading } = payload;
      return {
        ...state,
        list,
        pagination: {
          ...state.pagination,
          current: start + 1,
          pageSize: hits,
          total,
        },
        loading,
      };
    },
    setHotelLogList(state, { payload }) {
      const { data } = payload;
      const { pageNum, pageSize, totalCount, result } = data;
      let logList = [];
      if (Array.isArray(result) && result.length !== 0) {
        logList = result.map((item, key) => {
          const ele = item;
          ele.key = key;
          return ele;
        });
      }
      const logListData = {
        pagination: { current: pageNum, pageSize, total: totalCount },
        logList,
      };
      return { ...state, logListData };
    },
  },
};
