import { cistList, salesArea, newAreaList, getCluster, getStreetInfo } from '../services/hotels';

export default {
  namespace: 'hotelSearch',

  state: {
    cityList: [],
    areaList: [],
    loadAreaList: [],
    newAreaList: [],
  },

  effects: {
    *fetchNewAreaList({ payload }, { call, put, select }) {
      try {
        const hotelSearch = yield select(state => state.hotelSearch);

        if (hotelSearch.newAreaList.length) return;

        const response = yield call(newAreaList, payload);

        let newAreaPayload = JSON.stringify(response.data).replace(
          /(name|id|zoneList|hubList|clcList)/g,
          $0 => {
            switch ($0) {
              case 'zoneList':
              case 'hubList':
              case 'clcList':
                return 'children';
              case 'id':
                return 'value';
              case 'name':
                return 'label';
              default:
                return '';
            }
          }
        );

        // yield put({
        //   type: 'setNewAreaList',
        //   payload: JSON.parse(newAreaPayload),
        // });

        const list = JSON.parse(newAreaPayload);

        list.forEach(reg => {
          reg.children.forEach(zone => {
            if (zone.children && zone.children.length > 0) {
              zone.children.forEach(hub => {
                if (hub.children && hub.children.length > 0) {
                  hub.children.forEach(clc => {
                    clc.isLeaf = false;
                  });
                }
              });
            }
          });
        });

        yield put({
          type: 'setLoadAreaList',
          payload: list,
        });
      } catch (e) {
        console.log(e);
      }
    },
    *fetchCityList({ payload }, { call, put, select }) {
      try {
        const hotelSearch = yield select(state => state.hotelSearch);

        if (hotelSearch.cityList.length) return;

        const response = yield call(cistList, payload);

        let cityPayload = JSON.stringify(response.data).replace(
          /(stateId|stateName|cityVOList|cityId|cityName|clusterVOList|clusterId|clusterName)/g,
          $0 => {
            switch ($0) {
              case 'cityVOList':
              case 'clusterVOList':
                return 'children';
              case 'stateId':
              case 'cityId':
              case 'clusterId':
                return 'value';
              case 'stateName':
              case 'cityName':
              case 'clusterName':
                return 'label';
              default:
                return '';
            }
          }
        );

        yield put({
          type: 'setCityList',
          payload: JSON.parse(cityPayload),
        });
      } catch (e) {
        console.log(e);
      }
    },

    *fetchAreaList({ payload }, { call, put, select }) {
      try {
        const hotelSearch = yield select(state => state.hotelSearch);

        // if (hotelSearch.areaList.length) return; 避免内存移除的第二套方案每次进来重新拉取数据

        const response = yield call(salesArea, payload);

        let areaPayload = JSON.stringify(response.data).replace(
          /(hubBOList|cityBOList|id|cnName|cityCname|cityId)/g,
          $0 => {
            switch ($0) {
              case 'hubBOList':
              case 'cityBOList':
                return 'children';
              case 'id':
              case 'cityId':
                return 'value';
              case 'cnName':
              case 'cityCname':
                return 'label';
              default:
                return '';
            }
          }
        );

        const list = JSON.parse(areaPayload);

        list.forEach(zone => {
          if (zone.children && zone.children.length > 0) {
            zone.children.forEach(hub => {
              if (hub.children && hub.children.length > 0) {
                hub.children.forEach(city => {
                  city.isLeaf = false;
                });
              }
            });
          }
        });

        yield put({
          type: 'setAreaList',
          payload: list,
        });

        yield put({
          type: 'setLoadAreaList',
          payload: JSON.parse(JSON.stringify(list)),
        });

        return new Promise(resolve => {
          resolve(true);
        });
      } catch (e) {
        console.log(e);
      }
    },

    // *getCluster({ payload }, { call, put }) {
    //   const { id, selectList } = payload;

    //   try {
    //   let res = yield call(getCluster, { clcId: id });

    //     yield put({
    //       type: 'setSubCluster',
    //       payload: {
    //         data: res.data,
    //         selectList,
    //       },
    //     });

    //     if (
    //       !res.data ||
    //       !Array.isArray(res.data.clusterList) ||
    //       res.data.clusterList.length === 0
    //     ) {
    //       // debugger;
    //       return Promise.resolve(false);
    //     }
    //     return Promise.resolve(true);
    //   } catch (e) {
    //     console.log(e);
    //   }
    // },

    *getStreet({ payload }, { call, put }) {
      const { id, selectList } = payload;

      try {
        let res = yield call(getStreetInfo, { clcId: id });

        const list = res.data || [];

        yield put({
          type: 'setStreetInfo',
          payload: {
            list,
            selectList,
          },
        });

        if (!res.data || !Array.isArray(res.data) || res.data.length === 0) {
          return Promise.resolve(false);
        }
        return Promise.resolve(true);
      } catch (e) {
        console.log(e);
      }
    },
  },

  reducers: {
    // 三级联动列表
    setCityList(state, action) {
      return {
        ...state,
        cityList: action.payload,
      };
    },

    setAreaList(state, action) {
      return {
        ...state,
        areaList: action.payload,
      };
    },

    setNewAreaList(state, action) {
      return {
        ...state,
        newAreaList: action.payload,
      };
    },

    setLoadAreaList(state, action) {
      return {
        ...state,
        loadAreaList: action.payload,
      };
    },

    setStreetInfo(state, action) {
      let { list, selectList } = action.payload;

      let { loadAreaList, areaList } = state;

      list = JSON.stringify(list).replace(/(id|name)/g, $0 => {
        switch ($0) {
          case 'id':
            return 'value';
          case 'name':
            return 'label';
          default:
            return '';
        }
      });

      const [regionId, zoneId, hubId, clcId] = selectList;
      const indexArr = [];
      let clusterListCache = null;
      console.log('selectList', selectList);
      // let street
      for (let i = 0; i < loadAreaList.length; i++) {
        let region = loadAreaList[i];

        if (region.value === regionId) {
          let zoneList = region.children;

          indexArr.push(i);

          for (let j = 0; j < zoneList.length; j++) {
            let zone = zoneList[j];

            if (zone.value === zoneId) {
              let hubList = zone.children;
              indexArr.push(j);

              for (let k = 0; k < hubList.length; k++) {
                let hub = hubList[k];

                if (hub.value === hubId) {
                  let clcList = hub.children;
                  indexArr.push(k);

                  for (let o = 0; o < clcList.length; o++) {
                    let clc = clcList[o];

                    if (clc.value === clcId) {
                      indexArr.push(o);
                      clc.children = JSON.parse(list);
                      break;
                    }
                  }

                  break;
                }
              }

              break;
            }
          }

          break;
        }
      }

      // 每次5级联动重铸新数据 避免插入过多五级数据后内存泄漏
      // areaList = JSON.parse(JSON.stringify(areaList));

      // areaList[indexArr[0]].children[indexArr[1]].children[indexArr[2]].children = clusterListCache;

      // clusterListCache[indexArr[3]].children = JSON.parse(list);
      // console.log(areaList, indexArr);
      return {
        ...state,
        // loadAreaList: areaList,
        loadAreaList,
      };
    },

    setSubCluster(state, { payload }) {
      let {
        data: { clusterList },
        selectList,
      } = payload;
      const { loadAreaList } = state;

      if (!Array.isArray(clusterList)) return state;

      clusterList = JSON.stringify(clusterList).replace(/(clusterId|clusterCnName)/g, $0 => {
        switch ($0) {
          case 'clusterId':
            return 'value';
          case 'clusterCnName':
            return 'label';
          default:
            return '';
        }
      });

      clusterList = JSON.parse(clusterList).map(item => ({
        ...item,
        isLeaf: false,
      }));

      const [zoneId, hubId, cityId] = selectList;

      for (let i = 0; i < loadAreaList.length; i++) {
        let zone = loadAreaList[i];

        if (zone.value === zoneId) {
          let hubList = zone.children;

          for (let j = 0; j < hubList.length; j++) {
            let hub = hubList[j];

            if (hub.value === hubId) {
              let cityList = hub.children;

              for (let k = 0; k < cityList.length; k++) {
                let city = cityList[k];

                if (city.value === cityId) {
                  city.children = clusterList;

                  break;
                }
              }

              break;
            }
          }

          break;
        }
      }

      // console.log(loadAreaList);

      return {
        ...state,
        loadAreaList,
      };
    },
  },
};
