import { routerRedux } from 'dva/router';
import { stringify } from 'qs';
import { query as queryUsers, queryCurrent, getUserInfo, getUserMenu } from '@/services/user';
import formatMenuList from '@/utils/formatMenuList';
import { logout } from '@/pages/User/services/login';

export default {
  namespace: 'user',

  state: {
    list: [],
    currentUser: {},

    token: localStorage.token ? localStorage.token : '', // token 值
    userId: '', // 账号id
    username: '', // 用户名
    name: '', // 用户名
    expire: '', // 过期时间 ，单位毫秒
    role: '', // 角色，一期使用   酒店：HOTEL, AGM：AGM , 员工：EMPLOYEE

    accountId: '', // 账号id
    type: '', // 类型（酒店：HOTEL,AGM:AGM,员工EMPLOYEE
    hotelId: '', // 若类型为HOTEL，返回酒店id
    hotelName: '', // 若类型为HOTEL，返回酒店名称
    menuList: JSON.parse(localStorage.menuList || '[]'),
  },

  effects: {
    *fetch(_, { call, put }) {
      const response = yield call(queryUsers);

      yield put({
        type: 'save',
        payload: response,
      });
    },
    // 获取用户菜单
    *getUserMenu({ payload }, { call, put }) {
      // ;

      let response = '';
      const params = { ...payload, token: localStorage.token, system: 'CRS' };
      try {
        response = yield call(getUserMenu, params);
      } catch (error) {
        // ;
      }

      if (response.code === '000') {
        //
        // debugger
        yield put({
          type: 'saveMenuList',
          payload: formatMenuList(response.data),
        });
      }
    },
    *logout({ payload }, { put, call }) {
      let response = '';

      payload = {
        token: localStorage.token,
      };

      try {
        response = yield call(logout, payload);
      } catch (error) {
        console.log(error.status);
      }

      yield put({
        type: 'save',
        payload: {
          role: '',
          expire: '',
          hotelId: '',
          userName: '',
          token: '',
        },
      });

      localStorage.token = '';
      window.location.href = response.data;
    },

    *getUserInfo({ payload }, { call, put }) {
      // ;
      let response = '';
      const params = { ...payload, token: localStorage.token };
      try {
        response = yield call(getUserInfo, params);
      } catch (error) {
        console.log(error);
        console.log(error.status);
        console.log(error.response);
        // ;
      }

      if (response.code === '000') {
        yield put({
          type: 'saveInfo',
          payload: response.data,
        });
      }
      return response.data;
    },
    *getInfo({ payload }, { call, put, select }) {
      let info = null;
      let accountId = yield select(state => state.accountId);

      if (!accountId) {
        info = yield put({
          type: 'getUserInfo',
          payload: {},
        });
      } else {
        info = yield select(state => state);
      }

      return Promise.resolve(info);
    },
  },

  reducers: {
    save(state, action) {
      // ;
      return {
        ...state,
        ...action.payload,
      };
    },
    // 保存有权限的菜单 以及路由
    saveMenuList(state, action) {
      // debugger
      localStorage.menuList = JSON.stringify(action.payload);
      return {
        ...state,
        menuList: action.payload,
      };
    },
    saveInfo(state, action) {
      // 保存用户信息
      // ;
      return {
        ...state,
        ...action.payload,
      };
    },
    saveCurrentUser(state, action) {
      return {
        ...state,
        currentUser: action.payload || {},
      };
    },
    changeNotifyCount(state, action) {
      return {
        ...state,
        currentUser: {
          ...state.currentUser,
          notifyCount: action.payload,
        },
      };
    },
  },
};
