import React from 'react';
import { formatMessage } from 'umi/locale';
import Link from 'umi/link';
import _ from 'lodash';
import { matchRoutes } from 'react-router-config';
import RenderAuthorized from '@/components/Authorized';
import Exception from '@/components/Exception';

const Authorized = RenderAuthorized(['user']); // 当前角色

export default ({ children, route, location }) => {
  const routes = matchRoutes(route.routes, location.pathname);
  let authorities = []; // 准入角色

  routes.forEach(item => {
    if (Array.isArray(item.route.authority)) {
      authorities = authorities.concat(item.route.authority);
    } else if (typeof item.route.authority === 'string') {
      authorities.push(item.route.authority);
    }
  });

  const noMatch = (
    <Exception
      type="403"
      desc={formatMessage({ id: 'app.exception.description.403' })}
      linkElement={Link}
      backText={formatMessage({ id: 'app.exception.back' })}
    />
  );
  // debugger
  // console.log('准入角色',authorities)
  return (
    <Authorized
      authority={authorities.length === 0 ? undefined : _.uniq(authorities)}
      noMatch={noMatch}
    >
      {children}
    </Authorized>
  );
};
