import React, { PureComponent } from 'react';
import { connect } from 'dva';
import { Row, Col, Card, Form, Input, Select, Button, Modal, message, Badge, Table } from 'antd';
import PageHeaderWrapper from '@/components/PageHeaderWrapper';
import UpdateChannelModal from './components/UpdateChannelModal';
import ButtonAuthorized from '@/components/ButtonAuthorized';
import { IS_ONLINE } from '@/constant/channelType';
import styles from './List.less';

const FormItem = Form.Item;
const { Option } = Select;
const getValue = obj =>
  Object.keys(obj)
    .map(key => obj[key])
    .join(',');

/* eslint react/no-multi-comp:0 */
@connect(({ global, channel, loading, user }) => ({
  channel,
  user,
  global,
  loading: loading.models.channel,
  savingLoding: loading.effects['channel/add'],
}))
@Form.create()
export default class ChannelList extends PureComponent {
  state = {
    modalVisible: false,
    formValues: { channelName: '', status: '' },
    modelType: null,
    initData: null,
  };

  componentWillMount() {
    const { global, form, order } = this.props;

    const columns = [
      {
        title: '渠道代码',
        dataIndex: 'channelCode',
      },
      {
        title: '渠道接入方式',
        dataIndex: 'isDirect',
        key: 'isDirect',
        width: 250,

        render: isDirect => (isDirect ? '直连' : '非直连'),
      },
      {
        title: '渠道名称',
        dataIndex: 'channelName',
      },
      {
        title: '渠道类型',
        dataIndex: 'isOnline',
        key: 'isOnline',
        render(isOnline) {
          return IS_ONLINE[isOnline] ? IS_ONLINE[isOnline].label : '';
        },
      },
      {
        title: '渠道状态',
        dataIndex: 'status',
        // filters: [{ text: global.STATUS[0], value: 0 }, { text: global.STATUS[1], value: 1 }],
        // onFilter: function() {},
        render(val) {
          return <Badge status={global.STATUS_MAP[val]} text={global.STATUS[val]} />;
        },
      },
      {
        title: '操作',
        dataIndex: 'channelId',
        render: (channelId, status) => (
          <ButtonAuthorized
            code="CRS6.1.2"
            size="small"
            onClick={() => this.handleModalVisible(true, 1, status)}
          >
            编辑
          </ButtonAuthorized>
        ),
      },
    ];
    this.setState({ columns });
  }

  componentDidMount() {
    const { dispatch, channel, form } = this.props;
    // 更新：默认的表单数据
    const formValues = form.getFieldsValue();
    this.setState({ formValues });
    // 请求：渠道列表
    this.fetchChannelList(channel.defaultParams);
    // 请求：价格策略列表
    dispatch({ type: 'channel/fetchPriceList' });
  }

  // 请求：渠道列表
  fetchChannelList = params => {
    const { dispatch } = this.props;
    if (!params) return;
    dispatch({
      type: 'channel/fetchChannelList',
      payload: params,
    }).then(response => {
      this.handleFetchMessage(response);
    });
  };

  // 处理数据请求的消息提示
  handleFetchMessage = response => {
    // if (response.code === '000') {
    //   // Message.success('数据加载成功' || response.msg);
    // } else {
    //   Message.error(response.msg || '数据加载有误');
    // }
  };

  // 表格分页pageSize和PageNum回调
  handlePageChange = (pagination, filtersArg) => {
    const { formValues } = this.state;

    // const filtersValues = Object.keys(filtersArg).reduce((obj, key) => {
    //   const newObj = { ...obj };
    //   newObj[key] = getValue(filtersArg[key]);
    //   return newObj;
    // }, {});

    // 全选：‘1，2’；
    // filtersValues.status =
    //   filtersValues && filtersValues.status && filtersValues.status.length === 2
    //     ? ''
    //     : formValues.status;

    // 合并搜索区域和过滤器的status参数
    // const channelParams = Object.assign({}, formValues, filtersValues);

    const params = {
      pageNum: pagination.current,
      pageSize: pagination.pageSize,
      ...formValues,
    };

    // 请求：渠道列表
    this.fetchChannelList(params);
  };

  // 搜索重置功能
  handleFormReset = () => {
    const { form, channel } = this.props;
    form.resetFields();
    const formValues = form.getFieldsValue();
    this.setState({ formValues });
    // 请求：渠道列表
    this.fetchChannelList(channel.defaultParams);
  };

  // 搜索功能
  handleFormSearch = e => {
    e.preventDefault();

    const { form } = this.props;

    form.validateFields((err, fieldsValue) => {
      const params = {
        channelName: fieldsValue.channelName,
        status: fieldsValue.status,
        isDirect: fieldsValue.isDirect,
        pageNum: 1,
        pageSize: 20,
      };

      if (err) return;

      this.setState({
        formValues: {
          channelName: fieldsValue.channelName,
          status: fieldsValue.status,
        },
      });
      // 请求：渠道列表
      this.fetchChannelList(params);
    });
  };

  // 新增渠道modal
  handleModalVisible = async (flag, type, initData) => {
    let state = {
      modalVisible: !!flag,
      modelType: type,
    };

    if (type === 1) {
      state.initData = initData;
      const res = await this.props.dispatch({
        type: 'channel/fetchChannelRateCodeInfo',
        payload: {
          channelId: initData.channelId,
        },
      });

      state.initData.rateCodes = res.statue ? res.rateCodes : [];
    } else {
      state = {
        ...state,
        initData,
      };
    }

    this.setState(state);
  };

  // 新增渠道功能
  handleAddChannel = fieldsValue => {
    const { dispatch, user, form } = this.props;
    const operatorId = user.accountId;
    const params = { ...fieldsValue, operatorId };
    const msg = this.state.modelType === 1 ? '更新渠道成功' : '新增渠道成功';

    dispatch({ type: 'channel/add', payload: { ...params } }).then(data => {
      if (data.code === '000') {
        message.success(msg);
        this.handleModalVisible();
        form.resetFields();
        const formValues = form.getFieldsValue();
        this.setState({ formValues });
      } else {
        message.error('操作失败');
      }
    });
  };

  renderForm() {
    const {
      global,
      form: { getFieldDecorator },
    } = this.props;
    return (
      <Form onSubmit={this.handleFormSearch} layout="inline">
        <Row>
          <Col md={8} sm={24}>
            <FormItem label="渠道名称">
              {getFieldDecorator('channelName', {
                initialValue: '',
              })(<Input placeholder="请输入渠道名称" />)}
            </FormItem>
          </Col>
          <Col md={4} sm={24}>
            <FormItem label="渠道状态">
              {getFieldDecorator('status', {
                initialValue: '',
              })(
                <Select placeholder="请选择渠道状态" style={{ width: '100%' }}>
                  <Option value="">全部</Option>
                  {global.STATUS.map((status, key) => (
                    <Option key={`option-${key}`} value={key}>
                      {status}
                    </Option>
                  ))}
                </Select>
              )}
            </FormItem>
          </Col>
          <Col md={6} sm={24}>
            <FormItem label="渠道接入方式">
              {getFieldDecorator('isDirect', {
                initialValue: '',
              })(
                <Select style={{ width: '100%' }} placeholder="请选择直连方式">
                  <Option value="">全部</Option>
                  {global.ISDIRECT.map((status, key) => (
                    <Option value={status.key} key={`isDirect-search-${status.key}`}>
                      {status.value}
                    </Option>
                  ))}
                </Select>
              )}
            </FormItem>
          </Col>
          <Col md={4} sm={24} style={{ textAlign: 'right' }}>
            <span className={styles.submitButtons}>
              <Button type="primary" htmlType="submit">
                查询
              </Button>
              <Button style={{ marginLeft: 20 }} onClick={this.handleFormReset}>
                重置
              </Button>
            </span>
          </Col>
        </Row>
      </Form>
    );
  }

  render() {
    const { channel, loading, global, savingLoding } = this.props;
    const { modalVisible, modelType, initData } = this.state;
    const parentMethods = {
      handleAddChannel: this.handleAddChannel,
      handleModalVisible: this.handleModalVisible,
    };

    return (
      <PageHeaderWrapper>
        <Card bordered={false}>
          <div className={styles.tableList}>
            <div className={styles.tableListForm}>{this.renderForm()}</div>
          </div>
        </Card>

        <Card bordered={false} style={{ marginTop: 15 }}>
          <ButtonAuthorized
            code="CRS6.1.1"
            icon="plus"
            type="primary"
            onClick={() => this.handleModalVisible(true, 0, { isOnline: 1 })}
          >
            新增渠道
          </ButtonAuthorized>
          <Table
            loading={loading}
            bordered
            size="small"
            dataSource={channel.channelList}
            columns={this.state.columns}
            style={{ marginTop: 20 }}
            pagination={{
              showSizeChanger: true,
              current: channel.pageNum,
              pageSize: channel.pageSize,
              total: channel.totalCount,
            }}
            onChange={this.handlePageChange}
            onShowSizeChange={this.handlePageChange}
          />
        </Card>
        <UpdateChannelModal
          {...parentMethods}
          modelType={modelType}
          initData={initData}
          modalVisible={modalVisible}
          priceList={channel.priceList}
          global={global}
          confirmLoading={savingLoding}
        />
      </PageHeaderWrapper>
    );
  }
}
