import React from 'react';
import { Form, Input, Select, Modal } from 'antd';
import { IS_ONLINE } from '@/constant/channelType';

const FormItem = Form.Item;
const { Option } = Select;

const UpdateChannelModal = Form.create()(props => {
  let {
    global,
    modalVisible,
    form,
    priceList,
    handleAddChannel,
    handleModalVisible,
    modelType,
    initData,
    confirmLoading,
  } = props;

  const handleOK = () => {
    form.validateFields((err, fieldsValue) => {
      if (err) return;

      handleAddChannel(fieldsValue);
    });
  };

  initData = initData || {};

  return (
    <Modal
      destroyOnClose
      title={`${modelType === 1 ? '更新' : '新增'}渠道`}
      visible={modalVisible}
      confirmLoading={confirmLoading}
      onOk={handleOK}
      onCancel={() => handleModalVisible()}
    >
      {(() => {
        if (modelType === 1) {
          return (
            <FormItem labelCol={{ span: 5 }} wrapperCol={{ span: 15 }} label="渠道Id">
              {form.getFieldDecorator('channelId', {
                initialValue: initData.channelId,
              })(<Input disabled />)}
            </FormItem>
          );
        }
      })()}
      <FormItem labelCol={{ span: 5 }} wrapperCol={{ span: 15 }} label="渠道名称">
        {form.getFieldDecorator('channelName', {
          rules: [{ required: true, message: '请输入渠道名称', min: 1 }],
          initialValue: modelType === 1 ? initData.channelName : null,
        })(<Input placeholder="请输入渠道名称" />)}
      </FormItem>
      <FormItem labelCol={{ span: 5 }} wrapperCol={{ span: 15 }} label="渠道状态">
        {form.getFieldDecorator('status', {
          rules: [{ required: true, message: '请选择渠道状态' }],
          initialValue: modelType === 1 ? initData.status : null,
        })(
          <Select placeholder="请选择渠道状态" style={{ width: '100%' }}>
            {global.STATUS.map((status, key) => (
              <Option key={`option-${key}`} value={key}>
                {status}
              </Option>
            ))}
          </Select>
        )}
      </FormItem>
      <FormItem labelCol={{ span: 5 }} wrapperCol={{ span: 15 }} label="价格策略">
        {form.getFieldDecorator('rateCodeIdList', {
          rules: [{ required: true, message: '请选择价格策略' }],
          initialValue: modelType === 1 ? initData.rateCodes : [],
        })(
          <Select
            mode="multiple"
            style={{ width: '100%' }}
            placeholder="请选择价格策略"
            maxTagCount="5"
          >
            {priceList &&
              priceList.map(priceStrategy => (
                <Option key={priceStrategy.rateCodeId}>{priceStrategy.rateCodeName}</Option>
              ))}
          </Select>
        )}
      </FormItem>
      <FormItem labelCol={{ span: 5 }} wrapperCol={{ span: 15 }} label="渠道接入方式">
        {form.getFieldDecorator('isDirect', {
          rules: [{ required: true, message: '请选择渠道接入方式' }],
          initialValue: initData.isDirect === 1 ? initData.isDirect : 0,
        })(
          <Select style={{ width: '100%' }} placeholder="请选择直连方式">
            {global.ISDIRECT.map((status, key) => (
              <Option value={status.key} key={`isDirect-edit-${status.key}`}>
                {status.value}
              </Option>
            ))}
          </Select>
        )}
      </FormItem>
      <FormItem labelCol={{ span: 5 }} wrapperCol={{ span: 15 }} label="渠道类型">
        {form.getFieldDecorator('isOnline', {
          rules: [{ required: true, message: '请选择渠道类型' }],
          initialValue: initData.isOnline,
        })(
          <Select style={{ width: '100%' }} placeholder="请选择直连方式">
            {IS_ONLINE.map((status, key) => (
              <Option value={status.value} key={`isDirect-edit-${status.key}`}>
                {status.label}
              </Option>
            ))}
          </Select>
        )}
      </FormItem>
    </Modal>
  );
});

export default UpdateChannelModal;
