import {
  queryChannelList,
  addChannel,
  queryPriceList,
  channelRateCodeInfo,
} from '../services/channel';
import ChannelList from '../List';

export default {
  namespace: 'channel',

  state: {
    defaultParams: {
      status: '',
      channelName: '',
      pageNum: 1,
      pageSize: 10,
    },
    pageNum: 1,
    pageSize: 10,
    totalCount: 0,
    channelList: [],
    priceList: [],
    rateCodeId: [],
  },

  effects: {
    *fetchChannelRateCodeInfo({ payload }, { call, put }) {
      try {
        const response = yield call(channelRateCodeInfo, payload);
        const data = response.data;
        const rateCodes = data.rateCodes ? data.rateCodes.map(item => `${item.rateCodeId}`) : [];

        return {
          statue: 1,
          ...response,
          rateCodes,
        };
      } catch (e) {
        return e.response;
      }
    },
    *fetchChannelList({ payload }, { call, put }) {
      try {
        const response = yield call(queryChannelList, payload);
        yield put({
          type: 'queryChannelList',
          payload: response,
        });
        return response;
      } catch (e) {
        return e.response;
      }
    },
    *fetchPriceList({ payload }, { call, put }) {
      try {
        const response = yield call(queryPriceList);
        yield put({
          type: 'queryPriceList',
          payload: response,
        });
        return response;
      } catch (e) {
        return e.response;
      }
    },
    *add({ payload }, { call, put, select }) {
      try {
        const response = yield call(addChannel, payload);
        const defaultParams = yield select(state => state.channel.defaultParams);

        yield put({
          type: 'fetchChannelList',
          payload: defaultParams,
        });
        return response;
      } catch (e) {
        return e.response;
      }
    },
  },

  reducers: {
    saveRateCodeId(state, { payload }) {
      return {
        ...state,
        rateCodeId: payload.rateCodeId,
      };
    },
    queryChannelList(state, { payload }) {
      const { data } = payload;
      const { pageNum, pageSize, totalCount, result } = data;

      let channelList = [];
      if (result && result.length !== 0) {
        channelList = result.map((item, key) => {
          const ele = item;
          ele.key = key;
          ele.isOnline = typeof ele.isOnline === 'string' ? Number(ele.isOnline) : null;

          return ele;
        });
      }
      return {
        ...state,
        pageNum,
        pageSize,
        totalCount,
        channelList,
      };
    },
    queryPriceList(state, { payload }) {
      const { data } = payload;
      const priceList = data;

      return {
        ...state,
        priceList,
      };
    },
  },
};
