import React, { PureComponent } from 'react';
import { Card, message } from 'antd';
import PageHeaderWrapper from '@/components/PageHeaderWrapper';
import OYOTable from '@/components/OyoTable/OyoTable.tsx';
import { getLogList } from './services';

export default class IDCardDeviceLog extends PureComponent {
  state = {
    params: {},
    pageParams: ['pageNum', 'pageSize'],
  };

  tableConfig = [
    {
      title: '酒店名称',
      dataIndex: 'hotelName',
    },
    {
      title: '操作人',
      dataIndex: 'operator',
    },
    {
      title: '配置时间',
      dataIndex: 'deployTime',
    },
    {
      title: '系统版本',
      dataIndex: 'systemVersion',
    },
    {
      title: '读卡器品牌',
      dataIndex: 'cardReader',
    },
    {
      title: '配置类型',
      dataIndex: 'deployType',
    },
    {
      title: '身份证驱动版本',
      dataIndex: 'driveVersion',
    },
    {
      title: '是否兼容',
      dataIndex: 'campatible',
      render: text => (text ? '是' : '否'),
    },
    {
      title: '测试结果',
      dataIndex: 'testResult',
      render: text => (text ? '成功' : '失败'),
    },
  ];

  getList = params => {
    try {
      return getLogList(params).then(({ data }) => {
        const ret = {
          data: [],
          total: 0,
        };

        if (data) {
          data.list && (ret.data = data.list);
          data.total && (ret.total = data.total);
        }

        return ret;
      });
    } catch (error) {
      message.error('获取数据发生错误');
      return Promise.resolve({ data: [], total: 0 });
    }
  };

  render() {
    const { params, pageParams } = this.state;

    return (
      <PageHeaderWrapper>
        <Card title="操作日志">
          <OYOTable
            rowKey={({ deployTime, hotelName }, index) => `${index}-${hotelName}-${deployTime}`}
            columns={this.tableConfig}
            getList={this.getList}
            params={params}
            pageParams={pageParams}
            // scroll={{ x: 1000 }}
            bordered
            // preventGetList
          />
        </Card>
      </PageHeaderWrapper>
    );
  }
}
