import React, { PureComponent } from 'react';
import { Card, Button, Row, Col, Table, message } from 'antd';
import { connect } from 'dva';
import router from 'umi/router';
import moment from 'moment';

import PageHeaderWrapper from '@/components/PageHeaderWrapper';
import OYOTable from '@/components/OyoTable/OyoTable.tsx';
import { COOPERATION_TYPE } from '@/constant/cooperationType';
import getUUID from '@/utils/uuid';
import { downloadFile } from '@/utils/downloadFile';

import styles from '../../index.less';
import { lockStatusLogAll, lockStatusLogLowVolt } from '../sevices/index';

export default class EquipmentMonitorDetail extends PureComponent {
  constructor(props) {
    super(props);
    this.state = {
      tableParams: {
        startDate: '',
        endDate: '',
        hotelId: '',
        brand: '',
        pageNum: 1,
        pageSize: 10,
      },
      pageParams: ['pageNum', 'pageSize'],

      hotelDetailInfo: [],

      hotelRoomNum: 0,
      warnHotelRoomNum: 0,

      lockDataSource: [],
      queryType: 'totalNumQuery',
      columnsType: 'hotelRoomColumns',
    };

    this.hotelDetailInfoColumns = [
      {
        title: '酒店区域',
        dataIndex: 'clusterName',
        key: 'clusterName',
        render: (clusterName, record) => `${record.stateName}/${record.cityName}/${clusterName}`,
      },
      {
        title: '协议类型',
        dataIndex: 'china2',
        key: 'china2',
        render: china2 => (china2 ? 'china2.0' : '其他'),
      },
      {
        title: '酒店ID',
        dataIndex: 'hotelId',
        key: 'hotelId',
      },
      {
        title: '酒店名称',
        dataIndex: 'hotelName',
        key: 'hotelName',
      },
      {
        title: '品牌名称',
        dataIndex: 'brandName',
        key: 'brandName',
      },
      {
        title: 'OYO ID',
        dataIndex: 'oyoId',
        key: 'oyoId',
      },
      {
        title: '门锁状态',
        dataIndex: 'hotelLockStatusDesc',
        key: 'hotelLockStatusDesc',
      },
    ];

    this.lockDetailColumns = {
      hotelRoomColumns: [
        {
          title: '房间号',
          dataIndex: 'roomNo',
          key: 'roomNo',
          render: roomNo => roomNo || '-',
        },
        {
          title: '门锁状况',
          dataIndex: 'roomLockStatusDesc',
          key: 'roomLockStatusDesc',
          render: roomLockStatusDesc => roomLockStatusDesc || '-',
        },
        {
          title: '历史发生预警次数',
          dataIndex: 'lockWarnNum',
          key: 'lockWarnNum',
          render: lockWarnNum => lockWarnNum || '-',
        },
        {
          title: '最近预警时间',
          dataIndex: 'lastTime',
          key: 'lastTime',
          render: (lastTime, record) => {
            if (lastTime) {
              return record.warnDesc ? `${lastTime}${record.warnDesc}` : `${record.warnDesc}-`;
            }
            if (!lastTime) {
              return '--';
            }
          },
        },
      ],
      warnHotelRoomColumns: [
        {
          title: '房间号',
          dataIndex: 'roomNo',
          key: 'roomNo',
          render: roomNo => roomNo || '-',
        },
        {
          title: '门锁状况',
          dataIndex: 'roomLockStatusDesc',
          key: 'roomLockStatusDesc',
          render: roomLockStatusDesc => roomLockStatusDesc || '-',
        },
        {
          title: '发生时间',
          dataIndex: 'lastTime',
          key: 'lastTime',
          render: (lastTime, record) => {
            if (lastTime && !record.warnDesc) {
              return `${lastTime}-`;
            }
            if (!lastTime && record.warnDesc) {
              return `-${record.warnDesc}`;
            }
            if (!lastTime && !record.warnDesc) {
              return '--';
            }
            return `${lastTime}${record.warnDesc}`;
          },
        },
      ],
    };
  }

  componentDidMount() {
    let arr = [];
    let { tableParams, queryType } = this.state;
    const { query } = this.props.location;

    if (query) {
      const {
        startDate,
        endDate,
        hotelId,
        brand,
        hotelRoomNum,
        warnHotelRoomNum,
        china2,
        hotelStatus,
      } = query;

      arr.push(query);
      this.setState(
        {
          hotelDetailInfo: arr,
          hotelRoomNum,
          warnHotelRoomNum,
          tableParams: {
            ...tableParams,
            startDate,
            endDate,
            hotelId,
            brand,
          },
        },
        () => {
          this.oyotable.getPageList();
        }
      );
    } else {
      return message.warning('无数据');
    }
  }

  getLockStatusLogAll = params => {
    return lockStatusLogAll(params)
      .then(res => {
        if (res && res.data && Array.isArray(res.data.list)) {
          let { total } = res.data;
          let result = res.data.list.map((item, index) => {
            return { ...item, key: getUUID() };
          });
          return { data: result || [], total };
        }
      })
      .catch(err => {
        console.log(err);
      });
  };

  getLockStatusLogLowVolt = params => {
    return lockStatusLogLowVolt(params)
      .then(res => {
        if (res && res.data && Array.isArray(res.data.list)) {
          let { total } = res.data;
          let result = res.data.list.map((item, index) => {
            return { ...item, key: getUUID() };
          });
          return { data: result || [], total };
        }
      })
      .catch(err => {
        console.log(err);
      });
  };

  changeQuery = columnsName => {
    let { tableParams, queryType, columnsType } = this.state;

    this.setState(
      {
        queryType: columnsName === 'hotelRoomColumns' ? 'totalNumQuery' : 'warnNumQuery',
        columnsType: columnsName,
      },
      () => {
        this.oyotable.getPageList();
      }
    );
  };

  exportTable = queryType => {
    const totalExportUrl = '/api/crs/lock/dashboard/lockStatusLogAll/export';
    const warnExportUrl = '/api/crs/lock/dashboard/lockStatusLogLowVolt/export';
    let exportUrl = queryType === 'totalNumQuery' ? totalExportUrl : warnExportUrl;

    downloadFile(exportUrl, {
      ...this.state.tableParams,
      'Content-Type': ' application/json',
    });
  };

  render() {
    const {
      hotelDetailInfoColumns,
      lockDetailColumns,
      changeQuery,
      exportTable,
      getLockStatusLogAll,
      getLockStatusLogLowVolt,
    } = this;
    const {
      tableParams,
      pageParams,
      hotelDetailInfo,
      queryType,
      lockDataSource,
      columnsType,
      hotelRoomNum,
      warnHotelRoomNum,
    } = this.state;
    const choosedColor = '#ff000024';

    return (
      <PageHeaderWrapper>
        <Card>
          <Table
            rowKey="hotelId"
            dataSource={hotelDetailInfo}
            columns={hotelDetailInfoColumns}
            pagination={false}
          />
        </Card>
        <Card style={{ marginTop: '10px' }}>
          <h3>硬件预警筛选</h3>
          <div className={styles.row}>
            <div
              className={styles.monitorDashboard}
              onClick={() => changeQuery('hotelRoomColumns')}
              style={{
                background: queryType === 'totalNumQuery' ? choosedColor : '',
                cursor: 'pointer',
              }}
            >
              <div>门锁总数量</div>
              <div className={styles.dashboardItem}>
                <h2>{hotelRoomNum}间</h2>
              </div>
            </div>
            <div
              className={styles.monitorDashboard}
              onClick={() => changeQuery('warnHotelRoomColumns')}
              style={{
                background: queryType === 'totalNumQuery' ? '' : choosedColor,
                cursor: 'pointer',
              }}
            >
              <div>门锁预警数</div>
              <div className={styles.dashboardItem}>
                <h2>{warnHotelRoomNum}间</h2>
              </div>
            </div>
          </div>
        </Card>

        <Card style={{ marginTop: 15 }}>
          <Button
            type="primary"
            style={{ marginBottom: '10px' }}
            onClick={() => exportTable(queryType)}
          >
            导出
          </Button>
          <OYOTable
            rowKey="key"
            ref={re => {
              this.oyotable = re;
            }}
            bordered
            size="small"
            params={tableParams}
            pageParams={pageParams}
            columns={lockDetailColumns[columnsType]}
            getList={queryType === 'totalNumQuery' ? getLockStatusLogAll : getLockStatusLogLowVolt}
            preventGetList
          />
        </Card>
      </PageHeaderWrapper>
    );
  }
}
