import React, { PureComponent } from 'react';
import {
  Card,
  Table,
  Button,
  Form,
  Input,
  Select,
  Row,
  Col,
  message,
  DatePicker,
  Checkbox,
} from 'antd';
import router from 'umi/router';
import { connect } from 'dva';
import moment from 'moment';

import PageHeaderWrapper from '@/components/PageHeaderWrapper';
import OYOTable from '@/components/OyoTable/OyoTable.tsx';
import ButtonAuthorized from '@/components/ButtonAuthorized';
import CitySelect from '@/components/CitySelect';
import HotelSearch from '@/components/HotelSearch/HotelSearch';
import { HOTEL_STATUS, getNameFromStatus } from '@/constant/hotelStatus';
import { COOPERATION_TYPE } from '@/constant/cooperationType';
import { BRAND_TYPE } from '@/constant/brandNameType';
import {
  rowProps,
  col1Props,
  col3Props,
  col4Props,
  formItemLayout,
  widthStyle,
} from '@/utils/formProps';
import { downloadFile } from '@/utils/downloadFile';
import getUUID from '@/utils/uuid';

import { hardwareRobustnessHotelList } from '../sevices/index';

const Option = Select.Option;
const FormItem = Form.Item;

const hotelStatusOption = function() {
  return HOTEL_STATUS.map((item, key) => (
    <Option value={item.status} key={`HOTEL_STATUS-${key}`}>
      {item.name}
    </Option>
  ));
};

const cooperationTypeOption = function() {
  return COOPERATION_TYPE.map((item, key) => (
    <Option value={item.value} key={`COOPERATION_TYPE-${key}`}>
      {item.type}
    </Option>
  ));
};

const brandNameOption = function() {
  return BRAND_TYPE.map((item, key) => (
    <Option value={item.value} key={`BRAND_TYPE-${key}`}>
      {item.name}
    </Option>
  ));
};

const defaultQueryParam = {
  startDate: '',
  endDate: '',

  stateId: null, // 省
  cityId: null, // 市
  clusterId: null, // 区
  hotelName: null, // 酒店名称
  hotelId: null, // 酒店id
  oyoId: null, // oyoId
  hotelStatus: undefined, // 酒店状态
  china2: undefined, // 协议类型
  brand: undefined, // 品牌名称
  pageNum: 1,
  pageSize: 10,
};

@Form.create()
export default class HardwareMonitor extends PureComponent {
  constructor(props) {
    super(props);

    this.state = {
      tableParams: {
        ...defaultQueryParam,
      },
      force: true,
      pageParams: ['pageNum', 'pageSize'],
    };

    this.columns = [
      {
        title: '酒店区域',
        dataIndex: 'hotelAreaDescription',
        key: 'hotelAreaDescription',
      },
      {
        title: '协议类型',
        dataIndex: 'protocolTypeDescription',
        key: 'protocolTypeDescription',
      },
      {
        title: '酒店名称',
        dataIndex: 'hotelName',
        key: 'hotelName',
      },
      {
        title: 'OYO ID',
        dataIndex: 'oyoId',
        key: 'oyoId',
      },
      {
        title: '品牌名称',
        dataIndex: 'brandName',
        key: 'brandName',
      },
      {
        title: '总调用总数',
        dataIndex: 'totalCreateCardNum',
        key: 'totalCreateCardNum',
      },
      {
        title: '制卡成功率',
        dataIndex: 'createCardSuccessRate',
        key: 'createCardSuccessRate',
        render: createCardSuccessRate => `${createCardSuccessRate}%`,
      },
      {
        title: '制卡成功次数',
        dataIndex: 'createCardSuccessNum',
        key: 'createCardSuccessNum',
      },
      {
        title: '数据平均时间',
        dataIndex: 'dataReportTimeAvg',
        key: 'dataReportTimeAvg',
        render: dataReportTimeAvg => `${dataReportTimeAvg}秒`,
      },
      {
        title: '操作',
        width: '8%',
        render: (key, record) => (
          <>
            <Button
              onClick={() => {
                this.toHardwareDetail(record);
              }}
            >
              查看
            </Button>
          </>
        ),
      },
    ];
  }

  componentDidMount() {
    let { tableParams } = this.state;
    let { query } = this.props.location;

    if (query) {
      let { startDate, endDate, china2, hotelStatus } = query;
      this.setState(
        {
          tableParams: {
            ...tableParams,
            startDate,
            endDate,
            hotelStatus,
            china2,
          },
        },
        () => {
          this.oyotable.getPageList();
        }
      );
    }
  }

  getHardwareRobustnessHotelList = params => {
    return hardwareRobustnessHotelList(params)
      .then(res => {
        if (res && res.data && Array.isArray(res.data.list)) {
          let { total } = res.data;
          let result = res.data.list.map(item => {
            return { ...item, key: getUUID() };
          });
          return { data: result || [], total };
        }
      })
      .catch(err => {
        console.log(err);
      });
  };

  cityChange = value => {
    let { tableParams } = this.state;

    this.setState({
      tableParams: {
        ...tableParams,
        stateId: value[0] ? value[0] : null,
        cityId: value[1] ? value[1] : null,
        clusterId: value[2] ? value[2] : null,
      },
    });
  };

  handleChange = (e, key) => {
    let { tableParams } = this.state;

    if (key === 'hotelName') {
      this.setState({
        tableParams: {
          ...tableParams,
          hotelName: e.hotelName ? e.hotelName : e.val,
        },
      });
    } else {
      let res = typeof e === 'object' ? e.target.value : e;
      this.setState({
        tableParams: {
          ...tableParams,
          [key]: res,
        },
      });
    }
  };

  query = () => {
    this.oyotable.getPageList();
  };

  reset = () => {
    let { startDate, endDate, hotelStatus } = this.props.location.query;
    this.hotelSearch.reset();
    this.setState(
      {
        tableParams: {
          ...defaultQueryParam,
          startDate,
          endDate,
          hotelStatus,
        },
        force: false,
      },
      () => {
        this.query();
        this.setState({
          force: true,
        });
      }
    );
  };

  exportTable = () => {
    downloadFile('/api/crs/lock/dashboard/hardwareRobustnessHotelList/export', {
      ...this.state.tableParams,
      'Content-Type': ' application/json',
    });
  };

  toHardwareDetail = record => {
    const dashboardParams = this.props.location.query;

    router.push({
      pathname: '/equipment/dataDashboard/hardwareMonitorDetail',
      query: { ...record, ...dashboardParams },
    });
  };

  render() {
    const {
      cityChange,
      handleChange,
      query,
      reset,
      exportTable,
      columns,
      getHardwareRobustnessHotelList,
    } = this;
    const { tableParams, pageParams, dataSource, force } = this.state;

    const { stateId, cityId, clusterId, hotelId, oyoId, hotelStatus, china2, brand } = tableParams;
    const {
      form: { getFieldDecorator },
    } = this.props;

    return (
      <PageHeaderWrapper>
        <Card>
          <Form layout="inline">
            <Row {...rowProps}>
              <Col {...col4Props}>
                <FormItem style={widthStyle} label="酒店区域" {...formItemLayout}>
                  {force ? (
                    <CitySelect
                      style={{ width: '100%' }}
                      type="cityList"
                      onChange={cityChange}
                      changeOnSelect
                      ref={re => {
                        this.citySelect = re;
                      }}
                    />
                  ) : null}
                </FormItem>
              </Col>
              <Col {...col4Props}>
                <FormItem style={widthStyle} label="酒店名称" {...formItemLayout}>
                  <HotelSearch
                    ref={re => {
                      this.hotelSearch = re;
                    }}
                    type="0"
                    onChange={e => handleChange(e, 'hotelName')}
                  />
                </FormItem>
              </Col>
              <Col {...col4Props}>
                <FormItem style={widthStyle} label="酒店ID" {...formItemLayout}>
                  <Input
                    value={hotelId}
                    type="number"
                    placeholder="请输入酒店ID"
                    onChange={e => handleChange(e, 'hotelId')}
                  />
                </FormItem>
              </Col>
              <Col {...col4Props}>
                <FormItem style={widthStyle} label="OYOID" {...formItemLayout}>
                  <Input
                    value={oyoId}
                    placeholder="请输入OYOID"
                    onChange={e => handleChange(e, 'oyoId')}
                  />
                </FormItem>
              </Col>
            </Row>

            <Row {...rowProps} style={{ marginTop: '10px' }}>
              <Col {...col4Props}>
                <FormItem style={widthStyle} label="酒店状态" {...formItemLayout}>
                  <Select
                    value={hotelStatus}
                    style={{ width: '100%' }}
                    placeholder="请选择酒店状态"
                    onChange={e => handleChange(e, 'hotelStatus')}
                  >
                    {hotelStatusOption()}
                  </Select>
                </FormItem>
              </Col>
              <Col {...col4Props}>
                <FormItem style={widthStyle} label="协议类型" {...formItemLayout}>
                  <Select
                    value={china2}
                    placeholder="请选择协议类型"
                    onChange={e => handleChange(e, 'china2')}
                  >
                    {cooperationTypeOption()}
                  </Select>
                </FormItem>
              </Col>
              <Col {...col4Props}>
                <FormItem style={widthStyle} label="品牌名称" {...formItemLayout}>
                  <Select
                    value={brand}
                    placeholder="请选择品牌名称"
                    onChange={e => handleChange(e, 'brand')}
                  >
                    {brandNameOption()}
                  </Select>
                </FormItem>
              </Col>
            </Row>
          </Form>

          <Row {...rowProps} style={{ textAlign: 'center', marginTop: '20px' }}>
            <Col {...col1Props}>
              <Button type="primary" onClick={query}>
                查询
              </Button>
              <Button onClick={reset} style={{ marginLeft: 20 }}>
                重置
              </Button>
            </Col>
          </Row>
        </Card>

        <Card style={{ marginTop: 15 }}>
          <Button type="primary" style={{ marginBottom: '10px' }} onClick={exportTable}>
            导出
          </Button>

          <OYOTable
            rowKey="key"
            ref={re => {
              this.oyotable = re;
            }}
            bordered
            size="small"
            params={tableParams}
            pageParams={pageParams}
            columns={columns}
            getList={getHardwareRobustnessHotelList}
            preventGetList
          />
        </Card>
      </PageHeaderWrapper>
    );
  }
}
