import React, { PureComponent } from 'react';
import { Card, Button, Row, Col, Table, message } from 'antd';
import { connect } from 'dva';
import router from 'umi/router';
import moment from 'moment';

import PageHeaderWrapper from '@/components/PageHeaderWrapper';
import OYOTable from '@/components/OyoTable/OyoTable.tsx';
import ButtonAuthorized from '@/components/ButtonAuthorized';
import { downloadFile } from '@/utils/downloadFile';
import getUUID from '@/utils/uuid';

import { createCardRequestDetailList, openLockDetailList } from '../sevices/index';
import styles from '../../index.less';

export default class HardwareMonitorDetail extends PureComponent {
  constructor(props) {
    super(props);
    this.state = {
      tableParams: {
        startDate: '',
        endDate: '',
        hotelId: '',
        brand: '',
        pageNum: 1,
        pageSize: 10,
      },
      pageParams: ['pageNum', 'pageSize'],

      hotelDetailInfo: [],

      createCardSuccessRate: 0,
      dataReportTimeAvg: 0,
      totalCreateCardNum: 0,

      detailDataSource: [],
      queryType: 'createCardTotalNum',
      columnsType: 'createCardColumns',
    };

    this.hotelInfoColumns = [
      {
        title: '酒店区域',
        dataIndex: 'hotelAreaDescription',
        key: 'hotelAreaDescription',
      },
      {
        title: '协议类型',
        dataIndex: 'protocolTypeDescription',
        key: 'protocolTypeDescription',
      },
      {
        title: '酒店ID',
        dataIndex: 'hotelId',
        key: 'hotelId',
      },
      {
        title: '酒店名称',
        dataIndex: 'hotelName',
        key: 'hotelName',
      },
      {
        title: 'OYO ID',
        dataIndex: 'oyoId',
        key: 'oyoId',
      },
      {
        title: '品牌名称',
        dataIndex: 'brandName',
        key: 'brandName',
      },
    ];
    this.detailColumns = {
      createCardColumns: [
        {
          title: '房单号',
          dataIndex: 'roomReservationSn',
          key: 'roomReservationSn',
          render: roomReservationSn => roomReservationSn || '-',
        },
        {
          title: '房间号',
          dataIndex: 'roomNo',
          key: 'roomNo',
          render: roomNo => roomNo || '-',
        },
        {
          title: '制卡方式',
          dataIndex: 'action',
          key: 'action',
          render: action => action || '-',
        },
        {
          title: '调用结果',
          dataIndex: 'responseCodeDescription',
          key: 'responseCodeDescription',
          render: responseCodeDescription => responseCodeDescription || '-',
        },
        {
          title: '返回结果',
          dataIndex: 'responseMessage',
          key: 'responseMessage',
          render: responseMessage => responseMessage || '-',
        },
        {
          title: '制卡调用时间',
          dataIndex: 'requestTime',
          key: 'requestTime',
          render: requestTime => requestTime || '-',
        },
      ],
      dataReportColumns: [
        {
          title: '房间号',
          dataIndex: 'roomNo',
          key: 'roomNo',
          render: roomNo => roomNo || '-',
        },
        {
          title: '开锁发生时间',
          dataIndex: 'openLockTime',
          key: 'openLockTime',
          render: openLockTime => openLockTime || '-',
        },
        {
          title: '日志上传时间',
          dataIndex: 'dataReportTime',
          key: 'dataReportTime',
          render: dataReportTime => dataReportTime || '-',
        },
        {
          title: '数据上传时间',
          dataIndex: 'reportTimeInterval',
          key: 'reportTimeInterval',
          render: reportTimeInterval => `${reportTimeInterval}秒` || '-',
        },
      ],
    };
  }

  componentDidMount() {
    let arr = [];
    let { tableParams, queryType } = this.state;
    const { query } = this.props.location;

    if (query) {
      const {
        startDate,
        endDate,
        hotelId,
        brand,
        createCardSuccessRate,
        totalCreateCardNum,
        dataReportTimeAvg,
        china2,
        hotelStatus,
      } = query;

      arr.push(query);
      this.setState(
        {
          hotelDetailInfo: arr,
          createCardSuccessRate,
          dataReportTimeAvg,
          totalCreateCardNum,
          tableParams: {
            ...tableParams,
            startDate,
            endDate,
            hotelId,
            brand,
          },
        },
        () => {
          this.oyotable.getPageList();
        }
      );
    } else {
      return message.warning('无数据');
    }
  }

  getCreateCardRequestDetailList = params => {
    return createCardRequestDetailList(params)
      .then(res => {
        if (res && res.data && Array.isArray(res.data.list)) {
          let { total } = res.data;
          let result = res.data.list.map((item, index) => {
            return { ...item, key: getUUID() };
          });
          return { data: result || [], total };
        }
      })
      .catch(err => {
        console.log(err);
      });
  };

  getOpenLockDetailList = params => {
    return openLockDetailList(params)
      .then(res => {
        if (res && res.data && Array.isArray(res.data.list)) {
          let { total } = res.data;
          let result = res.data.list.map((item, index) => {
            return { ...item, key: getUUID() };
          });
          return { data: result || [], total };
        }
      })
      .catch(err => {
        console.log(err);
      });
  };

  changeQuery = columnsName => {
    let { tableParams, queryType, columnsType } = this.state;

    this.setState(
      {
        queryType: columnsName === 'createCardColumns' ? 'createCardTotalNum' : 'dataReportTime',
        columnsType: columnsName,
      },
      () => {
        this.oyotable.getPageList();
      }
    );
  };

  exportTable = queryType => {
    const createCardExportUrl = '/api/crs/lock/dashboard/createCardRequestDetailList/export';
    const dataReportExportUrl = '/api/crs/lock/dashboard/openLockDetailList/export';
    let exportUrl = queryType === 'createCardTotalNum' ? createCardExportUrl : dataReportExportUrl;

    downloadFile(exportUrl, {
      ...this.state.tableParams,
      'Content-Type': ' application/json',
    });
  };

  render() {
    const {
      hotelInfoColumns,
      detailColumns,
      changeQuery,
      exportTable,
      getCreateCardRequestDetailList,
      getOpenLockDetailList,
    } = this;
    const {
      tableParams,
      pageParams,
      hotelDetailInfo,
      queryType,
      detailDataSource,
      columnsType,
      createCardSuccessRate,
      dataReportTimeAvg,
      totalCreateCardNum,
    } = this.state;
    const choosedColor = '#ff000024';

    return (
      <PageHeaderWrapper>
        <Card>
          <Table
            rowKey="hotelId"
            dataSource={hotelDetailInfo}
            columns={hotelInfoColumns}
            pagination={false}
          />
        </Card>
        <Card style={{ marginTop: '10px' }}>
          <h3>硬件预警筛选</h3>
          <div className={styles.row}>
            <div className={styles.monitorDashboard}>
              <h3>
                制卡成功率<span className={styles.spanStyle}>{createCardSuccessRate}%</span>
              </h3>
            </div>
          </div>

          <div className={styles.row}>
            <div
              className={styles.monitorDashboard}
              onClick={() => changeQuery('createCardColumns')}
              style={{
                background: queryType === 'createCardTotalNum' ? choosedColor : '',
                cursor: 'pointer',
              }}
            >
              <div>制卡调用总次数</div>
              <div className={styles.dashboardItem}>
                <h2>{totalCreateCardNum}次</h2>
              </div>
            </div>
            <div
              className={styles.monitorDashboard}
              onClick={() => changeQuery('dataReportColumns')}
              style={{
                background: queryType === 'createCardTotalNum' ? '' : choosedColor,
                cursor: 'pointer',
              }}
            >
              <div>数据上传平均时间</div>
              <div className={styles.dashboardItem}>
                <h2>{dataReportTimeAvg}秒</h2>
              </div>
            </div>
          </div>
        </Card>

        <Card style={{ marginTop: 15 }}>
          <Button
            type="primary"
            style={{ marginBottom: '10px' }}
            onClick={() => exportTable(queryType)}
          >
            导出
          </Button>

          <OYOTable
            rowKey="key"
            ref={re => {
              this.oyotable = re;
            }}
            bordered
            size="small"
            params={tableParams}
            pageParams={pageParams}
            columns={detailColumns[columnsType]}
            getList={
              queryType === 'createCardTotalNum'
                ? getCreateCardRequestDetailList
                : getOpenLockDetailList
            }
            preventGetList
          />
        </Card>
      </PageHeaderWrapper>
    );
  }
}
