import React, { PureComponent } from 'react';
import { Card, Button, Row, Col, Table, message } from 'antd';
import { connect } from 'dva';
import router from 'umi/router';
import moment from 'moment';

import PageHeaderWrapper from '@/components/PageHeaderWrapper';
import OYOTable from '@/components/OyoTable/OyoTable.tsx';
import ButtonAuthorized from '@/components/ButtonAuthorized';
import { downloadFile } from '@/utils/downloadFile';
import getUUID from '@/utils/uuid';

import styles from '../../index.less';
import { queryEarngingsRoomDetail, queryEarngingsOpenDetail } from '../sevices/index';

export default class ProfitMonitorDetail extends PureComponent {
  constructor(props) {
    super(props);
    this.state = {
      tableParams: {
        startDate: '',
        endDate: '',
        hotelId: '',
        brand: '',
      },
      pageParams: ['pageNum', 'pageSize'],

      hotelDetailInfo: [],

      exceptionRoomNum: 0,
      exceptionOpenNum: 0,

      profitDataSourse: [],
      queryType: 'abnormalRoom',
      columnsType: 'abnormalRoomsColumns',
    };

    this.hotelInfoColumns = [
      {
        title: '酒店区域',
        dataIndex: 'areaName',
        key: 'areaName',
      },
      {
        title: '协议类型',
        dataIndex: 'hotelTag',
        key: 'hotelTag',
      },
      {
        title: '酒店ID',
        dataIndex: 'hotelId',
        key: 'hotelId',
      },
      {
        title: '酒店名称',
        dataIndex: 'hotelName',
        key: 'hotelName',
      },
      {
        title: 'OYO ID',
        dataIndex: 'oyoId',
        key: 'oyoId',
      },
      {
        title: '品牌名称',
        dataIndex: 'brandName',
        key: 'brandName',
      },
    ];
    this.profitDetailColumns = {
      abnormalRoomsColumns: [
        {
          title: '房间号',
          dataIndex: 'roomNo',
          key: 'roomNo',
          render: roomNo => roomNo || '-',
        },
        {
          title: '收益泄露状态',
          dataIndex: 'statusName',
          key: 'statusName',
          render: statusName => statusName || '-',
        },
        {
          title: '异常开门次数',
          dataIndex: 'exceptionOpenNumDesc',
          key: 'exceptionOpenNumDesc',
          render: exceptionOpenNumDesc => exceptionOpenNumDesc || '-',
        },
      ],
      abnormalOpeningColumns: [
        {
          title: '房间号',
          dataIndex: 'roomNo',
          key: 'roomNo',
          render: roomNo => roomNo || '-',
        },
        {
          title: '收益泄露状态',
          dataIndex: 'statusName',
          key: 'statusName',
          render: statusName => statusName || '-',
        },
        {
          title: '开门方式',
          dataIndex: 'openTypeDesc',
          key: 'openTypeDesc',
          render: openTypeDesc => openTypeDesc || '-',
        },
        {
          title: '未在入住时间开门',
          dataIndex: 'isNotCheckInTimeDesc',
          key: 'isNotCheckInTimeDesc',
        },
        {
          title: '异常开门时间-上次离店时间差',
          dataIndex: 'diffLastCheckOutDesc',
          key: 'diffLastCheckOutDesc',
          render: diffLastCheckOutDesc => diffLastCheckOutDesc || '-',
        },
      ],
    };
  }

  componentDidMount() {
    let arr = [];
    let { tableParams, queryType } = this.state;
    const { query } = this.props.location;

    if (query) {
      let { startDate, endDate, hotelId, brand, exceptionRoomNum, exceptionOpenNum } = query;

      arr.push(query);
      this.setState(
        {
          hotelDetailInfo: arr,
          exceptionRoomNum,
          exceptionOpenNum,
          tableParams: {
            ...tableParams,
            startDate,
            endDate,
            hotelId,
            brand,
          },
        },
        () => {
          this.oyotable.getPageList();
        }
      );
    } else {
      return message.warning('无数据');
    }
  }

  getEarngingsRoomDetail = params => {
    return queryEarngingsRoomDetail(params)
      .then(res => {
        if (res && res.data && Array.isArray(res.data.list)) {
          let { total } = res.data;
          let result = res.data.list.map((item, index) => {
            return { ...item, key: getUUID() };
          });
          return { data: result || [], total };
        }
      })
      .catch(err => {
        console.log(err);
      });
  };

  getEarngingsOpenDetail = params => {
    return queryEarngingsOpenDetail(params)
      .then(res => {
        if (res && res.data && Array.isArray(res.data.list)) {
          let { total } = res.data;
          let result = res.data.list.map((item, index) => {
            return { ...item, key: getUUID() };
          });
          return { data: result || [], total };
        }
      })
      .catch(err => {
        console.log(err);
      });
  };

  changeQuery = columnsName => {
    let { tableParams, queryType, columnsType } = this.state;

    this.setState(
      {
        queryType: columnsName === 'abnormalRoomsColumns' ? 'abnormalRoom' : 'abnormalOpen',
        columnsType: columnsName,
      },
      () => {
        this.oyotable.getPageList();
      }
    );
  };

  exportTable = queryType => {
    const roomExportUrl = '/api/crs/report/exportEarngingsReportRoomDetail';
    const openExportUrl = '/api/crs/report/exportEarngingsReportOpenDetail';
    let exportUrl = queryType === 'abnormalRoom' ? roomExportUrl : openExportUrl;

    downloadFile(exportUrl, {
      ...this.state.tableParams,
      'Content-Type': ' application/json',
    });
  };

  render() {
    const {
      hotelInfoColumns,
      profitDetailColumns,
      changeQuery,
      exportTable,
      getEarngingsRoomDetail,
      getEarngingsOpenDetail,
    } = this;
    const {
      tableParams,
      pageParams,
      hotelDetailInfo,
      queryType,
      profitDataSourse,
      columnsType,
      exceptionRoomNum,
      exceptionOpenNum,
    } = this.state;
    const choosedColor = '#ff000024';

    return (
      <PageHeaderWrapper>
        <Card>
          <Table
            rowKey="hotelId"
            dataSource={hotelDetailInfo}
            columns={hotelInfoColumns}
            pagination={false}
          />
        </Card>
        <Card style={{ marginTop: '10px' }}>
          <h3>收益泄露预警</h3>
          <div className={styles.row}>
            <div
              className={styles.monitorDashboard}
              onClick={() => changeQuery('abnormalRoomsColumns')}
              style={{
                background: queryType === 'abnormalRoom' ? choosedColor : '',
                cursor: 'pointer',
              }}
            >
              <div>异常房间数</div>
              <div className={styles.dashboardItem}>
                <h2>{exceptionRoomNum}间</h2>
              </div>
            </div>
            <div
              className={styles.monitorDashboard}
              onClick={() => changeQuery('abnormalOpeningColumns')}
              style={{
                background: queryType === 'abnormalRoom' ? '' : choosedColor,
                cursor: 'pointer',
              }}
            >
              <div>异常开门数</div>
              <div className={styles.dashboardItem}>
                <h2>{exceptionOpenNum}次</h2>
              </div>
            </div>
          </div>
        </Card>

        <Card style={{ marginTop: 15 }}>
          <Button
            type="primary"
            style={{ marginBottom: '10px' }}
            onClick={() => exportTable(queryType)}
          >
            导出
          </Button>
          <OYOTable
            rowKey="key"
            ref={re => {
              this.oyotable = re;
            }}
            bordered
            size="small"
            params={tableParams}
            pageParams={pageParams}
            columns={profitDetailColumns[columnsType]}
            getList={queryType === 'abnormalRoom' ? getEarngingsRoomDetail : getEarngingsOpenDetail}
            preventGetList
          />
        </Card>
      </PageHeaderWrapper>
    );
  }
}
