import React, { PureComponent } from 'react';
import { Card, Button, Form, Select, Row, Col, Table, message, DatePicker, Radio } from 'antd';
import router from 'umi/router';
import { connect } from 'dva';
import moment from 'moment';

import { rowProps, col1Props, formItemLayout, widthStyle } from '@/utils/formProps';
import { HOTEL_STATUS, getNameFromStatus } from '@/constant/hotelStatus';
import { COOPERATION_TYPE } from '@/constant/cooperationType';
import { dashboardHotelInfo } from './sevices/index';
import styles from '../index.less';

const Option = Select.Option;
const FormItem = Form.Item;
const { RangePicker } = DatePicker;

const cooperationTypeOption = function() {
  return COOPERATION_TYPE.map((item, key) => (
    <Option value={item.value} key={`COOPERATION_TYPE-${key}`}>
      {item.type}
    </Option>
  ));
};

const hotelStatusOption = function() {
  return HOTEL_STATUS.map((item, key) => (
    <Option value={item.status} key={`HOTEL_STATUS-${key}`}>
      {item.name}
    </Option>
  ));
};

const dateFormat = 'YYYY-MM-DD';

export default class SmartDoorLock extends PureComponent {
  constructor(props) {
    super(props);
    this.state = {
      // 查询条件的参数
      dashboardParams: {
        china2: null,
        hotelStatus: null,
        startDate: moment().format(dateFormat),
        endDate: moment().format(dateFormat),
      },
      chooseDuration: 'today',
      rangeDateValue: [],

      // 智能门锁设备数据
      smartHotelNum: 0,
      smartRoomLockNum: 0,
      warnSmartHotelNum: 0,
      warnSmartRoomLockNum: 0,
      // 硬件性稳定监控数据
      openLockDataReportTimeAvg: 0,
      createCardSuccessRate: 0,
      // 收益预警泄露监控数据
      normalHotelNum: 0,
      exceptionHotelNum: 0,
      normalRoomNum: 0,
      exceptionRoomNum: 0,
    };
  }

  componentDidMount() {
    this.getDashboardHotelInfo(this.state.dashboardParams);
  }

  handleSelectChange = (val, key) => {
    let { dashboardParams } = this.state;

    this.setState({
      dashboardParams: {
        ...dashboardParams,
        [key]: val,
      },
    });
  };

  getFirstEndDay = key => {
    let date = {
      startDate: '',
      endDate: '',
    };

    date.startDate =
      key !== 'today'
        ? moment()
            .startOf(key)
            .format(dateFormat)
        : moment().format(dateFormat);
    date.endDate = moment().format(dateFormat);

    return date;
  };

  handleDateChange = e => {
    let { value } = e.target;

    let { chooseDuration, dashboardParams } = this.state;
    this.setState({
      chooseDuration: value,
      rangeDateValue: [],
      dashboardParams: {
        ...dashboardParams,
        ...this.getFirstEndDay(value),
      },
    });
  };

  handleRangePickerChange = (date, dateString) => {
    let { dashboardParams, rangeDateValue } = this.state;
    let { startDate, endDate } = this.state.dashboardParams;
    if (date.length) {
      this.setState({
        chooseDuration: '',
        rangeDateValue: date,
        dashboardParams: {
          ...dashboardParams,
          startDate: date[0].format(dateFormat),
          endDate: date[1].format(dateFormat),
        },
      });
    } else {
      this.setState({
        chooseDuration: 'today',
      });
    }
  };

  getDashboardHotelInfo = params => {
    dashboardHotelInfo(params)
      .then(res => {
        if (res && res.data) {
          let {
            smartHotelNum,
            smartRoomLockNum,
            warnSmartHotelNum,
            warnSmartRoomLockNum,
            openLockDataReportTimeAvg,
            createCardSuccessRate,
            normalHotelNum,
            exceptionHotelNum,
            normalRoomNum,
            exceptionRoomNum,
          } = res.data;

          this.setState({
            smartHotelNum,
            smartRoomLockNum,
            warnSmartHotelNum,
            warnSmartRoomLockNum,
            openLockDataReportTimeAvg,
            createCardSuccessRate,
            normalHotelNum,
            exceptionHotelNum,
            normalRoomNum,
            exceptionRoomNum,
          });
        }
      })
      .catch(err => {
        console.log(err);
      });
  };

  query = () => {
    this.getDashboardHotelInfo(this.state.dashboardParams);
  };

  reset = () => {
    this.setState(
      {
        chooseDuration: 'today',
        rangeDateValue: [],
        dashboardParams: {
          china2: null,
          hotelStatus: null,
          startDate: moment().format(dateFormat),
          endDate: moment().format(dateFormat),
        },
      },
      () => {
        this.getDashboardHotelInfo(this.state.dashboardParams);
      }
    );
  };

  toTableInfo = (key, type) => {
    let { dashboardParams } = this.state;
    let pathName = '';

    if (key === 'smartHotelNum' || key === 'warnSmartHotelNum') {
      pathName = '/equipment/dataDashboard/equipmentMonitor';
    }
    if (key === 'openLockDataReportTimeAvg' || key === 'createCardSuccessRate') {
      pathName = '/equipment/dataDashboard/hardwareMonitor';
    }
    if (key === 'normalHotelNum' || key === 'exceptionHotelNum') {
      pathName = '/equipment/dataDashboard/profitMonitor';
    }
    router.push({
      pathname: pathName,
      query: {
        ...dashboardParams,
        hotelLockStatus: typeof type === 'string' ? type : '',
        status: typeof type === 'number' ? type : '',
      },
    });
  };

  render() {
    const { handleSelectChange, handleDateChange, handleRangePickerChange, query, reset } = this;

    const {
      dashboardParams,
      smartHotelNum,
      warnSmartHotelNum,
      smartRoomLockNum,
      warnSmartRoomLockNum,
      openLockDataReportTimeAvg,
      createCardSuccessRate,
      normalHotelNum,
      exceptionHotelNum,
      normalRoomNum,
      exceptionRoomNum,

      rangeDateValue,
    } = this.state;
    let { china2, hotelStatus } = dashboardParams;

    const disabledDate = current => {
      return (
        current && (current > moment().endOf('day') || current < moment().subtract(3, 'months'))
      );
    };

    return (
      <>
        <Card>
          <Form layout="inline">
            <Row {...rowProps}>
              <Col
                lg={{
                  span: 24,
                }}
                xl={{
                  span: 12,
                }}
                xxl={{
                  span: 8,
                }}
              >
                <FormItem style={widthStyle} label="酒店协议类型" {...formItemLayout}>
                  <Select
                    style={{
                      minWidth: '300px',
                    }}
                    placeholder="请选择协议类型"
                    value={china2}
                    onChange={e => handleSelectChange(e, 'china2')}
                  >
                    {cooperationTypeOption()}
                  </Select>
                </FormItem>
              </Col>
              <Col
                lg={{
                  span: 24,
                }}
                xl={{
                  span: 12,
                }}
                xxl={{
                  span: 8,
                }}
              >
                <FormItem style={widthStyle} label="酒店状态" {...formItemLayout}>
                  <Select
                    style={{
                      minWidth: '300px',
                    }}
                    placeholder="请选择酒店状态"
                    value={hotelStatus}
                    onChange={e => handleSelectChange(e, 'hotelStatus')}
                  >
                    {hotelStatusOption()}
                  </Select>
                </FormItem>
              </Col>
            </Row>
            <Row
              {...rowProps}
              style={{
                display: 'flex',
                justifyContent: 'center',
                marginRight: '20%',
                marginTop: '10px',
              }}
            >
              <Col
                lg={{
                  span: 24,
                }}
                xl={{
                  span: 12,
                }}
                xxl={{
                  span: 8,
                }}
              >
                <Radio.Group
                  value={this.state.chooseDuration}
                  defaultValue="today"
                  onChange={handleDateChange}
                  style={{
                    marginTop: '5px',
                  }}
                >
                  <Radio.Button
                    value="today"
                    style={{
                      width: '100px',
                      textAlign: 'center',
                    }}
                  >
                    今天
                  </Radio.Button>
                  <Radio.Button
                    value="week"
                    style={{
                      width: '100px',
                      textAlign: 'center',
                    }}
                  >
                    本周
                  </Radio.Button>
                  <Radio.Button
                    value="month"
                    style={{
                      width: '100px',
                      textAlign: 'center',
                    }}
                  >
                    本月
                  </Radio.Button>
                  {/* <Radio.Button
                    value="year"
                    style={{
                      width: '100px',
                      textAlign: 'center',
                    }}
                  >
                    本年
                  </Radio.Button> */}
                </Radio.Group>
              </Col>
              <Col
                lg={{
                  span: 24,
                }}
                xl={{
                  span: 12,
                }}
                xxl={{
                  span: 8,
                }}
              >
                <FormItem style={widthStyle} {...formItemLayout}>
                  <RangePicker
                    format="YYYY-MM-DD"
                    value={rangeDateValue}
                    disabledDate={disabledDate}
                    onChange={handleRangePickerChange}
                  />
                </FormItem>
              </Col>
            </Row>
          </Form>

          <Row
            {...rowProps}
            style={{
              textAlign: 'center',
              marginTop: '20px',
            }}
          >
            <Col {...col1Props}>
              <Button type="primary" onClick={query}>
                查询
              </Button>
              <Button
                onClick={reset}
                style={{
                  marginLeft: 20,
                }}
              >
                重置
              </Button>
            </Col>
          </Row>
        </Card>
        <Card
          style={{
            marginTop: '10px',
          }}
        >
          <h3> 智能门锁设备监控</h3>
          <div className={styles.row}>
            <div className={styles.monitorDashboard}>
              <div> 智能锁酒店数量</div>
              <div className={styles.dashboardItem}>
                <h2> {smartHotelNum}家</h2>
              </div>
              <div className={styles.dashboardItem}>
                <Button
                  onClick={() => {
                    this.toTableInfo('smartHotelNum', '');
                  }}
                >
                  查看
                </Button>
              </div>
            </div>
            <div className={styles.monitorDashboard}>
              <div> 智能锁预警酒店数量</div>
              <div className={styles.dashboardItem}>
                <h2> {warnSmartHotelNum}家</h2>
              </div>
              <div className={styles.dashboardItem}>
                <Button
                  onClick={() => {
                    this.toTableInfo('warnSmartHotelNum', 'VOLT_LOW');
                  }}
                >
                  查看
                </Button>
              </div>
            </div>
          </div>
          <div className={styles.row}>
            <div className={styles.monitorDashboard}>
              <div> 智能锁房间数量</div>
              <div className={styles.dashboardItem}>
                <h2> {smartRoomLockNum}间</h2>
              </div>
            </div>
            <div className={styles.monitorDashboard}>
              <div> 智能锁预警房间数量</div>
              <div className={styles.dashboardItem}>
                <h2> {warnSmartRoomLockNum}间</h2>
              </div>
            </div>
          </div>
        </Card>
        <Card
          style={{
            marginTop: '10px',
          }}
        >
          <h3> 硬件稳定性监控</h3>
          <div className={styles.row}>
            <div className={styles.monitorDashboard}>
              <div> 制卡成功率</div>
              <div className={styles.dashboardItem}>
                <h2> {createCardSuccessRate} %</h2>
              </div>
              <div className={styles.dashboardItem}>
                <Button
                  onClick={() => {
                    this.toTableInfo('createCardSuccessRate', '');
                  }}
                >
                  查看
                </Button>
              </div>
            </div>
            <div className={styles.monitorDashboard}>
              <div> 数据上传平均时间</div>
              <div className={styles.dashboardItem}>
                <h2>{openLockDataReportTimeAvg}秒</h2>
              </div>
              <div className={styles.dashboardItem}>
                <Button
                  onClick={() => {
                    this.toTableInfo('openLockDataReportTimeAvg', '');
                  }}
                >
                  查看
                </Button>
              </div>
            </div>
          </div>
        </Card>
        <Card
          style={{
            marginTop: '10px',
          }}
        >
          <h3> 收益泄露预警监控</h3>
          <div className={styles.row}>
            <div className={styles.monitorDashboard}>
              <div> 正常酒店数量</div>
              <div className={styles.dashboardItem}>
                <h2> {normalHotelNum}家</h2>
              </div>
              <div className={styles.dashboardItem}>
                <Button
                  onClick={() => {
                    this.toTableInfo('normalHotelNum', 0);
                  }}
                >
                  查看
                </Button>
              </div>
            </div>
            <div className={styles.monitorDashboard}>
              <div> 异常酒店数量</div>
              <div className={styles.dashboardItem}>
                <h2> {exceptionHotelNum}家</h2>
              </div>
              <div className={styles.dashboardItem}>
                <Button
                  onClick={() => {
                    this.toTableInfo('exceptionHotelNum', 1);
                  }}
                >
                  查看
                </Button>
              </div>
            </div>
            <div className={styles.monitorDashboard}>
              <div> 正常房间数量</div>
              <div className={styles.dashboardItem}>
                <h2> {normalRoomNum}间</h2>
              </div>
              <div className={styles.dashboardItem} style={{ opacity: '0' }}>
                <Button>查看</Button>
              </div>
            </div>
            <div className={styles.monitorDashboard}>
              <div> 异常房间数量</div>
              <div className={styles.dashboardItem}>
                <h2> {exceptionRoomNum}间</h2>
              </div>
              <div className={styles.dashboardItem} style={{ opacity: '0' }}>
                <Button>查看</Button>
              </div>
            </div>
          </div>
        </Card>
      </>
    );
  }
}
