import React, { PureComponent } from 'react';
import { connect } from 'dva';
import moment from 'moment';
import OYOTable from '@/components/OyoTable/OyoTable.tsx';
import { queryLimitPriceLog } from '../service/index';
import getUUID from '@/utils/uuid';

const STATUS_TYPE = [
  {
    label: '待执行',
    color: '#FFCC00',
    value: '0',
  },
  {
    label: '已完成',
    color: '#336600',
    value: '1',
  },
  {
    label: '执行失败',
    color: '#F5222D',
    value: '2',
  },
  {
    label: '失效',
    color: '#F5222D',
    value: '3',
  },
  {
    label: '执行中',
    color: '#FFCC00',
    value: '4',
  },
];

@connect(({ user }) => ({
  user,
}))
export default class batchResults extends PureComponent {
  oyotable = null;

  constructor(props) {
    super(props);
    this.state = {
      tableParams: {},
      pageParams: ['pageNum', 'pageSize'],
    };
  }

  componentDidMount() {
    // 默认请求：初始结果列表
    this.oyotable.getPageList();
  }

  componentWillReceiveProps(nextProps) {
    if (!this.props.isActive && nextProps.isActive) {
      this.oyotable.getPageList();
    }
  }

  // 请求：获取结果列表数据
  getResultsList = params =>
    queryLimitPriceLog(params)
      .then(res => {
        if (res.data) {
          let { result, totalCount } = res.data;
          let arr = [];
          if (Array.isArray(result)) {
            console.log('限价日志', result);
            result.forEach(item => {
              let { dateRange, dayRange, hotelRange } = item.restrictDisplayDetail;
              let { maxRate } = item.restrictRule;
              arr.push({
                dateRange,
                dayRange,
                hotelRange,
                maxRate: `${maxRate}元`,
                operateTime: item.operateTime,
                operatorId: item.operatorId,
                operatorName: item.operatorName,
                status: item.status,
                uuid: getUUID(),
              });
              return arr;
            });
          }
          return { data: arr || [], total: totalCount };
        }
      })
      .catch(err => {
        console.log(err);
      });

  render() {
    const { tableParams, pageParams } = this.state;
    const { loading } = this.props;
    const preventGetList = true;
    const OYOTableColumns = [
      {
        title: '操作人',
        dataIndex: 'operatorName',
        key: 'operatorName',
        width: '10%',
      },
      {
        title: '操作时间',
        dataIndex: 'operateTime',
        key: 'operateTime',
        width: '15%',
      },
      {
        title: '修改范围',
        dataIndex: 'hotelRange',
        key: 'hotelRange',
        width: '20%',
        render: hotelRange => {
          return (
            <span style={{ wordWrap: 'break-word', wordBreak: 'break-all' }}>{hotelRange}</span>
          );
        },
      },
      {
        title: '修改日期',
        dataIndex: 'dateRange',
        key: 'dateRange',
        width: '15%',
      },
      {
        title: '日期策略',
        dataIndex: 'dayRange',
        key: 'dayRange',
        width: '20%',
      },
      {
        title: '修改限价',
        dataIndex: 'maxRate',
        key: 'maxRate',
        width: '10%',
      },
      {
        title: '执行结果',
        dataIndex: 'status',
        key: 'status',
        width: '10%',
        render: status => {
          let { label, value, color } = STATUS_TYPE[status];
          return <p style={{ color: `${color}` }}>{label}</p>;
        },
      },
    ];

    return (
      <>
        <OYOTable
          ref={re => {
            this.oyotable = re;
          }}
          rowKey={record => record.uuid}
          bordered
          size="small"
          loading={loading}
          params={tableParams}
          pageParams={pageParams}
          columns={OYOTableColumns}
          getList={this.getResultsList}
          preventGetList={preventGetList}
        />
      </>
    );
  }
}
