import React, { PureComponent } from 'react';
import {
  Tabs,
  Card,
  Button,
  Form,
  Input,
  Select,
  Row,
  Col,
  Badge,
  Table,
  message,
  Radio,
  Checkbox,
  Tag,
  Icon,
  DatePicker,
  Modal,
} from 'antd';
import router from 'umi/router';
import { connect } from 'dva';
import moment from 'moment';
import PageHeaderWrapper from '@/components/PageHeaderWrapper';
import CitySelect from '@/components/CitySelect';
import MultiSelection from '@/components/MultiSelection/MultiSelection';
import config from '@/components/Exception/typeConfig';
import OYOTable from '@/components/OyoTable/OyoTable.tsx';
import {
  WEEK_LIST,
  DateFiliter,
  transDefaultList,
  transWeeklyList,
  getDisableList,
  transListToStr,
} from '@/utils/dateFiliterWeekday';
import ButtonAuthorized from '@/components/ButtonAuthorized';
import styles from './index.less';
import { checkOyoId, commitLimitPrice } from './service/index';
import { BatchResults } from './components/index';

const TabPane = Tabs.TabPane;
const RadioGroup = Radio.Group;
const CheckboxGroup = Checkbox.Group;
const { Option } = Select;
const { TextArea } = Input;
const { MonthPicker, RangePicker } = DatePicker;

const dateFormat = 'YYYY-MM-DD';

export default class BasePriceIndex extends PureComponent {
  constructor(props) {
    super(props);
    this.state = {
      activeTab: '1',
      slideName: '展开',
      slideType: 'down',
      currentArea: [],
      chosenArr: [],
      oyoIds: [],
      chosenIds: [],
      codeText: '',
      dateListNum: [{ key: 0, value: [] }],

      dateList: [],
      weekly: [],
      limitPrice: null,
      weekDisableList: [],

      zoneIds: [],
      hubIds: [],
      cityIds: [],

      submitVisible: false,
      dialogReginNames: [],
      dialogDateScope: [],
    };
  }

  componentDidMount() {}

  areaChange = (v, currentArea) => {
    this.setState({
      currentArea: currentArea.concat([]),
    });
  };

  addArea = e => {
    e.preventDefault();
    let { chosenArr, currentArea } = this.state;
    if (currentArea.length === 0) {
      return message.warning('请选择区域！');
    }
    let currentO = currentArea[currentArea.length - 1];
    let key = '';

    switch (currentArea.length) {
      case 1:
        key = 'zoneIds';
        break;
      case 2:
        key = 'hubIds';
        break;
      case 3:
        key = 'cityIds';
        break;
      default:
        key = '';
    }

    chosenArr.push({ ...currentO });
    this.setState({
      chosenArr: [...chosenArr],
      [key]: this.state[key].concat(currentO.value),
    });
  };

  inputText = e => {
    const { value } = e.target;
    this.setState({
      codeText: value,
    });
  };

  addTextCode = e => {
    e.preventDefault();
    let { codeText } = this.state;
    let arr = [];
    arr = codeText.split(/\n/);
    arr = arr.filter(item => {
      return item !== '';
    });
    arr = arr.map(item => item.replace(/\s+/g, '').replace(/，+/g, ''));
    arr = arr.map(item => item.replace(/\s+/g, '').replace(/,+/g, ''));

    this.setState({
      oyoIds: arr,
    });

    let ids = arr.join(',');

    if (!arr.length) {
      return message.warning('请填写OYO ID');
    }
    if (arr.length > 100) {
      return message.error('OYO Id不能超过100条！');
    }
    if (arr.length <= 100 && arr.length > 0) {
      checkOyoId({ oyoIds: ids })
        .then(res => {
          if (res.data.result) {
            this.setState({
              chosenIds: this.state.chosenIds.concat(arr),
            });
            message.success('添加OYO ID成功！');
          } else {
            message.error('请填写有效的OYO ID');
          }
        })
        .catch(err => {
          console.log(err);
        });
    }
  };

  delRegionTags = (e, item, i) => {
    e.preventDefault();
    let { chosenArr, currentArea } = this.state;
    let currentO = currentArea[currentArea.length - 1];
    // let key = '';

    // switch (currentArea.length) {
    //   case 1:
    //     key = 'zoneIds';
    //     break;
    //   case 2:
    //     key = 'hubIds';
    //     break;
    //   case 3:
    //     key = 'cityIds';
    //     break;
    //   default:
    //     key = '';
    // }

    chosenArr.splice(i, 1);

    const { zoneIds, hubIds, cityIds } = this.state;

    let spliceIndex = null;
    let key = '';
    const zoneIdsIndex = zoneIds.findIndex(val => val === item.value);
    const hubIdsIndex = hubIds.findIndex(val => val === item.value);
    const cityIdsIndex = cityIds.findIndex(val => val === item.value);

    if (zoneIdsIndex > -1) {
      spliceIndex = zoneIdsIndex;
      key = 'zoneIds';
    }

    if (hubIdsIndex > -1) {
      spliceIndex = hubIdsIndex;
      key = 'hubIds';
    }

    if (cityIdsIndex > -1) {
      spliceIndex = cityIdsIndex;
      key = 'cityIds';
    }

    const list = this.state[key].slice();
    list.splice(spliceIndex, 1);

    this.setState({
      chosenArr: [...chosenArr],
      [key]: list,
    });

    if (!chosenArr.length) {
      this.setState({
        [key]: [],
      });
    }
  };

  delIdsTags = (e, item, i) => {
    e.preventDefault();
    let { chosenIds } = this.state;
    chosenIds.splice(i, 1);
    this.setState({
      chosenIds: [...chosenIds],
    });
  };

  handleSlide = name => {
    this.setState({
      slideName: name === '展开' ? '收起' : '展开',
      slideType: name === '展开' ? 'up' : 'down',
    });
  };

  addDateSel = e => {
    e.preventDefault();
    let { dateListNum } = this.state;
    let newVal = dateListNum[dateListNum.length - 1].key + 1;
    dateListNum.push({ key: newVal, value: [] });
    this.setState({
      dateListNum: dateListNum.concat([]),
    });
  };

  delDateSel = (e, i) => {
    e.preventDefault();
    let { dateListNum } = this.state;
    dateListNum.splice(i, 1);

    let dateList = this.setDateList(dateListNum);
    this.setWeekSel(dateList);
    this.setState({
      dateListNum: [...dateListNum],
      dateList: [...dateList],
    });
  };

  dateChange = (timeArr, i) => {
    let { weekly, dateListNum } = this.state;

    if (timeArr.length !== 0) {
      let obj = [moment(timeArr[0]).format(dateFormat), moment(timeArr[1]).format(dateFormat)];
      dateListNum[i].value = obj;
    } else {
      dateListNum[i].value = [];
    }

    let dateList = this.setDateList(dateListNum);
    this.setWeekSel(dateList);
    this.setState({
      dateListNum: [...dateListNum],
      dateList: [...dateList],
    });
  };

  // 设置dateList
  setDateList(data) {
    let dateList = [];
    data.forEach(v => {
      if (v.value.length !== 0) {
        dateList.push(v.value);
      }
    });
    return dateList;
  }

  setWeekSel = data => {
    const weekly = DateFiliter.handleSection(data);
    const weekDisableList = getDisableList(weekly);

    this.setState({
      weekly: [...weekly],
      weekDisableList,
    });
  };

  onWeekList = (name, listIndex) => {
    this.setState({
      weekly: transWeeklyList(listIndex),
    });
  };

  limitPrice = e => {
    let { value } = e.target;

    if (!/^\d*$/.test(value)) return;

    this.setState({
      limitPrice: value,
    });
  };

  submitPrice = () => {
    let {
      chosenArr,
      chosenIds,
      dateList,
      weekly,
      limitPrice,
      zoneIds,
      hubIds,
      cityIds,
    } = this.state;
    let regionNames = [];

    let dateScope = [];
    chosenArr.forEach(item => {
      regionNames.push(item.label);
    });
    dateList.forEach(item => {
      dateScope.push({
        startDate: item[0],
        endDate: item[1],
      });
    });

    let params = {
      zoneIds,
      hubIds,
      cityIds,
      regionNames,
      oyoIds: chosenIds,
      dateScope,
      activeDay: weekly,
      limitPrice,
    };
    if (regionNames.length || chosenIds.length) {
      if (!(dateScope.length && params.activeDay.length && limitPrice)) {
        return message.warning('请完善要提交的限价信息！');
      }

      if (limitPrice > 9999 || limitPrice < 20) {
        return message.warning('请输入符合限价范围的价格');
      }

      commitLimitPrice(params)
        .then(res => {
          if (res.code === '000') {
            message.success('修改限价成功！');
          }
        })
        .catch(e => {
          console.log(e);
        });
    } else {
      message.warning('请选择要改价的区域或者输入要改价的酒店id!');
    }
  };

  handleSubmit = () => {
    this.setState({
      submitVisible: true,
    });
    let { chosenArr, dateList, dialogReginNames, dialogDateScope } = this.state;
    let regionNames = [];
    let dateScope = [];

    chosenArr.forEach(item => {
      regionNames.push(item.label);
    });
    dateList.forEach(item => {
      dateScope.push({
        startDate: item[0],
        endDate: item[1],
      });
    });

    this.setState({
      dialogReginNames: regionNames,
      dialogDateScope: dateScope,
    });
  };

  handleOk = e => {
    this.setState({
      submitVisible: false,
    });
    this.submitPrice();
  };

  handleCancel = e => {
    this.setState({
      submitVisible: false,
    });
  };

  showDialogRegionName = arr => {
    let str = arr.join(',');
    str = str.length > 200 ? `${str.slice(0, 100)}...` : str;
    return str;
  };

  showDialogDate = arr => {
    return (
      <ul>
        {arr.map((item, index) => (
          <li key={index}>
            {item.startDate} ~ {item.endDate}
          </li>
        ))}
      </ul>
    );
  };

  showDialogWeek = arrRes => {
    return transListToStr(arrRes);
  };

  tabChange = tab => {
    this.setState({
      activeTab: tab,
    });
  };

  render() {
    const {
      slideName,
      slideType,
      chosenArr,
      chosenIds,
      dateListNum,
      weekDisableList,
      activeTab,
      weekly,
      limitPrice,
      dialogReginNames,
      dialogDateScope,
    } = this.state;
    const slideStyle = { height: slideType === 'up' ? 'auto' : '60px' };
    const preventGetList = true;
    const disabledDate = current =>
      current && (current < moment().endOf('day') || current > moment().add(2, 'year'));

    return (
      <PageHeaderWrapper>
        <Card>
          <Tabs defaultActiveKey="1" onChange={this.tabChange}>
            <TabPane tab="修改限价" key="1" className={styles.basePriceSPage}>
              <div>
                <div className={`${styles.basePriceStayType}`}>
                  <p>选择入住类型: </p>
                  <RadioGroup value={1}>
                    <Radio value={1}>全日房</Radio>
                  </RadioGroup>
                </div>
                <hr />
                <Row>
                  <Col md={12} sm={12}>
                    <p className={`${styles.pageTitle}`}>区域选择:</p>
                    <CitySelect
                      style={{ width: '250px', marginRight: '10px' }}
                      type="cityList"
                      onChange={this.areaChange}
                      changeOnSelect
                      ref={re => {
                        this.citySelect = re;
                      }}
                    />
                    <Button type="primary" onClick={this.addArea}>
                      增加区域
                    </Button>
                  </Col>
                  <Col md={12} sm={12}>
                    <p className={`${styles.pageTitle}`}>OYO ID：</p>

                    <TextArea
                      rows={3}
                      style={{
                        width: '180px',
                        height: '70px',
                        marginRight: '10px',
                      }}
                      onChange={this.inputText}
                      placeholder="请输入CN开头的酒店ID,批量添加每行1个ID,最大可一次增加100条"
                    />
                    <Button
                      type="primary"
                      onClick={this.addTextCode}
                      style={{ marginBottom: '40px' }}
                    >
                      增加酒店
                    </Button>
                  </Col>
                </Row>
                <div className={`${styles.pageTitle}`}>已选择需要修改的酒店范围：</div>
                <div style={slideStyle} className={`${styles.slideDiv}`}>
                  {chosenArr.map((item, i) => (
                    <Tag
                      color="#40b3a3"
                      closable
                      onClose={e => this.delRegionTags(e, item, i)}
                      key={i}
                    >
                      {item.label}
                    </Tag>
                  ))}
                  {chosenIds.map((item, index) => (
                    <Tag
                      color="#40b3a3"
                      closable
                      onClose={e => this.delIdsTags(e, item, index)}
                      key={index}
                    >
                      {item}
                    </Tag>
                  ))}
                </div>
                {!!(chosenArr.length + chosenIds.length > 20) && (
                  <div className={`${styles.slideBtn}`} onClick={() => this.handleSlide(slideName)}>
                    {slideName}
                    <Icon type={slideType} style={{ fontSize: 12, marginLeft: '5px' }} />
                  </div>
                )}
              </div>
              <div className={`${styles.pageTitle}`}>请选择需要修改的日期范围：</div>
              <div>
                {dateListNum.map((v, i) => (
                  <div key={v.key} className={`${styles.dateItem}`}>
                    <RangePicker
                      format={dateFormat}
                      onChange={e => this.dateChange(e, i)}
                      disabledDate={disabledDate}
                    />

                    {dateListNum.length > 1 && (
                      <Button
                        type="primary"
                        className={`${styles.delDateInput}`}
                        onClick={e => this.delDateSel(e, i)}
                      >
                        删除
                      </Button>
                    )}
                  </div>
                ))}

                <div className={`${styles.addDateBtn}`}>
                  <Button type="primary" onClick={this.addDateSel}>
                    增加日期范围
                  </Button>
                </div>
              </div>
              <div className={`${styles.pageTitle}`}>请勾选时间段内的生效日：</div>
              <div>
                <MultiSelection
                  ref={re => {
                    this.weekRef = re;
                  }}
                  disableList={transDefaultList(weekDisableList)}
                  value={transDefaultList(weekly)}
                  list={WEEK_LIST}
                  onChange={(list, listIndex) => this.onWeekList(list, listIndex)}
                />
              </div>
              <div className={`${styles.pageTitle}`}>请选择修改后的限价：</div>
              <div className={`${styles.priceInput}`}>
                <Input
                  addonAfter="元"
                  onChange={this.limitPrice}
                  value={limitPrice}
                  placeholder="20以上的整数"
                />
              </div>
              <Row className={`${styles.pageTitle}`} justify="center" type="flex">
                <ButtonAuthorized type="primary" code="CRS7.11.1" onClick={this.handleSubmit}>
                  提交修改
                </ButtonAuthorized>
              </Row>
              <div style={{ textAlign: 'center' }}>
                基准价高于限价的房型均将会被调整至限价，调整将于24小时内完成。
              </div>
            </TabPane>
            <TabPane tab="操作日志" key="2">
              <BatchResults isActive={activeTab === '2'} />
            </TabPane>
          </Tabs>
        </Card>

        <Modal
          title="请确认修改范围"
          visible={this.state.submitVisible}
          onOk={this.handleOk}
          onCancel={this.handleCancel}
        >
          <div style={{ display: 'flex' }}>
            <p>修改范围：</p>
            <div style={{ width: '400px', textAlign: 'left' }}>
              {this.showDialogRegionName(dialogReginNames)}
            </div>
          </div>
          <div style={{ display: 'flex' }}>
            <p>修改日期：</p>
            <div>{this.showDialogDate(dialogDateScope)}</div>
          </div>
          <div style={{ display: 'flex' }}>
            <p>日期策略：</p>
            <div>{this.showDialogWeek(weekly)}</div>
          </div>
          <p>修改限价：{limitPrice} 元</p>
        </Modal>
      </PageHeaderWrapper>
    );
  }
}
