import React, { PureComponent } from 'react';
import { connect } from 'dva';
import { Button, Modal, Row, Col, Table } from 'antd';
import OYOTable from '@/components/OyoTable/OyoTable.tsx';
import { queryResultsList } from '../services';
import moment from 'moment';

const OPERATE_TYPE = [
  {
    name: '批量新增',
    value: '0',
  },
  {
    name: '批量解除',
    value: '1',
  },
];

@connect(({ associate, user, loading }) => ({
  associate,
  user,
  loading: loading.models.associate,
}))
export default class batchResults extends PureComponent<any, any> {
  constructor(props) {
    super(props);
    this.state = {
      tableParams: {},
      pageParams: ['pageNo', 'pageSize'],
      detailsVisible: false,
      resultMsg: '',
    };
  }
  oyotable = null;

  componentDidMount() {
    // 默认请求：初始结果列表
    this.oyotable.getPageList();
  }

  // 请求：获取结果列表数据
  getResultsList = params =>
    queryResultsList(params)
      .then(res => {
        const { result, totalCount } = res.data;
        console.log('批量解除操作日志', res);
        if (Array.isArray(result)) {
          result.forEach((item, key) => {
            const ele = item;
            ele.key = key;
            ele.No = key + 1;
          });
        }

        return { data: result || [], total: totalCount };
      })
      .catch(err => {
        console.log(err);
      });

  // 请求：查看单条结果明细
  getDetailsList = params => {
    const { dispatch } = this.props;

    dispatch({
      type: 'associate/fetchDetailsList',
      payload: params,
    })
      .then(res => {
        if (res.code === '000') {
          this.setState({ detailsVisible: true });
        }
      })
      .catch(err => {
        console.log(err);
      });
  };

  // 操作：查看单条结果明细
  handleResults = (batchNo, status) => {
    console.log('status', status);
    if (status === 0) {
      this.setState({
        resultMsg: '批量处理成功！',
      });
    } else if (status === 2) {
      this.setState({
        resultMsg: '批量处理中！',
      });
    }
    this.getDetailsList({ batchNo });
  };

  // 操作：关闭单条结果明细
  handleDetailsCancel = () => {
    this.setState({ detailsVisible: false });
  };

  renderErrorList = () => {
    const { loading, associate } = this.props;
    const errorCode = [
      {
        title: '酒店代码',
        dataIndex: 'hotelId',
        key: 'hotelId',
      },
      {
        title: '渠道代码',
        dataIndex: 'channelId',
        key: 'channelId',
      },
      {
        title: '价格策略代码',
        dataIndex: 'rateCodeId',
        key: 'rateCodeId',
      },
    ];

    return (
      Array.isArray(associate) &&
      associate.map((item, index) => {
        const { oyoIdList, channelCodeList, rateCodeIdList } = item;

        let maxLength = Math.max(oyoIdList.length, channelCodeList.length, rateCodeIdList.length);
        let errorList: any[] = [...new Array(maxLength).keys()];
        errorList = errorList.map((item, index) => ({
          key: index,
          hotelId: oyoIdList[index] ? oyoIdList[index] : null,
          channelId: channelCodeList[index] ? channelCodeList[index] : null,
          rateCodeId: rateCodeIdList[index] ? rateCodeIdList[index] : null,
        }));
        console.log('errorList', errorList);

        return (
          <div key={index}>
            <Row style={{ marginBottom: 10 }}>
              <Col
                span={8}
                style={{ color: 'rgba(0, 0, 0, 0.85)', fontWeight: 500, padding: '8px' }}
              >
                {item.failTypeName}
              </Col>
              <Col span={16} style={{ textAlign: 'right' }}>
                <Table
                  size="small"
                  loading={loading}
                  columns={errorCode}
                  dataSource={errorList}
                  pagination={false}
                />
              </Col>
            </Row>
          </div>
        );
      })
    );
  };

  // 结果明细弹窗列表
  renderDetailsModal = () => {
    const { detailsVisible } = this.state;
    let { associate } = this.props;
    let judgeEmpty: number;
    if (!associate || (Array.isArray(associate) && associate.length === 0)) {
      judgeEmpty = 0;
    } else {
      judgeEmpty = 1;
    }

    const success = (
      <div style={{ textAlign: 'center', padding: '50px 0' }}>{this.state.resultMsg}</div>
    );

    return (
      <Modal
        title="批量处理结果"
        width={800}
        footer={null}
        visible={detailsVisible}
        onCancel={this.handleDetailsCancel}
        bodyStyle={{ maxHeight: '500px', padding: '0px' }}
      >
        <div style={{ maxHeight: 'inherit', overflow: 'auto', padding: '24px' }}>
          {judgeEmpty === 1 ? this.renderErrorList() : success}
        </div>
      </Modal>
    );
  };

  render() {
    const { tableParams, pageParams } = this.state;
    const { loading } = this.props;
    const preventGetList = true;
    const OYOTableColumns: object[] = [
      {
        title: '批次号',
        dataIndex: 'batchNo',
        key: 'batchNo',
        width: '20%',
      },
      {
        title: '操作时间',
        dataIndex: 'createTime',
        key: 'createTime',
        width: '15%',
        render(createTime) {
          if (createTime) {
            return moment(createTime).format('YYYY-MM-DD HH:mm:ss');
          }
        },
      },
      {
        title: '操作人',
        dataIndex: 'operatorName',
        key: 'operatorName',
        width: '15%',
        render: (operatorName, record) => {
          return <p style={{ margin: 0 }}>{`${operatorName}(${record.operatorId})`}</p>;
        },
      },
      {
        title: '操作类型',
        dataIndex: 'type',
        key: 'type',
        width: '15%',
        render: type => {
          if (type === 1 || type === 0) {
            let { name, value } = OPERATE_TYPE[type];
            return <p style={{ margin: 0 }}>{`${name}`}</p>;
          }
        },
      },
      {
        title: '文件',
        dataIndex: 'fileName',
        key: 'fileName',
        width: '15%',
      },
      {
        title: '执行结果',
        dataIndex: 'result',
        key: 'result',
        render(result) {
          let status;
          if (result === 0) {
            status = <span style={{ color: '#259b24' }}>成功</span>;
          } else if (result === 1) {
            status = <span style={{ color: '#F5222D' }}>失败</span>;
          } else {
            status = <span>处理中</span>;
          }
          return status;
        },
      },
      {
        title: '结果明细',
        dataIndex: 'id',
        key: 'id',
        render: (id, record) => (
          <Button
            type="primary"
            size="small"
            onClick={() => this.handleResults(record.batchNo, record.result)}
          >
            查看
          </Button>
        ),
      },
    ];

    return (
      <>
        <OYOTable
          ref={re => {
            this.oyotable = re;
          }}
          bordered
          size="small"
          loading={loading}
          params={tableParams}
          pageParams={pageParams}
          columns={OYOTableColumns}
          getList={this.getResultsList}
          preventGetList={preventGetList}
        />
        {this.renderDetailsModal()}
      </>
    );
  }
}
