import React, { PureComponent } from 'react';
import {
  Tabs,
  Card,
  Button,
  Form,
  Input,
  Select,
  Row,
  Col,
  Badge,
  Table,
  message,
  DatePicker,
  Checkbox,
} from 'antd';
import router from 'umi/router';
import { connect } from 'dva';
import moment from 'moment';

import PageHeaderWrapper from '@/components/PageHeaderWrapper';
import OYOTable from '@/components/OyoTable/OyoTable.tsx';
import ButtonAuthorized from '@/components/ButtonAuthorized';
import {
  REPLY_TYPE_OPTION,
  getNameFromStatus as getNameFromStatusHotelType,
} from '@/constant/hotelType';
import {
  rowProps,
  col1Props,
  col3Props,
  col4Props,
  formItemLayout,
  widthStyle,
  formItemWithoutLabel,
} from '@/utils/formProps';

import EditReplyModal from '../components/EditReplyModal';
import styles from './index.less';
import { queryCommentList } from './services/index';

const Option = Select.Option;
const FormItem = Form.Item;
const CheckboxGroup = Checkbox.Group;
const { RangePicker } = DatePicker;
const data = [{}];

const scoreOptions = ['1', '2', '3', '4', '5'];
const contentOptions = ['有价值', '无价值', '空'];
// const defaultScoreChecked = [];
// const defaultContentChecked = [];

const contentDic = [
  {
    label: '有价值',
    value: '1',
  },
  {
    label: '无价值',
    value: '2',
  },
  {
    label: '空',
    value: '3',
  },
];

@connect(({ loading, user }) => ({
  loading: loading.models.hotelLists,
  user,
}))
export default class CommentManageIndex extends PureComponent {
  constructor(props) {
    super(props);
    this.state = {
      userType: 1, // 1客服 2组长
      visible: false,
      tableParams: {
        commentTimeStart: '',
        commentTimeEnd: '',
        replyStatus: '0',
        useCache: 0,
        rates: '1,2,3,4,5',
        commentTypes: '1',
      },
      pageParams: ['page', 'limit'],
      commentId: '',
      replyContent: '',
      scoreCheckedList: ['1', '2', '3', '4', '5'],
      contentCheckedList: ['有价值'],
    };
  }

  getCommentList = params => {
    return queryCommentList(params)
      .then(res => {
        if (res && res.data) {
          const { total, data: result } = res.data;
          let commentList = [];
          if (result && Array.isArray(result)) {
            commentList = result.map(({ comment, commentTags }) => {
              const list = Array.isArray(commentTags) ? commentTags : [];

              return {
                ...comment,
                commentTag: list.map(item => item.tagContent).join(','),
              };
            });
          }
          console.log('getCommentList', commentList);

          return { data: commentList || [], total };
        }
      })
      .catch(err => {
        console.log(err);
      });
  };

  onChangeRangePicker = (date, dateString) => {
    this.setState({
      tableParams: {
        ...this.state.tableParams,
        commentTimeStart: date[0] ? date[0].format('YYYY-MM-DD 00:00:00') : '',
        commentTimeEnd: date[1] ? date[1].format('YYYY-MM-DD 23:59:59') : '',
      },
    });
  };

  handleChange = (val, key) => {
    this.setState({
      tableParams: {
        ...this.state.tableParams,
        replyStatus: val,
      },
    });
  };

  query = () => {
    this.oyotable.getPageList();
  };

  toDetail = id => {
    window.open(`${window.location.origin}/#/order/detail/order?bookingId=${id}`);
    // router.push({
    //   pathname: '/order/detail/order',
    //   query: { bookingId: id },
    // });
  };

  showModal = (id, replyContent) => {
    this.setState({
      visible: true,
      commentId: id,
      replyContent,
    });
    // this.oyotable.saveScrollTop()
  };

  changeModal = bl => {
    this.setState({
      visible: bl,
    });
  };

  isCanEdit = (replyTime, replyContent) => {
    const { userType } = this.state;

    if (userType === 2) return true;

    let time = moment(); // 目前时间
    let endTime = moment(replyTime).endOf('day'); // 首次回复时间 推到当天最晚

    if (!replyContent || time.isBefore(endTime)) {
      return true;
    }
    return false;
  };

  componentDidMount() {
    const menuList = localStorage.menuList ? JSON.parse(localStorage.menuList) : [];
    const userType = menuList.some(item => item.code === 'CRS7.10.2') ? 2 : 1; // 是否是组长

    this.setState({
      userType,
    });
  }

  scoreOnChange = scoreCheckedList => {
    console.log('scoreCheckedList', scoreCheckedList);
    this.setState({
      scoreCheckedList,
      tableParams: {
        ...this.state.tableParams,
        rates: scoreCheckedList.join(','),
      },
    });
  };

  contentOnChange = contentCheckedList => {
    const arr = contentCheckedList.map((item, index) => {
      return contentDic.find(dic => dic.label === item).value;
    });

    this.setState({
      contentCheckedList,
      tableParams: {
        ...this.state.tableParams,
        commentTypes: arr.join(','),
      },
    });

    // this.setState({
    //   contentCheckedList,
    //   commentTypes:contentCheckedList.join(','),
    // });
    // console.log(contentCheckedList.join(','))
  };

  render() {
    let {
      getCommentList,
      onChangeRangePicker,
      handleChange,
      toDetail,
      showModal,
      changeModal,
      query,
      isCanEdit,
      onChange,
      scoreOnChange,
      contentOnChange,
    } = this;
    let {
      visible,
      tableParams,
      pageParams,
      commentId,
      replyContent,
      scoreCheckedList,
      contentCheckedList,
    } = this.state;

    let { loading } = this.props;
    const preventGetList = true;
    const columns = [
      {
        title: '点评ID',
        dataIndex: 'id',
        key: 'id',
        width: '8%',
        render: (id, item) => {
          return (
            <p
              style={{ margin: 'auto 0', cursor: 'pointer', color: '#F5222D' }}
              onClick={() => {
                toDetail(item.bookingId);
              }}
            >
              {`${id}`}
            </p>
          );
        },
      },
      {
        title: '评分',
        dataIndex: 'totalRate',
        key: 'totalRate',
        width: '8%',
      },
      {
        title: '点评时间',
        dataIndex: 'createTime',
        key: 'createTime',
        width: '12%',
        render: createTime => {
          return (
            <p style={{ margin: 'auto 0' }}>
              {createTime ? `${moment(createTime).format('YYYY-MM-DD HH:mm:ss')}` : ''}
            </p>
          );
        },
      },

      {
        title: '评论标签',
        dataIndex: 'commentTag',
        key: 'commentTag',
        width: '12%',
      },
      {
        title: '评论内容',
        dataIndex: 'comment',
        key: 'comment',
        width: '20%',
      },
      {
        title: '最新回复时间',
        dataIndex: 'customerServiceReplyTime',
        key: 'customerServiceReplyTime',
        width: '12%',
        render: (customerServiceReplyTime, record) => {
          return (
            <div>
              <p>{record.customerServiceName}</p>
              <p style={{ margin: 'auto 0' }}>
                {customerServiceReplyTime
                  ? `${moment(customerServiceReplyTime).format('YYYY-MM-DD HH:mm:ss')}`
                  : ''}
              </p>
            </div>
          );
        },
      },
      {
        title: '回复内容',
        dataIndex: 'customerServiceReplyContent',
        key: 'customerServiceReplyContent',
        width: '20%',
      },
      {
        title: '操作',
        width: '8%',
        render: (key, item) => (
          <>
            <ButtonAuthorized
              size="small"
              style={{ marginLeft: 10 }}
              code="CRS7.10.1"
              hiden
              onClick={() => showModal(item.id, item.customerServiceReplyContent)}
              myDisabled={
                !this.isCanEdit(item.customerServiceReplyTime, item.customerServiceReplyContent)
              }
            >
              修改回复
            </ButtonAuthorized>
            <ButtonAuthorized
              size="small"
              style={{ marginLeft: 10 }}
              code="CRS7.10.2"
              hiden
              onClick={() => showModal(item.id, item.customerServiceReplyContent)}
            >
              修改回复
            </ButtonAuthorized>
          </>
        ),
      },
    ];

    return (
      <PageHeaderWrapper>
        <Card className={styles.main}>
          <Form layout="inline" className={styles.tableList}>
            <Row {...rowProps}>
              <Col lg={{ span: 24 }} xl={{ span: 12 }} xxl={{ span: 8 }}>
                <FormItem style={widthStyle} label="点评日期选择" {...formItemLayout}>
                  <RangePicker format="YYYY-MM-DD" onChange={onChangeRangePicker} />
                </FormItem>
              </Col>
              <Col lg={{ span: 24 }} xl={{ span: 12 }} xxl={{ span: 8 }}>
                <FormItem style={widthStyle} label="回复状态" {...formItemLayout}>
                  <Select
                    defaultValue="未回复"
                    style={{ minWidth: '300px' }}
                    placeholder="全部/已回复/未回复"
                    onChange={e => handleChange(e, 'replyStatus')}
                  >
                    {REPLY_TYPE_OPTION}
                  </Select>
                </FormItem>
              </Col>
            </Row>
            <Row>
              <Col lg={{ span: 24 }} xl={{ span: 12 }} xxl={{ span: 8 }}>
                <FormItem style={widthStyle} label="评分" {...formItemLayout}>
                  <CheckboxGroup
                    style={{ minWidth: '300px' }}
                    options={scoreOptions}
                    value={scoreCheckedList}
                    onChange={scoreOnChange}
                  />
                </FormItem>
              </Col>
              <Col lg={{ span: 24 }} xl={{ span: 12 }} xxl={{ span: 8 }}>
                <FormItem style={widthStyle} label="评论内容" {...formItemLayout}>
                  <CheckboxGroup
                    style={{ minWidth: '300px' }}
                    options={contentOptions}
                    value={contentCheckedList}
                    onChange={contentOnChange}
                  />
                </FormItem>
              </Col>
            </Row>
          </Form>
          <div style={{ textAlign: 'center' }}>
            <Button type="primary" onClick={query}>
              查询
            </Button>
          </div>
        </Card>

        <Card style={{ marginTop: 15 }}>
          <OYOTable
            rowKey="id"
            ref={re => {
              this.oyotable = re;
            }}
            bordered
            size="small"
            style={{ marginTop: 20 }}
            loading={loading}
            columns={columns}
            getList={getCommentList}
            params={tableParams}
            pageParams={pageParams}
            reventGetList={preventGetList}
          />
        </Card>

        <EditReplyModal
          visible={visible}
          callback={bl => changeModal(bl)}
          commentId={commentId}
          replyContent={replyContent}
          updateCommentList={() => {
            this.oyotable.getPageList(this.oyotable.getCurrentPagination());
            // this.oyotable.goScrollTop()
          }}
          isCanEdit={isCanEdit}
        />
      </PageHeaderWrapper>
    );
  }
}
