import React, { Fragment } from 'react';
import router from 'umi/router';
import { connect } from 'dva';
import {
  Table,
  Input,
  Button,
  Message,
  Popconfirm,
  Rate,
  Row,
  Col,
  Card,
  Form,
  message,
} from 'antd';
import PageHeaderWrapper from '@/components/PageHeaderWrapper';
import TagTable from './components/TagTable';

const { TextArea } = Input;
const FormItem = Form.Item;
const formItemLayout = {
  labelCol: { span: 2 },
  wrapperCol: { span: 18 },
};
const tooltipsData = ['1星', '2星', '3星', '4星', '5星', '6星', '7星', '8星', '9星', '10星'];

// 输入框样式
const formItemStyle = {
  style: {
    width: '100%',
  },
};
@Form.create()
@connect(({ global, customerService, loading }) => ({
  global,
  customerService,
  loading: loading.effects['customerService/submitComment'],
}))
class CustomerService extends React.Component {
  constructor(props) {
    super(props);
    this.state = {
      commentTags: [],
      commentSubTags: [],
    };
  }

  componentWillReceiveProps(props) {
    console.log(props);
  }

  componentWillMount() {
    this.tagList();
  }

  solveTag(val, arr) {
    let tag = arr;
    const index = tag.findIndex(item => val.id === item.id);
    if (index >= 0) {
      tag.splice(index, 1);
    } else {
      tag.push(val);
    }
    return tag;
  }

  tabClick(val) {
    const { commentTags, commentSubTags } = this.state;
    if (val && val.templateTagId) {
      // 1~3星标签
      this.setState({
        commentSubTags: this.solveTag(val, commentSubTags),
      });
    } else {
      // 4、5星标签
      this.setState({
        commentTags: this.solveTag(val, commentTags),
      });
    }
  }

  tagList() {
    const { dispatch } = this.props;
    dispatch({
      type: 'customerService/getTagList',
      payload: '',
    });
  }

  submitComment = () => {
    let { commentSubTags, commentTags } = this.state;
    commentSubTags = JSON.parse(JSON.stringify(commentSubTags));
    commentTags = JSON.parse(JSON.stringify(commentTags));

    commentSubTags = commentSubTags.map(item => {
      item.templateTagId = item.templateTagId;
      item.templateSubTagId = item.id;
      return item;
    });
    commentTags = commentTags.map(item => {
      item.templateTagId = item.id;
      return item;
    });
    const { dispatch, location } = this.props;
    let bookingId = location.query.bookingId;
    this.props.form.validateFields((err, value) => {
      let { totalRate, comment } = value;
      const param = {
        commentTags: commentTags.concat(commentSubTags),
        commentSubTags,
        comment: {
          bookingId,
          commentType: 2,
          source: 4,
          totalRate: totalRate === undefined ? 0 : totalRate,
          comment,
        },
      };
      if (!err) {
        dispatch({
          type: 'customerService/submitComment',
          payload: param,
        })
          .then(data => {
            if (data.code === '000') {
              message.success('评论提交成功');
              router.push('/order/list?from=comment');
            }
          })
          .catch(e => {
            console.log(e);
          });
      }
    });
  };

  cancelSubmit = () => {
    router.push('/order/list?from=comment');
  };

  render() {
    const {
      form,
      loading,
      form: { getFieldDecorator },
      customerService,
    } = this.props;

    const stars_count = form.getFieldValue('totalRate') || 0;

    return (
      <PageHeaderWrapper>
        <Card>
          <Row>
            <FormItem label="评分" {...formItemLayout}>
              {getFieldDecorator('totalRate')(
                <Rate
                  style={{ fontSize: 25 }}
                  initialValue={0}
                  count={10}
                  tooltips={tooltipsData}
                  onChange={this.rateChange}
                />
              )}
              <span className="ant-rate-text">
                {`${stars_count === 'undefined' ? 0 : stars_count}星`}
              </span>
            </FormItem>
          </Row>

          <Row>
            <FormItem label="评价" {...formItemLayout}>
              {getFieldDecorator('comment', {
                rules: [
                  { required: true, message: '请输入评论' },
                  { max: 300, message: '评论内容超过300字' },
                ],
              })(<TextArea placeholder="请输入评论（必填）" rows={4} />)}
            </FormItem>
          </Row>

          <Row>
            <FormItem label="标签" {...formItemLayout}>
              <TagTable
                originData={customerService.tagList}
                clickEvent={tablist => this.tabClick(tablist)}
                commentTags={this.state.commentTags}
                commentSubTags={this.state.commentSubTags}
              />
            </FormItem>
          </Row>
          <Row justify="space-around" type="flex">
            <Col push={9} span={12}>
              <Button loading={loading} onClick={this.submitComment} type="primary">
                提交评论
              </Button>
            </Col>
            <Col span={12}>
              <Button onClick={this.cancelSubmit}>取消</Button>
            </Col>
          </Row>
        </Card>
      </PageHeaderWrapper>
    );
  }
}

export default CustomerService;
