import OYOTable from '@/components/OyoTable/OyoTable.tsx';
import { downloadFile } from '@/utils/downloadFile';
import { connect } from 'dva';
import moment from 'moment';
import React, { PureComponent } from 'react';
import { queryDetailsList, queryResultsList } from '../services/index';
import { STATUS_TYPE } from './statusType';

@connect(({ associate, user, loading }) => ({
  associate,
  user,
  loading: loading.models.associate,
}))
export default class batchResults extends PureComponent<any, any> {
  public oyotable = null;
  constructor(props) {
    super(props);
    this.state = {
      tableParams: {},
      pageParams: ['pageNo', 'pageSize'],
      detailsVisible: false,
    };
  }
  public componentDidMount() {
    // 默认请求：初始结果列表
    this.oyotable.getPageList();
  }

  // 请求：获取结果列表数据
  public getResultsList = params =>
    queryResultsList(params)
      .then(res => {
        if (res.data) {
          const { result, totalCount } = res.data;
          if (Array.isArray(result)) {
            result.forEach((item, key) => {
              item.key = key;
              item.No = key + 1;
            });
          }

          return { data: result || [], total: totalCount };
        }
      })
      .catch(err => {
        console.log(err);
      });

  // 操作：下载错误表格
  downloadErrorFile = (batchNo, fileName) => {
    queryDetailsList({ batchNo })
      .then(res => {
        downloadFile(res.data, fileName);
      })
      .catch(err => {
        console.log(err);
      });
  };
  public render() {
    const { tableParams, pageParams } = this.state;
    const { loading } = this.props;
    const preventGetList = true;
    const OYOTableColumns: object[] = [
      {
        title: '批次号',
        dataIndex: 'batchNo',
        key: 'batchNo',
      },
      {
        title: '操作时间',
        dataIndex: 'createTime',
        key: 'createTime',
        render(createTime) {
          if (createTime) {
            return moment(createTime).format('YYYY-MM-DD HH:mm:ss');
          }
        },
      },
      {
        title: '操作类别',
        dataIndex: 'typeDesc',
        key: 'typeDesc',
      },
      {
        title: '操作人',
        dataIndex: 'operatorName',
        key: 'operatorName',
        render: (operatorName, record) => {
          return `${operatorName}(${record.operatorId})`;
        },
      },
      {
        title: '文件',
        dataIndex: 'fileName',
        key: 'fileName',
      },
      {
        title: '执行结果显示',
        dataIndex: 'status',
        key: 'status',
        render: status => {
          let { color, name } = STATUS_TYPE[status];
          return (
            <p style={{ margin: 'auto 0', color: `${color}`, cursor: 'pointer' }}>{`${name}`}</p>
          );
        },
      },
      {
        title: '失败条目下载',
        dataIndex: 'downloadFileName',
        key: 'downloadFileName',
        render: (downloadFileName, record) => {
          if (downloadFileName) {
            return (
              <p
                onClick={() => this.downloadErrorFile(record.batchNo, downloadFileName)}
                style={{ margin: 'auto 0', color: '#F5222D', cursor: 'pointer' }}
              >{`${downloadFileName}`}</p>
            );
          }
        },
      },
    ];

    return (
      <>
        <OYOTable
          ref={re => {
            this.oyotable = re;
          }}
          bordered={true}
          size="small"
          loading={loading}
          params={tableParams}
          pageParams={pageParams}
          columns={OYOTableColumns}
          getList={this.getResultsList}
          preventGetList={preventGetList}
        />
      </>
    );
  }
}
