import React from 'react';
import {
  Tabs,
  Layout,
  Button,
  Table,
  Input,
  Switch,
  Select,
  Badge,
  Modal,
  Form,
  message,
  Popconfirm,
  Card,
} from 'antd';
import { connect } from 'dva';
import moment from 'moment';
import PageHeaderWrapper from '@/components/PageHeaderWrapper';

import { debounce } from '@/utils/decorator';

const TabPane = Tabs.TabPane;
const { Content } = Layout;
const FormItem = Form.Item;
const Option = Select.Option;

const formItemLayout = {
  labelCol: {
    xs: { span: 24 },
    sm: { span: 6 },
  },
  wrapperCol: {
    xs: { span: 24 },
    sm: { span: 14 },
  },
};

const tabfactory = (key, title) => ({ key, title, columns: `columns${key}` });
const defaultTab = tabfactory('5', '5分评论');
@connect(({ hotelCommentTag }) => hotelCommentTag)
export default class HotelCommentTag extends React.PureComponent {
  columns5 = [
    {
      title: '标签内容',
      dataIndex: 'content',
      key: 'content',
    },
    {
      title: '是否前端展示',
      dataIndex: 'isShow',
      key: 'isShow',
      render: text => (text ? '是' : '否'),
    },
    {
      title: '创建时间',
      dataIndex: 'createTime',
      key: 'createTime',
      render: text => moment(text).format('YYYY-MM-DD HH:mm:ss'),
    },
    {
      title: '最近修改时间',
      dataIndex: 'updateTime',
      key: 'updateTime',
      render: text => moment(text).format('YYYY-MM-DD HH:mm:ss'),
    },
    {
      title: '操作',
      key: 'action',
      render: (text, record) => (
        <div>
          <Button
            style={{ marginRight: 7 }}
            size="small"
            onClick={() => this.onUpdateCommentTagPosition(record, 'up')}
          >
            上移
          </Button>
          <Button
            style={{ marginRight: 7 }}
            size="small"
            onClick={() => this.onUpdateCommentTagPosition(record, 'down')}
          >
            下移
          </Button>
          <Popconfirm
            title={record.totalRate === 3 ? '确认删除一级标签（其子标签也将被删除）?' : '确认删除?'}
            onConfirm={() => this.onDeleteTag(record)}
            okText="是"
            cancelText="否"
          >
            <Button style={{ marginRight: 7 }} size="small">
              删除
            </Button>
          </Popconfirm>
          <Button style={{ marginRight: 7 }} size="small" onClick={() => this.onUpdateTag(record)}>
            编辑
          </Button>
        </div>
      ),
    },
  ];

  columns4 = [
    {
      title: '标签类型',
      dataIndex: 'type',
      key: 'type',
      render: text => (text ? '希望更好' : '值得表扬'),
    },
    ...this.columns5,
  ];

  columns3 = [
    {
      title: '标签级别',
      dataIndex: 'level',
      key: 'level',
      render: () => '一级标签',
    },
    ...this.columns5,
  ];

  state = {
    visible: false,
    tab: defaultTab,
    loading: true,
    tabs: [defaultTab, tabfactory('4', '4分评论'), tabfactory('3', '1～3分评论')],
    tag: {
      content: '',
      // 是否前端展示 1:展示 0 不展示
      isShow: 1,
    },
    tags: [],
  };

  componentDidMount() {
    console.log(this.props, 'props');
    this.onFetchCommentTags();
  }

  onFetchCommentTags = () => {
    const { tab } = this.state;
    this._dispatch('fetchCommentTags', tab.key, data => {
      this.setState({
        tags: data,
      });
    });
  };

  onTrigger = (tag = {}) => {
    const state = {
      visible: !this.state.visible,
      tag,
    };
    this.setState(state);
  };

  onTabChange = key => {
    const { tabs } = this.state;
    const [tab] = tabs.filter(t => t.key === key);
    this.setState(
      {
        tab,
      },
      this.onFetchCommentTags
    );
  };

  onInputChange = evt => this._setTag('content', evt.target.value);

  _setTag = (k, v) => {
    const tag = { ...this.state.tag };
    tag[k] = v;
    if (k === 'level') {
      tag.isShow = 0;
    }
    this.setState({
      tag,
    });
  };

  onSwitchChange = evt => this._setTag('isShow', evt ? 1 : 0);

  onCreateTag = () => {
    const { tab } = this.state;
    let tag = {
      content: '',
      isShow: 1,
    };
    if (tab.key === '4') {
      tag.type = '0';
    } else if (tab.key === '3') {
      tag.templateTagId = '';
      tag.level = '2';
      tag.isShow = 0;
    }
    this.onTrigger(tag);
  };

  onDeleteTag = tag => {
    this._dispatch('deleteCommentTagById', tag.id, () => {
      this.onFetchCommentTags();
    });
  };

  onDeleteSubTag = tag => {
    this._dispatch('deleteCommentSubTagById', tag.id, () => {
      this.onFetchCommentTags();
    });
  };

  onUpdateTag = tag => {
    tag.isEdit = true;
    this.onTrigger({ ...tag });
  };

  onUpdateSubTag = tag => {
    tag.isEdit = true;
    this.onTrigger({ ...tag });
  };

  onUpdateCommentTagPosition = (tag, direction) => {
    const params = {
      id: tag.id,
      direction: direction === 'up' ? 1 : 2,
    };
    this._dispatch('updateCommentTagPosition', params, () => {
      message.success('移动成功');
      console.log('====================================');
      console.log('回掉');
      console.log('====================================');
      setTimeout(() => {
        this.onFetchCommentTags();
      }, 300);
    });
  };

  onUpdateCommentSubTagPosition = (tag, direction) => {
    const params = {
      id: tag.id,
      direction: direction === 'up' ? 1 : 2,
    };
    this._dispatch('updateCommentSubTagPosition', params, () => {
      message.success('移动成功');
      setTimeout(() => {
        this.onFetchCommentTags();
      }, 300);
    });
  };

  _dispatch = (url, payload, fn) => {
    const { dispatch } = this.props;
    const params = {
      type: `hotelCommentTag/${url}`,
      payload,
    };
    this.setState({
      loading: true,
    });
    dispatch(params)
      .then(({ code, data }) => {
        fn && fn(data);
        setTimeout(() => {
          this.setState({
            loading: false,
          });
        }, 300);
      })
      .catch(er => {
        setTimeout(() => {
          this.setState({
            loading: false,
          });
        }, 300);
      });
  };

  onPersistCommentTag = tag => {
    if (!tag.content.trim()) {
      message.error('请输入标签内容');
      return;
    }

    if (tag.level === '2') {
      // 二级标签
      if (!tag.templateTagId) {
        message.error('请选择一级标签');
        return;
      }
      this._dispatch('persistCommentSubTag', tag, () => {
        this.onFetchCommentTags();
        this.onTrigger();
      });
    } else {
      // 一级标签
      this._dispatch('persistCommentTag', tag, () => {
        this.onFetchCommentTags();
        this.onTrigger();
      });
    }
  };

  onUpdateCommentTag = tag => {
    if (`${tag.level}` === '2') {
      this._dispatch('updateCommentSubTag', tag, () => {
        this.onFetchCommentTags();
        this.onTrigger();
      });
    }
    if (`${tag.level}` === '1') {
      this._dispatch('updateCommentTag', tag, () => {
        this.onFetchCommentTags();
        this.onTrigger();
      });
    }
  };

  onUpdateCommentSubTag = tag => {
    this._dispatch('updateCommentSubTag', tag, () => {
      this.onFetchCommentTags();
      this.onTrigger();
    });
  };

  onConfirm = () => {
    const { tag, tab } = this.state;
    tag.totalRate = tab.key;
    if (tag.id) {
      this.onUpdateCommentTag(tag);
    } else {
      this.onPersistCommentTag(tag);
    }
  };

  expandedRowRender = row => {
    let { loading } = this.state;
    const columns = [
      { dataIndex: 'level', render: () => '二级标签' },
      { dataIndex: 'content' },
      { dataIndex: 'isShow', render: text => (text ? '是' : '否') },
      { dataIndex: 'createTime', render: text => moment(text).format('YYYY-MM-DD HH:mm:ss') },
      { dataIndex: 'updateTime', render: text => moment(text).format('YYYY-MM-DD HH:mm:ss') },
      {
        dataIndex: 'operation',
        render: (text, record) => (
          <div>
            <Button
              style={{ marginRight: 7 }}
              size="small"
              onClick={() => this.onUpdateCommentSubTagPosition(record, 'up')}
            >
              上移
            </Button>
            <Button
              style={{ marginRight: 7 }}
              size="small"
              onClick={() => this.onUpdateCommentSubTagPosition(record, 'down')}
            >
              下移
            </Button>
            <Popconfirm
              title="确认删除?"
              onConfirm={() => this.onDeleteSubTag(record)}
              okText="是"
              cancelText="否"
            >
              <Button style={{ marginRight: 7 }} size="small">
                删除
              </Button>
            </Popconfirm>
            <Button
              style={{ marginRight: 7 }}
              size="small"
              onClick={() => this.onUpdateSubTag(record)}
            >
              编辑
            </Button>
          </div>
        ),
      },
    ];
    const dataSource = row.commentTemplateSubTags || [];
    return (
      <Table
        showHeader={false}
        bordered
        size="small"
        rowKey="id"
        loading={loading}
        columns={columns}
        dataSource={dataSource}
        pagination={false}
      />
    );
  };

  render() {
    const { tabs, tab, tags, tag, visible, loading } = this.state;
    return (
      <PageHeaderWrapper>
        <Card>
          <section style={{ backgroundColor: '#fff', padding: 10 }}>
            <Tabs onChange={this.onTabChange} type="card" defaultActiveKey={tab.key}>
              {tabs.map(tb => (
                <TabPane tab={tb.title} key={tb.key} />
              ))}
            </Tabs>
            <Layout>
              <Content style={{ backgroundColor: '#fff' }}>
                <p>
                  <Button onClick={this.onCreateTag} type="primary">
                    + 新建标签
                  </Button>
                </p>
                {tab.key === '3' && (
                  <Table
                    dataSource={tags}
                    bordered
                    size="small"
                    loading={loading}
                    expandedRowRender={this.expandedRowRender}
                    rowKey="id"
                    columns={this[tab.columns]}
                  />
                )}
                {tab.key !== '3' && (
                  <Table
                    loading={loading}
                    bordered
                    size="small"
                    dataSource={tags}
                    rowKey="id"
                    columns={this[tab.columns]}
                  />
                )}
              </Content>
            </Layout>
            <Modal
              title={tab.title}
              visible={visible}
              onOk={this.onConfirm}
              onCancel={() => this.onTrigger()}
            >
              <Form>
                {/* 1-3分评论有一级二级标签之分  用户手动选择一级还是二级 */}

                {tab.key === '3' && (
                  <FormItem label="标签级别 : " {...formItemLayout}>
                    <Select
                      disabled={!!tag.isEdit}
                      value={tag.level ? `${tag.level}` : undefined}
                      onChange={evt => this._setTag('level', evt)}
                    >
                      <Option value="1">一级标签</Option>
                      <Option value="2">二级标签</Option>
                    </Select>
                  </FormItem>
                )}
                {tab.key === '3' && (
                  <FormItem label="所属一级标签 ：" {...formItemLayout}>
                    <Select
                      value={tag.templateTagId ? `${tag.templateTagId}` : undefined}
                      placeholder="请选择"
                      disabled={tag.level === '1' || !!tag.isEdit}
                      onChange={evt => this._setTag('templateTagId', evt)}
                    >
                      {tags.map(tg => (
                        <Option value={`${tg.id}`} key={tg.id}>
                          {tg.content}
                        </Option>
                      ))}
                    </Select>
                  </FormItem>
                )}
                {tab.key === '4' && (
                  <FormItem label="标签类型 ：" {...formItemLayout}>
                    <Select value={`${tag.type}`} onChange={evt => this._setTag('type', evt)}>
                      <Option value="0">值得表扬</Option>
                      <Option value="1">希望更好</Option>
                    </Select>
                  </FormItem>
                )}

                <FormItem label="标签内容 ：" {...formItemLayout}>
                  <Input
                    placeholder="上限10个汉字"
                    maxLength={10}
                    value={tag.content}
                    onChange={this.onInputChange}
                  />
                </FormItem>
                <FormItem label="是否前端展示 ：" {...formItemLayout}>
                  <Switch
                    checkedChildren="是"
                    unCheckedChildren="否"
                    checked={!!tag.isShow}
                    disabled={`${tag.level}` === '2'}
                    onChange={e => this.onSwitchChange(e, 'isShow')}
                  />
                </FormItem>
              </Form>
            </Modal>
          </section>
        </Card>
      </PageHeaderWrapper>
    );
  }
}
