import { transAuthFetch } from '@/utils/fetch';

/**
 * 创建标签
 * @param {Object} params
 */
export function persistCommentTag(params) {
  return transAuthFetch(`/v1/back/page/templateTag/addTemplateTag`, {
    type: 8,
    method: 'POST',
    params,
  });
}

/**
 * 创建子标签
 * @param {Object} params
 */
export function persistCommentSubTag(params) {
  return transAuthFetch(`/v1/back/page/templateTag/addTemplateSubTag`, {
    type: 8,
    method: 'POST',
    params,
  });
}

/**
 * 删除对应到标签
 * @param {String} tagId
 */
export function deleteCommentTagById(tagId) {
  return transAuthFetch(`/v1/back/page/templateTag/deleteTemplateTag/${tagId}`, {
    type: 8,
  });
}

/**
 * 删除对应到子标签
 * @param {String} tagId
 */
export function deleteCommentSubTagById(tagId) {
  return transAuthFetch(`/v1/back/page/templateTag/deleteTemplateSubTag/${tagId}`, {
    type: 8,
  });
}

/**
 * 更改标签
 * @param {Object} params
 */
export function updateCommentTag(params) {
  return transAuthFetch(`/v1/back/page/templateTag/updateTemplateTag`, {
    type: 8,
    method: 'POST',
    params,
  });
}

/**
 * 更改子标签
 * @param {Object} params
 */
export function updateCommentSubTag(params) {
  return transAuthFetch(`/v1/back/page/templateTag/updateTemplateSubTag`, {
    type: 8,
    method: 'POST',
    params,
  });
}

/**
 * 修改标签位置
 * @param {String} fromId
 * @param {String} fromPosition
 * @param {String} toId
 * @param {String} toPosition
 */
export function updateCommentTagPosition(id, direction) {
  return transAuthFetch(`/v1/back/page/templateTag/templateTag/position/move/${id}/${direction}`, {
    type: 8,
    method: 'POST',
  });
}

/**
 * 修改子标签位置
 * @param {String} fromId
 * @param {String} fromPosition
 * @param {String} toId
 * @param {String} toPosition
 */
export function updateCommentSubTagPosition(id, direction) {
  return transAuthFetch(
    `/v1/back/page/templateTag/templateSubTag/position/move/${id}/${direction}`,
    {
      type: 8,
      method: 'POST',
    }
  );
}

/**
 * 传入评分等级,返回对应的tag列表
 * @param {String} totalRate
 */
export function fetchCommentTags(totalRate) {
  return transAuthFetch(`/v1/back/page/templateTag/templateTags/${totalRate}`, {
    type: 8,
  });
}
