import React, { PureComponent } from 'react';
import { Tabs, Card, Row, Col, Button, Progress, Icon, Select } from 'antd';
import router from 'umi/router';
import { connect } from 'dva';
import moment from 'moment';
import Connect from './BasiciInfoDetail/components/Connect';
import ButtonAuthorized from '@/components/ButtonAuthorized';
// import ButtonList from '../components/ButtonList';
// import HotelQualificationModal from './components/HotelQualificationModal';
// import HotelInvoiceModal from './components/HotelInvoiceModal';

const Option = Select.Option;

@connect(({ loading, HotelCreateEditHotelBasicInfo }) => ({
  HotelCreateEditHotelBasicInfo,
  loading: loading.models.hotelBasicInfo,
}))
export default class BasicInfo extends PureComponent {
  constructor(props) {
    super(props);
    this.state = {
      visibleQualification: false,
      visibleVoice: false,
      isPTIloading: false,
    };
  }

  componentDidMount() {
    let { dispatch, hotelId } = this.props;

    this.props.dispatch({
      type: 'HotelCreateEditHotelBasicInfo/getBase',
      payload: { hotelId },
    });

    dispatch({
      type: 'HotelCreateEditHotelBasicInfo/getHotelDetailInfo',
      payload: { hotelId },
    });
  }

  changeVisiable = (key, bl) => {
    this.setState({
      [key]: bl,
    });
  };

  toDetail = () => {
    let { hotelId } = this.props;
    router.push({
      pathname: '/hotel/hotelCreateEdit/basicInfoDetail',
      query: {
        hotelId,
      },
    });
  };

  toPic = () => {
    let { hotelId } = this.props;
    router.push({
      pathname: '/hotel/hotelCreateEdit/housePicHandler',
      query: {
        hotelId,
      },
    });
  };

  render() {
    let { changeVisiable, toDetail, toPic } = this;
    let { visibleQualification, visibleVoice, isPTIloading } = this.state;
    let { hotelId, HotelCreateEditHotelBasicInfo } = this.props;
    let { ptiCheckStatus } = HotelCreateEditHotelBasicInfo;

    let {
      name,
      roomNum,
      managerName,
      street,
      phoneList,
      activationDate,
      zoneName,
      hubName,
      cityName,
      landline,
      hotelTag,
      oyoId,
    } = HotelCreateEditHotelBasicInfo.hotelInfo;

    activationDate = moment.isMoment(activationDate)
      ? activationDate.format('YYYY-MM-DD')
      : activationDate;

    return (
      <div>
        <Card>
          <Card title="基本信息" bordered={false}>
            {/* <p>酒店首次上线时间：xxx,酒店最新上线时间</p> */}
            <p>酒店最新上线时间 :{activationDate || '无'}</p>

            <Row>
              <Col span={6}>
                <span>
                  酒店名称：
                  {name || '无'}
                </span>
              </Col>
              <Col span={6}>
                <span>
                  酒店ID：
                  {hotelId || '无'}
                </span>
                <span style={{ marginLeft: 10 }}>
                  OYO ID：
                  {oyoId || '无'}
                </span>
              </Col>
              <Col span={6}>
                <span>
                  酒店区域：
                  {`${zoneName || '无'}/${hubName || '无'}/${cityName || '无'}`}
                </span>
              </Col>
              <Col span={6}>
                <span>
                  酒店地址：
                  {street || '无'}
                </span>
              </Col>
            </Row>

            <Row>
              {/* <Col span={6}>
              <span>合作模式：xxx</span>{' '}
            </Col> */}
              <Col span={6}>
                <span>
                  房间总数：
                  {roomNum || '无'}
                </span>{' '}
              </Col>
              <Col span={6}>
                <span>
                  酒店经理：
                  {managerName || '无'}
                </span>{' '}
              </Col>
              <Col span={6}>
                <span>
                  电话：
                  {phoneList[0] || '无'}
                </span>{' '}
              </Col>
              <Col span={6}>
                <span>
                  酒店座机：
                  {landline || '无'}
                </span>{' '}
              </Col>
            </Row>
            <Row>
              <Col span={6}>
                <span>
                  酒店协议类型：
                  {hotelTag || '无'}
                </span>{' '}
              </Col>
            </Row>

            <Row style={{ marginTop: 40 }}>
              {/* <Col span={12} style={{ textAlign: 'center' }}>
              <p>
                <Progress type="circle" percent={75} strokeColor="#F5222D" />
              </p>
              <p>图片信息</p>
              <p>
                <Button>完善修改</Button>
              </p>
            </Col> */}
              <Col span={12} style={{ textAlign: 'center' }}>
                <div>
                  <Progress type="circle" percent={75} strokeColor="#F5222D" />
                </div>
                <p style={{ marginTop: 8 }}>酒店基础信息</p>
                <div>
                  <Button onClick={toDetail}>完善修改</Button>
                </div>
              </Col>
              <Col span={12} style={{ position: 'relative', textAlign: 'center' }}>
                <div>
                  <Progress type="circle" percent={75} strokeColor="#F5222D" />
                </div>
                <p style={{ marginTop: 8 }}>图片信息</p>
                {/*
  <p><Button onClick={toPic}>完善修改</Button></p>
                   */}
                <p>
                  <Button onClick={toPic}>完善修改</Button>
                </p>
                <div>
                  <Select style={{ width: 140 }} value={ptiCheckStatus} onChange={this.onPTIChange}>
                    <Option value={0}>PTI不通过</Option>
                    <Option value={1}>PTI通过</Option>
                    <Option value={2}>PTI上线</Option>
                  </Select>
                  <ButtonAuthorized
                    code="CRS7.2.1.4"
                    style={{ marginLeft: 2 }}
                    loading={isPTIloading}
                    onClick={this.handlerPTIsave}
                    type="primary"
                  >
                    保存
                  </ButtonAuthorized>
                </div>
              </Col>
            </Row>
          </Card>

          {/* <Card title="附加信息" bordered={false}>
          <Row style={{ color: '#F5222D' }}>
            <Col span={8}>
              <span style={{ cursor: 'pointer' }}>
                <Icon type="home" />
                业主法人信息维护
              </span>{' '}
            </Col>
            <Col span={8}>
              <span
                style={{ cursor: 'pointer' }}
                onClick={() => changeVisiable('visibleQualification', true)}
              >
                <Icon type="home" />
                酒店资质信息维护
              </span>{' '}
            </Col>
            <Col span={8}>
              <span
                style={{ cursor: 'pointer' }}
                onClick={() => changeVisiable('visibleVoice', true)}
              >
                <Icon type="home" />
                酒店发票信息维护
              </span>{' '}
            </Col>
          </Row>

          <HotelQualificationModal
            visible={visibleQualification}
            visibleChange={bl => changeVisiable('visibleQualification', bl)}
          />

          <HotelInvoiceModal
            visible={visibleVoice}
            visibleChange={bl => changeVisiable('visibleVoice', bl)}
          />
        </Card> */}
        </Card>
        <Connect style={{ marginTop: 25 }} hotelId={hotelId} />
      </div>
    );
  }

  onPTIChange = val => {
    this.props.dispatch({
      type: 'HotelCreateEditHotelBasicInfo/saveMainVal',
      payload: {
        ptiCheckStatus: val,
      },
    });
  };

  handlerPTIsave = async () => {
    let { hotelId } = this.props;

    this.setState({
      isPTIloading: true,
    });

    await this.props.dispatch({
      type: 'HotelCreateEditHotelBasicInfo/savePTI',
      payload: {
        hotelId,
      },
    });

    this.setState({
      isPTIloading: false,
    });
  };
}
