import React, { PureComponent } from 'react';
import { Card, Form, Input, Select, DatePicker, Icon, Row, Col } from 'antd';
import moment from 'moment';
import { connect } from 'dva';
import styles from '../basicInfoDetail.less';
import { BRAND_TYPE, getNameFromStatus } from '@/constant/brandType';

import {
  rowProps,
  col1Props,
  col3Props,
  col4Props,
  formLayout,
  formItemLayout,
  widthStyle,
} from '@/utils/formProps';

const Option = Select.Option;

@connect(({ loading, HotelCreateEditHotelBasicInfo }) => ({
  HotelCreateEditHotelBasicInfo,
}))
export default class Base extends PureComponent {
  constructor(props) {
    super(props);
    this.state = {
      subBranchOption: [],
    };
  }

  componentDidMount() {
    const {
      HotelCreateEditHotelBasicInfo: {
        hotelInfo: { type = 1 },
      },
      dispatch,
    } = this.props;
  }

  render() {
    let {
      // formItemLayout,
      HotelCreateEditHotelBasicInfo,
      changeInputVal,
      changeSelectVal,
      editType,
    } = this.props;
    const { subBranchOption } = this.state;
    let {
      name,
      enName,
      alternateName,
      oyoId,
      uniqueCode,
      roomNum,
      signRoomNum,
      activationDate,
      lastDecorateDate,
      email,
      contact,
      contactPhone,
      managerName,
      type,
      floor,
      nearybyLandmarkList,
      nearybyLandmarkDirection,
      phoneList,
      hotelFeature,
      landline,
      hotelTag,
      brandType,
      bookingEmail,
    } = HotelCreateEditHotelBasicInfo.hotelInfo;

    const {
      mainValData: { startDate },
    } = HotelCreateEditHotelBasicInfo;

    let { hotel_cooper_model } = HotelCreateEditHotelBasicInfo.metadataList;
    const { branchData = [], subBranchData = [] } = HotelCreateEditHotelBasicInfo;
    const renderDate = startDate ? moment(startDate) : null;
    return (
      <Card title="酒店基础信息">
        <Form layout="inline">
          <Row {...rowProps}>
            <Col {...col4Props}>
              <Form.Item style={widthStyle} label="OYO ID" {...formItemLayout}>
                <Input value={oyoId} disabled />
              </Form.Item>
            </Col>

            <Col {...col4Props}>
              <Form.Item style={widthStyle} label="唯一识别码" {...formItemLayout}>
                <Input value={uniqueCode} disabled />
              </Form.Item>
            </Col>
          </Row>
          <Row {...rowProps}>
            <Col {...col4Props}>
              <Form.Item style={widthStyle} label="酒店名称" {...formItemLayout}>
                <Input
                  disabled={!editType}
                  onChange={e => changeInputVal('name', e)}
                  value={name}
                />
              </Form.Item>
            </Col>

            <Col {...col4Props}>
              <Form.Item style={widthStyle} label="英文名称" {...formItemLayout}>
                <Input
                  disabled={!editType}
                  onChange={e => changeInputVal('enName', e)}
                  value={enName}
                />
              </Form.Item>
            </Col>
            <Col {...col4Props}>
              <Form.Item style={widthStyle} label="酒店原名称" {...formItemLayout}>
                <Input
                  disabled
                  onChange={e => changeInputVal('alternateName', e)}
                  value={alternateName}
                />
              </Form.Item>
            </Col>
            <Col {...col4Props}>
              <Form.Item style={widthStyle} label="开业时间" {...formItemLayout}>
                <DatePicker
                  style={{ width: '100%' }}
                  disabled
                  value={renderDate}
                  onChange={e => {
                    console.log(e);
                  }}
                />
              </Form.Item>
            </Col>
          </Row>
          <Row {...rowProps}>
            <Col {...col4Props}>
              <Form.Item style={widthStyle} label="房间总数" {...formItemLayout}>
                <Input
                  disabled={!editType}
                  onChange={e => changeInputVal('roomNum', e)}
                  value={roomNum}
                  type="number"
                />
              </Form.Item>
            </Col>
            <Col {...col4Props}>
              <Form.Item style={widthStyle} label="签约房间数" {...formItemLayout}>
                <Input
                  disabled={!editType}
                  onChange={e => changeInputVal('signRoomNum', e)}
                  value={signRoomNum}
                  type="number"
                />
              </Form.Item>
            </Col>
            <Col {...col4Props}>
              <Form.Item style={widthStyle} label="酒店楼层" {...formItemLayout}>
                <Input
                  disabled={!editType}
                  onChange={e => changeInputVal('floor', e)}
                  placeholder="层"
                  value={floor}
                />
              </Form.Item>
            </Col>

            <Col {...col4Props}>
              <Form.Item style={widthStyle} label="最近装修时间" {...formItemLayout}>
                <DatePicker
                  style={{ width: '100%' }}
                  disabled={!editType}
                  onChange={val => this.onDatePicker('lastDecorateDate', val)}
                  value={lastDecorateDate}
                />
              </Form.Item>
            </Col>
          </Row>
          <Row {...rowProps}>
            <Col {...col4Props}>
              <Form.Item style={widthStyle} label="合作模式" {...formItemLayout}>
                <Select
                  disabled={!editType}
                  onChange={val => {
                    changeSelectVal('type', val);
                    this.renderBranch(true);
                  }}
                  value={type}
                >
                  {branchData.map((item, index) => (
                    <Option value={item.typeId} key={index}>
                      {item.typeName}
                    </Option>
                  ))}
                </Select>
              </Form.Item>
            </Col>

            <Col {...col4Props}>
              <Form.Item style={widthStyle} label="品牌线" {...formItemLayout}>
                <Select
                  disabled={!editType}
                  onChange={val => {
                    changeSelectVal('brandType', val);
                  }}
                  value={brandType}
                >
                  {subBranchData.map((item, index) => (
                    <Option value={item.typeId} key={index}>
                      {item.typeName}
                    </Option>
                  ))}
                </Select>
              </Form.Item>
            </Col>
          </Row>
          <Row {...rowProps}>
            <Col {...col4Props}>
              <Form.Item style={widthStyle} label="酒店经理" {...formItemLayout}>
                <Input
                  disabled={!editType}
                  onChange={e => changeInputVal('managerName', e)}
                  value={managerName}
                />
              </Form.Item>
            </Col>

            <Col {...col4Props}>
              <Form.Item style={widthStyle} label="酒店预定电话" {...formItemLayout}>
                <Input
                  disabled={!editType}
                  onChange={e => changeInputVal('landline', e)}
                  value={landline}
                />
              </Form.Item>
            </Col>

            <Col {...col4Props}>
              <Form.Item style={widthStyle} label="酒店预定邮箱" {...formItemLayout}>
                <Input
                  disabled
                  onChange={e => changeInputVal('bookingEmail', e)}
                  value={bookingEmail}
                />
              </Form.Item>
            </Col>
            <Col {...col4Props}>
              <Form.Item style={widthStyle} label="酒店协议类型" {...formItemLayout}>
                {/* <Input value={hotelTag} disabled /> */}
                <Select
                  disabled={!editType}
                  value={hotelTag}
                  onChange={val => {
                    changeSelectVal('hotelTag', val);
                  }}
                >
                  <Option value="SOUTH_DIST_PILOT">china2.0</Option>
                  <Option value="others">其他</Option>
                </Select>
              </Form.Item>
            </Col>
          </Row>
          <Row {...rowProps}>
            <div
              className={`${styles.formInLine} ${styles.inputList}`}
              style={{ paddingLeft: 4, width: '100%' }}
            >
              <div
                className={styles.title}
                style={{ width: '8.1555%', textAlign: 'right', paddingRight: 7 }}
              >
                联系电话:
              </div>
              <div className={styles.markList}>
                {phoneList &&
                  phoneList.map((item, index) => (
                    <div className={styles.inputBox} key={index}>
                      <Input
                        disabled={!editType}
                        onChange={e => this.changeInputListVal('phoneList', index, e)}
                        value={item}
                      />
                      <Icon
                        type="close-circle"
                        onClick={() => this.deleteInput('phoneList', index)}
                      />
                      {index === phoneList.length - 1 && (
                        <Icon type="plus-circle" onClick={() => this.addInput('phoneList')} />
                      )}
                    </div>
                  ))}
              </div>
            </div>
          </Row>

          <Row {...rowProps}>
            <div className={`${styles.formInLine} ${styles.inputList}`} style={{ width: '100%' }}>
              <div
                className={styles.title}
                style={{ width: '8.1555%', textAlign: 'right', paddingRight: 7 }}
              >
                附近地标:
              </div>
              <div className={styles.markList}>
                {nearybyLandmarkList &&
                  nearybyLandmarkList.map((item, index) => (
                    <div className={styles.inputBox} key={index}>
                      <Input
                        disabled={!editType}
                        onChange={e => this.changeInputListVal('nearybyLandmarkList', index, e)}
                        value={item}
                      />
                      <Icon
                        type="close-circle"
                        onClick={() => this.deleteInput('nearybyLandmarkList', index)}
                      />
                      {index === nearybyLandmarkList.length - 1 && (
                        <Icon
                          type="plus-circle"
                          onClick={() => this.addInput('nearybyLandmarkList')}
                        />
                      )}
                    </div>
                  ))}
              </div>
            </div>
          </Row>
          <Row {...rowProps}>
            <div className={`${styles.formInLine} ${styles.nearybyLandmarkDirection}`}>
              <div className={styles.title}>酒店周边主要设施及到达方式和时间:</div>
              <div className={styles.markList}>
                <Input
                  disabled={!editType}
                  onChange={e => changeInputVal('nearybyLandmarkDirection', e)}
                  value={nearybyLandmarkDirection}
                />
              </div>
            </div>
            <div className={`${styles.formInLine} ${styles.nearybyLandmarkDirection}`}>
              <div className={styles.title}>酒店其他特色（风格、店内设施、特色服务等）:</div>
              <div className={styles.markList}>
                <Input
                  disabled={!editType}
                  onChange={e => changeInputVal('hotelFeature', e)}
                  value={hotelFeature}
                />
              </div>
            </div>
          </Row>
        </Form>
      </Card>
    );
  }

  // 品牌线
  renderBranch = val => {
    const { dispatch } = this.props;
    dispatch({
      type: 'HotelCreateEditHotelBasicInfo/saveSubBranch',
      payload: {
        branchStatus: val,
      },
    });
  };

  onDatePicker = (key, val) => {
    this.props.dispatch({
      type: 'HotelCreateEditHotelBasicInfo/saveHotelDetail',
      payload: {
        [key]: val,
      },
    });
  };

  changeInputListVal = (propName, index, e) => {
    let val = e.target.value;

    this.props.dispatch({
      type: 'HotelCreateEditHotelBasicInfo/changeInputListVal',
      payload: {
        propName,
        index,
        val,
      },
    });
  };

  deleteInput = (propName, index) => {
    if (!this.props.editType) return;

    this.props.dispatch({
      type: 'HotelCreateEditHotelBasicInfo/deleteInput',
      payload: {
        deleteIndex: index,
        propName,
      },
    });
  };

  addInput = propName => {
    if (!this.props.editType) return;

    this.props.dispatch({
      type: 'HotelCreateEditHotelBasicInfo/addInput',
      payload: {
        hotelId: this.props.hotelId,
        propName,
      },
    });
  };
}
