import React, { PureComponent } from 'react';
import {
  Card,
  Form,
  Input,
  Select,
  Checkbox,
  message,
  Icon,
  Table,
  Row,
  Col,
  Cascader,
} from 'antd';
import { connect } from 'dva';
import BaiduMapSearch from '@/components/BaiduMapSearch/index';
import CitySelect from '@/components/CitySelect/index';
import styles from '../basicInfoDetail.less';

import {
  rowProps,
  col1Props,
  col2Props,
  col3Props,
  col4Props,
  formLayout,
  formItemLayout,
  widthStyle,
} from '@/utils/formProps';

const Option = Select.Option;
const CheckboxGroup = Checkbox.Group;
const Search = Input.Search;

const formItemLayoutOnLine = {
  labelCol: {
    sm: { span: 4 },
  },
  wrapperCol: {
    sm: { span: 20 },
  },
};

const formItemLayoutAllLine = {
  labelCol: {
    sm: { span: 2 },
  },
  wrapperCol: {
    sm: { span: 22 },
  },
};

const columns = [
  {
    title: '地标名称',
    dataIndex: 'name',
    key: 'name',
  },
  {
    title: '地标距离酒店距离（km）',
    dataIndex: 'distance',
    key: 'distance',
  },
  {
    title: '位置描述',
    dataIndex: 'desc',
    key: 'desc',
  },
];
@connect(({ HotelCreateEditHotelBasicInfo, hotelSearch }) => ({
  HotelCreateEditHotelBasicInfo,
  hotelSearch,
}))
export default class HotelMap extends PureComponent {
  constructor(props) {
    super(props);
    this.state = {
      bMap: null,
      isShow: true,
      preLoadList: [],
    };
  }

  render() {
    let { isShow } = this.state;
    let { HotelCreateEditHotelBasicInfo, changeInputVal, changeSelectVal, editType } = this.props;
    let {
      latitude,
      longitude,
      mapLink,
      street,
      locationDescription,
      landmarkList,
      stateId,
      regionId,
      clcId,
      cityId,
      clusterId,
      zoneId,
      hubId,
      streetId,
      landmark = [],
    } = HotelCreateEditHotelBasicInfo.hotelInfo;
    let { cityList, areaList, loadAreaList } = this.props.hotelSearch;
    const { clusterData = [] } = HotelCreateEditHotelBasicInfo;

    return (
      <Card className={styles.basicInfoDetailContainer}>
        <div className={styles.basicInfoDetailTitle} onClick={this.handlerShow}>
          <p>酒店位置信息</p>
          {isShow ? <Icon type="caret-down" /> : <Icon type="caret-up" />}
        </div>
        <div className={styles.basicInfoDetailBd} style={{ height: isShow ? 'auto' : 0 }}>
          <Form layout="inline">
            <Row {...rowProps}>
              <Col {...col2Props}>
                <Form.Item style={widthStyle} label="酒店区域" {...formItemLayoutOnLine}>
                  <Cascader
                    disabled={!editType}
                    value={[regionId, zoneId, hubId, clcId, streetId]}
                    options={loadAreaList}
                    loadData={this.loadData}
                    onChange={(val, objVal) => this.onChangeArea(val, objVal)}
                    placeholder="请选择酒店区域"
                  />
                </Form.Item>
              </Col>

              <Col {...col3Props}>
                <Form.Item style={widthStyle} label="酒店地址" {...formItemLayout}>
                  <CitySelect
                    disabled
                    type="cityList"
                    style={{ width: '100%' }}
                    onChange={(val, objVal) => this.onChangeCity(val, objVal)}
                    value={[stateId, cityId, clusterId]}
                  />
                </Form.Item>
              </Col>
            </Row>
            <Row {...rowProps}>
              <Col {...col2Props}>
                <Form.Item style={widthStyle} label="详细地址" {...formItemLayoutOnLine}>
                  <Input
                    disabled={!editType}
                    value={street}
                    onChange={val => changeInputVal('street', val)}
                  />
                </Form.Item>
              </Col>
            </Row>
          </Form>
          <div id="bmap" style={{ width: '100%', height: '320px', margin: '30px auto 30px' }} />

          <Form layout="inline">
            <Row {...rowProps}>
              <Col {...col2Props}>
                <Form.Item style={widthStyle} label="地图搜索" {...formItemLayoutOnLine}>
                  <BaiduMapSearch
                    disabled={!editType}
                    placeholder="搜索地址"
                    onChange={this.onMapSearch}
                  />
                </Form.Item>
              </Col>

              <Col {...col2Props}>
                <Form.Item style={widthStyle} label="链接" {...formItemLayoutOnLine}>
                  <Input value={mapLink} disabled />
                </Form.Item>
              </Col>
            </Row>

            <Row {...rowProps}>
              <Col {...col4Props}>
                <Form.Item style={widthStyle} label="纬度" {...formItemLayout}>
                  <Input value={latitude} disabled />
                </Form.Item>
              </Col>
              <Col {...col4Props}>
                <Form.Item style={widthStyle} label="经度" {...formItemLayout}>
                  <Input value={longitude} disabled />
                </Form.Item>
              </Col>
              <Col {...col2Props}>
                <Form.Item style={widthStyle} label="位置说明" {...formItemLayoutOnLine}>
                  <Input
                    disabled={!editType}
                    value={locationDescription}
                    onChange={val => changeInputVal('locationDescription', val)}
                  />
                </Form.Item>
              </Col>
            </Row>
            <Row {...rowProps}>
              <Col {...col2Props}>
                <Form.Item style={widthStyle} label="关键词" {...formItemLayoutOnLine}>
                  <Select
                    disabled={!editType}
                    mode="tags"
                    value={landmarkList}
                    onChange={val => changeSelectVal('landmarkList', val)}
                    style={{ width: '100%' }}
                  />
                </Form.Item>
              </Col>
            </Row>
          </Form>
          <Table
            style={{ marginTop: 20 }}
            dataSource={landmark}
            columns={columns}
            pagination={false}
          />
        </div>
      </Card>
    );
  }

  componentDidMount() {
    this.initList();

    // 获取store hotelinfo
    this.initMap();
  }

  initList = async () => {
    const {
      dispatch,
      HotelCreateEditHotelBasicInfo: { hotelInfo },
    } = this.props;

    const { regionId, clcId, zoneId, hubId, cityId, clusterId, streetId } = hotelInfo;
    const selectList = [regionId, zoneId, hubId, clcId, streetId];

    // 获取酒店城市列表
    await dispatch({
      type: 'hotelSearch/fetchCityList',
    });

    // 销售地区列表
    await dispatch({
      type: 'hotelSearch/fetchNewAreaList',
    });

    //  查询4级联动
    if ((clcId || clcId === 0) && (streetId || streetId === 0)) {
      await dispatch({
        type: 'hotelSearch/getStreet',
        payload: {
          selectList,
          id: clcId,
        },
      });
    }
  };

  // 酒店区域变化
  changeCluster(val) {
    this.props.dispatch({
      type: 'HotelCreateEditHotelBasicInfo/saveHotelDetail',
      payload: {
        clusterId: val,
      },
    });
  }

  initMap() {
    let { latitude, longitude } = this.props.HotelCreateEditHotelBasicInfo.hotelInfo;

    if (!latitude || !longitude) {
      latitude = 39.915;
      longitude = 116.404;
    }
    let map = new BMap.Map('bmap'); // 创建地图实例
    let point = new BMap.Point(longitude, latitude); // 创建点坐标

    map.centerAndZoom(point, 15); // 初始化地图，设置中心点坐标和地图级别
    map.addOverlay(new BMap.Marker(point));

    this.setState({
      bMap: map,
    });
  }

  onMapSearch = val => {
    const { bMap } = this.state;
    const { lat, lng } = val;
    const myGeo = new BMap.Geocoder();
    const point = new BMap.Point(lng, lat); // 创建点坐标

    bMap.clearOverlays(); // 清除所有
    bMap.centerAndZoom(point, 15);
    bMap.addOverlay(new BMap.Marker(point));

    this.props.dispatch({
      type: 'HotelCreateEditHotelBasicInfo/saveHotelDetail',
      payload: {
        latitude: lat,
        longitude: lng,
        mapLink: `https://map.baidu.com/?latlng=${lat},${lng}`,
      },
    });
  };

  onChangeArea = (val, objVal) => {
    let [regionId, zoneId, hubId, clcId, streetId] = val;
    let [reginObj, zoneObj, hubObj, clcObj, streetObj] = objVal;
    let payload = {
      regionId,
      zoneId,
      hubId,
      clcId,
      streetId,
      reginName: reginObj ? reginObj.label : '',
      zoneName: zoneObj ? zoneObj.label : '',
      hubName: hubObj ? hubObj.label : '',
      clcName: clcObj ? clcObj.label : '',
      streetName: streetObj ? streetObj.label : '',
    };

    this.props.dispatch({
      type: 'HotelCreateEditHotelBasicInfo/saveHotelDetail',
      payload,
    });
  };

  onChangeCity = (val, objVal) => {
    let [stateId, cityId, clusterId] = val;
    let [stateObj, cityObj, clusterObj] = objVal;
    const hotelInfo = this.props.HotelCreateEditHotelBasicInfo.hotelInfo;
    const payload = {
      stateId,
      cityId,
      clusterId: clusterId || null,
      zoneName: stateObj ? stateObj.label : '',
      hubName: cityObj ? cityObj.label : '',
      cityName: clusterObj ? clusterObj.label : '',
    };

    this.props.dispatch({
      type: 'HotelCreateEditHotelBasicInfo/saveHotelDetail',
      payload,
    });
  };

  handlerShow = () => {
    this.setState({
      isShow: !this.state.isShow,
    });
  };

  loadData = selectedOptions => {
    const { dispatch } = this.props;
    const selectList = selectedOptions.map(item => item.value);
    const id = selectList[selectedOptions.length - 1];

    dispatch({
      type: 'hotelSearch/getStreet',
      payload: {
        id,
        selectList,
      },
    }).then(isHasData => {
      // if (!isHasData) {
      //   console.log('isHasData4');
      //   this.onChangeArea([...selectList, null], [...selectedOptions, null]);
      // }
    });
  };
}
