import React, { PureComponent } from 'react';
import { Card, Form, Input, Select, Checkbox, Icon, Row, Col } from 'antd';
import { connect } from 'dva';
import TimeSelect from '@/components/TimeSelect/index';
import styles from '../basicInfoDetail.less';

import {
  rowProps,
  col1Props,
  col4Props,
  formLayout,
  formItemLayout,
  widthStyle,
} from '@/utils/formProps';

const Option = Select.Option;
const CheckboxGroup = Checkbox.Group;

const formItemLayoutOnLine = {
  labelCol: {
    sm: { span: 2 },
  },
  wrapperCol: {
    sm: { span: 22 },
  },
};

@connect(({ loading, HotelCreateEditHotelBasicInfo }) => ({
  HotelCreateEditHotelBasicInfo,
}))
export default class Service extends PureComponent {
  constructor(props) {
    super(props);
    this.state = {
      isShow: true,
    };
  }

  render() {
    let { isShow } = this.state;
    let { HotelCreateEditHotelBasicInfo, changeSelectVal, editType } = this.props;
    let {
      checkinTime,
      checkoutTime,
      payMethodList,
      breakfast,
      styleTagList,
      locationTagList,
      travelTypeTagList,
      breakfastSt,
      breakfastEnd,
    } = HotelCreateEditHotelBasicInfo.hotelInfo;
    let {
      hotel_breakfast,
      hotel_pay_method,
      hotel_tag_style,
      hotel_tag_location,
      hotel_tag_travel_type,
      hotel_breakfast_address,
    } = HotelCreateEditHotelBasicInfo.metadataList;

    return (
      <Card className={styles.basicInfoDetailContainer}>
        <div className={styles.basicInfoDetailTitle} onClick={this.handlerShow}>
          <p>酒店服务信息</p>
          {isShow ? <Icon type="caret-down" /> : <Icon type="caret-up" />}
        </div>
        <div className={styles.basicInfoDetailBd} style={{ display: isShow ? 'block' : 'none' }}>
          <Form layout="inline">
            <Row {...rowProps}>
              <Col {...col4Props}>
                <Form.Item style={widthStyle} label="入住时间" {...formItemLayout}>
                  <TimeSelect
                    disabled={!editType}
                    value={checkinTime}
                    onChange={val => changeSelectVal('checkinTime', val)}
                  />
                </Form.Item>
              </Col>
              <Col {...col4Props}>
                <Form.Item style={widthStyle} label="离店时间" {...formItemLayout}>
                  <TimeSelect
                    disabled={!editType}
                    value={checkoutTime}
                    onChange={val => changeSelectVal('checkoutTime', val)}
                  />
                </Form.Item>
              </Col>
            </Row>

            <Row {...rowProps}>
              <Col {...col4Props}>
                <Form.Item style={widthStyle} label="是否有早餐" {...formItemLayout}>
                  <Select
                    disabled={!editType}
                    onChange={val => this.changeBreakfastVal('breakfastType', val)}
                    value={breakfast.breakfastType}
                  >
                    {hotel_breakfast.map((item, index) => (
                      <Option value={item.value} key={index}>
                        {item.label}
                      </Option>
                    ))}
                  </Select>
                </Form.Item>
              </Col>
              <Col {...col4Props}>
                <Form.Item style={widthStyle} label="早餐开始时间" {...formItemLayout}>
                  <TimeSelect
                    disabled={!editType}
                    value={breakfastSt}
                    onChange={val => changeSelectVal('breakfastSt', val)}
                  />
                </Form.Item>
              </Col>
              <Col {...col4Props}>
                <Form.Item style={widthStyle} label="早餐结束时间" {...formItemLayout}>
                  <TimeSelect
                    disabled={!editType}
                    value={breakfastEnd}
                    onChange={val => changeSelectVal('breakfastEnd', val)}
                  />
                </Form.Item>
              </Col>
              <Col {...col4Props}>
                <Form.Item style={widthStyle} label="早餐地点" {...formItemLayout}>
                  <Select
                    disabled={!editType}
                    onChange={val => this.changeBreakfastVal('addressType', val)}
                    value={breakfast.addressType}
                  >
                    {hotel_breakfast_address.map((item, index) => (
                      <Option value={item.value} key={index}>
                        {item.label}
                      </Option>
                    ))}
                  </Select>
                </Form.Item>
              </Col>
            </Row>

            <Row {...rowProps}>
              <Col {...col1Props}>
                <Form.Item style={widthStyle} label="结账方式" {...formItemLayoutOnLine}>
                  <CheckboxGroup
                    disabled={!editType}
                    onChange={val => changeSelectVal('payMethodList', val)}
                    options={hotel_pay_method}
                    value={payMethodList}
                  />
                </Form.Item>
              </Col>
            </Row>

            <Row {...rowProps}>
              <Col {...col1Props}>
                <Form.Item style={widthStyle} label="酒店风格" {...formItemLayoutOnLine}>
                  <CheckboxGroup
                    disabled={!editType}
                    onChange={val => changeSelectVal('styleTagList', val)}
                    options={hotel_tag_style}
                    value={styleTagList}
                  />
                </Form.Item>
              </Col>
            </Row>
            <Row {...rowProps}>
              <Col {...col1Props}>
                <Form.Item style={widthStyle} label="地理位置" {...formItemLayoutOnLine}>
                  <CheckboxGroup
                    disabled={!editType}
                    onChange={val => changeSelectVal('locationTagList', val)}
                    options={hotel_tag_location}
                    value={locationTagList}
                  />
                </Form.Item>
              </Col>
            </Row>
            <Row {...rowProps}>
              <Col {...col1Props}>
                <Form.Item style={widthStyle} label="出行类型" {...formItemLayoutOnLine}>
                  <CheckboxGroup
                    disabled={!editType}
                    onChange={val => changeSelectVal('travelTypeTagList', val)}
                    options={hotel_tag_travel_type}
                    value={travelTypeTagList}
                  />
                </Form.Item>
              </Col>
            </Row>
          </Form>
        </div>
      </Card>
    );
  }

  changeBreakfastVal(key, val) {
    let breakfast = this.props.HotelCreateEditHotelBasicInfo.hotelInfo.breakfast;

    this.props.dispatch({
      type: 'HotelCreateEditHotelBasicInfo/saveHotelDetail',
      payload: {
        breakfast: {
          ...breakfast,
          [key]: val,
        },
      },
    });
  }

  handlerShow = () => {
    this.setState({
      isShow: !this.state.isShow,
    });
  };
}
