import React, { PureComponent } from 'react';
import { connect } from 'dva';
import { Tabs, Card, Form, Input, Select, Icon, Button } from 'antd';
import PageHeaderWrapper from '@/components/PageHeaderWrapper';
import { EasyMap } from '@/utils/easyFormat';
import Base from './components/Base';
import Service from './components/Service';
import HotelMap from './components/HotelMap';
import Connect from './components/Connect';
import Equipment from '../components/Equipment';
import ButtonList from '../../components/ButtonList';
import FooterToolbar from '@/components/FooterToolbar';
import styles from './basicInfoDetail.less';
import { widthStyle } from '@/utils/formProps';
import { preLoadingMap } from '@/utils/preLoading';

const formItemLayout = {
  style: { width: 340 },
  labelCol: {
    sm: { span: 7 },
  },
  wrapperCol: {
    sm: { span: 17 },
  },
};

const Option = Select.Option;
// const MapKey = 'UpiGzKvHI69ewiB14LucBygfICIEmpvc'; // 'i7kFmYvwiMKvGzGh55UXON1t673zilnX';

@connect(({ HotelCreateEditHotelBasicInfo }) => ({
  HotelCreateEditHotelBasicInfo,
}))
export default class HotelDetail extends PureComponent {
  constructor(props) {
    super(props);
    this.state = {
      hotelId: '',
      isRequestaAll: false,
      isSaveRequest: false,
      type: 'query', // edit
    };
  }

  componentWillMount() {
    let { hotelId } = this.props.location.query;

    this.setState({
      hotelId,
    });
  }

  componentDidMount() {
    let { HotelCreateEditHotelBasicInfo, dispatch } = this.props;
    let { hotelId } = this.state;

    dispatch({
      type: 'HotelCreateEditHotelBasicInfo/getMetadataList',
    });

    dispatch({
      type: 'HotelCreateEditHotelBasicInfo/getBase',
      payload: { hotelId },
    });

    Promise.all([
      dispatch({
        type: 'HotelCreateEditHotelBasicInfo/getHotelDetailInfo',
        payload: { hotelId },
      }),
      dispatch({
        type: 'HotelCreateEditHotelBasicInfo/getBrand',
      }),
      preLoadingMap(),
    ]).then(() => {
      this.setState({
        isRequestaAll: true,
      });
      dispatch({
        type: 'HotelCreateEditHotelBasicInfo/saveSubBranch',
      });
    });
  }

  // async addBMap() {
  //   return new Promise((resolve, reject) => {
  //     if (window.BMap) {
  //       resolve();
  //     } else {
  //       window.HOST_TYPE = '2';
  //       window.BMap_loadScriptTime = new Date().getTime();

  //       let url = `https://api.map.baidu.com/getscript?v=2.0&ak=${MapKey}&services=&t=${
  //         window.BMap_loadScriptTime
  //       }&s=1`;

  //       let script = document.createElement('script');

  //       script.charset = 'utf-8';
  //       script.src = url;

  //       document.head.appendChild(script);

  //       script.onload = () => {
  //         resolve();
  //       };
  //     }
  //   });
  // }

  render() {
    let { isRequestaAll, hotelId, isSaveRequest, type } = this.state;
    let { HotelCreateEditHotelBasicInfo, history } = this.props;
    const editType = type === 'edit';

    return (
      <PageHeaderWrapper>
        <ButtonList
          code="CRS7.2.1.2"
          hotelId={hotelId}
          callBack={this.changeEditType}
          type={type}
          status={HotelCreateEditHotelBasicInfo.status}
        />
        <div className={styles.basicInfoDetail}>
          <Base
            formItemLayout={formItemLayout}
            hotelId={hotelId}
            changeInputVal={this.changeInputVal}
            changeSelectVal={this.changeSelectVal}
            editType={editType}
          />
          <Service
            formItemLayout={formItemLayout}
            hotelId={hotelId}
            changeSelectVal={this.changeSelectVal}
            changeInputVal={this.changeInputVal}
            editType={editType}
          />
          {isRequestaAll ? (
            <HotelMap
              formItemLayout={formItemLayout}
              hotelId={hotelId}
              changeInputVal={this.changeInputVal}
              changeSelectVal={this.changeSelectVal}
              editType={editType}
            />
          ) : null}
          <Connect formItemLayout={formItemLayout} hotelId={hotelId} />
          <Equipment
            formItemLayout={formItemLayout}
            hotelId={hotelId}
            data={HotelCreateEditHotelBasicInfo.hotelInfo.amenities}
            onChange={this.handlerEquipment}
            editType={editType}
          />
          <FooterToolbar style={widthStyle}>
            <Button
              type="primary"
              disabled={!isRequestaAll || !editType}
              loading={isSaveRequest}
              onClick={this.save}
            >
              保存
            </Button>
            <Button
              onClick={() => {
                history.push('/');
              }}
            >
              取消
            </Button>
          </FooterToolbar>
        </div>
      </PageHeaderWrapper>
    );
  }

  changeInputVal = (key, e) => {
    let val = e.target.value;

    this.props.dispatch({
      type: 'HotelCreateEditHotelBasicInfo/saveHotelDetail',
      payload: {
        [key]: val,
      },
    });
  };

  changeSelectVal = (key, val) => {
    this.props.dispatch({
      type: 'HotelCreateEditHotelBasicInfo/saveHotelDetail',
      payload: {
        [key]: val,
      },
    });
  };

  handlerEquipment = ({ baseAmenities, moreAmenities }) => {
    this.props.dispatch({
      type: 'HotelCreateEditHotelBasicInfo/saveHotelDetail',
      payload: {
        amenities: baseAmenities.concat(moreAmenities),
      },
    });
  };

  onCooperationModel = () => {};

  save = async () => {
    this.setState({
      isSaveRequest: true,
    });

    let res = await this.props.dispatch({
      type: 'HotelCreateEditHotelBasicInfo/save',
      payload: {
        hotelId: this.state.hotelId,
      },
    });

    this.setState({
      isSaveRequest: false,
    });
  };

  // 是否可以编辑
  changeEditType = type => {
    this.setState({
      type,
    });
  };
}
