import React, { PureComponent } from 'react';
import { Select } from 'antd';
import OYOForm from '@/components/OyoForm/SearchForm';
import { queryAllValidatedChannel } from './service';

type ChannelItem = {
  channelId: number | string;
  channelName: string;
};

type FormValue = {
  channelId: number | string;
  payType: number | string;
  checkinType: number | string;
  handleType: number | string;
};

interface BasicPriceFilterProps {
  onChange?: (values: FormValue) => void;
}

interface BasicPriceFilterState {
  channelList: ChannelItem[];
}

const { Option } = Select;

export default class BasicPriceFilter extends PureComponent<
  BasicPriceFilterProps,
  BasicPriceFilterState
> {
  state = {
    channelList: [],
  };

  OYOForm = null;

  componentDidMount() {
    queryAllValidatedChannel()
      .then(({ data }) => {
        let channelList = data || [];
        // 筛选直连渠道
        channelList = channelList.filter(({ isDirect }) => isDirect === 1);
        channelList.forEach(item => {
          item.channelName = '渠道价-' + item.channelName;
        });
        this.setState({ channelList });
      })
      .catch(err => console.log('获取有效直连渠道出错', err));
  }

  getFormFields = () => {
    const { state, onChange } = this;
    const { channelList } = state;

    return [
      {
        label: '渠道',
        type: 'channelId',
        options: { initialValue: null, onChange },
        component: (
          <Select
            filterOption={(input, option) => {
              let opt = option.props.children.toString();
              return opt.includes(input.toLowerCase());
            }}
            showSearch
          >
            <Option value={null}>基准价</Option>
            {channelList.map(({ channelId, channelName }) => (
              <Option value={channelId} key={channelId}>
                {channelName}
              </Option>
            ))}
          </Select>
        ),
      },
      {
        label: '支付方式',
        type: 'payType',
        options: { initialValue: 1, onChange },
        component: (
          <Select>
            <Option value={0}>现付</Option>
            <Option value={1}>预付</Option>
            <Option value={2}>信用住</Option>
          </Select>
        ),
      },
      {
        label: '房间类型',
        type: 'checkinType',
        options: { initialValue: 1, onChange },
        component: (
          <Select>
            <Option value={1}>全天房</Option>
            <Option value={2}>钟点房</Option>
          </Select>
        ),
      },
    ];
  };

  onChange = (value, option) => {
    setTimeout(() => {
      typeof this.props.onChange === 'function' && this.props.onChange(this.getValues());
    });
  };

  public getValues = () => {
    const values = this.OYOForm ? this.OYOForm.getFieldsValue() : {};

    if (values.channelId === null) {
      // 基准价
      values.channelId = undefined;
      values.handleType = 1;
    } else {
      // 渠道控价
      values.handleType = 0;
    }

    return { ...values };
  };

  render() {
    return (
      <OYOForm
        noSubmit
        fields={this.getFormFields()}
        ref={ref => {
          this.OYOForm = ref;
        }}
      />
    );
  }
}
