import React, { PureComponent } from 'react';
import { Tabs, DatePicker, Input, Row, Col, message, Select, Button, Alert } from 'antd';
import moment from 'moment';
import { connect } from 'dva';
import _ from 'lodash';
import { getDayHotelPrice, updateRoomTypePrice } from './service/index';
import { getRoomType } from '@/models/roomTypeAndRelation';
import MultiSelection from '@/components/MultiSelection/MultiSelection';
import {
  WEEK_LIST,
  DateFiliter,
  transDefaultList,
  transWeeklyList,
  getDisableList,
} from '@/utils/dateFiliterWeekday';
import ButtonAuthorized from '@/components/ButtonAuthorized';
import BasicPriceFilter from './BasicPriceFilter.tsx';

const Option = Select.Option;
const { RangePicker } = DatePicker;

const dateFormat = 'YYYY-MM-DD';

let day = new Date();
let currentDay = `${day.getFullYear()}-${day.getMonth() + 1}-${day.getDate()}`;

@connect(({ global, user, roomTypeAndRelation }) => ({ global, user, roomTypeAndRelation }))
export default class HotelPrice extends PureComponent {
  constructor(props) {
    super(props);
    this.state = {
      rangeDate: [[currentDay, currentDay]],
      week: '',
      weekly: [],
      weekDisableList: [],
      list: [],
      listVisible: true,
      weekList: [],
      errMsgVisible: false,
      isShowTopWarning: false,
    };
  }

  componentDidMount() {
    const { HOTEL_ROOM_TYPE } = this.props.global;
    let { weekly, rangeDate } = this.state;

    const allRoomType = HOTEL_ROOM_TYPE.map(({ roomTypeName, roomTypeId }) => ({
      roomTypeName,
      roomTypeId,
    }));

    this.setState({ allRoomType }, () => {
      this.getHotelPrice();
    });

    this.props.dispatch({ type: 'roomTypeAndRelation/fetchList', payload: {} });

    weekly = DateFiliter.handleSection(rangeDate);
    const weekDisableList = getDisableList(weekly);

    this.setState({ weekly, rangeDate, weekDisableList, weekList: weekly });
  }

  onDateChange = e => {
    let { weekly, rangeDate } = this.state;

    if (e.length !== 0) {
      let obj = {};
      obj = [moment(e[0]).format(dateFormat), moment(e[1]).format(dateFormat)];
      rangeDate[0] = obj;
    } else {
      rangeDate.splice(0, 1);
    }
    weekly = DateFiliter.handleSection(rangeDate);
    const weekDisableList = getDisableList(weekly);

    this.setState({ weekly, rangeDate, weekDisableList, weekList: weekly, listVisible: false });
  };

  onWeekList = (arr, listIndex) => {
    this.setState({ weekly: transWeeklyList(listIndex), weekList: listIndex, listVisible: false });
  };

  closeEdit = (e, index) => {
    const list = this.state.list.slice();
    const item = list[index];

    list[index] = {
      ...item,
      lastData: item.lastData,
      ...item.lastData,
    };
    this.setState({ list }, () => {
      this.changeEditStatus(e, index);
    });
  };

  changeEditStatus = (e, index) => {
    const list = this.state.list.slice();
    list[index].edit = !list[index].edit;

    this.setState({ list });
  };

  inputPrice = (e, i) => {
    const { value } = e.target;

    if (!/^\d*$/.test(value)) return;

    const { list } = this.state;
    list[i].rate = value;

    this.setState({ list: [...list] });
  };

  handlePriceChange = () => {
    const { rangeDate, weekly, list } = this.state;

    if (rangeDate.length && weekly.length) {
      this.setState({ listVisible: true, errMsgVisible: false }, () => {
        this.getHotelPrice(rangeDate[0][0]);
      });
    } else {
      this.setState({ errMsgVisible: true });
    }
  };

  valiValue = roomPrice => {
    if (roomPrice > 9999 || roomPrice < 20) {
      return { status: false, msg: '请输入符合限价范围的价格' };
    }

    return { status: true };
  };

  priceChange = _.debounce((e, item, index) => {
    const { rangeDate, weekly } = this.state;
    const price = Number(item.rate);
    const filterValue = this.bpFilter.getValues();

    const params = {
      ...filterValue,
      startDate: rangeDate[0][0],
      endDate: rangeDate[0][1],
      activeDay: weekly,
      roomTypeId: item.roomTypeId,
      price,
      hotelId: this.props.hotelId,
    };

    const isValueCanUp = this.valiValue(price);

    if (!isValueCanUp.status) return message.warning(isValueCanUp.msg);

    if (rangeDate.length < 0 || weekly.length < 0) {
      return message.error('日期范围与生效日选择不正确');
    }

    updateRoomTypePrice(params)
      .then(res => {
        if (res.code === '000') {
          message.success('改价成功！');
          this.changeEditStatus(e, index);
        }
      })
      .catch(err => {
        console.log(err);
      });
  }, 1000);

  getHotelPrice = dateString => {
    const { hotelId } = this.props;
    const { rangeDate } = this.state;
    const rateDate = dateString || moment().format(dateFormat);

    const filterValue = this.bpFilter.getValues();

    getDayHotelPrice({ ...filterValue, hotelId, rateDate })
      .then(({ data }) => {
        let list = [];
        if (Array.isArray(data)) {
          list = data.map(({ rate, roomTypeId }) => ({
            rate: rangeDate[0][0] === rangeDate[0][1] ? rate : null,
            roomTypeId,
            lastData: { rate, roomTypeId },
          }));
        }
        this.setState({ list });
      })
      .catch(e => {
        console.log(e);
      });
  };

  onFilterChange = values => {
    this.setState({ list: [], isShowTopWarning: values.handleType !== 1 }, this.getHotelPrice);
  };

  render() {
    const { type } = this.props;
    const {
      list,
      week,
      weekly,
      weekDisableList,
      listVisible,
      errMsgVisible,
      isShowTopWarning,
    } = this.state;

    return (
      <div>
        {isShowTopWarning && (
          <Alert
            style={{ marginBottom: 10 }}
            description="渠道价改价，仅对控价房型生效"
            type="warning"
            showIcon
          />
        )}
        <BasicPriceFilter
          onChange={this.onFilterChange}
          ref={ref => {
            this.bpFilter = ref;
          }}
        />
        <Row>
          <Col span={10}>
            日期范围
            <RangePicker
              onChange={this.onDateChange}
              style={{ marginLeft: 10 }}
              defaultValue={[moment(currentDay, dateFormat), moment(currentDay, dateFormat)]}
            />
          </Col>
          <Col span={10} style={{ display: 'flex', paddingTop: 2 }}>
            <span style={{ marginRight: 10, paddingTop: 4 }}>生效日</span>
            <MultiSelection
              ref={re => {
                this.weekRef = re;
              }}
              disableList={transDefaultList(weekDisableList)}
              value={transDefaultList(weekly)}
              list={WEEK_LIST}
              onChange={(arr, listIndex) => this.onWeekList(arr, listIndex)}
            />
          </Col>
          <Col span={4}>
            <Button type="primary" onClick={this.handlePriceChange}>
              对选择范围改价
            </Button>
          </Col>
        </Row>
        {!errMsgVisible ? (
          <p>请选择需要修改的日期范围和适用策略后点击查询，如无特殊周策略，保持全选查询。</p>
        ) : (
          <p style={{ color: '#F5222D' }}>日期范围与生效日选择不正确</p>
        )}

        <Row style={{ color: '#aaa', marginTop: 20 }}>
          <Col span={6}>房型</Col>
          <Col span={16}>改价</Col>
        </Row>

        {listVisible &&
          list.map((item, index) => (
            <Row style={{ marginTop: 10 }} key={index}>
              <Col span={6} style={{ marginTop: 10 }}>
                {getRoomType(item.roomTypeId).roomTypeName}
              </Col>
              <Col span={16}>
                <Row>
                  <Col span={9}>
                    <Input
                      style={{ width: 200 }}
                      addonBefore="¥"
                      value={item.rate}
                      disabled={!item.edit}
                      onChange={e => this.inputPrice(e, index)}
                    />
                  </Col>

                  <Col span={6}>
                    {!item.edit ? (
                      <ButtonAuthorized
                        type="primary"
                        code="CRS7.2.5.1"
                        onClick={e => this.changeEditStatus(e, index)}
                      >
                        修改
                      </ButtonAuthorized>
                    ) : (
                      <>
                        <Button type="primary" onClick={e => this.priceChange(e, item, index)}>
                          保存
                        </Button>
                        <Button onClick={e => this.closeEdit(e, index)} style={{ marginLeft: 10 }}>
                          取消
                        </Button>
                      </>
                    )}
                  </Col>
                </Row>
              </Col>
            </Row>
          ))}
      </div>
    );
  }
}
