import React, { PureComponent } from 'react';
import { connect } from 'dva';
import moment from 'moment';
import {
  Tabs,
  Card,
  DatePicker,
  Radio,
  Input,
  Row,
  Col,
  Slider,
  InputNumber,
  Divider,
  Calendar,
  Badge,
} from 'antd';
import BasicPriceFilter from './BasicPriceFilter.tsx';
import styles from './BenchmarkPrice.less';
import { getHotelListRateByMonth } from './service';

let allRoomType = [];

function findNameFromId(id, list) {
  const obj = list.find(item => item.roomTypeId === id);
  if (obj && obj.roomTypeName) {
    return obj.roomTypeName;
  }
  return '';
}

function dateCellRender(value, formatObj) {
  const key = value.format('YYYY-MM-DD');
  const listData = formatObj[key];

  if (listData) {
    return (
      <ul className="events">
        {listData.map(item => (
          <li key={item.roomTypeId}>
            {`${findNameFromId(item.roomTypeId, allRoomType)}:${item.rate}(${item.availableStock ||
              0})`}
          </li>
        ))}
      </ul>
    );
  }
  return null;
}

function formatList(list) {
  const obj = {};

  list.forEach(element => {
    if (!obj[element.rateDate]) {
      obj[element.rateDate] = [];
    }
    obj[element.rateDate].push(element);
  });

  return obj;
}

@connect(({ global, user, roomTypeAndRelation }) => ({ global, roomTypeAndRelation, user }))
export default class PriceDate extends PureComponent {
  constructor(props) {
    super(props);

    const { defaultDate } = props.location.query;
    const time = defaultDate ? moment(defaultDate) : moment();

    this.state = {
      time: time.format('YYYY-MM'),
      list: [],
      formatObj: {},
      defaultDate,
    };
  }

  componentDidMount() {
    this.getRelationList();
  }

  componentWillReceiveProps(nextProps) {
    if (!this.props.isActive && nextProps.isActive) {
      this.getRelationList();
    }
  }

  async getRelationList() {
    await this.props.dispatch({ type: 'roomTypeAndRelation/fetchList', payload: {} });

    const { list = [] } = this.props.roomTypeAndRelation;

    allRoomType = list.map(({ roomTypeName, roomTypeId }) => ({ roomTypeName, roomTypeId }));

    this.getPriceList();
  }

  getPriceList = async () => {
    const { hotelId } = this.props;
    const { time } = this.state;
    const filterValue = this.bpFilter.getValues();

    const res = await getHotelListRateByMonth({
      ...filterValue,
      hotelId,
      rateDate: time,
    });

    const list = res.data || [];
    const formatObj = formatList(list);

    this.setState({ list, formatObj });
  };

  onChange = data => {
    this.setState({ time: data.format('YYYY-MM') }, () => {
      this.getPriceList();
    });
  };

  onFilterChange = values => {
    this.getPriceList();
  };

  render() {
    const { onFilterChange, onChange } = this;

    const { formatObj, defaultDate } = this.state;
    const otherProps = defaultDate ? { defaultValue: moment(defaultDate) } : {};

    return (
      <div>
        <BasicPriceFilter
          onChange={onFilterChange}
          ref={ref => {
            this.bpFilter = ref;
          }}
        />
        <Calendar
          dateCellRender={value => dateCellRender(value, formatObj)}
          onChange={onChange}
          className={styles.main}
          {...otherProps}
        />
      </div>
    );
  }
}
