import React, { PureComponent } from 'react';
import {
  Tabs,
  Card,
  DatePicker,
  Radio,
  Input,
  Row,
  Col,
  Slider,
  InputNumber,
  Divider,
  Calendar,
  Badge,
} from 'antd';
import { connect } from 'dva';
import HotelPrice from './HotelPrice';
import PriceDate from './PriceDate';
import ButtonList from '../../components/ButtonList';
import BasicOperation from '../components/BasicOperation';
import { getPriceOperateLog } from '../service/housePriceChannel';
import { CHECK_IN_TYPE } from '@/constant/checkInType';
import { PAY_TYPE } from '@/constant/payType';
import { HANDLE_TYPE } from '@/constant/handleType';

const TabPane = Tabs.TabPane;
@connect(({ HotelCreateEditHotelBasicInfo }) => ({
  HotelCreateEditHotelBasicInfo,
}))
export default class BenchmarkPriceIndex extends PureComponent {
  constructor(props) {
    super(props);

    const { componentTab = '1' } = props.location.query;

    this.state = {
      type: 'query', // edit
      activeType: componentTab,
    };
    this.columns = [
      {
        title: '时间',
        dataIndex: 'operateTime',
      },
      {
        title: '操作人',
        dataIndex: 'operateName',
        render: (operateName, record) => (
          <span>
            {operateName}
            {record.operateId || record.operateId === 0 ? `(${record.operateId})` : null}
          </span>
        ),
      },
      {
        title: '变动类型',
        dataIndex: 'changeType',
      },
      {
        title: '日期策略',
        dataIndex: 'frameTime',
      },
      {
        title: '房型',
        dataIndex: 'roomTypeName',
      },
      {
        title: '价格变动',
        dataIndex: 'rate',
      },
      {
        title: '控价模式',
        dataIndex: 'handleType',
        render: handleType => {
          // 处理字典中有{ value: null, name: "全部"}
          if (handleType === null) return null;
          const type = HANDLE_TYPE.find(({ value }) => value === handleType);
          return type ? type.name : null;
        },
      },
      {
        title: '渠道',
        dataIndex: 'channelName',
      },
      {
        title: '入住类型',
        dataIndex: 'checkinType',
        render: checkinType => {
          if (checkinType === null) return null;
          const type = CHECK_IN_TYPE.find(({ value }) => value === checkinType);
          return type ? type.name : null;
        },
      },
      {
        title: '支付类型',
        dataIndex: 'payType',
        render: payType => {
          if (payType === null) return null;
          const type = PAY_TYPE.find(({ value }) => value === payType);
          return type ? type.name : null;
        },
      },
      {
        title: '备注',
        dataIndex: 'remark',
      },
    ];
  }

  tabChange = activeType => {
    this.setState({
      activeType,
    });
  };

  changeType = type => {
    this.setState({
      type,
    });
  };

  render() {
    let { tabChange, changeType, callBackStatus } = this;
    let { hotelId, status, location } = this.props;
    let { type, activeType } = this.state;

    return (
      <div>
        {/* <ButtonList
          code="CRS7.2.5.1"
          hotelId={hotelId}
          status={status}
          type={type}
          callBack={changeType}
          callBackStatus={callBackStatus}
        /> */}

        <Tabs activeKey={activeType} onChange={tabChange} type="card">
          <TabPane tab="更改房价" key="1">
            <HotelPrice hotelId={hotelId} status={status} type={type} />
          </TabPane>
          <TabPane tab="价格日历" key="2">
            <PriceDate
              hotelId={hotelId}
              status={status}
              location={location}
              isActive={activeType === '2'}
            />
          </TabPane>
          <TabPane tab="操作日志" key="3">
            <BasicOperation
              columns={this.columns}
              hotelId={hotelId}
              onLogOperation={getPriceOperateLog}
              rowKey="id"
            />
          </TabPane>
        </Tabs>
      </div>
    );
  }
}
