import React from 'react';
import { Rate, List, Avatar, Switch, Row, Col, message, Tabs } from 'antd';
import moment from 'moment';
import Link from 'umi/link';
import { connect } from 'dva';
// import WrappedSearchForm from './HotelCommentForm';
import CustomerServiceComment from './components/CustomerServiceComment';
import UserComment from './components/UserComment';
import judgePermission from '@/utils/judgePermission';

const defaultStyle = {
  overflow: 'hidden',
  textOverflow: 'ellipsis',
  display: '-webkit-box',
  WebkitLineClamp: 3,
  WebkitBoxOrient: 'vertical',
  paddingRight: '50px',
  totalRate: 0,
  totalCount: 0,
};
const dateFormat = 'YYYY-MM-DD HH:mm:ss';
const TabPane = Tabs.TabPane;

const tabType = [
  {
    text: '用户评论',
    key: '1',
    component: UserComment,
    show: judgePermission('CRS7.2.7.1'),
  },
  {
    text: '客服评论',
    key: '2',
    component: CustomerServiceComment,
    show: judgePermission('CRS7.2.7.2'),
  },
];
@connect(({ HotelComment }) => ({
  HotelComment,
}))
class HotelComment extends React.PureComponent {
  state = {
    total: 0,
    comments: [],
    currentPage: 1,
    pageSize: 10,
    query: {},
    customerQuery: {},
    activeType: `${tabType.findIndex(item => item.show) + 1}`,
  };

  componentDidMount() {
    this.onFetchHotelCommissionById();
  }

  onSearch = query => {
    this.setState(
      {
        query,
      },
      this.onFetchHotelCommissionById
    );
  };

  onFetchHotelCommissionById = () => {
    const { currentPage, pageSize, query, activeType } = this.state;
    let hotelId = this.props.hotelId;

    const params = {
      ...query,
      start: (currentPage - 1) * pageSize,
      hits: pageSize,
      hotelId,
      commentType: Number(activeType),
    };
    const url = activeType === '1' ? 'fetchHotelCommissionById' : 'fetchCustomerCommissionById';
    this._dispatch(url, params, data => {
      let comments = [];

      let total = 0;
      if (data && data.commentList && data.count) {
        comments = [...data.commentList];
        comments.forEach(item => {
          item.isDisplayAll = false;
        });
        total = data.count;
      }
      this.setState({
        comments,
        total,
      });
    });
  };

  getAverageRate = () => {
    let hotelId = this.props.hotelId;
    this._dispatch(
      'getAverageRate',
      {
        hotelIds: hotelId,
        commentType: 2,
      },
      data => {
        if (data && data.length) {
          this.setState({
            totalRate: data[0].averageRateInfo.customerServiceAverageTotalRate || 0,
            totalCount: data[0].averageRateInfo.customerServiceCommentCount || 0,
          });
        }
      }
    );
  };

  _dispatch = (url, payload, fn) => {
    const { dispatch } = this.props;
    const params = {
      type: `HotelComment/${url}`,
      payload,
    };
    dispatch(params)
      .then(({ code, data }) => {
        if (code === '000') {
          fn(data);
        }
      })
      .catch(er => {
        console.log(er);
      });
  };

  onShowSizeChange = (current, pageSize) => {
    this.setState(
      {
        currentPage: current,
        pageSize,
      },
      this.onFetchHotelCommissionById
    );
  };

  onQuickJumper = pageNumber => {
    this.setState(
      {
        currentPage: pageNumber,
      },
      this.onFetchHotelCommissionById
    );
  };

  onSwitchChange = (evt, item) => {
    // 1:正常，5：隐藏
    const status = evt ? '5' : '1';
    const payload = {
      status,
      id: item.id,
    };
    this._dispatch('updateHotelCommissionStatus', payload, () => {
      message.success('修改成功');
    });
  };

  caclTime = (start, end) => Math.ceil((end - start) / 1000 / 60 / 60 / 24);

  onTrigger = item => {
    const { comments } = this.state;
    comments.forEach(it => {
      if (it.id === item.id) {
        it.isDisplayAll = !it.isDisplayAll;
      }
    });
    this.setState({
      comments: [...comments],
    });
  };

  formatDate = date => moment(+date).format('YYYY-MM-DD');

  listItemTitle = (rate, startTime, endTime, num, roomType, createTime) => (
    <Row style={{ marginBottom: 10 }}>
      <Col span={4}>
        <Rate value={+rate} disabled />
      </Col>

      <Col span={6} style={{ marginTop: 7 }}>
        {this.formatDate(startTime)} 至 {this.formatDate(endTime)}
        入住
      </Col>
      <Col span={2} style={{ marginTop: 7 }}>
        {num}房{this.caclTime(startTime, endTime)}晚
      </Col>
      <Col span={4} style={{ marginTop: 7 }}>
        {' '}
        {roomType}
      </Col>

      <Col span={4} offset={4} style={{ marginTop: 7 }}>
        {' '}
        {`${this.formatDate(createTime)} 发表`}
      </Col>
    </Row>
  );

  solveDate = val => moment(new Date(Number(val))).format(dateFormat);

  listTag = item => {
    let arr = item.commentTags.concat(item.commentSubTags);
    if (arr.length) {
      let strArr = arr.map(val => val.tagContent);
      return <span>{`#${strArr.join('##')}#`}</span>;
    }
    return <span />;
  };

  tableDom = () => {
    const { comments, total, pageSize, currentPage } = this.state;
    const defaultAvatar = 'https://zos.alipayobjects.com/rmsportal/ODTLcjxAfvqbxHnVXCYX.png';
    const pagination = {
      showSizeChanger: true,
      showQuickJumper: true,
      onChange: this.onQuickJumper,
      onShowSizeChange: this.onShowSizeChange,
      current: currentPage,
      pageSize,
      total,
    };
    return (
      <List
        style={{ marginTop: 20 }}
        itemLayout="vertical"
        dataSource={comments}
        pagination={pagination}
        renderItem={item => (
          <List.Item key={item.userName}>
            {/* <List.Item.Meta
              // avatar={<Avatar src={item.avatar || defaultAvatar} />}
              title={item.userName}
              description={item.description}
            /> */}
            <Row>
              <Col span={4} style={{ fontSize: 16 }}>
                {item.userName}
              </Col>
              <Col span={6} offset={14}>
                {item.isFiltered === 1 ? (
                  '该评论含敏感内容，前端已屏蔽'
                ) : (
                  <div>
                    <span style={{ paddingLeft: 90, marginRight: 5 }}>隐藏评论</span>
                    <Switch
                      checkedChildren="是"
                      unCheckedChildren="否"
                      defaultChecked={`${item.status}` === '5'}
                      onChange={evt => this.onSwitchChange(evt, item)}
                    />
                  </div>
                )}
              </Col>
            </Row>
            <div>
              {this.listItemTitle(
                item.totalRate,
                item.arriveDate,
                item.departureDate,
                item.number,
                item.roomTypeDesc,
                item.createTime
              )}
            </div>
            <div
              onClick={() => this.onTrigger(item)}
              style={item.isDisplayAll ? { paddingRight: '50px' } : defaultStyle}
            >
              {item.comment}
            </div>
          </List.Item>
        )}
      />
    );
  };

  customerTableDom = () => {
    const { comments, total, pageSize, currentPage } = this.state;
    const defaultAvatar = 'https://zos.alipayobjects.com/rmsportal/ODTLcjxAfvqbxHnVXCYX.png';
    const pagination = {
      showSizeChanger: true,
      showQuickJumper: true,
      onChange: this.onQuickJumper,
      onShowSizeChange: this.onShowSizeChange,
      current: currentPage,
      pageSize,
      total,
    };
    return (
      <List
        style={{ marginTop: 20 }}
        itemLayout="vertical"
        dataSource={comments}
        pagination={pagination}
        renderItem={item => (
          <List.Item key={item.userName}>
            {/* <List.Item.Meta
              // avatar={<Avatar src={item.avatar || defaultAvatar} />}
              title={item.userName}
              description={item.description}
            /> */}
            <Row>
              <Col span={4} style={{ fontSize: 16 }}>
                <span style={{ fontWeight: 'bold' }}>{`客服ID：${item.operatorId}`}</span>
              </Col>
            </Row>
            <Row type="flex" justify="space-between" align="middle">
              <Col span={8}>
                <Rate style={{ fontSize: 20 }} count={10} disabled value={item.totalRate} />
              </Col>
              <Col span={6}>
                <div>
                  <span>订单ID：</span>
                  <Link to={`/order/detail/order?bookingId=${item.bookingId}`}>
                    {item.bookingSn || item.bookingId}
                  </Link>
                </div>
              </Col>
              <Col span={6}>
                <div>
                  <span>评价时间：</span>
                  <span>{`${this.solveDate(item.createTime)}`}</span>
                </div>
              </Col>
            </Row>
            <Row>
              <Col span={24}>{this.listTag(item.tags)}</Col>
            </Row>
            <Row>
              <Col span={24}>
                <p>{item.comment}</p>
              </Col>
            </Row>
          </List.Item>
        )}
      />
    );
  };

  callback = key => {
    this.setState({
      activeType: key,
      currentPage: 1,
      pageSize: 10,
      query: {},
      comments: [],
    });
  };

  render() {
    const { activeType, totalRate, totalCount } = this.state;
    const info = {
      totalRate,
      totalCount,
    };
    return (
      <section>
        {/* <WrappedSearchForm onSearch={this.onSearch} /> */}
        {/* {this.tableDom()} */}
        <Tabs defaultActiveKey={activeType} onChange={this.callback} type="card">
          {tabType.map(item => (
            <TabPane tab={item.text} key={item.key} disabled={!item.show}>
              {activeType === item.key ? (
                <item.component
                  customerComentCount={info}
                  getCommentRate={this.getAverageRate}
                  type={activeType}
                  solveSearch={this.onSearch}
                />
              ) : null}
            </TabPane>
          ))}
        </Tabs>
        {activeType === '1' && this.tableDom()}
        {activeType === '2' && this.customerTableDom()}
      </section>
    );
  }
}

export default HotelComment;
