import React from 'react';
import { Button, DatePicker, Input, Select, Form, Col } from 'antd';
import { formatMoney } from '@/utils/utils';

const FormItem = Form.Item;
const Option = Select.Option;
const { RangePicker } = DatePicker;

const option = {
  star2: [0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10],
  star1: [1, 2, 3, 4, 5],
};

const formItemLayout = {
  labelCol: {
    xs: { span: 24 },
    sm: { span: 7 },
  },
  wrapperCol: {
    xs: { span: 24 },
    sm: { span: 17 },
  },
};

const formItemLayout2 = {
  labelCol: {
    span: 5,
  },
  wrapperCol: {
    span: 19,
  },
};

const defaultForm = {
  username: '',
  comment: '',
  startTime: '',
  endTime: '',
  totalRate: [],
};
// 搜索表单
class SearchForm extends React.Component {
  handleSearch = e => {
    e.preventDefault();
    const { onSearch, form } = this.props;
    const comment = form.getFieldValue('comment');
    const releaseTime = form.getFieldValue('releaseTime');
    const totalRate = form.getFieldValue('totalRate');
    const query = {
      ...defaultForm,
    };
    if (comment) {
      query.username = comment;
      query.comment = comment;
      query.keyword = comment;
    }
    if (releaseTime && releaseTime.length > 1) {
      query.startTime = `${releaseTime[0].format('YYYY-MM-DD')} 00:00:00`;
      query.endTime = `${releaseTime[1].format('YYYY-MM-DD')} 23:59:59`;
    }
    if (totalRate) {
      query.totalRate = totalRate;
    }
    onSearch(query);
  };

  handleReset = () => {
    const { onSearch, form } = this.props;
    form.resetFields();
    onSearch({ ...defaultForm });
  };

  render() {
    const {
      form: { getFieldDecorator },
      type,
    } = this.props;
    const selectOption = option[`star${type}`].map(val => (
      <option key={val} value={val}>{`${val}分`}</option>
    ));
    return (
      <Form layout="inline" onSubmit={this.handleSearch}>
        <Col span={5}>
          {type === '1' && (
            <FormItem label="关键词:" {...formItemLayout}>
              {getFieldDecorator(`comment`, { initialValue: '' })(
                <Input placeholder="关键词" maxLength={20} />
              )}
            </FormItem>
          )}
          {type === '2' && (
            <FormItem>
              {this.props.customerComentCount.totalRate >= 0 && (
                <p style={{ marginRight: 100 }}>
                  <span style={{ fontSize: 20 }}>
                    {formatMoney(this.props.customerComentCount.totalRate, 1)}
                    分/
                  </span>
                  {this.props.customerComentCount.totalCount}条
                </p>
              )}
            </FormItem>
          )}
        </Col>
        <Col span={8}>
          <FormItem label="发布时间:" {...formItemLayout2}>
            {getFieldDecorator(`releaseTime`, { initialValue: [] })(<RangePicker />)}
          </FormItem>
        </Col>
        <Col span={6}>
          <FormItem label="评分:" {...formItemLayout}>
            {getFieldDecorator(`totalRate`)(
              <Select mode="multiple" style={{ width: 240 }}>
                {selectOption}
              </Select>
            )}
          </FormItem>
        </Col>
        <Col span={4} offset={1}>
          <FormItem>
            <Button type="primary" htmlType="submit">
              搜索
            </Button>
            <Button style={{ marginLeft: 8 }} onClick={this.handleReset}>
              重置
            </Button>
          </FormItem>
        </Col>
      </Form>
    );
  }
}

export default Form.create()(SearchForm);
