import React, { Fragment } from 'react';
import { Table, InputNumber, Select, Button, Message, Popconfirm, Alert } from 'antd';
import { connect } from 'dva';
import router from 'umi/router';

const Option = Select.Option;

const EditableContext = React.createContext();
const EditableRow = ({ form, index, ...props }) => (
  <EditableContext.Provider value={form}>
    <tr {...props} />
  </EditableContext.Provider>
);

// 输入框样式
const formItemStyle = {
  style: {
    width: '100%',
  },
};
@connect(({ global, HotelCreateEditHousePriceChannel }) => ({
  global,
  HotelCreateEditHousePriceChannel,
}))
class HouseTypeBindHotel extends React.Component {
  constructor(props) {
    super(props);
    this.state = {
      channelCommissions: [],
      validatedChannelListOption: [],
      commissionOption: [],
      statusOption: [],
      eidtType: 'query',
      editable: false,
    };
    this.columns = [
      {
        title: '渠道名称',
        dataIndex: 'channelId',
        key: 'channelId',
        editable: true,
        render: (text, record) => (
          <Select
            {...formItemStyle}
            defaultValue={text}
            value={text}
            onSelect={(value, opt) => this.handleSelect(value, opt, record.channelId)}
            placeholder="请选择渠道名称"
            disabled={this.state.editType === 'query' || (!!text && !record.isCreated)}
          >
            {this.state.validatedChannelListOption}
          </Select>
        ),
      },
      {
        title: '佣金类型',
        dataIndex: 'applyType',
        key: 'applyType',
        editable: true,
        render: (text, record) => (
          <Select
            {...formItemStyle}
            defaultValue={text}
            value={text}
            onSelect={(value, opt) => this.handleSelect(value, opt, record.channelId)}
            placeholder="请选择佣金类型"
            disabled={this.state.editType === 'query'}
          >
            {this.state.commissionOption}
          </Select>
        ),
      },
      {
        title: '佣金比例（%）',
        dataIndex: 'value',
        key: 'value',
        editable: true,
        render: (text, record) => (
          <InputNumber
            defaultValue={text}
            value={text}
            name="value"
            min={0}
            max={100}
            precision={2}
            onChange={e => this.handleInput(e, record.channelId)}
            parser={value => value.replace(/\$\s?|(,*)/g, '')}
            step={1}
            placeholder="请输入佣金比例"
            disabled={this.state.editType === 'query'}
          />
        ),
      },
      {
        title: '状态',
        dataIndex: 'status',
        key: 'status',
        editable: true,
        render: (text, record) => (
          <Select
            {...formItemStyle}
            defaultValue={text}
            value={text}
            name="status"
            onSelect={(value, opt) => this.handleSelect(value, opt, record.channelId)}
            placeholder="状态"
            disabled={this.state.editType === 'query'}
          >
            {this.state.statusOption}
          </Select>
        ),
      },
      {
        title: '操作',
        dataIndex: 'op',
        key: 'op',
        render: (text, record) => {
          if (this.state.editType === 'query') {
            return <div>--</div>;
          }
          return (
            <Popconfirm title="确认删除?" onConfirm={() => this.handleDelete(record.channelId)}>
              <a>删除</a>
            </Popconfirm>
          );
        },
      },
    ];
  }

  handleListInput = ({ target: { name, value } }, idx) => {
    if (!(/^[1-9][\d]{0,2}(?:\.[\d]{0,2})?$/.test(value) && value <= 100)) {
      Message.error('佣金比例无效');
    }
    this.setCustomCommissions(idx, name, value);
  };

  /**
   * 处理：选择
   */
  handleSelect = (value, opt, channelId) => {
    // console.log(value, opt, channelId);

    const {
      props: { name, children },
    } = opt;

    let {
      dispatch,
      HotelCreateEditHousePriceChannel: { channelCommissionList },
    } = this.props;

    // 判断 channelId字段
    if (name === 'channelId') {
      channelCommissionList.forEach(element => {
        if (element.channelId === channelId) {
          element[name] = value;
          element.channelName = children;
        }
      });
    } else {
      channelCommissionList.forEach(element => {
        if (element.channelId === channelId) {
          element[name] = value;
          // element.channelName = children;
        }
      });
    }
    dispatch({
      type: 'HotelCreateEditHousePriceChannel/setChannelCommissionList',
      payload: channelCommissionList,
    });
  };

  /**
   * 输入：佣金比例
   */
  handleInput = (value, channelId) => {
    let {
      dispatch,
      HotelCreateEditHousePriceChannel: { channelCommissionList },
    } = this.props;

    if (value === '') {
      return Message.error('请输入佣金比例');
    }

    if (!(/^[1-9][\d]{0,2}(?:\.[\d]{0,2})?$/.test(value) && value <= 100)) {
      return Message.error('佣金比例无效');
    }

    channelCommissionList.forEach(element => {
      if (element.channelId === channelId) {
        element.value = value;
      }
    });

    dispatch({
      type: 'HotelCreateEditHousePriceChannel/setChannelCommissionList',
      payload: channelCommissionList,
    });
  };

  componentWillReceiveProps(props) {
    const { validatedChannelList, editType } = props;
    const validatedChannelListOption =
      validatedChannelList.length !== 0 &&
      validatedChannelList.map((channel, key) => (
        <Option key={key} name="channelId" value={channel.channelId} disabled={channel.disabled}>
          {channel.channelName}
        </Option>
      ));
    this.setState({ validatedChannelListOption, editType });
  }

  componentDidMount() {
    const { dispatch, global } = this.props;
    const commissionOption = global.COMMISSION_TYPE.map((commission, key) => (
      <Option key={key} name="applyType" value={commission.key}>
        {commission.value}
      </Option>
    ));

    const statusOption = [{ key: 0, value: '无效' }, { key: 1, value: '有效' }].map(
      (status, key) => (
        <Option key={key} name="status" value={status.key}>
          {status.value}
        </Option>
      )
    );

    this.setState({ commissionOption, statusOption });

    dispatch({
      type: 'HotelCreateEditHousePriceChannel/fetchChannelCommission',
      payload: {},
    });
  }

  // 判断：渠道名称不为空
  checkHasEmptyChannelId = () => {
    let {
      HotelCreateEditHousePriceChannel: { channelCommissionList },
    } = this.props;

    const isNotChosen = channelCommissionList.some(commission => commission.channelId === '');
    if (isNotChosen) {
      Message.error('请选择渠道名称');
      return false;
    }

    return true;
  };

  // 返回：酒店是否设置渠道
  hasValidatedChannelOpt = () => {
    const {
      HotelCreateEditHousePriceChannel: { validatedChannelList },
    } = this.props;

    return validatedChannelList.length > 0;
  };

  // 返回：酒店佣金列表是否为空
  checkHasValidatedCommission = () => {
    const {
      HotelCreateEditHousePriceChannel: { channelCommissionList },
    } = this.props;

    if (channelCommissionList.length === 1) {
      Message.warn('酒店下面需绑定一个渠道');
      return false;
    }

    return true;
  };

  // 判断：酒店绑定了渠道
  checkHasValidatedChannel = () => {
    const hasValidatedChannelOpt = this.hasValidatedChannelOpt();
    if (!hasValidatedChannelOpt) {
      Message.error('酒店下没有可用渠道');
      return false;
    }
    return true;
  };

  // 处理：保存操作
  handleSave = () => {
    const { dispatch } = this.props;

    const step2 = this.checkHasEmptyChannelId();
    if (!step2) {
      return;
    }

    dispatch({
      type: 'HotelCreateEditHousePriceChannel/updateChannelCommission',
      payload: {},
    }).then(res => {
      if (res.code === '000') {
        Message.success('保存成功');
      }
    });
  };

  // 处理：取消操作
  handleCancel = () => {
    const { dispatch, onChangeType } = this.props;

    dispatch({
      type: 'HotelCreateEditHousePriceChannel/fetchChannelCommission',
      payload: {},
    }).then(res => {
      if (res.code === '000') {
        Message.success('取消成功');
        const type = 'query';
        typeof onChangeType === 'function' && onChangeType(type);
      }
    });
  };

  // 处理：新增操作
  handleAdd = () => {
    const { dispatch, HotelCreateEditHousePriceChannel } = this.props;
    let { channelCommissionList } = HotelCreateEditHousePriceChannel;
    const step1 = this.checkHasValidatedChannel();
    if (!step1) {
      return;
    }

    const step2 = this.checkHasEmptyChannelId();
    if (!step2) {
      return;
    }

    channelCommissionList.push({
      channelId: '',
      channelName: '',
      applyType: 0,
      value: 10,
      status: 1,
      isCreated: true, // 判断是否为新增，用于控制select能否下拉
    });

    dispatch({
      type: 'HotelCreateEditHousePriceChannel/setChannelCommissionList',
      payload: channelCommissionList,
    });
  };

  // 处理：删除操作
  handleDelete = channelId => {
    const { dispatch, HotelCreateEditHousePriceChannel } = this.props;
    let { channelCommissionList } = HotelCreateEditHousePriceChannel;
    channelCommissionList = channelCommissionList.filter(item => item.channelId !== channelId);

    const hasValidatedCommission = this.checkHasValidatedCommission();
    if (!hasValidatedCommission) {
      return;
    }
    dispatch({
      type: 'HotelCreateEditHousePriceChannel/setChannelCommissionList',
      payload: channelCommissionList,
    });
    dispatch({
      type: 'HotelCreateEditHousePriceChannel/updateChannelCommission',
      payload: {},
    }).then(res => {
      if (res.code === '000') {
        Message.success('删除成功');
      }
    });
  };

  render() {
    let { editType, editingKey } = this.state;

    const { HotelCreateEditHousePriceChannel } = this.props;
    const { channelCommissionList } = HotelCreateEditHousePriceChannel;

    const addBtnStyle =
      editType !== 'edit' ? { display: 'none' } : { marginBottom: 15, marginRight: 10 };
    const saveBtnStyle =
      editType === 'edit' && editingKey !== null
        ? { marginBottom: 15, marginRight: 10 }
        : { display: 'none' };

    return (
      <Fragment>
        <Button onClick={this.handleAdd} style={addBtnStyle}>
          新增
        </Button>
        <Button onClick={this.handleSave} style={saveBtnStyle}>
          保存
        </Button>
        <Popconfirm title="确认取消?" onConfirm={this.handleCancel}>
          <Button style={saveBtnStyle}>取消</Button>
        </Popconfirm>

        <Alert
          message="注意"
          description="酒店和渠道设置新增渠道或设置有效时，请务必在【房型价格关联】中添加酒店房型和渠道下相应的价格策略关系，否则会造成渠道下酒店不可销售，谢谢！"
          type="warning"
          showIcon
          style={{ marginBottom: 15 }}
        />
        <Table
          bordered
          size="small"
          dataSource={channelCommissionList}
          columns={this.columns}
          rowKey="channelId"
          pagination={false}
        />
      </Fragment>
    );
  }
}

export default HouseTypeBindHotel;
