import React, { PureComponent } from 'react';
import { Tabs } from 'antd';
import { connect } from 'dva';
import Hotel from './Hotel';
import ButtonList from '../../components/ButtonList';
import BasicOperation from '../components/BasicOperation';
import { getHotelOperateLog } from '../service/housePriceChannel';
import { getApplyTypeFromStatus } from './constant/applyType';
import { getStatusFromStatus } from './constant/status';

const TabPane = Tabs.TabPane;

@connect(({ global, HotelCreateEditHousePriceChannel, HotelCreateEditHotelBasicInfo }) => ({
  global,
  HotelCreateEditHousePriceChannel,
  HotelCreateEditHotelBasicInfo,
}))
export default class HotelPriceChannel extends PureComponent {
  constructor(props) {
    super(props);
    this.state = {
      type: 'query', // edit
    };
    this.columns = [
      {
        title: '时间',
        dataIndex: 'createTime',
        key: 'createTime',
      },
      {
        title: '操作人姓名/id',
        dataIndex: 'createBy',
        key: 'createBy',
        render: (createBy, record) => (
          <span>
            {createBy}
            {record.operatorId || record.operatorId === 0 ? `(${record.operatorId})` : null}
          </span>
        ),
      },
      {
        title: '操作',
        dataIndex: 'operateType',
        key: 'operateType',
        render: operateType => {
          if (operateType === 'add') {
            return '新增渠道';
          }
          if (operateType === 'delete') {
            return '删除渠道';
          }
          if (operateType === 'update') {
            return '修改渠道';
          }
        },
      },
      {
        title: '渠道名称',
        dataIndex: 'channelName',
        key: 'channelName',
      },
      {
        title: '操作明细',
        dataIndex: 'property',
        key: 'property',
        render: (property, record) => {
          if (property) {
            if (property === 'applyType') {
              return `佣金类型：${getApplyTypeFromStatus(record.from)} --> ${getApplyTypeFromStatus(
                record.to
              )}`;
            }
            if (property === 'calculateValue') {
              return `佣金比例：${record.from}% --> ${record.to}%`;
            }
            if (property === 'status') {
              return `状态：${getStatusFromStatus(record.from)}-->${getStatusFromStatus(
                record.to
              )}`;
            }
          }
        },
      },
      {
        title: '备注',
        dataIndex: 'remark',
        key: 'remark',
      },
    ];
  }

  componentWillMount() {
    const { dispatch, hotelId } = this.props;

    dispatch({
      type: 'HotelCreateEditHousePriceChannel/setHotelId',
      payload: hotelId,
    });
    dispatch({
      type: 'HotelCreateEditHousePriceChannel/fetchAllValidatedChannel',
      payload: {},
    });
  }

  handleStatusChange = ({ status, hotelId }) => {
    let { dispatch } = this.props;
    dispatch({
      type: 'HotelCreateEditHotelBasicInfo/updateStatus',
      payload: status,
    });
  };

  handleTypeChange = type => {
    this.setState({
      type,
    });
  };

  handleType = type => {
    this.setState({
      type,
    });
  };

  render() {
    let { hotelId, status } = this.props;
    let { type } = this.state;
    const { HotelCreateEditHousePriceChannel } = this.props;
    const { validatedChannelList } = HotelCreateEditHousePriceChannel;
    return (
      <div>
        <ButtonList
          code="CRS7.2.8.1"
          hotelId={hotelId}
          status={status}
          type={type}
          callBack={this.handleTypeChange}
          callBackStatus={this.handleStatusChange}
        />
        <Tabs onChange={this.tabChange} type="card">
          <TabPane tab="酒店渠道关联" key="1">
            <Hotel
              validatedChannelList={validatedChannelList}
              status={status}
              editType={type}
              onChangeType={this.handleType}
            />
          </TabPane>
          <TabPane tab="操作日志" key="2">
            <BasicOperation
              columns={this.columns}
              hotelId={hotelId}
              onLogOperation={getHotelOperateLog}
            />
          </TabPane>
        </Tabs>
      </div>
    );
  }
}
