import React, { PureComponent, Fragment } from 'react';
import {
  Button,
  Card,
  Form,
  Row,
  Col,
  Input,
  Select,
  Radio,
  InputNumber,
  Modal,
  Message,
} from 'antd';
import { connect } from 'dva';
import router from 'umi/router';
import PageHeaderWrapper from '@/components/PageHeaderWrapper';
import Equipment from '../components/Equipment';
import Bed from '../components/Bed';
import { getByteLen } from '@/utils/utils';

const { Option } = Select;

@connect(({ global, HotelCreateEditHouseFacilities, user }) => ({
  global,
  user,
  HotelCreateEditHouseFacilities,
}))
@Form.create()
export default class HouseFacilitiesUpdate extends PureComponent {
  constructor(props) {
    super(props);
    const { pathname, query } = props.location;
    const editable = pathname.indexOf('update') > -1;
    const formLayout = 'horizontal';
    const formItemLayout = {
      labelCol: { span: 6 },
      wrapperCol: { span: 18 },
    };
    const windowTypeOpt = [
      { label: '全部有窗', value: 0 },
      { label: '部分有窗', value: 1 },
      { label: '无窗', value: 2 },
    ];
    const hasBedOpt = [{ label: '是', value: 1 }, { label: '否', value: 0 }];
    const windowDisadvantageList = ['朝向走廊', '装饰性假窗', '天窗', '窗户较小', '窗外是墙体'];
    const windowDisadvantageOpt = windowDisadvantageList.map((disadvantage, key) => (
      <Option key={disadvantage}>{disadvantage}</Option>
    ));
    this.state = {
      query,
      editable,
      formLayout,
      formItemLayout,
      windowTypeOpt,
      hasBedOpt,
      windowDisadvantageOpt,
    };
  }

  componentDidMount() {
    const {
      query: { hotelId, roomTypeId },
    } = this.state;

    if (!hotelId) {
      Message.warning('hotelId不能为空');
      router.push('/hotel/list');
      return;
    }

    if (!roomTypeId) {
      Message.warning('roomTypeId不能为空');
      router.push({
        pathname: '/hotel/hotelCreateEdit/index',
        query: {
          hotelId,
        },
      });
      return;
    }

    this.fetchHotelBedInfoAll();
    this.fetchHotelRoomTypeAmenities();
  }

  fetchHotelBedInfoAll = () => {
    const {
      dispatch,
      HotelCreateEditHouseFacilities: { allBedList },
    } = this.props;

    if (allBedList === undefined || allBedList.length === 0) {
      dispatch({
        type: 'HotelCreateEditHouseFacilities/fetchHotelBedInfoAll',
      });
    }
  };

  fetchHotelRoomTypeAmenities = () => {
    const { dispatch } = this.props;

    const {
      query: { hotelId, roomTypeId },
    } = this.state;

    if (hotelId === undefined || hotelId === '') {
      Message.warning('hotelId不能为空');
      router.push('/hotel/list');
      return;
    }

    if (roomTypeId === undefined || roomTypeId === null) {
      Message.warning('roomTypeId不能为空');
      router.push({
        pathname: '/hotel/hotelCreateEdit/index',
        query: {
          hotelId,
        },
      });
      return;
    }

    dispatch({
      type: 'HotelCreateEditHouseFacilities/fetchHotelRoomTypeAmenities',
      payload: { hotelId },
    }).then(response => {
      this.setRoomTypeAmenities(roomTypeId, response.data);
    });
  };

  setRoomTypeAmenities = (roomTypeId, amenitiesList) => {
    const { dispatch } = this.props;
    if (roomTypeId === undefined) return;

    let roomTypeAmenities = {};
    if (Array.isArray(amenitiesList) && !amenitiesList.length) {
      return;
    }

    roomTypeAmenities = amenitiesList.find(item => `${item.hotelRoomTypeId}` === `${roomTypeId}`);

    dispatch({
      type: 'HotelCreateEditHouseFacilities/setRoomTypeAmenities',
      payload: { roomTypeAmenities },
    });
  };

  setBedInfoList = bedInfoList => {
    this.props.dispatch({
      type: 'HotelCreateEditHouseFacilities/setBedInfoList',
      payload: { bedInfoList },
    });
  };

  handleDelete = bedInfo => {
    const that = this;

    const {
      dispatch,
      user: { accountId },
    } = this.props;

    const operator = accountId;

    if (bedInfo === undefined) return;
    if (JSON.stringify(bedInfo) === '{}') return;

    let { bedInfoId, deleteType, bedInfoList } = bedInfo;
    let bedInfoIdType = 0;
    let deleteTxt = '或关系';

    if (deleteType === 'bed') {
      bedInfoIdType = 1;
      deleteTxt = '床型';
    }

    // 判断：如果返回的bedIndoId为null，表示还没有保存的数据，直接操作数组删除即可
    if (bedInfoId === null) {
      this.setBedInfoList(bedInfoList);
      return;
    }

    const params = {
      operator,
      // ①删除或关系是传 hotelRoomTypeBedInfoId
      // ②删除床型是传 baseBedInfoList 里面元素的id
      bedInfoId,
      // 0删除或关系 1删除床型
      bedInfoIdType,
    };
    Modal.confirm({
      title: `删除床型信息`,
      content: `确认删除此${deleteTxt}?`,
      okText: '确认',
      cancelText: '取消',
      onOk() {
        dispatch({
          type: 'HotelCreateEditHouseFacilities/deleteRoomTypeBedInfo',
          payload: params,
        }).then(resp => {
          if (resp.code === '000') {
            Message.success('删除床型信息成功');
            that.fetchHotelRoomTypeAmenities();
          }
        });
      },
    });
  };

  handleAdd = () => {
    const {
      HotelCreateEditHouseFacilities: { roomTypeAmenities },
    } = this.props;

    const { bedInfoList } = roomTypeAmenities;

    bedInfoList.push({
      // 新增或关系bedInfoId为null
      bedInfoParentId: null,
      baseBedInfoList: [
        {
          // 新增床型id为null
          id: null,
          bedInfoId: null,
          count: 1,
        },
      ],
    });
    this.setBedInfoList(bedInfoList);
  };

  handleUpdate = () => {
    let params = this.props.form.getFieldsValue();
    const {
      dispatch,
      HotelCreateEditHouseFacilities: { roomTypeAmenities },
    } = this.props;

    const { baseAmenities, moreAmenities, bedInfoList } = roomTypeAmenities;

    // 转化：接口要求字符串形式
    if (params.roomFeature) {
      params.roomFeature = params.roomFeature.toString();
    }

    // 转化：接口要求字符串形式
    if (params.windowDisadvantage) {
      params.windowDisadvantage = params.windowDisadvantage.toString();
    }

    // 去除：接口不需要标准房型和销售房型中文字段，本身不可更新这两个字段
    delete params.saleRoomTypeName;
    delete params.roomTypeName;

    params = { ...roomTypeAmenities, ...params, baseAmenities, moreAmenities };

    for (let i = 0, bedLen = bedInfoList.length; i < bedLen; i += 1) {
      const bedInfo = bedInfoList[i];
      const baseBedInfoList = bedInfo.baseBedInfoList;

      for (let j = 0, len = baseBedInfoList.length; j < len; j += 1) {
        const bed = baseBedInfoList[j];
        if (bed.bedInfoId === null) {
          Message.warning('请先选择新增的床型信息');
          return;
        }
      }
    }

    dispatch({
      type: 'HotelCreateEditHouseFacilities/updateHotelRoomTypeAmenities',
      payload: params,
    }).then(resp => {
      if (resp.code === '000') {
        Message.success('保存房型信息成功');
        this.fetchHotelRoomTypeAmenities();
      }
    });
  };

  handleCancel = () => {
    const {
      query: { hotelId, roomTypeId },
    } = this.state;

    if (hotelId === undefined || hotelId === '') {
      router.push('/hotel/list');
    } else {
      router.push({
        pathname: '/hotel/hotelCreateEdit/index',
        query: {
          hotelId,
        },
      });
    }
  };

  handleRoomFeature = (value, option) => {
    if (value.length === 0) return;

    const len = value.length;
    const handleRoomFeature = value[len - 1];

    const byteLen = getByteLen(handleRoomFeature);

    if (byteLen > 20) {
      Message.error('特色词汇最多十个字');
      value.pop();
    }
  };

  handleEquipment = amenities => {
    const {
      dispatch,
      HotelCreateEditHouseFacilities: { roomTypeAmenities },
    } = this.props;
    let { baseAmenities, moreAmenities } = amenities;

    dispatch({
      type: 'HotelCreateEditHouseFacilities/setHotelAmenities',
      payload: { baseAmenities, moreAmenities },
    });
  };

  renderBedList = () => {
    const { HotelCreateEditHouseFacilities, form } = this.props;
    const { roomTypeAmenities, allBedList } = HotelCreateEditHouseFacilities;
    const { editable } = this.state;
    let bedList = [];

    const handler = {
      onDelete: this.handleDelete,
      onAddBed: this.setBedInfoList,
      onAddOrRelationShip: this.setBedInfoList,
      onSelect: this.setBedInfoList,
      onChange: this.setBedInfoList,
    };

    if (JSON.stringify(roomTypeAmenities) !== '{}') {
      bedList =
        Array.isArray(roomTypeAmenities.bedInfoList) &&
        roomTypeAmenities.bedInfoList.map((bed, key) => (
          <Bed
            bedIndex={key}
            bedInfoParentId={bed.bedInfoParentId}
            baseBedInfoList={bed.baseBedInfoList}
            bedInfoList={roomTypeAmenities.bedInfoList}
            editable={editable}
            allBedList={allBedList}
            key={`Bed-${key}`}
            {...handler}
          />
        ));
    } else {
      bedList = [];
    }

    return bedList;
  };

  render() {
    const { HotelCreateEditHouseFacilities, form } = this.props;

    let { roomTypeAmenities } = HotelCreateEditHouseFacilities;
    const {
      formLayout,
      formItemLayout,
      windowTypeOpt,
      hasBedOpt,
      windowDisadvantageOpt,
      editable,
    } = this.state;

    let {
      roomFeature = '',
      windowDisadvantage = '',
      baseAmenities = [],
      moreAmenities = [],
    } = roomTypeAmenities;

    windowDisadvantage =
      windowDisadvantage !== null && windowDisadvantage !== '' ? windowDisadvantage.split(',') : [];
    roomFeature = roomFeature !== null && roomFeature !== '' ? roomFeature.split(',') : [];

    let allAmenities = baseAmenities.concat(moreAmenities);
    const hidden = !editable ? { display: 'none' } : { display: 'block', marginTop: 20 };

    return (
      <PageHeaderWrapper title={(roomTypeAmenities && roomTypeAmenities.name) || ''}>
        <Card title="房型基础信息" style={{ marginBottom: 24 }} bordered={false}>
          <Form layout={formLayout} hideRequiredMark>
            <Row gutter={16}>
              <Col lg={8} md={12} sm={24}>
                <Form.Item label="销售房型" {...formItemLayout}>
                  {form.getFieldDecorator('saleRoomTypeName', {
                    initialValue: (roomTypeAmenities && roomTypeAmenities.saleRoomTypeName) || '',
                  })(<Input disabled />)}
                </Form.Item>
              </Col>
              <Col lg={8} md={12} sm={24}>
                <Form.Item label="标准房型" {...formItemLayout}>
                  {form.getFieldDecorator('roomTypeName', {
                    initialValue: (roomTypeAmenities && roomTypeAmenities.roomTypeName) || '',
                  })(<Input disabled />)}
                </Form.Item>
              </Col>
            </Row>

            <Row gutter={16}>
              <Col lg={8} md={12} sm={24}>
                <Form.Item label="所在楼层" {...formItemLayout}>
                  {form.getFieldDecorator('floor', {
                    initialValue: (roomTypeAmenities && roomTypeAmenities.floor) || '',
                  })(
                    <Input
                      disabled={!editable}
                      addonAfter="层"
                      placeholder="格式：1-3，3或者3"
                      style={{ width: '60%' }}
                      onChange={val => {
                        console.log(val);
                      }}
                    />
                  )}
                </Form.Item>
              </Col>
              <Col lg={8} md={12} sm={24}>
                <Form.Item label="使用面积" {...formItemLayout}>
                  {form.getFieldDecorator('space', {
                    initialValue: (roomTypeAmenities && roomTypeAmenities.space) || '',
                  })(<Input addonAfter="平方米" disabled={!editable} placeholder="输入1-250" />)}
                </Form.Item>
              </Col>
              <Col lg={8} md={12} sm={24}>
                <Form.Item label="最多容纳" {...formItemLayout} style={{ width: '80%' }}>
                  {form.getFieldDecorator('personAllowed', {
                    initialValue: (roomTypeAmenities && roomTypeAmenities.personAllowed) || '',
                  })(
                    <InputNumber
                      disabled={!editable}
                      min={1}
                      max={10}
                      step={1}
                      placeholder="输入1-10"
                    />
                  )}
                  名成人
                </Form.Item>
              </Col>
            </Row>

            <Row gutter={16}>
              <Col lg={8} md={12} sm={24}>
                <Form.Item label="是否有窗" {...formItemLayout}>
                  {form.getFieldDecorator('windowType', {
                    initialValue: roomTypeAmenities && roomTypeAmenities.windowType,
                  })(
                    <Radio.Group disabled={!editable} buttonStyle="solid" options={windowTypeOpt} />
                  )}
                </Form.Item>
              </Col>

              <Col lg={8} md={12} sm={24}>
                <Form.Item label="是否可加床" {...formItemLayout}>
                  {form.getFieldDecorator('extraBedAllowed', {
                    initialValue: roomTypeAmenities && roomTypeAmenities.extraBedAllowed,
                  })(<Radio.Group disabled={!editable} buttonStyle="solid" options={hasBedOpt} />)}
                </Form.Item>
              </Col>
            </Row>
            <Row gutter={16}>
              <Col lg={8} md={12} sm={24}>
                <Form.Item label="窗户不利处" {...formItemLayout}>
                  {form.getFieldDecorator('windowDisadvantage', {
                    initialValue: windowDisadvantage || [],
                  })(
                    <Select disabled={!editable} mode="multiple" style={{ width: '100%' }}>
                      {windowDisadvantageOpt}
                    </Select>
                  )}
                </Form.Item>
              </Col>
            </Row>
            <Row gutter={16}>
              <Col lg={8} md={12} sm={24}>
                <Form.Item label="房间特色描述" {...formItemLayout}>
                  {form.getFieldDecorator('roomFeature', {
                    initialValue: roomFeature || [],
                  })(
                    <Select
                      disabled={!editable}
                      mode="tags"
                      style={{ width: '100%' }}
                      maxTagCount={10}
                      onChange={this.handleRoomFeature}
                    />
                  )}
                </Form.Item>
              </Col>
            </Row>
          </Form>
        </Card>
        <Card title="床型信息" bordered={false} style={{ marginBottom: 20 }}>
          <Form layout={formLayout} hideRequiredMark>
            {this.renderBedList()}
          </Form>
          <Row gutter={16}>
            <Col span={18}>
              <Button type="primary" disabled={!editable} onClick={this.handleAdd}>
                添加或关系
              </Button>
            </Col>
          </Row>
        </Card>
        <Equipment
          data={allAmenities || []}
          onChange={this.handleEquipment}
          editType={editable}
          defaultShow
        />
        <Row gutter={16} style={hidden}>
          <Col style={{ textAlign: 'center' }}>
            <Button type="primary" disabled={!editable} onClick={this.handleUpdate}>
              保存
            </Button>
            <Button style={{ marginLeft: 20 }} onClick={this.handleCancel}>
              取消
            </Button>
          </Col>
        </Row>
      </PageHeaderWrapper>
    );
  }
}
