import React, { PureComponent, Fragment } from 'react';
import { Table, Message } from 'antd';
import { connect } from 'dva';
import router from 'umi/router';

import ButtonAuthorized from '@/components/ButtonAuthorized';

@connect(
  ({
    global,
    HotelCreateEditHousePriceChannel,
    HotelCreateEditHotelBasicInfo,
    HotelCreateEditHouseFacilities,
  }) => ({
    global,
    HotelCreateEditHousePriceChannel,
    HotelCreateEditHotelBasicInfo,
    HotelCreateEditHouseFacilities,
  })
)
export default class HouseFacilitiesQuery extends PureComponent {
  constructor(props) {
    super(props);
    this.state = {
      columns: [
        {
          title: '房型名称',
          dataIndex: 'roomTypeName',
          editable: true,
          width: '20%',
        },
        {
          title: '基础设施',
          dataIndex: 'bedInfoList',
          width: '25%',

          render: (text, record) => {
            const { space, floor, extraBedAllowed } = record;
            return (
              <div>
                <div>{space !== null && space !== '' ? `建筑面积：${space}平方米` : ''}</div>
                <div>{floor !== null && floor !== '' ? `楼层：${floor}层` : ''}</div>
                <div>{extraBedAllowed ? '可以加床' : '不可加床'}</div>
              </div>
            );
          },
        },
        {
          title: '服务设施',
          dataIndex: 'amenityString',
          render: (amenityString, record) => (
            <div>{amenityString !== undefined && amenityString}</div>
          ),
        },
        {
          title: '操作',
          dataIndex: 'hotelRoomTypeId',
          width: 150,
          render: (hotelRoomTypeId, record) => (
            <div>
              <ButtonAuthorized
                code="CRS7.2.3.2"
                onClick={() => this.handleToDetail(hotelRoomTypeId, 'query')}
                size="small"
              >
                查看
              </ButtonAuthorized>
              <ButtonAuthorized
                code="CRS7.2.3.1"
                onClick={() => this.handleToDetail(hotelRoomTypeId, 'update')}
                style={{ marginLeft: 10 }}
                size="small"
              >
                编辑
              </ButtonAuthorized>
            </div>
          ),
        },
      ],
    };
  }

  componentDidMount() {
    const { dispatch, hotelId } = this.props;

    dispatch({
      type: 'HotelCreateEditHouseFacilities/fetchHotelBedInfoAll',
    });

    dispatch({
      type: 'HotelCreateEditHouseFacilities/fetchHotelRoomTypeAmenities',
      payload: { hotelId },
    });
  }

  // 处理：查询操作
  handleToDetail = (roomTypeId, type) => {
    if (roomTypeId === undefined) return;
    if (type === undefined) return;

    const { hotelId } = this.props;

    this.setRoomTypeAmenities(roomTypeId);

    router.push({
      pathname: `/hotel/hotelCreateEdit/houseFacilities/${type}`,
      query: {
        hotelId,
        roomTypeId,
      },
    });
  };

  setRoomTypeAmenities = roomTypeId => {
    if (roomTypeId === undefined) return;
    const {
      dispatch,
      HotelCreateEditHouseFacilities: { amenitiesList },
    } = this.props;

    let roomTypeAmenities = {};
    roomTypeAmenities =
      Array.isArray(amenitiesList) &&
      amenitiesList.find(item => item.hotelRoomTypeId === roomTypeId);
    dispatch({
      type: 'HotelCreateEditHouseFacilities/setRoomTypeAmenities',
      payload: { roomTypeAmenities },
    });
  };

  render() {
    const { HotelCreateEditHouseFacilities } = this.props;
    const { amenitiesList } = HotelCreateEditHouseFacilities;
    const { columns } = this.state;

    return (
      <Fragment>
        <Table
          bordered
          size="small"
          pagination={false}
          rowKey="roomTypeName"
          dataSource={amenitiesList}
          columns={columns}
        />
      </Fragment>
    );
  }
}
