import React, { PureComponent } from 'react';
import { connect } from 'dva';
import Zmage from 'react-zmage';
import { Button, Modal, Card, Input, Checkbox, Icon, Radio, Upload, message } from 'antd';
import PageHeaderWrapper from '@/components/PageHeaderWrapper';
import ButtonList from '../../components/ButtonList';
import PicUpload from '../components/PicUpload';
import PicDrag from '@/components/PicDrag/PicDrag';
import CowImage from '@/components/CowImage/CowImage';
import styles from './HousePicHandler.less';

const RadioGroup = Radio.Group;
const Backdrop = 'rgba(255, 255, 255, .82)';

@connect(({ user, hotelCreateEditHousePic, HotelCreateEditHotelBasicInfo }) => ({
  user,
  hotelCreateEditHousePic,
  HotelCreateEditHotelBasicInfo,
}))
class HouseTypeManagement extends PureComponent {
  constructor() {
    super();

    this.state = {
      hotelId: '',
      isShowUploadModel: false,
      isChangeCategoryModel: false,
      isChangeCategoryloading: false,
      isLoadSort: false,
      type: 'query', // edit
    };
  }

  componentDidMount() {
    const params = this.props.history.location.query;

    this.props.dispatch({
      type: 'hotelCreateEditHousePic/getImgList',
      payload: {
        hotelId: params.hotelId,
      },
    });

    this.props.dispatch({
      type: 'HotelCreateEditHotelBasicInfo/getBase',
      payload: {
        hotelId: params.hotelId,
      },
    });

    this.setState({
      hotelId: params.hotelId,
    });
  }

  componentWillUnmount() {
    this.props.dispatch({
      type: 'hotelCreateEditHousePic/initData',
    });
  }

  render() {
    let { hotelCreateEditHousePic, HotelCreateEditHotelBasicInfo } = this.props;
    let { imgList, isImgLoad, selectImgIdList } = hotelCreateEditHousePic;
    let {
      hotelId,
      isShowUploadModel,
      isChangeCategoryModel,
      isChangeCategoryloading,
      isLoadSort,
      type,
      seletType,
    } = this.state;
    const editType = type === 'edit';

    return (
      <PageHeaderWrapper>
        <Card className={styles.housePic}>
          <ButtonList
            code="CRS7.2.1.3"
            type={type}
            hotelId={hotelId}
            callBack={this.changeEditType}
            status={HotelCreateEditHotelBasicInfo.status}
            callBackStatus={this.callBackStatus}
          />
          <div className={styles.housePicControl}>
            <Button type="primary" disabled={isImgLoad || !editType} onClick={this.showUploadModel}>
              上传图片
            </Button>
            <Button
              disabled={isImgLoad || !editType}
              style={{ width: 75 }}
              onClick={() => this.selectAll(1)}
            >
              全选
            </Button>
            <Button
              disabled={isImgLoad || !editType}
              style={{ width: 75 }}
              onClick={() => this.selectAll(0)}
            >
              全不选
            </Button>
            <Button disabled={isImgLoad || !editType} onClick={this.showChangeCategoryModel}>
              批量修改种类
            </Button>
            <Button disabled={isImgLoad || !editType} onClick={this.removeImage}>
              批量删除
            </Button>
          </div>
          {isImgLoad ? (
            <div className={styles.housePicLoading}>
              <Icon type="loading" />
            </div>
          ) : (
            <div className={styles.housePicWrapper}>
              <ul>
                {imgList.map((item, index) => (
                  <li className={styles.housePicContainer} key={item.category}>
                    <p className={styles.housePicTitle}>
                      <Icon type="menu-unfold" theme="outlined" />
                      {item.title}
                    </p>
                    {item.imageList.length ? (
                      <PicDrag
                        ref={ref => {
                          this[`picDrag${item.category}Ref`] = ref;
                        }}
                        className={styles.housePicList}
                        transition={350}
                        minArea={5000}
                        isLoading={isLoadSort}
                        onChange={op => this.handlerPicSort(op, item.category)}
                        disableMove={isChangeCategoryModel || isShowUploadModel || !editType}
                      >
                        {item.imageList.map((img, i) => (
                          <li className={styles.housePicBox} key={img.url}>
                            <div
                              className={`${styles.perview} ${styles[img.classType] ||
                                styles.perviewW}`}
                            >
                              <Checkbox
                                disabled={!editType}
                                onClick={() => this.onSelectPic(index, i, img.imageId)}
                                checked={img.isSelect}
                              />
                              <CowImage src={img.showUrl || img.url} largeSrc={img.url} />
                            </div>
                            <div className={styles.info}>
                              <Input placeholder="描述" disabled onBlur={() => this.onInfoBlur()} />
                            </div>
                          </li>
                        ))}
                      </PicDrag>
                    ) : (
                      <ul className={styles.housePicList}>
                        <li>暂无图片...</li>
                      </ul>
                    )}
                  </li>
                ))}
              </ul>
            </div>
          )}
          <Modal
            title="更换类型"
            className={styles.housePicModel}
            visible={isChangeCategoryModel}
            onOk={this.changeCategory}
            okText="保存"
            okButtonProps={{
              className: 'upload-demo-start',
              type: 'primary',
              loading: isChangeCategoryloading,
            }}
            width="1000px"
            onCancel={this.hidenChangeCategoryModel}
          >
            <div className={styles.picTypeList}>
              <RadioGroup
                options={hotelCreateEditHousePic.categoryList}
                onChange={this.onChangeCategoryType}
                value={hotelCreateEditHousePic.changeCategoryType}
              />
            </div>
          </Modal>
          <PicUpload
            isShowUploadModel={isShowUploadModel}
            hidenUploadModel={this.hidenUploadModel}
            hotelId={hotelId}
          />
        </Card>
      </PageHeaderWrapper>
    );
  }

  removeImage = () => {
    this.props.dispatch({
      type: 'hotelCreateEditHousePic/removeImage',
      payload: {
        hotelId: this.state.hotelId,
      },
    });
  };

  selectAll = seletType => {
    this.props.dispatch({
      type: 'hotelCreateEditHousePic/selectAll',
      payload: {
        seletType,
      },
    });
  };

  handlerPicSort = async (op, category) => {
    let PicList = this.props.hotelCreateEditHousePic.imgList.slice();
    let PicData = PicList.find(item => item.category === category);

    if (PicData) {
      let imageList = PicData.imageList.slice();
      let newPicList = [];
      let { moveIndex, targetIndex, propList } = op;

      propList.forEach((item, index) => {
        newPicList[item] = imageList[index];
      });

      this.setState({
        isLoadSort: true,
      });

      await this.props.dispatch({
        type: 'hotelCreateEditHousePic/changePriority',
        payload: {
          newPicList,
          hotelId: this.state.hotelId,
          PicData,
          ref: this[`picDrag${category}Ref`],
        },
      });

      setTimeout(() => {
        this.setState({
          isLoadSort: false,
        });
      }, 200);
    }
  };

  showUploadModel = () => {
    this.setState({
      isShowUploadModel: true,
    });
  };

  hidenUploadModel = () => {
    this.setState({
      isShowUploadModel: false,
    });
  };

  showChangeCategoryModel = () => {
    if (this.props.hotelCreateEditHousePic.selectImgIdList.length === 0) {
      return message.error('请先选择图片');
    }

    this.setState({
      isChangeCategoryModel: true,
    });
  };

  hidenChangeCategoryModel = () => {
    this.setState({
      isChangeCategoryModel: false,
    });
  };

  changeCategory = async () => {
    let res = await this.props.dispatch({
      type: 'hotelCreateEditHousePic/changeCategory',
      payload: {
        hotelId: this.state.hotelId,
      },
    });

    if (res && res.statue) {
      this.hidenChangeCategoryModel();
    }
  };

  onChangeCategoryType = e => {
    let val = e.target.value;

    this.props.dispatch({
      type: 'hotelCreateEditHousePic/changeMainVal',
      payload: {
        changeCategoryType: val,
      },
    });
  };

  onInfoBlur = () => {
    console.log('onInfoBlur');
  };

  onSelectPic = (index, i, imageId) => {
    this.props.dispatch({
      type: 'hotelCreateEditHousePic/selectPic',
      payload: {
        index,
        i,
        imageId,
      },
    });
  };

  // 是否可以编辑
  changeEditType = type => {
    this.setState({
      type,
    });
  };

  callBackStatus = ({ status, hotelId }) => {
    let { dispatch } = this.props;
    // dispatch({
    //   type: 'HotelCreateEditHotelBasicInfo/updateStatus',
    //   payload: status,
    // });
  };
}

export default HouseTypeManagement;
