import React, { PureComponent, Fragment } from 'react';
import {
  Table,
  Message,
  Button,
  Row,
  Col,
  Card,
  Radio,
  Tag,
  Popconfirm,
  message,
  Checkbox,
} from 'antd';
import { connect } from 'dva';
import RoomTypeBindPriceUpdateModel from '../components/RoomTypeBindPriceUpdateModel';

const RadioGroup = Radio.Group;
const CheckboxGroup = Checkbox.Group;

const defaultOpt = {
  description: '',
  rateCodeId: '',
  rateCodeName: '请选择',
};

const optionss = [
  { label: 'Apple', value: 'Apple' },
  { label: 'Pear', value: 'Pear' },
  { label: 'Orange', value: 'Orange' },
];

@connect(({ HotelCreateEditHotelBasicInfo, HotelCreateEditHousePriceChannel }) => ({
  HotelCreateEditHotelBasicInfo,
  HotelCreateEditHousePriceChannel,
}))
export default class HouseTypeBindPrice extends PureComponent {
  state = {
    selectedRoom: {},
    modalVisible: false,
    openPriceStategyList: false, // 打开评论列表
    willDeletePriceStrategy: '', // 即将删除的价格策略的父级房型
    willDeleteRoom: '', // 即将删除的价格策略
  };

  componentWillReceiveProps(props, next) {
    const { editType, dispatch } = props;
    const { editType: oldEditType = '' } = this.state;
    this.setState({ editType });
    if (oldEditType === 'edit' && editType === 'query') {
      // 取消编辑后清空所选择的价格策略;
      this.cancelAddPriceStrategy();
      // 取消编辑以后清空所选的列
      dispatch({
        type: 'HotelCreateEditHousePriceChannel/setHasChoosenColumns',
        payload: [],
      });
    }
  }

  componentWillUnmount() {
    const { dispatch } = this.props;
    // Tab 清空所选择的价格策略;
    this.cancelAddPriceStrategy();
    // Tab 后清空所选的列
    dispatch({
      type: 'HotelCreateEditHousePriceChannel/setHasChoosenColumns',
      payload: [],
    });
  }

  componentWillMount() {
    const { dispatch, HotelCreateEditHousePriceChannel } = this.props;
    const { hotelId } = HotelCreateEditHousePriceChannel;

    dispatch({
      type: 'HotelCreateEditHousePriceChannel/fetchRoomTypeMatchPriceList',
      payload: { hotelId },
    });

    dispatch({
      type: 'HotelCreateEditHousePriceChannel/fetchRoomTypeRateCodeList',
      payload: { hotelId },
    });
  }

  // 操作列的处事件
  handleSelect = selectedRoom => {
    // deep clone
    const sr = { ...selectedRoom };
    const rateCodeList = selectedRoom.rateCodeList.map(it => `${it.rateCodeId}`);
    sr.rateCodeList = rateCodeList;
    this.setState({ selectedRoom: sr });
    this.handleModalVisible();
  };

  // 保存价格策略关系
  handleModalConfirm = params => {
    const { dispatch } = this.props;
    dispatch({
      type: 'HotelCreateEditHousePriceChannel/updateBindRateCodes',
      payload: params,
    })
      .then(data => {
        Message.success('绑定价格策略关系成功');
        this.setState({ modalVisible: false });
      })
      .catch(e => {
        console.log(e);
      });
  };

  // 关联价格策略modal
  handleModalVisible = () => {
    let { modalVisible } = this.state;
    modalVisible = !modalVisible;
    this.setState({ modalVisible });
  };

  // 增加价格策略
  handleModalAdd = () => {
    const { selectedRoom, selectedCategory } = this.state;
    if (!selectedCategory.rateCodeId) {
      Message.error('请选择价格策略');
    } else if (
      selectedRoom.rateCodeList.some(rc => rc.rateCodeId === selectedCategory.rateCodeId)
    ) {
      Message.error('该策略已选，不可重复');
    } else {
      selectedRoom.rateCodeList.push({ ...selectedCategory });
      this.setState({
        selectedRoom,
      });
    }
  };

  // 批量选择价格策略
  priceStrategyChange = list => {
    const {
      dispatch,
      HotelCreateEditHousePriceChannel: { hasChoosenColumns },
    } = this.props;
    if (hasChoosenColumns.length === 0) {
      message.warn('请先选择需要加入的房型');
      return;
    }
    if (list) {
      const payload = {
        type: 'add',
        data: list,
      };
      dispatch({
        type: 'HotelCreateEditHousePriceChannel/setChoosenPriceStrategy',
        payload,
      });
    }
  };

  // 取消添加房型价格策略
  cancelAddPriceStrategy = () => {
    const {
      dispatch,
      HotelCreateEditHousePriceChannel: { hasChoosenPriceStrategy },
    } = this.props;
    if (hasChoosenPriceStrategy.length === 0) {
      this.setState({
        openPriceStategyList: false,
      });
      return;
    }
    const payload = {
      type: 'delete',
      data: hasChoosenPriceStrategy,
    };
    dispatch({
      type: 'HotelCreateEditHousePriceChannel/setChoosenPriceStrategy',
      payload,
    });
  };

  // 过滤map中的空数据
  nullFilter = arr => arr !== '';

  // 确认添加房型价格策略
  addPriceStrategy = () => {
    const {
      dispatch,
      HotelCreateEditHousePriceChannel: {
        priceList,
        hasChoosenColumns,
        hotelId,
        hasChoosenPriceStrategy = [],
      },
    } = this.props;

    if (hasChoosenPriceStrategy.length === 0) {
      message.warn('请先选择价格策略!');
      return;
    }

    let roomTypeRateCodes = priceList.map(item => {
      const { roomTypeId, roomTypeName, rateCodeList } = item;
      if (hasChoosenColumns.join(',').indexOf(roomTypeId) >= 0) {
        const roomIDArr = rateCodeList.map(priceStrategyItem => {
          // 去除不可操作（字段isSupport === N）的价格策略
          if (`${priceStrategyItem.isSupport}` !== `N`) {
            return priceStrategyItem.rateCodeId;
          }
          return '';
        });
        let submitData = {
          roomTypeId,
          roomTypeName,
          rateCodeIds: roomIDArr.filter(this.nullFilter),
        };
        return submitData;
      }
      return '';
    });
    dispatch({
      type: 'HotelCreateEditHousePriceChannel/doUpdatePriceStategy',
      payload: roomTypeRateCodes.filter(this.nullFilter),
    })
      .then(data => {
        // 成功后清空所选择的列表
        this.cancelAddPriceStrategy();
        message.success('操作成功');
        // 成功后更新列表数据
        dispatch({
          type: 'HotelCreateEditHousePriceChannel/fetchRoomTypeMatchPriceList',
          payload: { hotelId },
        });
      })
      .catch(e => {
        console.log(e);
      });
  };

  // 点击删除原来的标签的图标
  deletePriceStrategy = (record, item, e) => {
    const {
      HotelCreateEditHousePriceChannel: { hasChoosenPriceStrategy },
      dispatch,
    } = this.props;
    if (e) {
      e.preventDefault();
    }
    if (hasChoosenPriceStrategy.length !== 0) {
      message.warn('请完成价格策略新增后再删除已存在价格策略！');
      return;
    }
    this.setState({
      willDeleteRoom: record.roomTypeId,
      willDeletePriceStrategy: item.rateCodeId,
    });
  };

  // 提示框回调
  popComfirmChange = (type, roomData, subPriceStategy) => {
    const {
      HotelCreateEditHousePriceChannel: { hotelId },
      dispatch,
    } = this.props;
    // 失败就清空popComfirm
    if (type === 'cancel') {
      this.setState({
        willDeleteRoom: '',
        willDeletePriceStrategy: '',
      });
      return;
    }
    // 确认删除数据
    const { roomTypeId, rateCodeList, roomTypeName } = roomData;
    let rateCodeIds = [];
    if (subPriceStategy.isSupport === 'N') {
      // 如果选择的失效的价格策略，那直接剔除isSupport 为 N的数据就可以了
      rateCodeIds = rateCodeList.map(item => {
        if (item.isSupport !== 'N') {
          return item.rateCodeId;
        }
        return '';
      });
    } else {
      rateCodeIds = rateCodeList.map(item => {
        // 如果选择的有效的价格策略，过滤当前删除的价格策略和isSupport 为 N的数据
        if (item.rateCodeId !== subPriceStategy.rateCodeId && item.isSupport !== 'N') {
          return item.rateCodeId;
        }
        return '';
      });
    }
    dispatch({
      type: 'HotelCreateEditHousePriceChannel/updateBindRateCodes',
      payload: {
        hotelId,
        rateCodeIds: rateCodeIds.filter(this.nullFilter),
        roomTypeName,
        roomTypeId,
      },
    })
      .then(data => {
        Message.success('价格策略删除成功');
        this.setState({
          willDeleteRoom: '',
          willDeletePriceStrategy: '',
        });
      })
      .catch(e => {
        this.setState({
          willDeleteRoom: '',
          willDeletePriceStrategy: '',
        });
        console.log(e);
      });
  };

  //  打开价格策略列表
  openPriceStategyList = () => {
    this.setState({
      openPriceStategyList: true,
    });
  };

  // 标签的颜色
  tagColor = item => {
    if (`${item}` === 'N') {
      return '#ccc';
    }
    if (`${item}` === 'Y') {
      return '';
    }
    return '#f50';
  };

  render() {
    const {
      selectedRoom,
      modalVisible,
      editType,
      openPriceStategyList,
      willDeletePriceStrategy,
      willDeleteRoom,
    } = this.state;
    const { HotelCreateEditHousePriceChannel, dispatch } = this.props;
    const {
      roomTypeRateCodeList,
      priceList,
      hotelName,
      hotelId,
      hasChoosenPriceStrategy,
      hasChoosenColumns,
    } = HotelCreateEditHousePriceChannel;
    const parentMethods = {
      handleModalConfirm: this.handleModalConfirm,
      handleModalVisible: this.handleModalVisible,
    };
    // table columns
    const columns = [
      {
        title: '房型名称',
        dataIndex: 'roomTypeName',
        editable: true,
        width: editType === 'edit' ? 100 : 'auto',
      },
      {
        title: '价格策略',
        dataIndex: 'rateCodeList',
        render: (text, record) => {
          const { rateCodeList = [] } = record;
          return (
            <ul>
              {rateCodeList.map((rcl, idx) => {
                if (editType === 'edit') {
                  return (
                    <Popconfirm
                      title="是否确认删除这个房型价格策略?"
                      visible={
                        willDeletePriceStrategy === rcl.rateCodeId &&
                        willDeleteRoom === record.roomTypeId
                      }
                      key={idx}
                      okText="Yes"
                      cancelText="No"
                      onCancel={() => this.popComfirmChange('cancel', '', '')}
                      onConfirm={() => this.popComfirmChange('confirm', record, rcl)}
                    >
                      <Tag
                        key={idx}
                        closable={rcl.isSupport && rateCodeList.length !== 1}
                        color={this.tagColor(rcl.isSupport)}
                        onClose={e => this.deletePriceStrategy(record, rcl, e)}
                      >
                        {rcl.rateCodeName}
                      </Tag>
                    </Popconfirm>
                  );
                }
                return <li key={idx}>{rcl.rateCodeName}</li>;
              })}
            </ul>
          );
        },
      },
    ];
    const rowSelection = {
      selectedRowKeys: hasChoosenColumns,
      onChange: (selectedRowKeys, selectedRows) => {
        dispatch({
          type: 'HotelCreateEditHousePriceChannel/setHasChoosenColumns',
          payload: selectedRowKeys,
        });
      },
      getCheckboxProps: record => ({
        disabled: hasChoosenPriceStrategy.length !== 0, // Column configuration not to be checked
        // name: record.name,
      }),
    };
    return (
      <Fragment>
        <Row>
          <Col span={editType === 'edit' ? 16 : 24}>
            <Table
              bordered
              size="small"
              pagination={false}
              rowKey="roomTypeId"
              dataSource={priceList}
              columns={columns}
              rowSelection={editType === 'edit' ? rowSelection : null}
            />
          </Col>
          {editType === 'edit' && (
            <Col span={8}>
              <div style={{ textAlign: 'center' }}>
                <Button
                  style={{ marginBottom: 15 }}
                  type="primary"
                  size="small"
                  onClick={this.openPriceStategyList}
                >
                  批量增加价格策略
                </Button>
                {openPriceStategyList && (
                  <Card
                    style={{
                      width: 300,
                      margin: '0 auto',
                      textAlign: 'left',
                      overflow: 'hidden',
                    }}
                    actions={[
                      <Button onClick={this.cancelAddPriceStrategy}>取消</Button>,
                      <Button onClick={this.addPriceStrategy}>确认</Button>,
                    ]}
                  >
                    <div style={{ maxHeight: 300, overflow: 'auto' }}>
                      <CheckboxGroup
                        onChange={this.priceStrategyChange}
                        value={hasChoosenPriceStrategy}
                      >
                        {roomTypeRateCodeList.map(item => (
                          <Checkbox
                            style={{ display: 'block', marginBottom: 10, marginLeft: 8 }}
                            value={item}
                          >
                            <span style={{ marginLeft: 10 }}>{item.rateCodeName}</span>
                          </Checkbox>
                        ))}
                      </CheckboxGroup>
                    </div>
                  </Card>
                )}
              </div>
            </Col>
          )}
        </Row>

        <RoomTypeBindPriceUpdateModel
          {...parentMethods}
          hotelId={hotelId}
          hotelName={hotelName}
          selectedRoom={selectedRoom}
          modalVisible={modalVisible}
          roomTypeRateCodeList={roomTypeRateCodeList}
        />
      </Fragment>
    );
  }
}
