import React, { Component, Fragment } from 'react';
import { connect } from 'dva';
import { Table, Button, Modal, Radio, Form, message, Tag } from 'antd';
import moment from 'moment';

const STYLE = {
  height: 40,
  lineHeight: '40px',
  marginBottom: 7,
};

@connect(({ HotelCreateEditHousePriceChannel, loading }) => ({
  hotelChannel: HotelCreateEditHousePriceChannel,
  channelLoading: loading.effects['HotelCreateEditHousePriceChannel/modifyHotelState'],
}))
@Form.create()
export default class HouseStateChannel extends Component {
  constructor(props) {
    super(props);
    this.state = {
      visible: false,
      editType: 'query',
      timeDiff: 0, // 本地时间和服务端时间差
    };
    this.columns = [
      {
        title: '渠道',
        dataIndex: 'channelName',
      },
      {
        title: '状态',
        dataIndex: 'status',
        render: (status, record) => {
          if (record.isBtn) {
            return (
              <div>
                <Button
                  onClick={() => this.handleChangeVisible()}
                  disabled={this.state.editType === 'query'}
                >
                  {status === 'close' ? '已关房' : '已开房'}
                </Button>
                {status === 'close' && <p style={{ margin: '10px 0 0' }}>{record.time}后恢复</p>}
              </div>
            );
          }
          return status === 'close' ? (
            <Tag color="red">已关房</Tag>
          ) : (
            <Tag color="green">已开房</Tag>
          );
        },
      },
    ];
  }

  handleChangeVisible = () => {
    this.setState({
      visible: !this.state.visible,
    });
  };

  handleSubmit = () => {
    const {
      form,
      dispatch,
      hotelChannel: { channelStatusList },
    } = this.props;
    const { timeDiff } = this.state;
    let paramsList = [];
    form.validateFields((err, values) => {
      if (err) {
        return;
      }
      if (channelStatusList[0] && channelStatusList[0].isBtn) {
        paramsList = channelStatusList.slice(1);
      }
      paramsList = paramsList.map(item => ({
        channelId: item.channelId,
        oldStatus: item.status,
        // startTime:
        //   values.status === 'timedClose'
        //     ? moment()
        //         .subtract(timeDiff, 'seconds')
        //         .format('YYYY-MM-DD HH:mm:ss')
        //     : null,
        // endTime:
        //   values.status === 'timedClose'
        //     ? moment()
        //         .subtract(timeDiff, 'seconds')
        //         .add(2, 'hours')
        //         .format('YYYY-MM-DD HH:mm:ss')
        //     : null,
        status: values.status,
      }));
      dispatch({
        type: 'HotelCreateEditHousePriceChannel/modifyHotelState',
        payload: { roomTypeStatusRequestList: paramsList },
      })
        .then(() => {
          message.success('设置成功！');
          dispatch({
            type: 'HotelCreateEditHousePriceChannel/getHotelState',
            payload: {},
          });
          this.setState({ visible: false });
        })
        .catch(e => {
          console.log(e);
        });
    });
  };

  componentDidMount() {
    const { dispatch } = this.props;
    dispatch({
      type: 'HotelCreateEditHousePriceChannel/getHotelState',
      payload: {},
    }).then(res => {
      this.setState(
        {
          timeDiff: res.currentDate ? moment().diff(moment(res.currentDate), 'seconds') : 0,
        },
        () => {
          this.setChannelStateList();
        }
      );
    });
  }

  componentWillReceiveProps(props) {
    const { editType } = props;
    this.setState({
      editType,
    });
  }

  setChannelStateList = () => {
    const {
      hotelChannel: { channelStatusList },
      dispatch,
    } = this.props;
    const channelStatusNewList = channelStatusList.map((item, index) => ({
      ...item,
      time: this.compareEndTime(item, index),
    }));

    dispatch({
      type: 'HotelCreateEditHousePriceChannel/setHotelState',
      payload: channelStatusNewList,
    });

    this.timeout = setTimeout(() => this.setChannelStateList(), 1000);
  };

  /**
   * 计算关房结束时间和当前时间的时间差
   *
   * @memberof HouseStateChannel
   */
  compareEndTime = (item, index) => {
    const { dispatch } = this.props;
    const { timeDiff } = this.state; // 服务器与本地时间差

    if (!item.endTime) return '00:00:00';

    // 增加本地时间与服务端正确时间偏移量
    const second = Math.floor(moment(item.endTime).diff(moment(), 'seconds', true)) + timeDiff;
    console.log('compareEndTime', second);
    if (second <= 0) {
      if (item.isNeed) {
        item.isNeed = false;

        setTimeout(() => {
          dispatch({
            type: 'HotelCreateEditHousePriceChannel/getHotelState',
            payload: {},
          });
        }, 6000);
      }

      return '00:00:00';
    }

    // if (second < 0) return '00:00:00';

    const date = moment()
      .hour(0)
      .minute(0)
      .second(0)
      .add(second, 'seconds');

    return moment(date).format('HH:mm:ss');
  };

  componentWillUnmount = () => {
    clearTimeout(this.timeout);
  };

  render() {
    const { visible } = this.state;
    const {
      hotelChannel: { channelStatusList },
      form: { getFieldDecorator },
      channelLoading,
    } = this.props;
    return (
      <Fragment>
        <Table
          size="small"
          rowKey="channelId"
          pagination={false}
          columns={this.columns}
          dataSource={channelStatusList}
        />
        <Modal
          visible={visible}
          onCancel={this.handleChangeVisible}
          onOk={this.handleSubmit}
          confirmLoading={channelLoading}
          title="更改关房状态"
        >
          <Form layout="inline">
            <p style={STYLE}>售卖房型：全部房型</p>
            <p style={STYLE}>销售渠道：全部直连渠道</p>
            <Form.Item label="房态设置">
              {getFieldDecorator('status', {
                initialValue:
                  channelStatusList[0] && channelStatusList[0].status === 'close'
                    ? 'timedClose'
                    : 'open',
              })(
                <Radio.Group>
                  <Radio value="open">开房</Radio>
                  <Radio value="timedClose">临时关房（120分钟）</Radio>
                </Radio.Group>
              )}
            </Form.Item>
          </Form>
        </Modal>
      </Fragment>
    );
  }
}
