import React, { PureComponent } from 'react';
import { Tabs } from 'antd';

import { connect } from 'dva';

import Price from './Price';
import Channel from './Channel';
import State from './State';
import ButtonList from '../../components/ButtonList';
import BasicOperation from '../components/BasicOperation';
import { getHouseOperateLog } from '../service/housePriceChannel';

const TabPane = Tabs.TabPane;

const tabType = [
  {
    text: '房型价格关联',
    key: '0',
    component: Price,
  },
  {
    text: '房型渠道开关房',
    key: '1',
    component: State,
  },
  {
    text: '操作日志',
    key: '2',
    component: BasicOperation,
  },
];
@connect(({ global, HotelCreateEditHousePriceChannel, HotelCreateEditHotelBasicInfo }) => ({
  global,
  HotelCreateEditHousePriceChannel,
  HotelCreateEditHotelBasicInfo,
}))
export default class HousePriceChannel extends PureComponent {
  constructor(props) {
    super(props);
    this.state = {
      type: 'query', // edit
    };
    this.columns = [
      {
        title: '时间',
        dataIndex: 'operateTime',
      },
      {
        title: '操作人',
        dataIndex: 'operateName',
        render: (operateName, record) => (
          <span>
            {operateName}
            {record.operateId || record.operateId === 0 ? `(${record.operateId})` : null}
          </span>
        ),
      },
      {
        title: '房型名称',
        dataIndex: 'roomTypeName',
      },
      {
        title: '操作',
        dataIndex: 'operateType',
        render: operateType => <span>{operateType === 1 ? '添加 价格策略' : '删除 价格策略'}</span>,
      },
      {
        title: '价格策略',
        dataIndex: 'rateCodes',
      },
      {
        title: '备注',
        dataIndex: 'remark',
      },
    ];
  }

  componentWillMount() {
    const { dispatch, hotelId } = this.props;

    dispatch({
      type: 'HotelCreateEditHousePriceChannel/setHotelId',
      payload: hotelId,
    });
    dispatch({
      type: 'HotelCreateEditHousePriceChannel/fetchAllValidatedChannel',
      payload: {},
    });
  }

  handleStatusChange = ({ status, hotelId }) => {
    let { dispatch } = this.props;
    dispatch({
      type: 'HotelCreateEditHotelBasicInfo/updateStatus',
      payload: status,
    });
  };

  handleTypeChange = type => {
    this.setState({
      type,
    });
  };

  handleType = type => {
    this.setState({
      type,
    });
  };

  render() {
    let { hotelId, status } = this.props;
    let { type } = this.state;
    const { HotelCreateEditHousePriceChannel } = this.props;
    const { validatedChannelList } = HotelCreateEditHousePriceChannel;
    return (
      <div>
        <ButtonList
          code="CRS7.2.6.1"
          type={type}
          hotelId={hotelId}
          status={status}
          callBack={this.handleTypeChange}
          callBackStatus={this.handleStatusChange}
        />
        <Tabs onChange={this.tabChange} type="card">
          {tabType.map(item => (
            <TabPane tab={item.text} key={item.key}>
              <item.component
                editType={type}
                hotelId={hotelId}
                columns={this.columns}
                onLogOperation={getHouseOperateLog}
              />
            </TabPane>
          ))}
        </Tabs>
      </div>
    );
  }
}
