import React, { PureComponent } from 'react';
import { connect } from 'dva';
import { Button, Modal, Transfer, Popconfirm, message } from 'antd';
import HouseTypeTable from './components/HouseTypeTable';
import RoomAdmin from './components/RoomAdmin';
import RoomListAdmin from './components/RoomListAdmin';
import ButtonList from '../components/ButtonList';
import styles from './HouseType.less';

// id:14183
@connect(({ user, hotelCreateEditHouseType, roomTypeAndRelation }) => ({
  user,
  hotelCreateEditHouseType,
  roomTypeAndRelation,
}))
class HouseTypeManagement extends PureComponent {
  constructor() {
    super();

    this.state = {
      isLoadingDeleteType: false, // 是否在请求删除房型
      isLoadingSave: false, // 是否在请求保存总表
      isLoadingRoomTransfer: false, // 是否在请求保存房间接口
      isShowRoomCount: false, // 是否显示房间数的模态框
      isRoomAdminShow: false, // 是否显示房间管理的模态框
      transferTitle: '', // 穿梭框标题
      roomTypeId: '', // 穿梭框展示的房间类型
      type: 'query', // edit
    };
  }

  render() {
    let { hotelId, status, hotelCreateEditHouseType, isLoadingSave } = this.props;
    let {
      isShowRoomCount,
      isRoomAdminShow,
      transferTitle,
      roomTypeId,
      type,
      isLoadingDeleteType,
    } = this.state;
    let { roomList, roomRemark } = hotelCreateEditHouseType;
    const editType = type === 'edit';

    return (
      <div>
        <ButtonList
          code="CRS7.2.2.1"
          type={type}
          hotelId={hotelId}
          status={status}
          callBack={this.changeEditType}
          callBackStatus={this.callBackStatus}
        />
        <div className={styles.houseTypeManagement}>
          <div className={styles.houseTypeHd}>
            <Button onClick={this.addType} disabled={!editType}>
              新增房型
            </Button>
            <Button onClick={this.showRoomAdmin} disabled>
              房间管理
            </Button>
            <Button
              className={styles.signedRoomStateBtn}
              onClick={this.goViewSignedRoomStatus}
              type="primary"
            >
              查看签约房态
            </Button>
          </div>
          <div className={styles.houseTypeTableWrapper}>
            <HouseTypeTable
              hotelId={hotelId}
              status={status}
              editType={editType}
              showRoomCount={this.showRoomCount}
            />
            <div className={styles.houseTypeRemarks}>
              <div className={styles.houseTypeRemarksHd}>备注</div>
              <div className={styles.houseTypeRemarksBd}>
                <p>
                  <span>标准房型:</span>
                  {roomRemark.standard.count}({roomRemark.standard.prop || 0}
                  %)
                </p>
                <p className={roomRemark.custom.prop > 30 ? styles.danger : ''}>
                  <span>自定义房型:</span>
                  {roomRemark.custom.count}({roomRemark.custom.prop || 0}
                  %)
                </p>
                <p>
                  <span>未分配房型:</span>
                  {roomRemark.default.count}({roomRemark.default.prop || 0}
                  %)
                </p>
              </div>
            </div>
          </div>
          <div className={styles.houseTypeControl}>
            <Popconfirm
              placement="topLeft"
              title="是否确认删除"
              onConfirm={() => this.deleteTypeList()}
              okText="确定"
              cancelText="取消"
            >
              <Button type="danger" loading={isLoadingDeleteType} disabled={!editType}>
                删除房型配置
              </Button>
            </Popconfirm>
            <Button
              type="primary"
              loading={isLoadingSave}
              onClick={() => this.save()}
              disabled={!editType}
            >
              保存房型配置
            </Button>
          </div>
          <Modal
            className={styles.roomTransferModel}
            title={transferTitle}
            visible={isShowRoomCount}
            onOk={this.handlerRoomTransfer}
            onCancel={this.hidenRoomCount}
            okText="保存"
            width="924px"
          >
            <RoomListAdmin />
          </Modal>
          <Modal
            visible={isRoomAdminShow}
            onOk={this.handleRoomAdminOk}
            onCancel={this.handleRoomAdminCancel}
            width="900px"
            title="房间管理"
            okText="保存设置"
          >
            <RoomAdmin />
          </Modal>
        </div>
      </div>
    );
  }

  // 是否可以编辑
  changeEditType = type => {
    let isEdit = type === 'edit';

    this.setState({
      type,
    });

    // 取消编辑状态
    if (!isEdit) {
      this.props.dispatch({
        type: 'hotelCreateEditHouseType/resetRoomTypeList',
      });
    }

    // 取消所有编辑状态
    this.props.dispatch({
      type: 'hotelCreateEditHouseType/changeMainVal',
      payload: {
        editingKey: '',
      },
    });
  };

  callBackStatus = ({ status, hotelId }) => {
    let { dispatch } = this.props;
    // dispatch({
    //   type: 'HotelCreateEditHotelBasicInfo/updateStatus',
    //   payload: status,
    // });
  };

  showRoomAdmin = () => {
    this.setState({
      isRoomAdminShow: true,
    });
  };

  goViewSignedRoomStatus = () => {
    window.open(
      `#/hotel/hotelCreateEdit/hotelRoomStatusType?hotelId=${this.props.hotelId}`,
      '_blank'
    );
  };

  handleRoomAdminOk = () => {
    this.setState({
      isRoomAdminShow: false,
    });
  };

  handleRoomAdminCancel = () => {
    this.setState({
      isRoomAdminShow: false,
    });
  };

  handleTransferChange = (targetKeys, direction, moveKeys) => {
    this.props.dispatch({
      type: 'hotelCreateEditHouseType/handlerRoomList',
      payload: {
        targetKeys,
        moveKeys,
        direction,
        roomTypeId: this.state.roomTypeId,
      },
    });
  };

  // 新增房型
  addType = async () => {
    await this.props.dispatch({
      type: 'hotelCreateEditHouseType/addType',
    });

    this.props.dispatch({
      type: 'hotelCreateEditHouseType/changeRoomRemark',
    });
  };

  showRoomCount = async record => {
    let { hotelId } = this.props;
    let { roomTypeId, roomTypeName, isCustom } = record;

    await this.props.dispatch({
      type: 'hotelCreateEditHouseType/getRoomListByRoomType',
      payload: {
        hotelId,
        roomTypeId,
      },
    });

    this.setState({
      transferTitle: roomTypeName,
      roomTypeId,
      isCustom,
      isShowRoomCount: true,
    });
  };

  handlerRoomTransfer = async () => {
    if (this.state.isLoadingRoomTransfer) return;

    this.setState({
      isLoadingRoomTransfer: true,
    });

    const res = await this.props.dispatch({
      type: 'hotelCreateEditHouseType/saveRoomList',
      payload: {
        hotelId: this.props.hotelId,
        roomTypeId: this.state.roomTypeId,
        isCustom: this.state.isCustom,
      },
    });

    this.setState({
      isLoadingRoomTransfer: false,
      isShowRoomCount: !(res && res.statue),
    });
  };

  hidenRoomCount = () => {
    this.setState({
      isShowRoomCount: false,
    });
  };

  async deleteTypeList() {
    if (this.state.isLoadingDeleteType) return;

    this.setState({
      isLoadingDeleteType: true,
    });

    await this.props.dispatch({
      type: 'hotelCreateEditHouseType/deleteType',
      payload: {
        hotelId: this.props.hotelId,
      },
    });

    this.setState({
      isLoadingDeleteType: false,
    });
  }

  /**
   * 保存房型列表数据
   */
  async save() {
    if (this.state.isLoadingSave) return;

    let { statue, msg } = this.validate();

    if (!statue) {
      msg && message.error(msg);
      return;
    }

    this.setState({
      isLoadingSave: true,
    });

    await this.props.dispatch({
      type: 'hotelCreateEditHouseType/save',
      payload: {
        hotelId: this.props.hotelId,
      },
    });

    await this.props.dispatch({
      type: 'hotelCreateEditHouseType/changeMainVal',
      payload: {
        editingKey: '',
      },
    });

    this.setState({
      isLoadingSave: false,
    });
  }

  /**
   * 校验是否可以上传房型列表数据
   */
  validate() {
    let { hotelCreateEditHouseType } = this.props;
    let { roomTypeList } = hotelCreateEditHouseType;

    if (roomTypeList.filter(item => item.isCustom).length > 3) {
      return {
        statue: false,
        msg: '自定义房型不得超过3个',
      };
    }

    if (hotelCreateEditHouseType.roomRemark.custom.prop > 30) {
      return {
        statue: false,
        msg: '自定义房型房间数不得超过30%',
      };
    }

    for (let i = 0; i < roomTypeList.length; i++) {
      let { saleRoomTypeName, roomTypeName, roomTypeId } = roomTypeList[i];

      if (
        !saleRoomTypeName ||
        !roomTypeName ||
        !roomTypeId ||
        (Array.isArray(saleRoomTypeName) && saleRoomTypeName.length === 0)
      ) {
        console.log('错误', i);
        return {
          statue: false,
          msg: '请填写完整表格数据',
        };
      }
    }
    return {
      statue: true,
    };
  }
}

export default HouseTypeManagement;
