import React, { PureComponent } from 'react';
import { Modal, Switch, Card, Table } from 'antd';
import { connect } from 'dva';
import styles from './styles.less';
import OYOCheckLabel from '@/components/OYOCheckLabel';
import { ROOM_STATUS_TYPE } from '@/constant/roomStatusType';
import PageHeaderWrapper from '@/components/PageHeaderWrapper';

// apolloStatus可能很多，我这里只筛选1234，注意原始code是number还是string，需求描述顺序是1324的code
const FILTER_LABEL = [];
[1, 3, 2, 4].forEach(code => {
  FILTER_LABEL.push(ROOM_STATUS_TYPE.find(value => value.code === code));
});

const labelStyle = { width: 130, marginRight: 15 };

@connect(({ hotelCreateEditHouseType }) => ({
  hotelCreateEditHouseType,
}))
export default class ViewSignedRoomState extends PureComponent {
  state = {
    isShowGreen: true,
    isShowSellable: true,
    isShowModified: true,
    isShowNotSellable: true,
    isShowFloorName: false,
  };

  componentDidMount() {
    const { hotelId } = this.props.location.query;

    if (!hotelId) {
      Modal.error({
        title: '参数无效',
        content: '未获取到酒店ID',
        okText: '确定',
      });
    } else {
      this.props.dispatch({
        type: 'hotelCreateEditHouseType/getSignedRommState',
        payload: hotelId,
      });
    }
  }

  //  公用onChange，提供valueName确定更新state的字段
  onCheckLabelChange = (value, valueName) => this.setState({ [valueName]: value });

  onSwitchChange = isShowFloorName => this.setState({ isShowFloorName });

  filterRooms = (data = []) => {
    return data.filter(room => {
      // 1选择了标签，2找到code对应的room（例如：选择了绿房，筛选出code为1的）
      return FILTER_LABEL.some(
        label => this.state[label.valueName] === true && label.code === room.apolloStatus
      );
    });
  };

  render() {
    const { hotelCreateEditHouseType = {} } = this.props;
    const { signedRoomState = [] } = hotelCreateEditHouseType;
    const { isShowFloorName } = this.state;

    return (
      <PageHeaderWrapper>
        <Card>
          <div style={{ display: 'flex', alignItems: 'center' }}>
            <span>筛选房态：</span>
            <span>
              {FILTER_LABEL.map(({ name, valueName, color, code }) => (
                <OYOCheckLabel
                  key={`check-label-${code}`}
                  valueName={valueName}
                  checked={this.state[valueName]}
                  onChange={this.onCheckLabelChange}
                  color={color}
                  style={labelStyle}
                >
                  {name}
                </OYOCheckLabel>
              ))}
            </span>
            <span>显示楼层：</span>
            <Switch checked={isShowFloorName} onChange={this.onSwitchChange} />
          </div>
        </Card>
        <br />
        <Card>
          {signedRoomState.length > 0 ? (
            signedRoomState.map(roomType => (
              <div key={roomType.roomTypeId} className={styles.wrap}>
                {/* 现在房型下无房也会显示房型，因为room数量在floors遍历内层，
                  所以如果需要做不展示，需要提前遍历，而渲染也需要遍历，
                  两次遍历同一个东西有性能损失 */}
                <div className={styles.typeName}>{roomType.roomTypeName}</div>
                {roomType.floors.map((floor, floorIndex) => {
                  //  筛选后无房就不显示楼层名了
                  let rooms = this.filterRooms(floor.rooms);
                  return rooms.length > 0 ? (
                    <div
                      key={`floor-key-${floorIndex}`}
                      className={styles.roomWrap}
                      style={{ marginTop: isShowFloorName ? 15 : 0 }}
                    >
                      <div
                        className={styles.floorName}
                        style={{ display: isShowFloorName ? 'block' : 'none' }}
                      >
                        {floor.floor}楼
                      </div>
                      <div>
                        {rooms.map(room => (
                          <OYOCheckLabel
                            key={room.roomNo}
                            color={FILTER_LABEL.find(item => item.code === room.apolloStatus).color}
                            style={labelStyle}
                          >
                            {room.roomNo}
                          </OYOCheckLabel>
                        ))}
                      </div>
                    </div>
                  ) : null;
                })}
              </div>
            ))
          ) : (
            // 空Table代替无数据提示
            <Table />
          )}
        </Card>
      </PageHeaderWrapper>
    );
  }
}
