import React, { PureComponent, Component } from 'react';
import {
  Tabs,
  Card,
  Modal,
  Button,
  Row,
  Col,
  Form,
  Input,
  Radio,
  Select,
  Divider,
  Message,
} from 'antd';
import BedInfoDate from './BedInfoDate';

const formLayout = 'horizontal';
const formItemLayout = {
  labelCol: { span: 6 },
  wrapperCol: { span: 18 },
};

export default class Bed extends Component {
  constructor(props) {
    super(props);
    const { bedIndex, editable, allBedList, bedInfoParentId, baseBedInfoList, bedInfoList } = props;

    this.state = {
      bedIndex,
      editable,
      allBedList,
      bedInfoParentId,
      baseBedInfoList,
      bedInfoList,
    };
  }

  componentWillReceiveProps(props) {
    const { editable, allBedList, bedInfoParentId, baseBedInfoList, bedInfoList } = props;

    this.setState({
      editable,
      allBedList,
      bedInfoParentId,
      baseBedInfoList,
      bedInfoList,
    });
  }

  renderBedInfoDate = () => {
    const { onDelete, onAddBed, onSelect, onChange } = this.props;
    const {
      bedIndex,
      baseBedInfoList,
      editable,
      allBedList,
      bedInfoList,
      bedInfoParentId,
    } = this.state;
    let bedInfoDateList = [];

    const handler = {
      onDelete,
      onAdd: onAddBed,
      onSelect,
      onChange,
    };

    if (baseBedInfoList.length === 0) return bedInfoDateList;

    bedInfoDateList = baseBedInfoList.map((bedInfo, key) => (
      <BedInfoDate
        bedIndex={bedIndex}
        editable={editable}
        allBedList={allBedList}
        bedInfoParentId={bedInfoParentId}
        bedInfoIndex={key}
        bedInfo={bedInfo}
        bedInfoList={bedInfoList}
        key={`BedInfoDate-${key}`}
        {...handler}
      />
    ));

    return bedInfoDateList;
  };

  onAdd = () => {
    const { onAddOrRelationShip } = this.props;
    const { bedInfoList } = this.state;

    bedInfoList.push({
      // 新增或关系bedInfoId为null
      bedInfoParentId: null,
      baseBedInfoList: [
        {
          // 新增床型id为null
          id: null,
          bedInfoId: null,
          count: 1,
        },
      ],
    });

    typeof onAddOrRelationShip === 'function' && onAddOrRelationShip(bedInfoList);
  };

  onDelete = () => {
    const { onDelete, bedInfoParentId } = this.props;
    const { bedInfoList, bedIndex } = this.state;
    const bedInfoLen = bedInfoList.length;
    const thisBedInfo = bedInfoList[bedIndex];

    if (thisBedInfo.bedInfoParentId === null) {
      if (bedInfoLen > 0) {
        bedInfoList.splice(bedIndex, 1);
      }
    }

    typeof onDelete === 'function' &&
      onDelete({ bedInfoId: bedInfoParentId, deleteType: 'room', bedInfoList });
  };

  render() {
    const {
      editable,
      allBedList,
      bedInfoList,
      hotelRoomTypeBedInfoId,
      baseBedInfoList,
      bedIndex,
    } = this.state;

    const len = bedInfoList.length;
    const DividerStyle = bedIndex === len - 1 ? { display: 'none' } : {};

    return (
      <div>
        <Row gutter={16}>
          <Col span={18} style={{ marginBottom: 15 }}>
            {/* <Button type="primary" disabled={!editable} onClick={this.onAdd}>
              添加或关系
            </Button> */}
            <Button type="primary" disabled={!editable} onClick={this.onDelete}>
              删除或关系
            </Button>
          </Col>
        </Row>
        <Row gutter={16}>
          <Col span={18}>
            {this.renderBedInfoDate({
              baseBedInfoList,
              editable,
              allBedList,
              bedInfoList,
              hotelRoomTypeBedInfoId,
            })}
          </Col>
        </Row>
        <Divider style={DividerStyle}>或关系</Divider>
      </div>
    );
  }
}
