import React, { PureComponent, Component } from 'react';
import { Tabs, Card, Modal, Button, Row, Col, Form, Input, Radio, Select, InputNumber } from 'antd';

const formLayout = 'horizontal';
const formItemLayout = {
  labelCol: { span: 6 },
  wrapperCol: { span: 18 },
};

const { Option } = Select;

export default class BedInfoDate extends Component {
  constructor(props) {
    super(props);
    const {
      bedIndex,
      editable,
      bedInfo,
      allBedList,
      bedInfoParentId,
      bedInfoIndex,
      bedInfoList,
    } = props;

    this.state = {
      bedIndex,
      editable,
      allBedList,
      bedInfo,
      bedInfoParentId,
      bedInfoIndex,
      allBedListOpt: [],
      bedInfoList,
    };
  }

  componentWillMount() {
    const { allBedList, bedInfoParentId, bedInfoIndex } = this.state;
    let allBedListOpt = [];
    allBedListOpt = allBedList.map((bed, index) => (
      <Option value={bed.id} key={`allBedListOpt-${bedInfoParentId}-${bedInfoIndex}-${index}`}>
        {`${bed.name}/${bed.size}米`}
      </Option>
    ));
    this.setState({ allBedListOpt });
  }

  componentWillReceiveProps(props) {
    const { editable, allBedList, bedInfoParentId, bedInfoIndex, bedInfo, bedInfoList } = props;

    this.setState({
      editable,
      allBedList,
      bedInfoParentId,
      bedInfoIndex,
      bedInfo,
      bedInfoList,
    });
  }

  onAdd = () => {
    let { bedInfoList, bedIndex } = this.state;
    const { onAdd } = this.props;

    bedInfoList[bedIndex].baseBedInfoList.push({ id: null, bedInfoId: null, count: 1 });

    typeof onAdd === 'function' && onAdd(bedInfoList);
  };

  onChange = value => {
    let { bedInfoList, bedInfoIndex, bedIndex } = this.state;
    const { onChange } = this.props;

    bedInfoList[bedIndex].baseBedInfoList[bedInfoIndex].count = value;

    typeof onChange === 'function' && onChange(bedInfoList);
  };

  onSelect = (value, option) => {
    const { onSelect } = this.props;
    let { bedInfoList, bedInfoIndex, bedIndex } = this.state;

    bedInfoList[bedIndex].baseBedInfoList[bedInfoIndex].bedInfoId = value;

    typeof onSelect === 'function' && onSelect(bedInfoList);
  };

  onDelete = () => {
    const { bedInfo, bedInfoList, bedInfoIndex, bedIndex } = this.state;
    const { onDelete } = this.props;

    const baseInfo = bedInfoList[bedIndex];
    const baseBedInfoList = baseInfo.baseBedInfoList;
    const baseBedInfoLen = baseBedInfoList.length;

    if (baseBedInfoLen > 1) {
      if (baseBedInfoList[bedInfoIndex].id === null) {
        baseBedInfoList.splice(bedInfoIndex, 1);
      }
    } else if (baseBedInfoList[bedInfoIndex].id === null) {
      bedInfoList.splice(bedIndex, 1);
    }

    typeof onDelete === 'function' &&
      onDelete({ bedInfoId: bedInfo.id, deleteType: 'bed', bedInfoList });
  };

  render() {
    const { editable, allBedListOpt, bedInfo } = this.state;
    return (
      <Row gutter={16}>
        <Col span={12}>
          <Form.Item label="床型大小" {...formItemLayout}>
            <Select disabled={!editable} value={bedInfo.bedInfoId} onSelect={this.onSelect}>
              {allBedListOpt}
            </Select>
          </Form.Item>
        </Col>
        <Col span={6}>
          <Form.Item label="张数" {...formItemLayout}>
            <InputNumber disabled={!editable} value={bedInfo.count} onChange={this.onChange} />
          </Form.Item>
        </Col>
        <Col span={6}>
          <Button disabled={!editable} onClick={this.onAdd}>
            加床
          </Button>
          <Button style={{ marginLeft: 10 }} disabled={!editable} onClick={this.onDelete}>
            删床
          </Button>
        </Col>
      </Row>
    );
  }
}
