import React, { PureComponent } from 'react';
import { Card, Form, Input, Radio, Icon } from 'antd';
import { connect } from 'dva';
import styles from './basicInfoDetail.less';

const RadioGroup = Radio.Group;

const formItemLayoutThreeLine = {
  style: { width: 340 },
  labelCol: {
    sm: { span: 7 },
  },
  wrapperCol: {
    sm: { span: 17 },
  },
};

@connect(({ equipment }) => ({
  equipment,
}))
export default class HotelMap extends PureComponent {
  constructor(props) {
    super(props);
    this.state = {
      baseAmenities: [],
      moreAmenities: [],
      isShow: true,
    };
  }

  componentWillReceiveProps(nextProps) {
    let { data, equipment } = nextProps;
    let { groupValues } = equipment;

    let baseAmenities = [];
    let moreAmenities = [];

    if (!Array.isArray(data)) return;

    data.forEach(id => {
      if (groupValues.includes(id)) {
        baseAmenities.push(id);
      } else {
        moreAmenities.push(id);
      }
    });

    this.setState({
      baseAmenities,
      moreAmenities,
    });
  }

  componentDidMount() {
    let { defaultShow } = this.props;

    if (defaultShow === true) {
      this.setState({
        isShow: true,
      });
    }

    this.props.dispatch({
      type: 'equipment/fetchList',
    });
  }

  render() {
    let { equipment, formItemLayout, editType } = this.props;
    let { baseAmenities, moreAmenities, isShow } = this.state;
    let { singleList, groupList } = equipment;

    return (
      <Card className={styles.basicInfoDetailContainer} style={{ marginTop: 10 }}>
        <div className={styles.basicInfoDetailTitle} onClick={this.handlerShow}>
          <p>酒店设施信息</p>
          {isShow ? <Icon type="caret-down" /> : <Icon type="caret-up" />}
        </div>
        <div className={styles.basicInfoDetailBd} style={{ display: isShow ? 'block' : 'none' }}>
          <Form>
            {groupList.map((item, index) => (
              <Form.Item label={item.name} {...formItemLayoutThreeLine} key={index}>
                <RadioGroup value={this.getValue(item.childValues)} disabled={!editType}>
                  {item.child.map((c, i) => (
                    <Radio
                      key={c.value}
                      value={c.value}
                      onClick={() => this.changeGroupVal(c.value)}
                    >
                      {c.label}
                    </Radio>
                  ))}
                </RadioGroup>
              </Form.Item>
            ))}
          </Form>
          <p className={styles.equipmentTitle}>更多设施</p>
          <ul className={styles.equipmentList} style={{ opacity: editType ? '1' : '0.5' }}>
            {singleList.map((item, index) => (
              <li
                key={index}
                className={moreAmenities.includes(item.id) ? styles.active : ''}
                onClick={() => this.changeSingleVal(item.id)}
                title={item.name}
              >
                {item.name}
                {moreAmenities.includes(item.id) ? <Icon type="check" theme="outlined" /> : null}
              </li>
            ))}
          </ul>
        </div>
      </Card>
    );
  }

  getValue(childValues) {
    let val = childValues.filter(v => this.state.baseAmenities.includes(v)) || [null];

    return val[0];
  }

  changeGroupVal = id => {
    let { baseAmenities, moreAmenities } = this.state;
    let groupList = this.props.equipment.groupList;
    let { onChange, editType } = this.props;
    let spliceIndex = -1;

    if (baseAmenities.includes(id) || !editType) return;

    for (let i = 0; i < groupList.length; i++) {
      if (groupList[i].childValues.includes(id)) {
        baseAmenities = baseAmenities.filter(item => !groupList[i].childValues.includes(item));
        break;
      }
    }

    baseAmenities.push(id);

    onChange &&
      onChange({
        baseAmenities,
        moreAmenities,
      });
  };

  changeSingleVal = id => {
    let { baseAmenities, moreAmenities } = this.state;
    let { onChange, editType } = this.props;

    if (!editType) return;

    let index = moreAmenities.findIndex(item => id === item);

    if (index >= 0) {
      moreAmenities.splice(index, 1);
    } else {
      moreAmenities.push(id);
    }

    onChange &&
      onChange({
        baseAmenities,
        moreAmenities,
      });
  };

  handlerShow = () => {
    this.setState({
      isShow: !this.state.isShow,
    });
  };
}
