import React, { PureComponent } from 'react';
import { connect } from 'dva';
import { Table, Form, Select, Icon, message } from 'antd';
import { getUUID } from '@/utils/utils';
import styles from '../HouseType.less';

const Option = Select.Option;

const FormItem = Form.Item;

const EditableContext = React.createContext();

@connect(({ user, hotelCreateEditHouseType, roomTypeAndRelation }) => ({
  user,
  hotelCreateEditHouseType,
  roomTypeAndRelation,
}))
class HouseTypeManagement extends PureComponent {
  constructor() {
    super();

    this.state = {
      roomTypeId: '',
    };

    this.columns = [
      {
        title: '原有房型',
        dataIndex: 'oldRoomTypeName',
        width: '150px',
        editable: true,
      },
      {
        title: 'OYO房型',
        dataIndex: 'roomTypeName',
        width: '150px',
        render: (text, record) => {
          const editable = this.isEditing(record);
          let { roomTypeList } = this.props.hotelCreateEditHouseType;
          let existId = roomTypeList.map(item => item.roomTypeId);

          if (!this.props.editType) {
            return <p>{text}</p>;
          }

          return (
            <div>
              {editable ? (
                <Select
                  style={{ width: 120 }}
                  value={record.roomTypeId}
                  onChange={val => this.handleRoomTypeChange(val, record)}
                >
                  {this.props.roomTypeAndRelation.list.map((item, index) => (
                    <Option
                      key={index}
                      value={item.roomTypeId}
                      disabled={existId.includes(item.roomTypeId)}
                    >
                      {item.roomTypeName}
                    </Option>
                  ))}
                </Select>
              ) : (
                <span>{text}</span>
              )}
            </div>
          );
        },
      },
      {
        title: '销售房型',
        dataIndex: 'saleRoomTypeName',
        width: '150px',
        render: (text, record) => {
          const editable = this.isEditing(record);
          let { roomTypeList } = this.props.hotelCreateEditHouseType;

          if (!record.isCustom || !editable) {
            return <span>{text}</span>;
          }
          return (
            <Select
              mode="tags"
              style={{ width: '100%' }}
              onChange={val => this.selectSaleHouseType(val, record)}
              value={record.saleRoomTypeName}
            >
              {this.props.roomTypeAndRelation.saleList.map((item, index) => (
                <Option key={index} value={item.saleRoomTypeName}>
                  {item.saleRoomTypeName}
                </Option>
              ))}
            </Select>
          );
        },
      },
      {
        title: '房型代码',
        dataIndex: 'roomTypeCode',
        width: '150px',
        editable: false,
      },
      {
        title: '房间数',
        dataIndex: 'roomCount',
        width: '120px',
        render: (text, record) => (
          <div className={styles.recordRoomCout}>
            <p>
              {text}/{this.props.hotelCreateEditHouseType.totalCount || 0}
              {record.isNew || !this.props.editType || record.isChange ? null : (
                <Icon type="diff" theme="outlined" onClick={() => this.showRoomCount(record)} />
              )}
            </p>
          </div>
        ),
      },
      {
        title: '操作',
        dataIndex: 'edit',
        width: '90px',
        render: (text, record) => {
          const editable = this.isEditing(record);
          if (!this.props.editType) {
            return <p>--</p>;
          }

          return (
            <div>
              {editable ? (
                <span>
                  <EditableContext.Consumer>
                    {form => (
                      <a
                        href="javascript:;"
                        onClick={() => this.editOk(form, record.key)}
                        style={{ marginRight: 8 }}
                      >
                        完成
                      </a>
                    )}
                  </EditableContext.Consumer>
                </span>
              ) : (
                <a onClick={() => this.startEdit(record.key)}>编辑</a>
              )}
            </div>
          );
        },
      },
    ];

    this.columnsData = this.columns;
  }

  componentDidMount() {
    this.props.dispatch({
      type: 'hotelCreateEditHouseType/getHotelDetail',
      payload: {
        hotelId: this.props.hotelId,
      },
    });

    this.props.dispatch({
      type: 'roomTypeAndRelation/fetchList',
    });
  }

  render() {
    let { hotelId, status, hotelCreateEditHouseType } = this.props;
    let { isRelationShow, isRoomAdminShow, transferTitle, roomTypeId } = this.state;
    let { roomTypeList, roomList, roomRemark, tableUuid } = hotelCreateEditHouseType;

    return (
      <Table
        className={styles.houseTypeTable}
        rowSelection={this.rowSelection}
        bordered
        size="small"
        dataSource={roomTypeList}
        columns={this.columnsData}
        pagination={false}
        rowClassName="editable-row"
        rowKey="key"
        key={tableUuid}
      />
    );
  }

  // 左边checkbox点击后的事件
  rowSelection = {
    getCheckboxProps: record => ({
      disabled: record.deletable === 0 || !this.props.editType, // 1可以删除 0不可以删除
    }),
    onChange: (selectedRowKeys, selectedRows) => {
      this.props.dispatch({
        type: 'hotelCreateEditHouseType/changeMainVal',
        payload: {
          selectList: selectedRows,
        },
      });
    },
  };

  selectSaleHouseType(value, record) {
    let { saleList, list } = this.props.roomTypeAndRelation;

    this.props.dispatch({
      type: 'hotelCreateEditHouseType/changeCustomVal',
      payload: {
        value,
        record,
        saleList,
        mainList: list,
      },
    });
  }

  // 房间类型改变时
  async handleRoomTypeChange(val, record) {
    const { roomTypeList } = this.props.hotelCreateEditHouseType;
    const { list: roomOption } = this.props.roomTypeAndRelation;
    let roomData = roomOption.find(item => item.roomTypeId === val);
    let isChange = roomData.roomTypeId !== record.roomTypeIdOld;

    if (!roomData) return;

    let {
      roomTypeCode,
      saleRoomTypeId,
      saleRoomTypeName,
      roomTypeName,
      roomTypeId,
      isCustom,
    } = roomData;

    if (isCustom) {
      saleRoomTypeName = saleRoomTypeName ? [saleRoomTypeName] : [];
    }

    let list = roomTypeList.map(item => {
      if (item === record) {
        return {
          ...item,
          roomTypeCode,
          saleRoomTypeId,
          saleRoomTypeName,
          roomTypeName,
          roomTypeId,
          isCustom,
          isNewSellType: false,
          isChange,
        };
      }
      return item;
    });

    await this.props.dispatch({
      type: 'hotelCreateEditHouseType/changeMainVal',
      payload: {
        roomTypeList: list,
      },
    });

    this.props.dispatch({
      type: 'hotelCreateEditHouseType/changeRoomRemark',
    });
  }

  // 穿梭框移动
  handleTransferChange = (targetKeys, direction, moveKeys) => {
    this.props.dispatch({
      type: 'hotelCreateEditHouseType/handlerRoomList',
      payload: {
        targetKeys,
        moveKeys,
        direction,
        roomTypeId: this.state.roomTypeId,
      },
    });
  };

  // 显示房间数的模态框
  showRoomCount = record => {
    this.props.showRoomCount(record);
  };

  // 每行是否在编辑状态
  isEditing = record => record.key === this.props.hotelCreateEditHouseType.editingKey;

  /**
   * 开始编辑
   * @param  {String} key 用于判断每一行的编辑状态
   */
  startEdit(key) {
    this.props.dispatch({
      type: 'hotelCreateEditHouseType/changeMainVal',
      payload: {
        editingKey: key,
      },
    });
  }

  // 结束编辑
  editOk(form, key) {
    this.props.dispatch({
      type: 'hotelCreateEditHouseType/changeMainVal',
      payload: {
        editingKey: '',
      },
    });
  }
}

export default HouseTypeManagement;
