import React, { PureComponent } from 'react';
import { connect } from 'dva';
import { Modal, Upload, Button, Icon, Radio, message } from 'antd';
import { accDiv } from '@/utils/cal';
import styles from '../HousePicHandler/HousePicHandler.less';

const RadioGroup = Radio.Group;

const MinSize = 0;
const MaxSize = 15000000; // 15mb

@connect(({ hotelCreateEditHousePic }) => ({
  hotelCreateEditHousePic,
}))
class PicUpload extends PureComponent {
  constructor() {
    super();
    this.state = {
      fileList: [],
      uploading: false,
    };
  }

  handleUpload = async () => {
    let picType = this.props.hotelCreateEditHousePic.picType;

    if (picType === null || picType === '') return message.error('请先选择类型');

    const { fileList } = this.state;
    const formData = new FormData();

    fileList.forEach(file => {
      formData.append('files', file);
    });

    this.setState({
      uploading: true,
    });

    let res = await this.props.dispatch({
      type: 'hotelCreateEditHousePic/uploadHotelImage',
      payload: {
        formData,
        hotelId: this.props.hotelId,
      },
    });

    this.setState({
      uploading: false,
    });

    if (res && res.statue) {
      this.setState({
        fileList: [],
      });

      let $picList = document.querySelectorAll('.ant-upload-list-picture');

      $picList[0].innerHTML = '';

      this.hidenUploadModel();
    }
  };

  uploadProps = {
    listType: 'picture',
    className: 'upload-list-inline',
    multiple: true,
    accept: 'image/png, image/jpeg, image/jpeg',
    onRemove: file => {
      this.setState(({ fileList }) => {
        const index = fileList.indexOf(file);
        const newFileList = fileList.slice();

        newFileList.splice(index, 1);

        return {
          fileList: newFileList,
        };
      });
    },
    beforeUpload: file => {
      let isDelete = false;
      let deleteName = '';

      // if (file.size < MinSize) {
      //   message.error('图片最少1mb');
      //   isDelete = true;
      //   deleteName = file.name;
      // }
      console.log(file.size);
      if (file.size > MaxSize) {
        message.error(`图片最大${accDiv(MaxSize, 1000000)}mb`);
        isDelete = true;
        deleteName = file.name;
      }

      if (this.state.fileList.some(item => item.name === file.name)) {
        message.error('去除重名图片');
        isDelete = true;
        deleteName = file.name;
      }

      if (isDelete) {
        setTimeout(() => {
          let $picList = document.querySelectorAll('.ant-upload-list-item');
          let $deletDom = [...$picList].find(dom => dom.textContent === deleteName);

          $deletDom.parentNode.removeChild($deletDom);
        }, 300);

        return false;
      }

      this.setState(({ fileList }) => ({
        fileList: [...fileList, file],
      }));

      return false;
    },
  };

  render() {
    const { isShowUploadModel, hotelCreateEditHousePic } = this.props;
    const { uploading } = this.state;

    return (
      <Modal
        title="上传图片"
        visible={isShowUploadModel}
        onOk={this.handleUpload}
        okText="保存"
        okButtonProps={{
          className: 'upload-demo-start',
          type: 'primary',
          disabled: this.state.fileList.length === 0,
          loading: uploading,
        }}
        maskClosable={false}
        width="1000px"
        className={styles.housePicModel}
        onCancel={this.hidenUploadModel}
      >
        <div className={styles.housePicUploads}>
          <Upload {...this.uploadProps}>
            <Button disabled={uploading}>
              <Icon type="upload" /> 上传图片
            </Button>
          </Upload>
        </div>
        <div className={styles.picTypeList}>
          <RadioGroup
            disabled={uploading}
            options={hotelCreateEditHousePic.categoryList}
            onChange={this.onPicType}
            value={hotelCreateEditHousePic.picType}
          />
        </div>
      </Modal>
    );
  }

  onPicType = e => {
    this.props.dispatch({
      type: 'hotelCreateEditHousePic/changeMainVal',
      payload: {
        picType: e.target.value,
      },
    });
  };

  hidenUploadModel = () => {
    if (this.state.uploading) {
      return message.warn('上传中, 请耐心等待.');
    }
    this.props.hidenUploadModel();
  };
}

export default PicUpload;
