import React, { PureComponent } from 'react';
import { Input, Icon, message, Button } from 'antd';
import styles from './RoomAdmin.less';

export default class RoomDetail extends PureComponent {
  constructor() {
    super();
    this.state = {
      roomList: [
        {
          level: 1,
          list: ['8101', '8103', '8104', '8103'],
        },
        {
          level: 3,
          list: ['8301', '8302', '8303', '8304', '8305', '8306', '8307', '8308'],
        },
        {
          level: 5,
          list: ['8501', '8503', '8504', '8503'],
        },
      ],
    };
  }

  render() {
    const { roomList } = this.state;

    return (
      <div className={styles.roomAdmin}>
        <ul className={styles.roomAdminContainer}>
          {roomList.map((item, listIndex) => (
            <li key={listIndex}>
              <div className={styles.level}>
                <div className={styles.levelInput}>
                  <Input
                    value={item.level}
                    onChange={e => this.handlerLevelChange(e, listIndex)}
                    maxLength="2"
                  />
                  <Icon
                    className={styles.levelDelete}
                    type="close-circle"
                    theme="outlined"
                    onClick={() => this.deletLevel(listIndex)}
                  />
                </div>
                <span>
                  ({item.list.length}
                  间)
                </span>
              </div>
              <ul className={styles.roomAdminList}>
                {item.list.map((children, index) => (
                  <li key={index}>
                    <Input
                      value={children}
                      placeholder="请输入"
                      onChange={e => this.handlerRoomChange(e, listIndex, index)}
                    />
                    <Icon
                      type="close-circle"
                      theme="outlined"
                      onClick={() => this.deletRoom(listIndex, index)}
                    />
                  </li>
                ))}
                <li>
                  <p onClick={() => this.addRoom(listIndex)}>增加 +</p>
                </li>
              </ul>
            </li>
          ))}
        </ul>
        <Button onClick={this.addLevel}>增加楼层</Button>
      </div>
    );
  }

  addLevel = () => {
    let roomList = [...this.state.roomList];

    roomList.push({
      level: null,
      list: [''],
    });

    this.setState({
      roomList,
    });
  };

  deletLevel = listIndex => {
    let roomList = [...this.state.roomList];

    roomList.splice(listIndex, 1);

    this.setState({
      roomList,
    });
  };

  addRoom(listIndex) {
    let roomList = [...this.state.roomList];
    let data = roomList[listIndex];

    data.list.push('');

    roomList[listIndex] = {
      ...data,
    };

    this.setState({
      roomList,
    });
  }

  deletRoom(listIndex, index) {
    let roomList = [...this.state.roomList];
    let data = roomList[listIndex];

    data.list.splice(index, 1);

    roomList[listIndex] = {
      ...data,
    };

    this.setState({
      roomList,
    });
  }

  handlerLevelChange(e, listIndex) {
    let val = e.target.value;
    let roomList = [...this.state.roomList];
    let data = roomList[listIndex];

    roomList[listIndex] = {
      ...data,
      level: val,
    };

    this.setState({
      roomList,
    });
  }

  handlerRoomChange(e, listIndex, index) {
    let val = e.target.value;
    let roomList = [...this.state.roomList];
    let data = roomList[listIndex];

    if (val.length >= 4 && data.list.includes(val)) {
      return message.error('已经存在该房号');
    }

    let list = data.list.map((d, i) => {
      if (i === index) {
        return val;
      }
      return d;
    });

    roomList[listIndex] = {
      ...data,
      list,
    };

    this.setState({
      roomList,
    });
  }
}
