import React, { PureComponent } from 'react';
import { connect } from 'dva';
import { Input, Icon, message, Button } from 'antd';
import styles from './RoomListAdmin.less';

@connect(({ hotelCreateEditHouseType }) => ({
  hotelCreateEditHouseType,
}))
class RoomDetail extends PureComponent {
  constructor() {
    super();
    this.state = {};
  }

  render() {
    const { roomSelected, roomSelectable } = this.props.hotelCreateEditHouseType;

    return (
      <div className={styles.roomListWrapper}>
        <div className={styles.roomListLt}>
          <p className={styles.tagTitle}>
            已选房间(
            {roomSelected.count})
          </p>
          <ul className={styles.roomListContainer}>
            {roomSelected.roomList.map((item, index) => {
              if (item.roomDateList.length === 0) return <div />;

              return (
                <li className={styles.roomListBlock} key={`floor-${index}`}>
                  <div className={styles.roomLevel}>
                    8- ({item.floor}
                    楼)
                  </div>
                  <ul className={styles.roomList}>
                    {item.roomDateList.map((room, i) => (
                      <li
                        className={this.getSelectedClass(room)}
                        key={`room-${i}`}
                        onClick={() => this.handlerMove('roomSelected', index, i, room.choosable)}
                      >
                        {room.roomNum}
                      </li>
                    ))}
                  </ul>
                </li>
              );
            })}
          </ul>
        </div>
        <div className={styles.roomListRt}>
          <p className={styles.tagTitle}>
            可选房间(
            {roomSelectable.count})
          </p>
          <ul className={styles.roomListContainer}>
            {roomSelectable.roomList.map((item, index) => {
              if (item.roomDateList.length === 0) return <div />;

              return (
                <li className={styles.roomListBlock} key={`floor-${index}`}>
                  <div className={styles.roomLevel}>
                    8- ({item.floor}
                    楼)
                  </div>
                  <ul className={styles.roomList}>
                    {item.roomDateList.map((room, i) => (
                      <li
                        className={this.getSelectedClass(room)}
                        key={`room-${i}`}
                        onClick={() => this.handlerMove('roomSelectable', index, i, room.choosable)}
                      >
                        {room.roomNum}
                      </li>
                    ))}
                  </ul>
                </li>
              );
            })}
          </ul>
        </div>
      </div>
    );
  }

  getSelectedClass = room => {
    let classList = [];

    if (room.removeCount % 2 === 0) classList.push(styles.active);

    if (room.choosable === 0) classList.push(styles.disable);

    return classList.toString().replace(/,/, ' ');
  };

  handlerMove(type, index, i, choosable) {
    if (choosable === 0) return;

    this.props.dispatch({
      type: 'hotelCreateEditHouseType/removeRoom',
      payload: {
        type,
        index,
        i,
      },
    });
  }
}

export default RoomDetail;
