import React from 'react';
import { Form, Input, Select, Modal } from 'antd';

const FormItem = Form.Item;
const { Option } = Select;

const RoomTypeBindPriceUpdateModel = Form.create()(props => {
  let {
    modalVisible,
    form,
    roomTypeRateCodeList,
    handleModalConfirm,
    handleModalVisible,
    selectedRoom,
    hotelId,
    hotelName,
  } = props;

  const handleOK = () => {
    form.validateFields((err, fieldsValue) => {
      if (err) return;
      fieldsValue.hotelName !== undefined && delete fieldsValue.hotelName;
      typeof handleModalConfirm === 'function' && handleModalConfirm(fieldsValue);
    });
  };

  const handleCancel = handleModalVisible;

  return (
    <Modal
      destroyOnClose
      title="关联价格策略"
      visible={modalVisible}
      onOk={handleOK}
      onCancel={() => handleCancel()}
    >
      <FormItem
        labelCol={{ span: 5 }}
        wrapperCol={{ span: 15 }}
        label="酒店ID"
        style={{ display: 'none' }}
      >
        {form.getFieldDecorator('hotelId', {
          initialValue: hotelId,
        })(<Input disabled />)}
      </FormItem>

      <FormItem
        labelCol={{ span: 5 }}
        wrapperCol={{ span: 15 }}
        label="房型ID"
        style={{ display: 'none' }}
      >
        {form.getFieldDecorator('roomTypeId', {
          initialValue: selectedRoom.roomTypeId,
        })(<Input disabled />)}
      </FormItem>

      <FormItem labelCol={{ span: 5 }} wrapperCol={{ span: 15 }} label="已选酒店">
        {form.getFieldDecorator('hotelName', {
          initialValue: hotelName,
        })(<Input disabled />)}
      </FormItem>

      <FormItem labelCol={{ span: 5 }} wrapperCol={{ span: 15 }} label="已选房型">
        {form.getFieldDecorator('roomTypeName', {
          initialValue: selectedRoom.roomTypeName,
        })(<Input disabled />)}
      </FormItem>

      <FormItem labelCol={{ span: 5 }} wrapperCol={{ span: 15 }} label="价格策略">
        {form.getFieldDecorator('rateCodeIds', {
          rules: [{ required: true, message: '请选择价格策略' }],
          initialValue: selectedRoom.rateCodeList || [],
        })(
          <Select mode="multiple" style={{ width: '100%' }} placeholder="请选择价格策略">
            {roomTypeRateCodeList &&
              roomTypeRateCodeList.map(priceStrategy => (
                <Option key={priceStrategy.rateCodeId}>{priceStrategy.rateCodeName}</Option>
              ))}
          </Select>
        )}
      </FormItem>
    </Modal>
  );
});

export default RoomTypeBindPriceUpdateModel;
