import React, { PureComponent } from 'react';
import { connect } from 'dva';
import { Tabs, Card, Row, Col, Button, message } from 'antd';
import PageHeaderWrapper from '@/components/PageHeaderWrapper';
import BasicInfo from './BasicInfo';
import BenchmarkPrice from './BenchmarkPrice/index';
import HouseFacilities from './HouseFacilities/index';
import HousePriceChannel from './HousePriceChannel/index';
import HotelPriceChannel from './HotelPriceChannel/index';
import HouseType from './HouseType';
import SAP from './SAP';
import HotelComment from './HotelComment/index';
import judgePermission from '@/utils/judgePermission';

const TabPane = Tabs.TabPane;

const tabType = [
  {
    text: '酒店基础信息',
    key: '0',
    component: BasicInfo,
    show: judgePermission('CRS7.2.1'),
  },
  {
    text: '酒店房型管理',
    key: '1',
    component: HouseType,
    show: judgePermission('CRS7.2.2'),
  },
  {
    text: '酒店房型设施',
    key: '2',
    component: HouseFacilities,
    show: judgePermission('CRS7.2.3'),
  },
  {
    text: '基准价管理',
    key: '3',
    component: BenchmarkPrice,
    show: judgePermission('CRS7.2.5'),
  },
  {
    text: '房型价格策略',
    key: '4',
    component: HousePriceChannel,
    show: judgePermission('CRS7.2.6'),
  },
  {
    text: '酒店渠道管理',
    key: '5',
    component: HotelPriceChannel,
    show: judgePermission('CRS7.2.8'),
  },
  {
    text: '酒店评分管理',
    key: '6',
    component: HotelComment,
    show: judgePermission('CRS7.2.7'),
  },
  {
    text: '酒店合约及银行账号',
    key: '7',
    component: SAP,
    show: judgePermission('CRS7.2.4'),
  },
];

@connect(({ loading, HotelCreateEditHotelBasicInfo }) => ({
  HotelCreateEditHotelBasicInfo,
}))
export default class HotelCreateEditIndex extends PureComponent {
  constructor(props) {
    super(props);

    const { hotelTab } = this.props.location.query;
    const activeType =
      typeof hotelTab === 'string' ? hotelTab : `${tabType.findIndex(item => item.show)}`;

    this.state = {
      hotelId: '',
      activeType,
    };
  }

  componentWillMount() {
    let { hotelId } = this.props.location.query;

    this.setState({
      hotelId,
    });
  }

  componentDidMount() {
    let { HotelCreateEditHotelBasicInfo, dispatch } = this.props;
    let { hotelId, hotelTab } = this.props.location.query;
    if (!hotelId) {
      message.info('请从列表页进入');
      return;
    }

    dispatch({
      type: 'HotelCreateEditHotelBasicInfo/getHotelDetailInfo',
      payload: { hotelId },
    });
  }

  setTabType = key => {
    this.setState({
      activeType: key,
    });
  };

  render() {
    let { HotelCreateEditHotelBasicInfo, location } = this.props;
    const { activeType, hotelId } = this.state;
    let { status } = HotelCreateEditHotelBasicInfo;
    return (
      <PageHeaderWrapper>
        <Card>
          <Tabs activeKey={activeType} onChange={this.setTabType} forceRender>
            {tabType.map(item => (
              <TabPane tab={item.text} key={item.key} disabled={!item.show}>
                {activeType === item.key ? (
                  <item.component
                    hotelId={hotelId}
                    status={status}
                    activeType={activeType}
                    location={location}
                  />
                ) : null}
              </TabPane>
            ))}
          </Tabs>
        </Card>
      </PageHeaderWrapper>
    );
  }
}
