import {
  queryAllValidatedChannel,
  queryRoomTypeMatchPriceList,
  queryRoomTypeRateCodeList,
  updateRoomTypeBindRateCodes,
  queryChannelHotelCommission,
  updateChannelHotelCommission,
} from '../service/housePriceChannel';
import {
  fetchHotelCommissionById,
  fetchCustomerCommissionById,
  updateHotelCommissionStatus,
  updateHotelCommissionIsTopStatus,
  getPieData,
  queryAverageRate,
} from '../service/comment';

export default {
  namespace: 'HotelComment',
  state: {
    hotelId: null,
    hotelName: null,
    priceList: [],
    channelCommissionList: [],
    roomTypeRateCodeList: [],
    validatedChannelList: [],
  },
  effects: {
    /**
     * 获取对应hotelId的评论
     * @param {Object} param0
     * @param {Object} param1
     */
    *fetchHotelCommissionById({ payload }, { call, put, select }) {
      try {
        let user = yield select(state => state.user);
        // payload.operatorId = user.accountId || user.operatorId;
        payload.totalRate = payload.totalRate ? payload.totalRate : [];
        let response = yield call(fetchHotelCommissionById, payload);
        return Promise.resolve(response);
      } catch (error) {
        return Promise.reject(error);
      }
    },
    /**
     * 获取对应hotelId的客服评论
     * @param {Object} param0
     * @param {Object} param1
     */
    *fetchCustomerCommissionById({ payload }, { call, put, select }) {
      try {
        let user = yield select(state => state.user);
        // payload.operatorId = user.accountId || user.operatorId;
        payload.totalRate = payload.totalRate ? payload.totalRate : [];
        let response = yield call(fetchCustomerCommissionById, payload);
        return Promise.resolve(response);
      } catch (error) {
        return Promise.reject(error);
      }
    },
    /**
     * 更改该评论在c端展示与否
     * @param {*} param0
     * @param {*} param1
     */
    *updateHotelCommissionStatus({ payload }, { call, put }) {
      try {
        let response = yield call(updateHotelCommissionStatus, payload.id, payload.status);
        return Promise.resolve(response);
      } catch (error) {
        return Promise.reject(error);
      }
    },
    /**
     * 更改该评论在c端是否置顶
     * @param {*} param0
     * @param {*} param1
     */
    *updateHotelCommissionIsTopStatus({ payload }, { call, put }) {
      try {
        let response = yield call(
          updateHotelCommissionIsTopStatus,
          payload.commentId,
          payload.setTop
        );
        return Promise.resolve(response);
      } catch (error) {
        return Promise.reject(error);
      }
    },
    /**
     * 获取评分分布图数据
     * @param {*} param0
     * @param {*} param1
     */
    *getPieData({ payload }, { call, put }) {
      try {
        let response = yield call(getPieData, payload.hotelId);
        return Promise.resolve(response);
      } catch (error) {
        return Promise.reject(error);
      }
    },
    /**
     * 获取所有有效渠道名称
     */
    *fetchAllValidatedChannel({ payload }, { call, put }) {
      try {
        let response = yield call(queryAllValidatedChannel, payload);
        // console.log('获取所有有效渠道名称:', response.data);
        yield put({
          type: 'setAllValidatedChannelList',
          payload: response.data,
        });
        return response;
      } catch (error) {
        yield put({
          type: 'setAllValidatedChannelList',
          payload: [],
        });
        return error.response;
      }
    },
    /**
     * 酒店房型价格策略列表
     */
    *fetchRoomTypeMatchPriceList({ payload }, { call, put, select }) {
      try {
        const hotelId = yield select(state => state.HotelCreateEditHousePriceChannel.hotelId);
        const hotelName = yield select(state => state.HotelCreateEditHotelBasicInfo.hotelInfo.name);
        let response = yield call(queryRoomTypeMatchPriceList, { hotelId });
        // console.log('酒店房型价格策略列表:', response.data);
        yield put({
          type: 'setPriceList',
          payload: response.data,
        });
        yield put({
          type: 'setHotelName',
          payload: hotelName,
        });
        return response;
      } catch (error) {
        // console.error('fetchRoomTypeMatchPriceList:', error);
        yield put({
          type: 'setPriceList',
          payload: [],
        });
        return error.response;
      }
    },
    /**
     * 酒店价格策略下拉列表
     */
    *fetchRoomTypeRateCodeList({ payload }, { call, put }) {
      try {
        let response = yield call(queryRoomTypeRateCodeList, payload);
        // console.log('酒店价格策略下拉列表:', response.data);
        yield put({
          type: 'setRoomTypeRateCodeList',
          payload: response.data,
        });
        return response;
      } catch (error) {
        // console.error('queryRoomTypeRateCodeList:', error);
        yield put({
          type: 'setRoomTypeRateCodeList',
          payload: [],
        });
        return error.response;
      }
    },
    /**
     * 获取酒店所有渠道佣金列表
     */
    *fetchChannelCommission({ payload }, { call, put, select }) {
      try {
        const hotelId = yield select(state => state.HotelCreateEditHousePriceChannel.hotelId);
        const response = yield call(queryChannelHotelCommission, { hotelId });

        // console.log('获取酒店所有渠道佣金列表', response.data);

        yield put({
          type: 'setChannelCommissionList',
          payload: response.data,
        });

        return response;
      } catch (error) {
        yield put({
          type: 'setChannelCommissionList',
          payload: [],
        });
        return error.response;
      }
    },
    /**
     * 更新设置酒店渠道佣金
     */
    *updateChannelCommission({ payload }, { call, put, select }) {
      try {
        const hotelId = yield select(state => state.HotelCreateEditHousePriceChannel.hotelId);
        const operator = yield select(state => state.user.accountId);
        const channelCommissions = yield select(
          state => state.HotelCreateEditHousePriceChannel.channelCommissionList
        );

        const response = yield call(updateChannelHotelCommission, {
          operator,
          hotelId,
          channelCommissions,
        });

        yield put({
          type: 'fetchChannelCommission',
          payload: {},
        });
        return response;
      } catch (error) {
        return error.response;
      }
    },
    /**
     * 更新房型绑定价格策略
     */
    *updateBindRateCodes({ payload }, { call, put, select }) {
      try {
        const hotelId = yield select(state => state.HotelCreateEditHousePriceChannel.hotelId);
        const operatorId = yield select(state => state.user.accountId);
        let response = yield call(updateRoomTypeBindRateCodes, { ...payload, operatorId });
        yield put({
          type: 'fetchRoomTypeMatchPriceList',
          payload: { hotelId },
        });
        return response;
      } catch (error) {
        return error.response;
      }
    },
    /**
     * 获取客服评论列表
     */
    *getAverageRate({ payload }, { call, put }) {
      try {
        const response = yield call(queryAverageRate, payload);
        return response;
      } catch (error) {
        return error.response;
      }
    },
  },
  reducers: {
    setHotelId(state, { payload }) {
      const hotelId = payload;
      return {
        ...state,
        hotelId,
      };
    },
    setHotelName(state, { payload }) {
      const hotelName = payload;
      return {
        ...state,
        hotelName,
      };
    },
    setPriceList(state, { payload }) {
      const priceList = payload;
      return {
        ...state,
        priceList,
      };
    },
    setRoomTypeRateCodeList(state, { payload }) {
      const roomTypeRateCodeList = payload;
      return {
        ...state,
        roomTypeRateCodeList,
      };
    },
    setAllOYORoomTypeList(state, { payload }) {
      const allOYORoomTypeList = payload;
      return {
        ...state,
        allOYORoomTypeList,
      };
    },
    setAllSellRoomTypeList(state, { payload }) {
      const allSellRoomTypeList = payload;
      return {
        ...state,
        allSellRoomTypeList,
      };
    },
    setAllValidatedChannelList(state, { payload }) {
      const validatedChannelList = payload;
      return {
        ...state,
        validatedChannelList,
      };
    },
    setChannelCommissionList(state, { payload }) {
      const channelCommissionList = payload;
      const validatedChannelList = state.validatedChannelList;

      // console.log('//处理：setChannelCommissionList model1', channelCommissionList);
      // console.log('//处理：setChannelCommissionList model1:', validatedChannelList);

      let newValidatedChannelList = [];
      for (let i = 0; i < validatedChannelList.length; i++) {
        let channelOpt = validatedChannelList[i];
        let channelId = channelOpt.channelId;
        let isExist = false;
        for (let j = 0; j < channelCommissionList.length; j++) {
          let commissionOpt = channelCommissionList[j];
          let selectChannelId = commissionOpt.channelId;
          if (channelId === selectChannelId) {
            isExist = true;
            break;
          }
        }
        if (!isExist) {
          channelOpt.disabled = false;
          newValidatedChannelList.push(channelOpt);
        } else {
          channelOpt.disabled = true;
          newValidatedChannelList.push(channelOpt);
        }
      }

      // console.log('//处理：setChannelCommissionList model2:', newValidatedChannelList);
      // console.log('//处理：setChannelCommissionList model2', channelCommissionList);

      return {
        ...state,
        channelCommissionList,
        validatedChannelList: newValidatedChannelList,
      };
    },
  },
};
