import moment from 'moment';
import { message } from 'antd';
import {
  getHotelDetail,
  getMetadataList,
  getAmenityAll,
  save,
  getPTI,
  savePTI,
  getBrand,
} from '@/pages/Hotel/HotelCreateEdit/service/basicInfo';

const DefaultBreakfast = {
  breakfastType: null,
  breakfastTime: '',
  addressType: null,
};

const DefaultData = {
  id: null,
  oyoId: '',
  uniqueCode: '',
  name: '',
  enName: '',
  alternateName: '',
  type: null,
  activationDate: moment(),
  signRoomNum: null,
  roomNum: null,
  floor: '',
  lastDecorateDate: moment(),
  nearybyLandmarkDirection: '',
  hotelFeature: '',
  checkinTime: '',
  checkoutTime: '',
  payMethodList: [],
  mapLink: '',
  latitude: '',
  longitude: '',
  locationDescription: '',
  street: '',
  regionId: null,
  zoneId: null,
  zoneName: null,
  hubId: null,
  hubName: null,
  stateId: null,
  stateName: null,
  cityId: null,
  clcId: null,
  cityName: '',
  startDate: null,
  clusterId: null,
  clusterName: null,
  streetId: null,
  streetName: null,
  styleTagList: [],
  locationTagList: [],
  travelTypeTagList: [],
  nearybyLandmarkList: [],
  landmarkList: [],
  breakfast: {
    ...DefaultBreakfast,
  },
  managerName: '',
  phoneList: [],
  amenities: [],
  landmark: [],
  contact: [],
  clusterData: [],
};

export default {
  namespace: 'HotelCreateEditHotelBasicInfo',
  state: {
    ptiCheckStatus: null,
    hasBmap: false,
    status: null,
    hotelInfo: {
      ...DefaultData,
    },
    metadataList: {
      isHasData: false,
      hotel_breakfast: [],
      hotel_tag_style: [],
      hotel_tag_location: [],
      hotel_tag_travel_type: [],
      hotel_cooper_model: [],
      hotel_pay_method: [],
      hotel_breakfast_address: [],
    },
    branchData: [],
    subBranchData: [],
    mainValData: {}, // 储存getBase的数据
  },
  effects: {
    *getMetadataList({ payload }, { call, put, select }) {
      try {
        let HotelCreateEditHotelBasicInfo = yield select(
          state => state.HotelCreateEditHotelBasicInfo
        );

        if (HotelCreateEditHotelBasicInfo.metadataList.isHasData) return;
        // yield HotelCreateEditHotelBasicInfo.metadataList;

        let res = yield call(getMetadataList);
        let data = {};

        Object.entries(res.data).forEach(([key, val]) => {
          data[key] = val.map(item => ({
            label: item.description,
            value: item.code,
          }));
        });

        yield put({
          type: 'saveMainVal',
          payload: {
            metadataList: {
              isHasData: true,
              ...data,
            },
          },
        });
      } catch (e) {
        console.log(e);
      }
    },

    *getHotelDetailInfo({ payload }, { call, put }) {
      try {
        let res = yield call(getHotelDetail, payload);
        let data = res.data;

        data.activationDate = data.activationDate ? moment(data.activationDate) : null;
        data.lastDecorateDate = data.lastDecorateDate ? moment(data.lastDecorateDate) : null;
        data.nearybyLandmarkList = data.nearybyLandmarkList || [''];
        data.phoneList = data.phoneList || [''];
        data.payMethodList = data.payMethodList || [];
        data.breakfast = data.breakfast || DefaultBreakfast;
        data.styleTagList = data.styleTagList || [];
        data.locationTagList = data.locationTagList || [];
        data.travelTypeTagList = data.travelTypeTagList || [];
        data.amenities = data.amenities || [];

        let breakfast = data.breakfast;

        if (
          breakfast &&
          typeof breakfast.breakfastTime === 'string' &&
          /^\d{1,2}:\s?00-\d{1,2}:\s?00$/.test(breakfast.breakfastTime)
        ) {
          let [st, end] = breakfast.breakfastTime.split('-');
          data.breakfastSt = st;
          data.breakfastEnd = end;
        }

        yield put({
          type: 'saveHotelDetail',
          payload: data,
        });
      } catch (error) {
        console.log(error);
      }
    },

    *updateStatus({ payload }, { call, put }) {
      yield put({
        type: 'changeStatus',
        payload: {
          status: payload,
        },
      });
    },

    *getBase({ payload }, { call, put, select }) {
      try {
        let res = yield call(getPTI, payload);

        yield put({
          type: 'saveMainVal',
          payload: {
            ptiCheckStatus: res.data.ptiCheckStatus,
            status: res.data.status,
            mainValData: res.data,
          },
        });
      } catch (e) {
        console.log(e);
      }
    },

    *savePTI({ payload }, { call, put, select }) {
      try {
        let user = yield select(state => state.user);
        let HotelCreateEditHotelBasicInfo = yield select(
          state => state.HotelCreateEditHotelBasicInfo
        );
        let res = yield call(savePTI, {
          status: HotelCreateEditHotelBasicInfo.ptiCheckStatus,
          hotelId: payload.hotelId,
          operator: user.accountId,
        });

        message.success('保存成功');

        return Promise.resolve({
          statue: true,
        });
      } catch (e) {
        console.log(e);
        message.error('保存失败');

        return Promise.resolve({
          statue: false,
        });
      }
    },

    *save({ payload }, { call, put, select }) {
      try {
        let user = yield select(state => state.user);
        let HotelCreateEditHotelBasicInfo = yield select(
          state => state.HotelCreateEditHotelBasicInfo
        );
        let hotelInfo = { ...HotelCreateEditHotelBasicInfo.hotelInfo };

        hotelInfo.breakfast.breakfastTime = `${hotelInfo.breakfastSt}-${hotelInfo.breakfastEnd}`;

        hotelInfo.activationDate = moment.isMoment(hotelInfo.activationDate)
          ? hotelInfo.activationDate.format('YYYY-MM-DD')
          : null;
        hotelInfo.lastDecorateDate = moment.isMoment(hotelInfo.lastDecorateDate)
          ? hotelInfo.lastDecorateDate.format('YYYY-MM-DD')
          : null;
        delete hotelInfo.uniqueCode;
        delete hotelInfo.oyoId;

        let res = yield call(save, {
          operator: user.accountId,
          data: {
            id: payload.hotelId,
            ...hotelInfo,
          },
        });

        message.success('保存成功');

        return Promise.resolve({
          statue: true,
        });
      } catch (e) {
        console.log(e);
        message.error('保存失败');
        return Promise.resolve({
          statue: false,
        });
      }
    },

    *getBrand({ payload }, { call, put }) {
      try {
        let response = yield call(getBrand);
        yield put({
          type: 'saveBranch',
          payload: response.data || [],
        });
        return Promise.resolve({
          statue: true,
        });
      } catch (e) {
        return Promise.resolve({
          statue: false,
        });
      }
    },
  },
  reducers: {
    saveMainVal(state, { payload }) {
      return {
        ...state,
        ...payload,
      };
    },

    saveBranch(state, { payload }) {
      return {
        ...state,
        branchData: payload,
      };
    },

    saveSubBranch(state, { payload }) {
      const { branchData, hotelInfo } = state;
      const { type } = hotelInfo;
      let subBranchData = [];

      branchData.forEach(item => {
        if (item.typeId === type) {
          subBranchData = item.brandTypeList;
        }
      });

      let last = {};
      // 如果主动改变了合作模式，那么直接改变品牌线
      if (payload && payload.branchStatus) {
        hotelInfo.brandType = subBranchData[0].typeId;
        last = {
          ...state,
          hotelInfo,
          subBranchData,
        };
      } else {
        last = {
          ...state,
          subBranchData,
        };
      }
      return last;
    },

    saveHotelDetail(state, { payload }) {
      return {
        ...state,
        hotelInfo: {
          ...state.hotelInfo,
          ...payload,
        },
      };
    },

    changeStatus(state, { payload }) {
      return {
        ...state,
        status: payload.status,
        hotelInfo: {
          ...state.hotelInfo,
          status: payload,
        },
      };
    },

    changeInputListVal(state, { payload }) {
      let { propName, index, val } = payload;
      let list = state.hotelInfo[propName];

      list[index] = val;

      return {
        ...state,
      };
    },

    deleteInput(state, { payload }) {
      let { propName, deleteIndex } = payload;
      let list = state.hotelInfo[propName];

      if (list.length === 1) {
        message.error('不能全删除');
        return state;
      }

      list.splice(deleteIndex, 1);

      return {
        ...state,
      };
    },

    addInput(state, { payload }) {
      let { propName } = payload;
      let list = state.hotelInfo[propName];

      if (list.length >= 10) {
        message.error('太多了');
        return state;
      }

      list.push('');

      return {
        ...state,
      };
    },
  },
};
