import { message } from 'antd';
import {
  getHotelImage,
  getHotelImageCategoryList,
  changeCategory,
  removeImage,
  uploadHotelImage,
  changePriority,
} from '@/pages/Hotel/HotelCreateEdit/service/housePic';

const CategoryAche = [];

const DefaultData = {
  imgList: [],
  categoryList: [],
  selectImgIdList: [],
  isImgLoad: true,
  changeCategoryType: '',
  picType: '',
};

export default {
  namespace: 'hotelCreateEditHousePic',

  state: {
    ...DefaultData,
  },

  effects: {
    *getImgList({ payload }, { call, put, select }) {
      try {
        yield put({
          type: 'changeMainVal',
          payload: {
            isImgLoad: true,
          },
        });

        let respose = yield call(getHotelImage, payload);
        let category = [];
        let imgListData = [];

        if (CategoryAche.length) {
          category = CategoryAche;
        } else {
          let categoryRes = yield call(getHotelImageCategoryList, payload);

          category = categoryRes.data.map(({ code, name }) => ({
            label: name,
            value: code,
          }));
        }

        let imgList = [];
        let noDataList = [];

        // respose.data[0].imageList.push({
        //   imageId: 10182,
        //   resourceType: 1,
        //   url: 'http://img1.imgtn.bdimg.com/it/u=702810779,3136032350&fm=15&gp=0.jpg',
        // });

        category.forEach(cate => {
          let resData = respose.data.find(d => d.category === cate.value);

          if (resData) {
            resData.title = cate.label || '未知';
            resData.imageList &&
              resData.imageList.forEach(img => {
                if (/\?resourceType=0$/.test(img.url)) {
                  let url = img.url.match(/[^?]+/)[0];

                  img.showUrl = `${url}?x-oss-process=image/resize,m_lfit,w_166,h_130/sharpen,100`;
                }

                imgListData.push(img);
              });

            imgList.push(resData);
          } else {
            noDataList.push({
              category: cate.value,
              title: cate.label,
              imageList: [],
            });
          }
        });

        imgList = imgList.concat(noDataList);

        let imgCount = imgListData.length;
        let nowCount = 0;

        yield put({
          type: 'changeMainVal',
          payload: {
            imgList,
            isImgLoad: false,
            categoryList: category,
          },
        });

        let payloadData = yield new Promise((resolve, reject) => {
          if (imgListData.length === 0) {
            message.info('本酒店暂无图片');

            resolve({
              type: 'changeMainVal',
              payload: {
                imgList,
                isImgLoad: false,
                categoryList: category,
              },
            });
          }

          imgListData.forEach(item => {
            item.isSelect = false;

            let img = new Image();

            img.src = item.url;

            img.onload = function() {
              if (this.width > this.height) {
                item.classType = 'perviewW';
              } else {
                item.classType = 'perviewH';
              }

              if (++nowCount === imgCount) {
                resolve({
                  type: 'changeMainVal',
                  payload: {
                    imgList,
                    isImgLoad: false,
                    categoryList: category,
                  },
                });
              }
            };

            img.onerror = function() {
              if (++nowCount === imgCount) {
                resolve({
                  type: 'changeMainVal',
                  payload: {
                    imgList,
                    isImgLoad: false,
                    categoryList: category,
                  },
                });
              }
            };
          });
        });

        yield put(payloadData);

        return Promise.resolve({
          statue: true,
        });
      } catch (e) {
        console.log(e);
        return Promise.resolve({
          statue: false,
        });
      }
    },

    *removeImage({ payload }, { call, put, select }) {
      let hotelCreateEditHousePic = yield select(state => state.hotelCreateEditHousePic);
      let user = yield select(state => state.user);
      let { selectImgIdList, imgList } = hotelCreateEditHousePic;

      if (selectImgIdList.length === 0) return message.error('请先选择图片');

      try {
        let response = yield call(removeImage, {
          hotelId: payload.hotelId,
          imageIdList: hotelCreateEditHousePic.selectImgIdList,
          operator: user.accountId,
        });

        let newSelectImgIdList = imgList.map(item => ({
          ...item,
          imageList: item.imageList ? item.imageList.filter(img => !img.isSelect) : [],
        }));

        yield put({
          type: 'changeMainVal',
          payload: {
            imgList: newSelectImgIdList,
            selectImgIdList: [],
          },
        });

        message.success('删除成功');
      } catch (e) {
        console.log(e);
      }
    },

    *changeCategory({ payload }, { call, put, select }) {
      let hotelCreateEditHousePic = yield select(state => state.hotelCreateEditHousePic);
      let user = yield select(state => state.user);
      let { imgList, selectImgIdList, changeCategoryType } = hotelCreateEditHousePic;

      if (selectImgIdList.length === 0) return message.error('请先选择图片');
      if (changeCategoryType === null || changeCategoryType === '')
        return message.error('请先选择类型');

      try {
        let response = yield call(changeCategory, {
          hotelId: payload.hotelId,
          imageIdList: hotelCreateEditHousePic.selectImgIdList,
          operator: user.accountId,
          category: changeCategoryType,
        });

        let selectImgItem = [];
        let selectTypeData = {};

        imgList.forEach(item => {
          let unSelect = [];
          item.imageList.forEach(img => {
            if (img.isSelect) {
              selectImgItem.push({
                ...img,
                isSelect: false,
              });
            } else {
              unSelect.push(img);
            }
          });

          if (item.category === changeCategoryType) selectTypeData = item;

          item.imageList = unSelect;
        });

        selectTypeData.imageList = selectTypeData.imageList.concat(selectImgItem);

        let hasDataimgList = [];
        let noDataList = [];

        imgList.forEach(item => {
          if (item.imageList.length) {
            hasDataimgList.push(item);
          } else {
            noDataList.push(item);
          }
        });

        imgList = hasDataimgList.concat(noDataList);

        yield put({
          type: 'changeMainVal',
          payload: {
            imgList,
            selectImgIdList: [],
          },
        });

        message.success('移动成功');

        return Promise.resolve({
          statue: true,
        });
      } catch (e) {
        console.log(e);
        return Promise.resolve({
          statue: false,
        });
      }
    },

    *uploadHotelImage({ payload }, { call, put, select }) {
      let hotelCreateEditHousePic = yield select(state => state.hotelCreateEditHousePic);
      let user = yield select(state => state.user);
      let { picType } = hotelCreateEditHousePic;

      message.info('上传过程较慢, 请耐心等待');

      try {
        let response = yield call(uploadHotelImage, {
          formData: payload.formData,
          params: {
            hotelId: payload.hotelId,
            operator: user.accountId,
            category: picType,
          },
        });

        let data = response.data;

        if (data && data.uploadFailedFileNameList.length) {
          let msg = data.uploadFailedFileNameList.toString();

          message.warn(`${msg}上传失败`);
        }

        yield put({
          type: 'getImgList',
          payload: {
            hotelId: payload.hotelId,
          },
        });

        return Promise.resolve({
          statue: true,
        });
      } catch (e) {
        console.log(e);
        return Promise.resolve({
          statue: false,
        });
      }
    },

    *changePriority({ payload }, { call, put, select }) {
      let hotelCreateEditHousePic = yield select(state => state.hotelCreateEditHousePic);
      let user = yield select(state => state.user);

      let imageIdList = payload.newPicList.map(item => item.imageId);

      try {
        let response = yield call(changePriority, {
          hotelId: payload.hotelId,
          operator: user.accountId,
          imageIdList,
        });

        let PicData = payload.PicData;

        // debugger;
        let newImgList = hotelCreateEditHousePic.imgList.slice().map(item => {
          if (item === PicData) {
            return {
              ...item,
              imageList: payload.newPicList,
            };
          }
          return item;
        });

        yield put({
          type: 'changeMainVal',
          payload: {
            imgList: newImgList,
          },
        });

        message.success('调整顺序成功');

        return Promise.resolve({
          statue: true,
        });
      } catch (e) {
        message.error('调整顺序失败');
        yield put({
          type: 'changeMainVal',
          payload: {
            imgList: hotelCreateEditHousePic.imgList.slice(),
          },
        });

        return Promise.resolve({
          statue: false,
        });
      }
    },
  },

  reducers: {
    init() {
      return {
        ...JSON.parse(JSON.stringify(DefaultData)),
      };
    },

    selectAll(state, action) {
      const { imgList, selectImgIdList } = state;
      const { seletType } = action.payload;
      const selectId = [];

      imgList.forEach(item => {
        item.imageList.forEach(img => {
          img.isSelect = !!seletType;
          !!seletType && selectId.push(img.imageId);
        });
      });

      return {
        ...state,
        imgList,
        selectImgIdList: selectId,
      };
    },

    selectPic(state, action) {
      let { imgList, selectImgIdList } = state;
      let { index, i, imageId } = action.payload;

      imgList[index].imageList[i].isSelect = !imgList[index].imageList[i].isSelect;

      let imageIdIndex = selectImgIdList.findIndex(item => item === imageId);

      if (imageIdIndex !== -1) {
        selectImgIdList.splice(imageIdIndex, 1);
      } else {
        selectImgIdList.push(imageId);
      }

      return {
        ...state,
        imgList,
        selectImgIdList,
      };
    },

    // 改变普通值
    changeMainVal(state, action) {
      return {
        ...state,
        ...action.payload,
      };
    },

    // 初始化值
    initData(state, action) {
      return {
        ...DefaultData,
      };
    },
  },
};
