import { message } from 'antd';
import {
  getHotelDetail,
  saveHotelBindRoomTypeList,
  getRoomListByRoomType,
  saveRoomListForRoomType,
  deleteRoomType,
  getSignedRommState,
} from '../service/houseType';
import { getUUID } from '@/utils/utils';

const DefaultData = {
  roomRemark: {
    standard: {
      count: 0,
      prop: 100,
    },
    custom: {
      count: 0,
      prop: 0,
    },
    default: {
      count: 0,
      prop: 0,
    },
  },
  cacheList: [],
  roomTypeList: [],
  roomList: [],
  roomSelectable: {
    count: 0,
    roomList: [],
  },
  roomSelected: {
    count: 0,
    roomList: [],
  },
  selectList: [],
  tableUuid: getUUID(),
  editingKey: '',
  totalCount: 0,
  signedRoomState: [],
};

export default {
  namespace: 'hotelCreateEditHouseType',

  state: {
    ...DefaultData,
  },

  effects: {
    *getHotelDetail({ payload }, { call, put, select }) {
      try {
        const response = yield call(getHotelDetail, payload);
        let data = response.data.roomTypeInfoList;

        data.forEach((item, index) => {
          item.roomTypeIdOld = item.roomTypeId;
          item.key = index;
          item.index = index;
          item.isNew = false;
          item.isCustom = /自定义/.test(item.roomTypeName);
          item.isOldCustom = item.isCustom;
          item.isNewSellType = false; // 自定义后新的名字
        });

        let cacheList = JSON.parse(JSON.stringify(data));

        yield put({
          type: 'changeMainVal',
          payload: {
            roomTypeList: data,
            cacheList,
            totalCount: data[0] ? data[0].totalCount : 0,
          },
        });

        yield put({
          type: 'changeRoomRemark',
        });
      } catch (e) {
        return e.response;
      }
    },

    // 删除房型配置
    *deleteType({ payload }, { call, put, select }) {
      let hotelCreateEditHouseType = yield select(state => state.hotelCreateEditHouseType);
      let { selectList } = hotelCreateEditHouseType;
      let localList = selectList.filter(item => item.isNew); // 新增出来的房型（数据在本地, 不在服务器上）
      let servicesList = selectList.filter(item => !item.isNew); // 服务器上的数据
      let roomTypeList = hotelCreateEditHouseType.roomTypeList.slice();
      let deleteList = selectList.map(item => item.index).sort((a, b) => b - a);

      deleteList.forEach(index => {
        roomTypeList.splice(index, 1);
      });

      if (selectList.length === 0) {
        return message.info('请选择删除的房型');
      }

      // 删除的数据全是本地新增的数据
      if (selectList.length === localList.length) {
        yield put({
          type: 'changeMainVal',
          payload: {
            roomTypeList,
            selectList: [],
            tableUuid: getUUID(),
          },
        });

        // 初始化 对房型列表的key index重新赋值
        yield put({
          type: 'initRoomTypeList',
          payload: {
            isSave: false, // 不赋值为老数据
          },
        });

        yield put({
          type: 'changeRoomRemark',
        });

        message.success('删除成功');
      } else {
        try {
          const response = yield call(deleteRoomType, {
            hotelId: payload.hotelId,
            roomTypeIdList: servicesList.map(item => item.roomTypeId),
          });

          // 设置值
          yield put({
            type: 'changeMainVal',
            payload: {
              selectList: [],
              roomTypeList,
              tableUuid: getUUID(),
            },
          });

          // 初始化 对房型列表的key index重新赋值
          yield put({
            type: 'initRoomTypeList',
            payload: {
              isSave: false, // 不赋值为老数据
            },
          });

          // 重新计算右侧备注
          yield put({
            type: 'changeRoomRemark',
          });

          message.success('删除成功');
        } catch (e) {
          console.log(e);
        }
      }
    },

    // 取消编辑 获取缓存数据
    *resetRoomTypeList({ payload }, { call, put, select }) {
      let hotelCreateEditHouseType = yield select(state => state.hotelCreateEditHouseType);

      yield put({
        type: 'changeMainVal',
        payload: {
          roomTypeList: JSON.parse(JSON.stringify(hotelCreateEditHouseType.cacheList)),
        },
      });

      yield put({
        type: 'changeRoomRemark',
      });
    },

    // 获取关联房间列表展示
    *getRoomListByRoomType({ payload }, { call, put, select }) {
      try {
        let response = yield call(getRoomListByRoomType, payload);
        // response = {
        //   code: '000',
        //   data: {
        //     roomSelected: {
        //       count: 11,
        //       roomList: [
        //         {
        //           roomDateList: [
        //             { roomNum: '137', choosable: 0, id: 613435 },
        //             { roomNum: '147', choosable: 0, id: 613443 },
        //             { roomNum: '127', choosable: 0, id: 613446 },
        //             { roomNum: '139', choosable: 0, id: 613447 },
        //             { roomNum: '111', choosable: 0, id: 613448 },
        //           ],
        //           floor: '8',
        //         },
        //         {
        //           roomDateList: [
        //             { roomNum: '137', choosable: 0, id: 613435 },
        //             { roomNum: '147', choosable: 0, id: 613443 },
        //             { roomNum: '127', choosable: 0, id: 613446 },
        //             { roomNum: '139', choosable: 0, id: 613447 },
        //             { roomNum: '111', choosable: 0, id: 613448 },
        //             { roomNum: '115', choosable: 0, id: 613453 },
        //             { roomNum: '109', choosable: 0, id: 613455 },
        //             { roomNum: '105', choosable: 0, id: 613462 },
        //             { roomNum: '119', choosable: 0, id: 613465 },
        //             { roomNum: '102', choosable: 0, id: 613469 },
        //           ],
        //           floor: '-1',
        //         },
        //         { roomDateList: [{ roomNum: '003', choosable: 0, id: 613456 }], floor: '1' },
        //         { roomDateList: [{ roomNum: '003', choosable: 0, id: 613456 }], floor: '18' },
        //         { roomDateList: [{ roomNum: '001', choosable: 0, id: 613456 }], floor: '102' },
        //         { roomDateList: [{ roomNum: '032', choosable: 0, id: 613456 }], floor: '22' },
        //         { roomDateList: [{ roomNum: '077', choosable: 0, id: 613456 }], floor: '88' },
        //       ],
        //     },
        //     roomSelectable: {
        //       count: 0,
        //       roomList: [
        //         {
        //           roomDateList: [
        //             { roomNum: '002', choosable: 0, id: 613456 },
        //             { roomNum: '012', choosable: 0, id: 613456 },
        //             { roomNum: '032', choosable: 0, id: 613456 },
        //           ],
        //           floor: '-1',
        //         },
        //         { roomDateList: [{ roomNum: '999', choosable: 0, id: 613456 }], floor: '12' },
        //         { roomDateList: [{ roomNum: '001', choosable: 0, id: 613456 }], floor: '99' },
        //         { roomDateList: [{ roomNum: '003', choosable: 0, id: 613456 }], floor: '20' },
        //         { roomDateList: [{ roomNum: '009', choosable: 0, id: 613456 }], floor: '21' },
        //         { roomDateList: [{ roomNum: '012', choosable: 0, id: 613456 }], floor: '22' },
        //         { roomDateList: [{ roomNum: '022', choosable: 0, id: 613456 }], floor: '88' },
        //         { roomDateList: [{ roomNum: '022', choosable: 0, id: 613456 }], floor: '-3' },
        //       ],
        //     },
        //   },
        //   msg: '成功',
        // };
        const { roomSelected, roomSelectable } = response.data;

        roomSelected.roomList = roomSelected.roomList.sort(
          (a, b) => Number(a.floor) - Number(b.floor)
        );
        roomSelectable.roomList = roomSelectable.roomList.sort(
          (a, b) => Number(a.floor) - Number(b.floor)
        );

        yield put({
          type: 'changeMainVal',
          payload: {
            roomSelectable,
            roomSelected,
          },
        });
      } catch (e) {
        yield put({
          type: 'changeMainVal',
          payload: {
            roomSelectable: {
              count: 0,
              roomList: [],
            },
            roomSelected: {
              count: 0,
              roomList: [],
            },
          },
        });
      }
    },

    *saveRoomList({ payload }, { call, put, select }) {
      let { hotelId, roomTypeId, isCustom } = payload;
      let hotelCreateEditHouseType = yield select(state => state.hotelCreateEditHouseType);
      let roomTypeAndRelation = yield select(state => state.roomTypeAndRelation);
      let user = yield select(state => state.user);
      let roomTypeList = hotelCreateEditHouseType.roomTypeList.slice();
      let roomIdList = [];
      let customCount = 0;

      hotelCreateEditHouseType.roomSelected.roomList.forEach(item => {
        item.roomDateList.forEach(room => {
          roomIdList.push(room.id);
        });
      });

      roomTypeList.forEach(item => {
        if (item.isOldCustom === true && item.roomTypeIdOld !== roomTypeId) {
          customCount += item.roomCount || 0;
        }
      });

      customCount += roomIdList.length;

      if (isCustom && Math.round((customCount / hotelCreateEditHouseType.totalCount) * 100) > 30) {
        return message.error('自定义房型房数量不得超过30%');
      }

      try {
        const response = yield call(saveRoomListForRoomType, {
          hotelId,
          roomTypeId,
          roomIdList,
          operator: user.accountId,
        });

        let newRoomTypeList = roomTypeList.map(item => {
          if (roomTypeId === item.roomTypeId) {
            return {
              ...item,
              roomCount: roomIdList.length,
            };
          }
          return item;
        });

        let cacheList = hotelCreateEditHouseType.cacheList.map(item => {
          if (roomTypeId === item.roomTypeId) {
            return {
              ...item,
              roomCount: roomIdList.length,
            };
          }
          return item;
        });

        yield put({
          type: 'changeMainVal',
          payload: {
            roomTypeList: newRoomTypeList,
            cacheList: JSON.parse(JSON.stringify(cacheList)),
          },
        });

        yield put({
          type: 'changeRoomRemark',
        });

        message.success('保存成功');

        return {
          statue: true,
        };
      } catch (e) {
        console.log(e);
      }
    },
    // 保存数据
    *save({ payload }, { call, put, select }) {
      let hotelCreateEditHouseType = yield select(state => state.hotelCreateEditHouseType);
      let user = yield select(state => state.user);
      let roomTypeList = hotelCreateEditHouseType.roomTypeList;
      const roomTypeIdList = [];
      let bindInfoList = roomTypeList.map(
        ({
          oldRoomTypeId,
          roomTypeId,
          saleRoomTypeId,
          saleRoomTypeName,
          isNewSellType,
          roomTypeIdOld,
        }) => {
          let customSellTypeName;

          // 判断是否是手动输入的
          if (isNewSellType) {
            customSellTypeName = Array.isArray(saleRoomTypeName)
              ? saleRoomTypeName[0]
              : saleRoomTypeName;
          } else {
            customSellTypeName = null; // 非手动输入的直接传null
          }

          return {
            roomTypeIdOld: roomTypeIdOld || null,
            sellRoomTypeId: saleRoomTypeId,
            roomTypeId,
            customSellTypeName,
          };
        }
      );

      bindInfoList.forEach(({ roomTypeIdOld, roomTypeId }) => {
        if (roomTypeId !== roomTypeIdOld) roomTypeIdList.push(roomTypeIdOld);
      });

      let params = {
        hotelId: payload.hotelId,
        operator: user.accountId,
        bindInfoList,
        roomTypeIdList,
      };

      try {
        const response = yield call(saveHotelBindRoomTypeList, params);

        message.success('保存成功');

        yield put({
          type: 'getHotelDetail',
          payload: {
            hotelId: payload.hotelId,
          },
        });
      } catch (e) {
        message.error('保存失败');
      }
    },
    // 获取签约房态
    *getSignedRommState({ payload }, { call, put, select }) {
      try {
        const res = yield call(getSignedRommState, payload);
        // 由于后端对空数据不返回空数组而是null，data不使用解构
        yield put({ type: 'setSignedRoomState', payload: res.data || [] });

        return res;
      } catch (e) {
        message.error('获取失败');
        return Promise.reject(e.response);
      }
    },
  },

  reducers: {
    init() {
      return {
        ...JSON.parse(JSON.stringify(DefaultData)),
      };
    },

    // 改变普通值
    changeMainVal(state, action) {
      return {
        ...state,
        ...action.payload,
      };
    },

    // 初始化RoomTypeLis
    initRoomTypeList(state, { payload }) {
      let { isSave } = payload;

      let roomTypeList = state.roomTypeList.map((item, index) => {
        let data = {
          ...item,
          index,
          key: index,
        };

        if (isSave) data.isNew = false;

        return data;
      });

      return {
        ...state,
        roomTypeList,
      };
    },

    // 修改自定义房型的属性
    changeCustomVal(state, action) {
      let { value, record, saleList, mainList } = action.payload;
      let { isCustom, index, roomTypeName } = record;
      let roomTypeList = state.roomTypeList.slice();
      let customNameList = roomTypeList
        .map(item => item.saleRoomTypeName)
        .toString()
        .split(',');

      let roomData = roomTypeList[index];

      if (value.length > 1) value = [value[1]];

      if (/[,，]/g.test(value[0])) {
        message.error('名字中不得存在逗号');
        return {
          ...state,
        };
      }

      if (customNameList.includes(value[0])) {
        message.error('已经存在该销售房型');
        return {
          ...state,
        };
      }

      let customOptionrRoom = saleList.find(item => item.saleRoomTypeName === value[0]);
      let mainListOptionrRoom = mainList.find(item => item.roomTypeName === roomData.roomTypeName);

      if (customOptionrRoom) {
        roomData = {
          ...roomData,
          saleRoomTypeId: customOptionrRoom.saleRoomTypeId,
          saleRoomTypeName: value,
          roomTypeCode: mainListOptionrRoom.roomTypeCode,
          isNewSellType: false,
        };
      } else {
        let codeNumber = roomTypeName.match(/\d$/);

        roomData = {
          ...roomData,
          saleRoomTypeId: null,
          saleRoomTypeName: value,
          roomTypeCode: `UD${codeNumber ? codeNumber[0] : '?'}-?`,
          isNewSellType: true,
        };
      }

      roomTypeList[index] = roomData;

      return {
        ...state,
        roomTypeList,
      };
    },

    removeRoom(state, { payload }) {
      let { roomSelected, roomSelectable } = state;
      let { type, index, i } = payload;
      let isRoomSelected = type === 'roomSelected';
      let oldData = isRoomSelected ? roomSelected : roomSelectable;
      let newData = isRoomSelected ? roomSelectable : roomSelected;

      oldData = JSON.parse(JSON.stringify(oldData));
      newData = JSON.parse(JSON.stringify(newData));

      oldData.count--;
      newData.count++;

      let spliceData = oldData.roomList[index].roomDateList.splice(i, 1)[0];
      let pushRoomDateList = newData.roomList.find(
        item => item.floor === oldData.roomList[index].floor
      );
      // debugger;
      if (!pushRoomDateList) {
        let pushData = {
          roomDateList: [],
          floor: oldData.roomList[index].floor,
        };

        newData.roomList.push(pushData);
        newData.roomList.sort((a, b) => Number(a.floor) - Number(b.floor));

        pushRoomDateList = pushData.roomDateList;
      } else {
        pushRoomDateList = pushRoomDateList.roomDateList;
      }

      let findIndex = pushRoomDateList.findIndex(item => item.roomNum > spliceData.roomNum);

      if (findIndex === -1) findIndex = pushRoomDateList.length;

      pushRoomDateList.splice(findIndex, 0, {
        ...spliceData,
        removeCount: spliceData.removeCount === undefined ? 0 : spliceData.removeCount + 1,
      });

      let payloadData = {};

      if (isRoomSelected) {
        payloadData = {
          roomSelected: oldData,
          roomSelectable: newData,
        };
      } else {
        payloadData = {
          roomSelectable: oldData,
          roomSelected: newData,
        };
      }

      return {
        ...state,
        ...payloadData,
      };
    },

    addType(state, action) {
      let roomTypeList = [...state.roomTypeList];

      if (roomTypeList.length >= 10) {
        message.warn('房型总类不能超过10种');
        return {
          ...state,
        };
      }

      roomTypeList.push({
        key: roomTypeList.length,
        oldRoomTypeId: null,
        oldRoomTypeName: '',
        roomTypeId: null,
        roomTypeName: '',
        roomTypeCode: '',
        saleRoomTypeId: null,
        saleRoomTypeName: '',
        roomCount: 0,
        index: roomTypeList.length,
        isCustom: null,
        isNew: true, // 新创建的数据
        deletable: 1, // 可以删除
      });

      return {
        ...state,
        roomTypeList,
      };
    },

    // 重新计算房型数量
    changeRoomRemark(state, action) {
      let roomTypeList = state.roomTypeList;
      let totalCount = state.totalCount;
      let standardCount = 0;
      let customCount = 0;
      let defaultCount = 0;

      roomTypeList.forEach(item => {
        if (item.isCustom === false) {
          standardCount += item.roomCount || 0;
        } else if (item.isCustom === true) {
          customCount += item.roomCount || 0;
        }
      });

      defaultCount = totalCount - standardCount - customCount;

      let standardProp = Math.round((standardCount / totalCount) * 100);
      let customProp = Math.round((customCount / totalCount) * 100);
      let defaultProp = 100 - standardProp - customProp;

      return {
        ...state,
        roomRemark: {
          standard: {
            count: standardCount,
            prop: standardProp,
          },
          custom: {
            count: customCount,
            prop: customProp,
          },
          default: {
            count: defaultCount,
            prop: defaultProp,
          },
        },
      };
    },

    setSignedRoomState(state, { payload }) {
      return {
        ...state,
        signedRoomState: payload,
      };
    },
  },
};
