import {
  queryHotelRoomTypeAmenities,
  updateHotelRoomTypeAmenities,
  queryHotelAllBedInfoList,
  deleteRoomTypeBedInfo,
} from '../service/houseFacilities';

import { findSameItemInTwoArray } from '@/utils/utils';

export default {
  namespace: 'HotelCreateEditHouseFacilities',
  state: {
    amenitiesList: [],
    roomTypeAmenities: {},
    allBedList: [],
    baseAndMoreAmenities: {},
  },
  effects: {
    /**
     * 获取酒店房型绑定设施列表
     */
    *fetchHotelRoomTypeAmenities({ payload }, { call, put, select }) {
      try {
        const response = yield call(queryHotelRoomTypeAmenities, payload);
        let amenitiesList = response.data;

        yield put({
          type: 'setAmenitiesList',
          payload: amenitiesList,
        });

        return response;
      } catch (error) {
        console.log(error);
      }
    },
    /**
     * 更新酒店房型设施： 新增/编辑 保存
     */
    *updateHotelRoomTypeAmenities({ payload }, { call, put }) {
      try {
        let response = yield call(updateHotelRoomTypeAmenities, payload);

        return response;
      } catch (error) {
        return error.response;
      }
    },
    /**
     * 酒店床型列表【静态数据】
     */
    *fetchHotelBedInfoAll(action, { call, put }) {
      try {
        let response = yield call(queryHotelAllBedInfoList);

        let bedList = response.data;
        let allBedList = [];

        bedList.forEach(bed => {
          bed.sizeList.forEach(size => {
            allBedList.push(size);
          });
        });

        yield put({
          type: 'setAllBedList',
          payload: { allBedList },
        });
        return response;
      } catch (error) {
        yield put({
          type: 'setAllBedList',
          payload: {
            allBedList: [],
          },
        });
        return error.response;
      }
    },
    *deleteRoomTypeBedInfo({ payload }, { call }) {
      try {
        let response = yield call(deleteRoomTypeBedInfo, payload);
        return response;
      } catch (e) {
        return e.response;
      }
    },
  },
  reducers: {
    setAmenitiesList(state, { payload }) {
      const amenitiesList = payload;
      return {
        ...state,
        amenitiesList,
      };
    },
    setBaseAndMoreAmenities(state, { payload }) {
      const baseAndMoreAmenities = payload;
      return {
        ...state,
        baseAndMoreAmenities,
      };
    },
    setRoomTypeAmenities(state, { payload }) {
      return {
        ...state,
        ...payload,
      };
    },
    setAllBedList(state, { payload }) {
      return {
        ...state,
        ...payload,
      };
    },
    setHotelAmenities(state, { payload }) {
      let { roomTypeAmenities } = state;
      roomTypeAmenities = { ...roomTypeAmenities, ...payload };
      return {
        ...state,
        roomTypeAmenities,
      };
    },
    setBedInfoList(state, { payload }) {
      return {
        ...state,
        ...payload,
      };
    },
  },
};
