import {
  queryAllValidatedChannel,
  queryRoomTypeMatchPriceList,
  queryRoomTypeRateCodeList,
  updateRoomTypeBindRateCodes,
  queryChannelHotelCommission,
  updateChannelHotelCommission,
  multipleAddRoomPriceStrategy,
  updatePriceStategy,
  getHotelState,
  setChannelState,
} from '@/pages/Hotel/HotelCreateEdit/service/housePriceChannel';

export default {
  namespace: 'HotelCreateEditHousePriceChannel',
  state: {
    hotelId: null,
    hotelName: null,
    priceList: [],
    originPriceList: [], // 保存历史的列表，便于展示新的价格策略
    channelCommissionList: [],
    roomTypeRateCodeList: [],
    validatedChannelList: [],
    // 已经选取的价格策略
    hasChoosenPriceStrategy: [],
    // 已经选取的行
    hasChoosenColumns: '',
    // 渠道酒店关房状态列表
    channelStatusList: [],
  },
  effects: {
    /**
     * 获取所有有效渠道名称
     */
    *fetchAllValidatedChannel({ payload }, { call, put }) {
      try {
        let response = yield call(queryAllValidatedChannel, payload);
        yield put({
          type: 'setAllValidatedChannelList',
          payload: response.data,
        });
        return response;
      } catch (error) {
        yield put({
          type: 'setAllValidatedChannelList',
          payload: [],
        });
        return error.response;
      }
    },
    /**
     * 酒店房型价格策略列表
     */
    *fetchRoomTypeMatchPriceList({ payload }, { call, put, select }) {
      try {
        const hotelId = yield select(state => state.HotelCreateEditHousePriceChannel.hotelId);
        const hotelName = yield select(state => state.HotelCreateEditHotelBasicInfo.hotelInfo.name);
        let response = yield call(queryRoomTypeMatchPriceList, { hotelId });
        yield put({
          type: 'setPriceList',
          payload: response.data,
        });
        yield put({
          type: 'setHotelName',
          payload: hotelName,
        });
        return response;
      } catch (error) {
        yield put({
          type: 'setPriceList',
          payload: [],
        });
        return error.response;
      }
    },
    /**
     * 酒店价格策略下拉列表
     */
    *fetchRoomTypeRateCodeList({ payload }, { call, put }) {
      try {
        let response = yield call(queryRoomTypeRateCodeList, payload);
        yield put({
          type: 'setRoomTypeRateCodeList',
          payload: response.data,
        });
        return response;
      } catch (error) {
        // console.error('queryRoomTypeRateCodeList:', error);
        yield put({
          type: 'setRoomTypeRateCodeList',
          payload: [],
        });
        return error.response;
      }
    },
    /**
     * 获取酒店所有渠道佣金列表
     */
    *fetchChannelCommission({ payload }, { call, put, select }) {
      try {
        const hotelId = yield select(state => state.HotelCreateEditHousePriceChannel.hotelId);
        const response = yield call(queryChannelHotelCommission, { hotelId });
        yield put({
          type: 'setChannelCommissionList',
          payload: response.data,
        });

        return response;
      } catch (error) {
        yield put({
          type: 'setChannelCommissionList',
          payload: [],
        });
        return error.response;
      }
    },
    /**
     * 更新设置酒店渠道佣金
     */
    *updateChannelCommission({ payload }, { call, put, select }) {
      try {
        const hotelId = yield select(state => state.HotelCreateEditHousePriceChannel.hotelId);
        const operator = yield select(state => state.user.accountId);
        const channelCommissions = yield select(
          state => state.HotelCreateEditHousePriceChannel.channelCommissionList
        );

        const response = yield call(updateChannelHotelCommission, {
          operator,
          hotelId,
          channelCommissions,
        });
        yield put({
          type: 'fetchChannelCommission',
          payload: {},
        });

        yield put({
          type: 'fetchRoomTypeMatchPriceList',
          payload: { hotelId },
        });

        yield put({
          type: 'fetchRoomTypeRateCodeList',
          payload: { hotelId },
        });
        return response;
      } catch (error) {
        return error.response;
      }
    },
    /**
     * 更新房型绑定价格策略
     */
    *updateBindRateCodes({ payload }, { call, put, select }) {
      try {
        const hotelId = yield select(state => state.HotelCreateEditHousePriceChannel.hotelId);
        const operatorId = yield select(state => state.user.accountId);
        let response = yield call(updateRoomTypeBindRateCodes, { ...payload, operatorId });
        yield put({
          type: 'fetchRoomTypeMatchPriceList',
          payload: { hotelId },
        });
        return response;
      } catch (error) {
        return Promise.reject(error.response);
      }
    },
    /**
     * 批量新增房型价格策略
     */
    *doAddRoomPriceStrategy({ payload }, { call, put, select }) {
      try {
        const hotelId = yield select(state => state.HotelCreateEditHousePriceChannel.hotelId);
        const operatorId = yield select(state => state.user.accountId);
        let response = yield call(multipleAddRoomPriceStrategy, {
          ...payload,
          operatorId,
          hotelId,
        });
        // yield put({
        //   type: 'fetchRoomTypeMatchPriceList',
        //   payload: { hotelId },
        // });
        return response;
      } catch (error) {
        return Promise.reject(error.response);
      }
    },
    /**
     * 批量绑定房型价格策略
     */
    *doUpdatePriceStategy({ payload }, { call, put, select }) {
      try {
        const hotelId = yield select(state => state.HotelCreateEditHousePriceChannel.hotelId);
        const operatorId = yield select(state => state.user.accountId);
        const response = yield call(updatePriceStategy, {
          hotelId,
          operatorId,
          roomTypeRateCodes: payload,
        });
        return response;
      } catch (error) {
        return error.response;
      }
    },
    /**
     * 获取渠道房型关房状态
     */
    *getHotelState({ payload }, { call, put, select }) {
      try {
        const hotelId = yield select(state => state.HotelCreateEditHousePriceChannel.hotelId);
        const response = yield call(getHotelState, { hotelId, ...payload });
        let channelList = response.data.channelStatusList;
        if (!Array.isArray(channelList) || !channelList[0]) {
          channelList = [];
        }
        yield put({
          type: 'setHotelState',
          payload: channelList,
        });
        return response.data;
      } catch (error) {
        return error.response;
      }
    },
    /**
     * 更改渠道房型关房状态
     */
    *modifyHotelState({ payload }, { call, put, select }) {
      try {
        const hotelId = yield select(state => state.HotelCreateEditHousePriceChannel.hotelId);
        const operatorId = yield select(state => state.user.accountId);
        const response = yield call(setChannelState, {
          hotelId,
          operatorId,
          ...payload,
        });
        return response;
      } catch (e) {
        return Promise.reject(e);
      }
    },
  },
  reducers: {
    setHotelId(state, { payload }) {
      const hotelId = payload;
      return {
        ...state,
        hotelId,
      };
    },
    setHotelName(state, { payload }) {
      const hotelName = payload;
      return {
        ...state,
        hotelName,
      };
    },
    setPriceList(state, { payload }) {
      const priceList = JSON.parse(JSON.stringify(payload));
      const originPriceList = JSON.parse(JSON.stringify(payload));
      return {
        ...state,
        priceList,
        originPriceList,
      };
    },
    setRoomTypeRateCodeList(state, { payload }) {
      const roomTypeRateCodeList = payload;
      return {
        ...state,
        roomTypeRateCodeList,
      };
    },
    setAllOYORoomTypeList(state, { payload }) {
      const allOYORoomTypeList = payload;
      return {
        ...state,
        allOYORoomTypeList,
      };
    },
    setAllSellRoomTypeList(state, { payload }) {
      const allSellRoomTypeList = payload;
      return {
        ...state,
        allSellRoomTypeList,
      };
    },
    setAllValidatedChannelList(state, { payload }) {
      const validatedChannelList = payload;
      return {
        ...state,
        validatedChannelList,
      };
    },
    setChannelCommissionList(state, { payload }) {
      const channelCommissionList = payload;
      const validatedChannelList = state.validatedChannelList;
      let newValidatedChannelList = [];
      for (let i = 0; i < validatedChannelList.length; i++) {
        let channelOpt = validatedChannelList[i];
        let channelId = channelOpt.channelId;
        let isExist = false;
        for (let j = 0; j < channelCommissionList.length; j++) {
          let commissionOpt = channelCommissionList[j];
          let selectChannelId = commissionOpt.channelId;
          if (channelId === selectChannelId) {
            isExist = true;
            break;
          }
        }
        if (!isExist) {
          channelOpt.disabled = false;
          newValidatedChannelList.push(channelOpt);
        } else {
          channelOpt.disabled = true;
          newValidatedChannelList.push(channelOpt);
        }
      }
      return {
        ...state,
        channelCommissionList,
        validatedChannelList: newValidatedChannelList,
      };
    },
    // 设置已经选择的价格策略
    setChoosenPriceStrategy(state, { payload }) {
      const { hasChoosenColumns } = state;
      const { type, data } = payload;
      const priceList =
        type === 'add'
          ? JSON.parse(JSON.stringify(state.originPriceList))
          : JSON.parse(JSON.stringify(state.priceList));
      // 把选择的价格策略展示在列表中
      if (type === 'add') {
        priceList.map(item => {
          if (hasChoosenColumns.indexOf(item.roomTypeId) >= 0) {
            // 提取已存在的id
            const idsArr = item.rateCodeList.map(rateItem => rateItem.rateCodeId);
            let newRateCodeList = JSON.parse(JSON.stringify(item.rateCodeList));
            // 比较现有的id是否存在，不存在就添加
            data.forEach(chooseItem => {
              if (idsArr.find(id => id === chooseItem.rateCodeId)) {
                // find()返回第一匹配的元素或者返回undefined
                console.log(chooseItem);
              } else {
                newRateCodeList.push(chooseItem);
              }
            });

            item.rateCodeList = newRateCodeList;
          }
          return item;
        });
      } else {
        priceList.map(item => {
          if (hasChoosenColumns.indexOf(item.roomTypeId) >= 0) {
            // 比较现有的id是否存在，不存在就添加
            data.forEach(chooseItem => {
              // 提取已存在的id
              const idsArr = item.rateCodeList.map(rateItem => rateItem.rateCodeId);
              const subItemIndex = idsArr.findIndex(
                id => id === chooseItem.rateCodeId && !chooseItem.isSupport
              );
              if (subItemIndex >= 0) {
                // 删除已经存在但是非数据库的项
                item.rateCodeList.splice(subItemIndex, 1);
              }
            });
            return item;
          }
          return item;
        });
      }
      return {
        ...state,
        priceList,
        hasChoosenPriceStrategy: type === 'add' ? data : [],
      };
    },
    // 设置选取的行
    setHasChoosenColumns(state, { payload }) {
      return {
        ...state,
        hasChoosenColumns: payload,
      };
    },
    // 设置渠道关房状态
    setHotelState(state, { payload }) {
      if (payload[0] && payload[0].isBtn) {
        return {
          ...state,
          channelStatusList: payload,
        };
      }
      return {
        ...state,
        channelStatusList: [
          {
            channelName: '全部直连渠道',
            channelId: 0,
            isBtn: true,
            isNeed: true,
            status: payload[0] && payload[0].status ? payload[0].status : '',
            endTime: payload[0] && payload[0].endTime ? payload[0].endTime : null,
          },
          ...payload,
        ],
      };
    },
  },
};
