import { authFetch as request, transAuthFetch } from '@/utils/fetch';

/**
 * 酒店房型价格策略列表
 * @param {Object} { hotelId }
 */
export function queryRoomTypeMatchPriceList(params) {
  // return request(`/api/crs/v1/roomType/roomTypeListWithRateCode`, {
  return transAuthFetch(`/hotel/roomTypeListWithRateCode`, {
    method: 'GET',
    type: 1,
    params,
  });
}

/**
 * 酒店价格策略下拉列表
 * @param {Object} { hotelId }
 */
export function queryRoomTypeRateCodeList(params) {
  return request(`/api/crs/v1/roomType/getRoomTypeRateCodeList`, {
    params,
  });
}

/**
 * 更新房型价格策略绑定关系
 * @param {Object} params
 */
export function updateRoomTypeBindRateCodes(params) {
  return request(`/api/crs/v1/roomType/roomTypeBindRateCodes`, {
    method: 'POST',
    params,
  });
}

/**
 * 获取所有有效渠道名称
 */
export function queryAllValidatedChannel() {
  return request(`/api/crs/v1/channel/getAllValidatedChannel`);
}

/**
 * 获取酒店所有渠道佣金信息
 * @param {Object} { hotelId }
 */
export function queryChannelHotelCommission(params) {
  return transAuthFetch(`/channel/hotelCommission`, {
    method: 'GET',
    type: 1,
    params,
  });
}

/**
 * 更新设置酒店渠道佣金
 * @param {Object} params
 */
export function updateChannelHotelCommission(params) {
  return transAuthFetch(`/channel/commitHotelCommission`, {
    method: 'POST',
    type: 1,
    params,
  });
}

/**
 * 批量新增房型价格策略
 * @param {Object} params
 */
export function multipleAddRoomPriceStrategy(params) {
  return request(`/roomType/batchRoomTypeBindRateCodes`, {
    method: 'POST',
    params,
  });
}

/**
 * 批量绑定房型价格策略接口
 * @param {Object} { hotelId }
 */
export function updatePriceStategy(params) {
  return transAuthFetch(`/roomType/batchRoomTypeBindRateCodes`, {
    method: 'POST',
    type: 1,
    params,
  });
}

/**
 * 获取渠道关房状态
 * @param {Object} { hotelId }
 */
export function getHotelState(params) {
  return transAuthFetch(`/hotel/manage/v1/getHotelRoomTypeStatus`, {
    method: 'GET',
    params,
    type: 1,
  });
}

/**
 * 更改渠道关房状态
 * @param {Object} { hotelId }
 */
export function setChannelState(params) {
  return transAuthFetch(`/hotel/manage/v1/updateHotelRoomTypeStatus`, {
    method: 'POST',
    params,
    type: 1,
  });
}

/**
 * 获取酒店渠道管理操作日志
 * @param {Object} { hotelId }
 */
export function getHotelOperateLog(params) {
  return transAuthFetch(`/hotel/manage/getHotelChannelUpdateLogs`, {
    params,
    type: 1,
  });
}

/**
 * 获取房型价格策略操作日志
 * @param {Object} { hotelId }
 */
export function getHouseOperateLog(params) {
  return request(`/api/crs/operate/log/rateCode`, {
    params,
  });
}

/**
 * 获取酒店基准价操作日志
 * @param {Object} { hotelId }
 */
export function getPriceOperateLog(params) {
  return request(`/api/crs/operate/log/markPrice`, {
    params,
  });
}
