import React, { PureComponent } from 'react';
import { connect } from 'dva';
import router from 'umi/router';
import { Tabs, Card, Button, Form, Input, Select, Row, Col, Badge, Table, message } from 'antd';
import { isArray } from 'util';
import PageHeaderWrapper from '@/components/PageHeaderWrapper';
import CitySelect from '@/components/CitySelect';
import ChangeStatusModal from '../components/ChangeStatusModal';
import LogModal from '@/components/OyoModal/OyoLogTableModal';
import styles from './index.less';
import { HOTEL_STATUS, getNameFromStatus } from '@/constant/hotelStatus';
import {
  HOTEL_TYPE_OPTION,
  getNameFromStatus as getNameFromStatusHotelType,
} from '@/constant/hotelType';
import ButtonAuthorized from '@/components/ButtonAuthorized';
import {
  rowProps,
  col1Props,
  col3Props,
  col4Props,
  formItemLayout,
  widthStyle,
} from '@/utils/formProps';

const Option = Select.Option;
const FormItem = Form.Item;
const data = [{}];

const createOption = function() {
  return HOTEL_STATUS.map((item, key) => (
    <Option value={item.status} key={`HOTEL_STATUS-${key}`}>
      {item.name}
    </Option>
  ));
};

// #endregion

const defaultQueryParam = {
  hotelId: null, // 酒店id
  hotelName: null, // 酒店名称
  status: undefined, // 酒店状态
  stateId: null, // 省
  cityId: null, // 市
  clusterId: null, // 区
  oyoId: null, // oyoId
  uniqueCode: null, // 唯一识别码
  type: undefined, // 酒店类型 直营1/加盟2/测试3
  cooperationType: undefined, // 酒店协议类型
};
@connect(({ hotelLists, loading }) => ({
  hotelLists,
  loading: loading.models.hotelLists,
}))
export default class HotelListIndex extends PureComponent {
  constructor(props) {
    super(props);
    // this.myModal = React.createRef();
    this.state = {
      data,
      loading: false,
      name: null,
      visible: false,
      activeHotelId: '',
      activeStatus: '',
      ...defaultQueryParam,
      force: true,
      fromTime: null,
      toTime: null,
      logHotelId: null,
      logVisible: false,
      logParams: {
        pageNum: 1,
        pageSize: 10,
      },
    };
    this.logModalColumns = [
      { title: '操作时间', dataIndex: 'createTime' },
      {
        title: '操作人',
        dataIndex: 'operator',
        render: (operator, record) => (
          <span>
            {operator}
            {record.operatorId || record.operatorId === 0 ? `(${record.operatorId})` : null}
          </span>
        ),
      },
      {
        title: '状态',
        dataIndex: 'status',
        render: (status, record) => {
          let results = '';
          const oldStatusColumn = record.oldStatus ? getNameFromStatus(record.oldStatus) : '';
          const isNeedArrow = record.oldStatus ? ' --> ' : '';
          const configTimes = record.startDate ? `(${record.startDate} ~ ${record.endDate})` : '';
          if (status === '6' || status === '7') {
            results = `${oldStatusColumn}${isNeedArrow}${getNameFromStatus(status)}${configTimes}`;
          } else {
            results = `${oldStatusColumn}${configTimes}${isNeedArrow}${getNameFromStatus(status)}`;
          }

          return results;
        },
      },
      {
        title: '变更原因',
        dataIndex: 'reason',
        render: (reason, record) => {
          return `${reason} ${
            record.onholdTructureReasonList && isArray(record.onholdTructureReasonList)
              ? `,${record.onholdTructureReasonList.join('>')}`
              : ''
          }`;
        },
      },
      // { title: 'IP', dataIndex: 'operatorIP' }, // 先注释不删原因同上
    ];
  }

  componentDidMount() {
    this.getList();
  }

  getList = ({ start = 0, hits = 10 } = {}) => {
    if (start * hits + hits > 5000) {
      message.error('超出5000条数据请输入条件查询。');
      return;
    }
    let { dispatch } = this.props;
    let {
      hotelId,
      hotelName,
      status,
      stateId,
      cityId,
      clusterId,
      oyoId,
      uniqueCode,
      type,
      cooperationType,
    } = this.state;
    dispatch({
      type: 'hotelLists/getList',
      payload: {
        start: start * hits,
        hits,
        hotelId: hotelId ? hotelId.trim() : null,
        hotelName: hotelName ? hotelName.trim() : null,
        status: status || null,
        stateId,
        cityId,
        clusterId,
        oyoId: oyoId ? oyoId.trim() : null,
        uniqueCode: uniqueCode ? uniqueCode.trim() : null,
        type: type || null,
        cooperationType: cooperationType || null,
      },
    });
  };

  // 请求：操作日志
  getLogList = params => {
    const { dispatch } = this.props;
    const { logHotelId } = this.state;
    dispatch({
      type: 'hotelLists/getLogList',
      payload: {
        ...params,
        hotelId: logHotelId,
      },
    })
      .then(res => {
        if (res.code === '000') {
          this.setState({ logVisible: true });
        }
      })
      .catch(err => {
        console.log(err);
      });
  };

  handleChange = (e, key) => {
    let res = typeof e === 'object' ? e.target.value : e;
    this.setState({
      [key]: res,
    });
  };

  toDetail = hotelId => {
    router.push({
      pathname: '/hotel/hotelCreateEdit/index',
      query: { hotelId },
    });
  };

  showModal = (id, status, fromTime, toTime) => {
    this.setState({
      visible: true,
      activeHotelId: id,
      activeStatus: status,
      fromTime,
      toTime,
    });
  };

  changeModal = bl => {
    this.setState({
      visible: bl,
    });
  };

  // 查看操作日志
  showLogModal = logHotelId => {
    const { pageNum, pageSize } = this.state.logParams;
    this.setState(
      {
        logHotelId,
      },
      () => {
        this.getLogList(pageNum, pageSize);
      }
    );
  };

  toCreate = () => {
    router.push({
      pathname: '/hotel/create',
    });
  };

  query = () => {
    this.getList();
  };

  handlePageChange = ({ current, pageSize }) => {
    this.getList({
      start: current - 1,
      hits: pageSize,
    });
  };

  changeStatus = ({ status, hotelId }) => {
    message.info(`更新状态为${getNameFromStatus(status)}成功`);
    setTimeout(() => {
      this.query();
    }, 1500);
    // debugger
  };

  cityChange = value => {
    this.setState({
      stateId: value[0] ? value[0] : null,
      cityId: value[1] ? value[1] : null,
      clusterId: value[2] ? value[2] : null,
    });
  };

  toBatchUpload = () => {
    router.push({
      pathname: '/hotel/batchUpload',
    });
  };

  reset = () => {
    this.setState(
      {
        ...defaultQueryParam,
        force: false,
      },
      () => {
        this.query();
        this.setState({
          force: true,
        });
      }
    );
  };

  render() {
    let { handleChange, changeModal, toCreate, query, changeStatus, reset, toBatchUpload } = this;
    let {
      visible,
      hotelId,
      hotelName,
      status,
      activeHotelId,
      activeStatus,
      oyoId,
      uniqueCode,
      type,
      cooperationType,
      force,
      fromTime,
      toTime,
      logVisible,
    } = this.state;
    const { list, pagination, logListData } = this.props.hotelLists;
    let { loading } = this.props;
    const columns = [
      {
        title: '酒店ID',
        dataIndex: 'hotelId',
        key: 'hotelId',
      },
      {
        title: '酒店名称',
        dataIndex: 'hotelName',
        key: 'hotelName',
        width: 250,
      },
      {
        title: 'OYO ID',
        dataIndex: 'oyoId',
        key: 'oyoId',
      },
      {
        title: '唯一识别码',
        dataIndex: 'uniqueCode',
        key: 'uniqueCode',
      },
      {
        // title: '省市区',
        title: '市',

        dataIndex: 'state',
        key: 'state',
        render: (xx, item) => {
          let { state, city, cname } = item;
          return `${cname}`;
        },
        width: 50,
      },
      {
        title: '地址',
        dataIndex: 'street',
        key: 'street',
        width: 250,
      },
      {
        title: '合作模式',
        dataIndex: 'type',
        key: 'type',
        render: hotelType => getNameFromStatusHotelType(hotelType),
      },
      {
        title: '状态',
        dataIndex: 'status',
        key: 'status',
        render: (sta, item) => {
          let str = '';
          if (!item.hotelConfigStatus) {
            str = getNameFromStatus(sta);
            return <span title={str}>{str}</span>;
          }
          str = (
            <>
              {getNameFromStatus(sta)}
              <br />
              {`(配置状态：${getNameFromStatus(item.hotelConfigStatus)}`}
              <br />
              {`起：${item.hotelStatusConfigFromtime}；止：${item.hotelStatusConfigTotime})`}
            </>
          );
          let title =
            `(配置状态：${getNameFromStatus(item.hotelConfigStatus)}` +
            `。 起：${item.hotelStatusConfigFromtime}；止：${item.hotelStatusConfigTotime})`;
          return (
            <span title={title} style={{ display: 'inline-block', maxWidth: 200 }}>
              {str}
            </span>
          );
        },
      },

      {
        title: '操作',
        dataIndex: 'xx',
        key: 'xx',
        render: (xx, item) => (
          <>
            <ButtonAuthorized
              style={{ margin: '0 10px 10px 0' }}
              code="CRS7.1.2"
              onClick={() => this.toDetail(item.hotelId)}
              size="small"
            >
              查看
            </ButtonAuthorized>

            <ButtonAuthorized
              size="small"
              style={{ margin: '0 10px 10px 0' }}
              code="CRS7.1.1"
              onClick={() =>
                this.showModal(
                  item.hotelId,
                  item.status,
                  item.hotelStatusConfigFromtime,
                  item.hotelStatusConfigTotime
                )
              }
            >
              更新状态
            </ButtonAuthorized>
            <ButtonAuthorized
              size="small"
              style={{ margin: '0 10px 10px 0' }}
              code="CRS7.1.5"
              onClick={() => this.showLogModal(item.hotelId)}
            >
              操作日志
            </ButtonAuthorized>
          </>
        ),
      },
    ];

    return (
      <PageHeaderWrapper>
        <Card className={styles.main}>
          <Form layout="inline" className={styles.tableList}>
            <Row {...rowProps}>
              <Col {...col4Props}>
                <FormItem style={widthStyle} label="酒店ID" {...formItemLayout}>
                  <Input
                    type="number"
                    placeholder="请输入酒店ID"
                    value={hotelId}
                    onChange={e => handleChange(e, 'hotelId')}
                  />
                </FormItem>
              </Col>
              <Col {...col4Props}>
                <FormItem style={widthStyle} label="酒店名称" {...formItemLayout}>
                  <Input
                    placeholder="请输入酒店名称"
                    value={hotelName}
                    onChange={e => handleChange(e, 'hotelName')}
                  />
                </FormItem>
              </Col>
              <Col {...col4Props}>
                <FormItem style={widthStyle} label="酒店状态" {...formItemLayout}>
                  <Select
                    value={status}
                    style={{ width: '100%' }}
                    placeholder="请选择酒店状态"
                    onChange={e => handleChange(e, 'status')}
                  >
                    {createOption()}
                  </Select>
                </FormItem>
              </Col>
              <Col {...col4Props}>
                <FormItem style={widthStyle} label="酒店类型" {...formItemLayout}>
                  <Select
                    value={type}
                    style={{ width: '100%' }}
                    placeholder="请选择酒店类型"
                    onChange={e => handleChange(e, 'type')}
                  >
                    {HOTEL_TYPE_OPTION}
                  </Select>
                </FormItem>
              </Col>
            </Row>

            <Row {...rowProps}>
              <Col {...col4Props}>
                <FormItem style={widthStyle} label="区域" {...formItemLayout}>
                  {force ? (
                    <CitySelect
                      style={{ width: '100%' }}
                      type="cityList"
                      onChange={this.cityChange}
                      changeOnSelect
                      ref={re => {
                        this.citySelect = re;
                      }}
                    />
                  ) : null}
                </FormItem>
              </Col>
              <Col {...col4Props}>
                <FormItem style={widthStyle} label="OYOID" {...formItemLayout}>
                  <Input
                    placeholder="请输入OYOID"
                    value={oyoId}
                    onChange={e => handleChange(e, 'oyoId')}
                  />
                </FormItem>
              </Col>
              <Col {...col4Props}>
                <FormItem style={widthStyle} label="唯一识别码" {...formItemLayout}>
                  <Input
                    placeholder="请输入唯一识别码"
                    value={uniqueCode}
                    onChange={e => handleChange(e, 'uniqueCode')}
                  />
                </FormItem>
              </Col>
              <Col {...col4Props}>
                <FormItem style={widthStyle} label="酒店协议类型" {...formItemLayout}>
                  <Select
                    value={cooperationType}
                    placeholder="请选择酒店协议类型"
                    onChange={e => handleChange(e, 'cooperationType')}
                  >
                    <Option value="SOUTH_DIST_PILOT">china2.0</Option>
                  </Select>
                </FormItem>
              </Col>
            </Row>
          </Form>

          <Row {...rowProps} style={{ textAlign: 'center' }}>
            <Col {...col1Props}>
              <Button type="primary" onClick={query}>
                查询
              </Button>

              <Button onClick={reset} style={{ marginLeft: 20 }}>
                重置
              </Button>
            </Col>
          </Row>
        </Card>

        <Card style={{ marginTop: 15 }}>
          <ButtonAuthorized onClick={toBatchUpload} type="primary" code="CRS7.1.3">
            批量上传更新
          </ButtonAuthorized>
          <Table
            rowKey="hotelId"
            bordered
            size="small"
            style={{ marginTop: 20 }}
            loading={loading}
            dataSource={list}
            columns={columns}
            pagination={pagination}
            onChange={this.handlePageChange}
            onShowSizeChange={this.handlePageChange}
          />
        </Card>

        <ChangeStatusModal
          ref={ta => {
            this.myModal = ta;
          }}
          visible={visible}
          hotelId={activeHotelId}
          status={activeStatus}
          changeStatus={changeStatus}
          callback={bl => changeModal(bl)}
          fromTime={fromTime}
          toTime={toTime}
        />
        <LogModal
          title="操作日志"
          rowKey="key"
          visible={logVisible}
          columns={this.logModalColumns}
          dataSource={logListData.logList}
          pagination={logListData.pagination}
          getLogList={this.getLogList}
          onCancel={e => {
            this.setState({ logVisible: false });
          }}
        />
      </PageHeaderWrapper>
    );
  }
}
