import OYOTable from '@/components/OyoTable/OyoTable.tsx';
import LogModal from '@/components/OyoModal/OyoLogTableModal';
import { connect } from 'dva';
import moment from 'moment';
import React, { PureComponent } from 'react';
import { queryResultsList, getLogList, roomTypeChangeDo } from '../services/index';
import { STATUS_TYPE, LOGMODEL } from './statusType.jsx';
import ButtonAuthorized from '@/components/ButtonAuthorized';
import { transDownloadFile } from '@/utils/downloadFile';
import { message } from 'antd';
import getUUID from '@/utils/uuid';

@connect(({ associate, user, loading }) => ({
  associate,
  user,
  loading: loading.models.associate,
}))
export default class batchResults extends PureComponent<any, any> {
  public oyotable = null;
  constructor(props) {
    super(props);
    this.state = {
      tableParams: {},
      pageParams: ['pageNo', 'pageSize'],
      detailVisible: false,
      modelType: '',
      paramsType: '',
      batchNumber: '',
      pagination: {
        pageNum: 1,
        pageSize: 10,
        total: 20,
      },
      logList: [],
      isShowRoomNo: false,
    };
  }

  public componentDidMount() {
    // 默认请求：初始结果列表
    this.oyotable.getPageList();
  }

  // 请求：获取结果列表数据
  public getResultsList = params =>
    queryResultsList(params)
      .then(res => {
        if (res && res.data) {
          const { result, totalCount } = res.data;
          if (Array.isArray(result)) {
            result.forEach((item, key) => {
              item.key = key;
              item.No = key + 1;
            });
          }

          return { data: result || [], total: totalCount };
        }
      })
      .catch(err => {
        console.log(err);
      });

  // 操作：下载错误表格
  public downloadErrorFile = (batchNo, fileName) => {
    transDownloadFile('/hotel/manage/document/download', { batchNo }, fileName);
  };

  //展示执行中信息模态框
  showModal = record => {
    let columnsType = '';

    if (record.type === 'ROOM_TYPE_CHANGE' && record.apolloReSign) {
      columnsType = 'ROOM_TYPE_CHANGE_NEW';
    }

    this.setState(
      {
        detailVisible: true,
        modelType: columnsType ? columnsType : record.type,
        paramsType: record.type,
        batchNumber: record.batchNo,
      },
      () => this.getDetailList()
    );
  };

  // 获取执行中的详细信息
  getDetailList = (pagination, type) => {
    getLogList({
      type: this.state.paramsType,
      batchNo: this.state.batchNumber,
      pageNo: pagination ? pagination.pageNum : 1,
      pageSize: pagination ? pagination.pageSize : 10,
    })
      .then(res => {
        if (res.data) {
          const { result, totalCount, pageSize, pageNo } = res.data;
          if (Array.isArray(result)) {
            result.forEach((item, key) => {
              item.key = getUUID();
              item.No = key + 1;
            });

            this.setState({
              logList: res.data.result,
              pagination: {
                pageNum: pageNo,
                pageSize,
                total: totalCount,
              },
            });
          }
        }
      })
      .catch(er => {
        console.log(er);
      });
  };

  batchDo = batchNo => {
    roomTypeChangeDo({ batchNo })
      .then(res => {
        if (res.code === '000') {
          message.success('立即执行成功！');
        }
      })
      .catch(err => {
        console.log(err);
      });
  };

  render() {
    const { tableParams, pageParams, detailVisible, logList, pagination, modelType } = this.state;
    const { getResultsList, getDetailList } = this;
    const { loading } = this.props;

    const preventGetList = true;
    const OYOTableColumns: object[] = [
      {
        title: '批次号',
        dataIndex: 'batchNo',
        key: 'batchNo',
        width: '12%',
      },
      {
        title: '操作时间',
        dataIndex: 'createTime',
        key: 'createTime',
        width: '10%',
        render(createTime) {
          if (createTime) {
            return moment(createTime).format('YYYY-MM-DD HH:mm:ss');
          }
        },
      },
      {
        title: '操作类别',
        dataIndex: 'typeDesc',
        key: 'typeDesc',
        width: '8%',
      },
      {
        title: '操作人',
        dataIndex: 'operatorName',
        key: 'operatorName',
        width: '8%',
      },
      {
        title: '文件',
        dataIndex: 'fileName',
        key: 'fileName',
        width: '10%',
      },
      {
        title: '执行结果显示',
        dataIndex: 'status',
        key: 'status',
        width: '10%',
        render: (status, record) => {
          let { color, name } = STATUS_TYPE[status];
          return (
            <p
              style={{
                margin: 'auto 0',
                color: `${color}`,
                cursor: 'pointer',
                textDecoration: 'underline',
              }}
              onClick={() => {
                this.showModal(record);
              }}
            >
              {`${name}`}
            </p>
          );
        },
      },
      {
        title: '失败条目下载',
        dataIndex: 'downloadFileName',
        key: 'downloadFileName',
        width: '10%',
        render: (downloadFileName, record) => {
          if (downloadFileName) {
            return (
              <p
                onClick={() => this.downloadErrorFile(record.batchNo, downloadFileName)}
                style={{ margin: 'auto 0', color: '#F5222D', cursor: 'pointer' }}
              >{`${downloadFileName}`}</p>
            );
          }
        },
      },
      {
        title: '操作',
        dataIndex: 'type',
        key: 'type',
        width: '8%',
        render: (type, record) => {
          if (type === 'ROOM_TYPE_CHANGE') {
            return (
              <ButtonAuthorized
                code="CRS7.9.1.1"
                onClick={() => this.batchDo(record.batchNo)}
                style={{ margin: 'auto 0', cursor: 'pointer' }}
              >
                立即执行
              </ButtonAuthorized>
            );
          }
        },
      },
    ];

    return (
      <>
        <OYOTable
          ref={re => {
            this.oyotable = re;
          }}
          bordered={true}
          size="small"
          loading={loading}
          params={tableParams}
          pageParams={pageParams}
          columns={OYOTableColumns}
          getList={getResultsList}
          preventGetList={preventGetList}
        />

        <LogModal
          title="详细信息"
          rowKey="key"
          visible={detailVisible}
          columns={LOGMODEL[modelType]}
          dataSource={logList}
          pagination={pagination}
          getLogList={getDetailList}
          onCancel={e => {
            this.setState({ detailVisible: false });
          }}
        />
      </>
    );
  }
}
