import { uploadAssociateFile } from '../services';

export function getDefaultConfig({ comments, downloadUrl, type }, context) {
  return {
    xlsx: '.xlsx',
    isNeedTag: true,
    stepList: [
      {
        buttonTitle: '下载模版',
        comments: '',
      },
      {
        comments,
      },
      {
        buttonTitle: '上传文件',
        comments: ' 因处理数据较多，请等待5分钟后，在“批量执行结果”页面查看执行结果！',
      },
    ],
    uploadFile: function(param) {
      const { user } = this.props;
      const { formData } = param;
      const params = {
        operateId: user.accountId,
        operatorName: user.name,
        type,
      };

      return uploadAssociateFile({ formData, params }).then(res => {
        return {
          success: true,
          dom: this.renderRes(res),
        };
      });
    }.bind(context),

    downloadUrl,
  };
}

export function getRoomStateChangeProps(context) {
  return getDefaultConfig(
    {
      comments: `  <p>填写模板：</p>
  <p>首行为标题，请勿覆盖。：</p>

  <p>CRS_ID（CN代码，例：CN_SHN018）<span style="color: #F5222D;">必填</span></p>
  <p>原房间号。不可填写中文及特殊符号。（例：OBS_0001）<span style="color: #F5222D;">必填</span></p>
  <p>房型。填写对应代码。（例：48）<span style="color: #F5222D;">必填</span></p>
  <p>原房间状态。必须填写不可售黑房、可售黑房、可改造黑房、绿房 的状态代码。（例：4）<span style="color: #F5222D;">必填</span></p>
  <p>更改后房间状态。必须填写不可售黑房、可售黑房、可改造黑房、绿房 的状态代码。（例：4）<span style="color: #F5222D;">必填</span></p>

  <p>*单次不超过500家酒店`,

      downloadUrl: './roomStateChange-template.xlsx',
      type: 'ROOM_STATE_CHANGE',
    },
    context
  );
}

export function getRoomFloorChangeProps(context) {
  return getDefaultConfig(
    {
      comments: `  <p>填写模板：</p>
  <p>首行为标题，请勿覆盖。</p>

  <p>CRS_ID（CN代码，例：CN_SHN018）<span style="color: #F5222D;">必填</span></p>
  <p>原房间号。不可填写中文及特殊符号。（例：OBS_0001）<span style="color: #F5222D;">必填</span></p>
  <p>原楼层。如果原数据为空，则保持为空。不可填写中文及特殊符号。（例：13A）<span style="color: #F5222D;">如果原来没有楼层，置空</span></p>
  <p>更改后楼层。不可为空，不可填写中文及特殊符号。（例：13A）<span style="color: #F5222D;">必填</span> </p>

  <p>*单次不超过500家酒店`,

      downloadUrl: './roomFloorChange-template.xlsx',
      type: 'ROOM_FLOOR_CHANGE',
    },
    context
  );
}

export function getRoomNumChangeProps(context) {
  return getDefaultConfig(
    {
      comments: `  <p>填写模板：</p>
  <p>首行为标题，请勿覆盖。</p>

  <p>CRS_ID（CN代码，例：CN_SHN018）<span style="color: #F5222D;">必填</span></p>
  <p>房间号。不可填写中文及特殊符号。（例：308A）<span style="color: #F5222D;">必填</span></p>
  <p>房型。填写对应代码。（例：48）<span style="color: #F5222D;">必填</span></p>
  <p>更改后房间号。不可为空，不可填写中文及特殊符号。（例：399A）<span style="color: #F5222D;">必填</span></p>

  <p>*单次不超过500家酒店`,

      downloadUrl: './roomNumChange-template.xlsx',
      type: 'ROOM_NO_CHANGE',
    },
    context
  );
}

export function getRoomTotalChangeProps(context) {
  return getDefaultConfig(
    {
      comments: `  <p>填写模板：</p>
  <p>首行为标题，请勿覆盖。</p>

  <p>CRS_ID（CN代码，例：CN_SHN018）<span style="color: #F5222D;">必填</span></p>
  <p>增加/减少房间。必须填写"增加"或"减少"。（例：增加）<span style="color: #F5222D;">必填</span></p>
  <p>房间号。不可为空，不可填写中文及特殊符号。（例：399A）<span style="color: #F5222D;">必填</span></p>
  <p>楼层。增加酒店不可为空，不可填写中文及特殊符号。（例：16）</p>
  <p>房型。增加酒店不可为空，填写对应代码。（例：48）</p>
  <p>房态。增加酒店不可为空，填写对应代码。（例：48）</p>
  *单次不超过500家酒店`,

      downloadUrl: './roomTotalChange-template.xlsx',
      type: 'ROOM_ADD_OR_DELETE',
    },
    context
  );
}

export function getRoomTypeChangeProps(context) {
  return getDefaultConfig(
    {
      comments: `  <p>填写模板：</p>
  <p>首行为标题，请勿覆盖。</p>

  <p>CRS_ID（CN代码，例：CN_SHN018）<span style="color: #F5222D;">必填</span></p>
  <p>原房型。填写对应代码。（例：DK）<span style="color: #F5222D;">必填</span></p>
  <p>目标房型。填写对应代码。（例：DK）<span style="color: #F5222D;">必填</span></p>

  `,

      downloadUrl: './roomTypeChange-template.xlsx',
      type: 'ROOM_TYPE_CHANGE',
    },
    context
  );
}
