import React, { PureComponent } from 'react';
import { Input, Button, Popconfirm, Modal, message } from 'antd';
import OyoForm from '@/components/OyoForm/SearchForm';
import OyoTable from '@/components/OyoTable/OyoTable';
// eslint-disable-next-line import/no-unresolved
import { pageList, editWifi, deleteWifi } from '../services/index';
import ButtonAuthorized from '@/components/ButtonAuthorized';
import { downloadUrl } from '@/utils/downloadFile';
// import QRCode from 'qrcode';

export default class WifiTable extends PureComponent {
  constructor(props) {
    super(props);

    this.state = {
      loading: false,
      isShowEditModel: false,
      imgSrc: '',
      pageParams: ['page', 'limit'],
      editParams: {
        SSID: '',
        WiFi: '',
      },
      searchParams: {},
      dataSource: [],
      editLoading: false,
      isShowImgModel: false,
      qrCodeImageUrl: '',
    };

    this.OYOSearchFormConfig = [
      {
        type: 'OYOID',
        label: 'OYO ID',
        component: <Input placeholder="请输入OYO ID" />,
      },
      {
        type: 'hotelName',
        label: '酒店名称',
        component: <Input placeholder="请输入酒店名称" />,
      },
      {
        type: 'WIFIID',
        label: 'WIFI ID',
        component: <Input placeholder="请输入WIFI ID" />,
      },
    ];

    this.OYOEditFormConfig = [
      {
        type: 'ssid',
        label: 'SSID',
        options: {
          rules: [{ message: '请填写SSID' }],
        },
        component: (
          <Input placeholder="请输入SSID" onChange={e => this.handlerEditParams('ssid', e)} />
        ),
      },
      {
        type: 'password',
        label: 'WiFi 密码',
        options: {
          rules: [{ message: '请填写WiFi 密码' }],
        },
        component: (
          <Input
            placeholder="请填写WiFi 密码"
            onChange={e => this.handlerEditParams('password', e)}
          />
        ),
      },
      {
        type: 'remark',
        label: '备注',
        options: {
          rules: [{ required: true, message: '请填写备注' }],
        },
        component: (
          <Input placeholder="请输入备注" onChange={e => this.handlerEditParams('remark', e)} />
        ),
      },
    ];

    this.columns = [
      {
        title: '酒店OYO ID',
        dataIndex: 'oyoId',
        width: '8%',
      },
      {
        title: '酒店名',
        dataIndex: 'hotelName',
        width: '8%',
      },
      {
        title: 'WiFi ID',
        dataIndex: 'wifiId',
        width: '15%',
      },
      {
        title: 'WiFi 热点名称（SSID）',
        dataIndex: 'ssid',
        width: '10%',
      },
      {
        title: 'WiFi密码',
        dataIndex: 'password',
        width: '12%',
      },
      {
        title: '备注',
        dataIndex: 'remark',
        width: '12%',
      },
      {
        title: '二维码',
        dataIndex: 'code',
        width: '10%',
        render: (contral, record) => {
          return (
            <>
              <Button
                style={{ marginRight: 10 }}
                onClick={() => {
                  this.showImgModel(record);
                }}
                size="small"
              >
                查看
              </Button>
              <Button
                size="small"
                onClick={() => {
                  this.downloadImg(record);
                }}
              >
                下载
              </Button>
            </>
          );
        },
      },
      {
        title: '操作',
        dataIndex: 'contral',
        width: '10%',
        render: (contral, record) => {
          return (
            <>
              <ButtonAuthorized
                code="CRS7.12.1"
                style={{ marginRight: 10 }}
                onClick={() => {
                  this.showEditModel(record);
                }}
                size="small"
              >
                编辑
              </ButtonAuthorized>
              <Popconfirm
                placement="topRight"
                title="是否删除该WiFi 热点？"
                onConfirm={() => {
                  this.delete(record);
                }}
                okText="确认删除"
                cancelText="取消"
              >
                <ButtonAuthorized code="CRS7.12.2" size="small">
                  删除
                </ButtonAuthorized>
              </Popconfirm>
            </>
          );
        },
      },
    ];
  }

  componentDidMount() {
    this.oyotable.getPageList();
  }

  requestWifiData() {}

  handlerEditParams = (key, e) => {
    this.setState({
      editParams: {
        ...this.state.editParams,
        [key]: e.target.value,
      },
    });
  };

  delete = async record => {
    try {
      const res = await deleteWifi({
        hotelWifiId: record.id,
      });

      if (res.code === '000') {
        message.success('删除成功');

        setTimeout(() => {
          this.oyotable.getPageList();
        }, 500);
      }
    } catch (e) {
      console.log(e);
    }
  };

  query = params => {
    this.setState(
      {
        searchParams: params,
      },
      this.oyotable.getPageList
    );
  };

  showEditModel = record => {
    this.setState(
      {
        isShowEditModel: true,
        editData: {
          hotelWifiId: record.id,
        },
      },
      () => {
        setTimeout(() => {
          this.oyoEditForm.setFieldsValue({
            ssid: record.ssid,
            password: record.password,
            remark: record.remark,
          });
        }, 200);
      }
    );
  };

  hidenShowEditModel = () => {
    this.setState({
      editParams: {
        SSID: '',
        WiFi: '',
      },
      isShowEditModel: false,
    });

    this.oyoEditForm.resetFields();
  };

  getList = async params => {
    try {
      const res = await pageList({
        ...this.state.searchParams,
        ...params,
      });

      if (res.data) {
        const { totalSize, dataList } = res.data;

        return { data: dataList || [], total: totalSize };
      }
    } catch (e) {
      console.log(e);
    }
  };

  requestEditWifi = () => {
    this.oyoEditForm.validateFields(async (err, values) => {
      if (err) return;

      this.setState({
        editLoading: true,
      });

      const { ssid, password, remark } = values;

      try {
        const res = await editWifi({
          hotelWifiId: this.state.editData.hotelWifiId,
          ssid,
          password,
          remark,
        });

        if (res.code === '000') {
          message.success('修改成功');

          this.setState({
            isShowEditModel: false,
            editLoading: false,
          });

          setTimeout(() => {
            this.oyotable.getPageList();
          }, 500);
        }
      } catch (e) {
        this.setState({
          isShowEditModel: false,
          editLoading: false,
        });
        console.log(e);
      }

      console.log(err, values);
    });
  };

  showImgModel = ({ qrCodeImageUrl }) => {
    if (!qrCodeImageUrl) return message.warn('图片生成中，请稍后刷新重试');

    this.setState({
      qrCodeImageUrl,
      isShowImgModel: true,
    });
  };

  downloadImg = record => {
    if (!record.qrCodeImageUrl) return message.warn('图片生成中，请稍后刷新重试');

    downloadUrl(record.qrCodeImageUrl, record.ssid);
  };

  hidenImgModel = () => {
    this.setState({
      isShowImgModel: false,
    });
  };

  render() {
    const {
      loading,
      pageParams,
      dataSource,
      isShowEditModel,
      imgSrc,
      editLoading,
      qrCodeImageUrl,
      isShowImgModel,
    } = this.state;

    return (
      <div>
        <img src={imgSrc} width="200" />
        <OyoForm
          fields={this.OYOSearchFormConfig}
          onSearch={this.query}
          onReset={this.reset}
          column={4}
        />
        <OyoTable
          rowKey="id"
          ref={ref => {
            this.oyotable = ref;
          }}
          bordered
          size="small"
          style={{ marginTop: 20 }}
          loading={loading}
          columns={this.columns}
          getList={this.getList}
          params={dataSource}
          pageParams={pageParams}
          preventGetList
        />
        <Modal
          title="查看"
          visible={this.state.isShowImgModel}
          onCancel={this.hidenImgModel}
          footer={[
            <Button key="close" onClick={this.hidenImgModel}>
              关闭
            </Button>,
          ]}
        >
          <img src={qrCodeImageUrl} width="470" />
        </Modal>
        <Modal
          title="修改wifi"
          visible={this.state.isShowEditModel}
          onOk={this.requestEditWifi}
          onCancel={this.hidenShowEditModel}
          confirmLoading={editLoading}
        >
          <OyoForm
            ref={ref => {
              this.oyoEditForm = ref;
            }}
            fields={this.OYOEditFormConfig}
            column={1}
            noSubmit
          />
        </Modal>
      </div>
    );
  }
}
