import React, { PureComponent } from 'react';
import { Card, Input, Button, Table, message } from 'antd';
import router from 'umi/router';
import { connect } from 'dva';
import moment from 'moment';
import { accMul } from '@/utils/cal';
import PageHeaderWrapper from '@/components/PageHeaderWrapper';
import SearchPart from './components/SearchPart';
import titleTool from '@/utils/titleTool';

@connect(({ nearby }) => ({ nearby }))
export default class Nearby extends PureComponent {
  columns = [
    {
      title: titleTool.center('结果序号'),
      width: 100,
      key: 'order',
      render: (text, record, index) => {
        return index + 1;
      },
    },
    {
      title: '酒店名称',
      dataIndex: 'hotelName',
    },
    {
      title: titleTool.center('市'),
      dataIndex: 'city',
      render: text => titleTool.center(text),
    },
    {
      title: '地址',
      dataIndex: 'street',
    },
    {
      title: titleTool.center('距离搜索点'),
      dataIndex: 'distance',
      width: 150,
      render: text => {
        let num = Number.parseFloat(text);
        if (Number.isNaN(num)) return '';
        if (num === 0) return titleTool.center(`${num}m`);

        let dis = 0;

        if (num > 1) {
          dis = `${num.toFixed(1)}km`;
        } else {
          dis = `${accMul(accMul(num, 10).toFixed(), 100)}m`;

          if (dis === '1000m') dis = '1km';
        }

        // 大于1公里，四舍五入保留1位，小于1公里，精确到1米（即保留3位小数），保留后小数部分，再去除前导的0
        return titleTool.center(dis);
      },
    },
    {
      title: titleTool.center('操作'),
      dataIndex: 'hotelId',
      width: 150,
      render: hotelId =>
        titleTool.center(<Button onClick={() => this.goView(hotelId)}>查看</Button>),
    },
  ];

  componentDidMount() {
    const { nearbyHotels, current } = this.props.nearby;

    nearbyHotels.length > 0 && current > 1 && this.table.handlePageChange(current);
    this.props.dispatch({ type: 'nearby/setCurrent', payload: { current: 1 } });
  }

  goView = hotelId => {
    const {
      state: {
        pagination: { current = 1 },
      },
    } = this.table;
    this.props.dispatch({ type: 'nearby/setCurrent', payload: { current } });

    const date = moment();
    // 凌晨6点前，查询前一天的，临界值为 05:99
    date.get('hours') < 6 && date.subtract(1, 'days');

    router.push({
      pathname: '/hotel/hotelCreateEdit/index',
      query: {
        hotelId,
        hotelTab: '3',
        componentTab: '2',
        defaultDate: date.format('YYYY-MM-DD'),
      },
    });
  };

  onSearch = position => {
    console.log(position);
    this.props
      .dispatch({
        type: 'nearby/fetchNearbyHotels',
        payload: position,
      })
      .then(() => {
        if (this.props.nearby.nearbyHotels.length === 0)
          message.info('5km内无任何可推荐的酒店，请检查或更换搜索条件');
      });
  };

  render() {
    const { nearbyHotels } = this.props.nearby;

    return (
      <PageHeaderWrapper>
        <Card>
          <SearchPart onSearch={this.onSearch} />
        </Card>
        <br />
        <Card>
          <Table
            style={{
              marginTop: 48,
            }}
            ref={ref => {
              this.table = ref;
            }}
            columns={this.columns}
            dataSource={nearbyHotels}
            rowKey="hotelId"
            bordered
          />
        </Card>
      </PageHeaderWrapper>
    );
  }
}
