import { fetchNearbyHotels, searchHotel } from '../services';

export default {
  namespace: 'nearby',

  state: {
    nearbyHotels: [],
    hotelList: [],
    current: 1, // 保存当前是第几页，查看日历后返回跳回
  },

  effects: {
    *searchHotel({ payload }, { call, put, select }) {
      try {
        const response = yield call(searchHotel, payload);
        console.log(response);
        const {
          data: { hotels = [], count = 0 },
        } = response;

        yield put({
          type: 'setHotelList',
          payload: {
            hotelList: hotels,
          },
        });
        return response;
      } catch (e) {
        console.log(e);
      }
    },
    *fetchNearbyHotels({ payload }, { call, put, select }) {
      try {
        const { latitude, longitude } = yield select(state => state.nearby);

        const response = yield call(fetchNearbyHotels, {
          distance: 5, // 5km内
          start: 0,
          hits: 100,
          status: 3,
          physicalInventory: true,
          sort: 'DISTANCE_ASC',
          ...payload,
        });

        const {
          data: { hotels = [], count = 0 },
        } = response;

        yield put({
          type: 'setNearbyHotels',
          payload: {
            nearbyHotels: hotels,
          },
        });
        yield put({
          type: 'setPagination',
          payload: {
            total: count,
          },
        });
        return response;
      } catch (e) {
        console.log(e);
      }
    },
  },

  reducers: {
    setHotelList(state, { payload }) {
      let { hotelList = [] } = payload;
      hotelList = hotelList.map(({ hotelName, street, latitude, longitude }) => {
        return {
          text: `${hotelName}(${street})`,
          value: JSON.stringify([latitude, longitude]),
        };
      });

      return { ...state, hotelList };
    },
    setNearbyHotels(state, { payload }) {
      return {
        ...state,
        nearbyHotels: payload.nearbyHotels,
      };
    },
    setCurrent(state, { payload }) {
      return {
        ...state,
        current: payload.current,
      };
    },
  },
};
