import React, { PureComponent } from 'react';
import {
  Tabs,
  Card,
  Row,
  Col,
  Button,
  Modal,
  Radio,
  Input,
  DatePicker,
  message,
  Cascader,
  Select,
} from 'antd';
import moment from 'moment';
import { connect } from 'dva';
import { isArray } from 'util';
import _ from 'lodash';
import { changeHotelStatus, getReasontructure } from './service';
import { HOTEL_STATUS, getNameFromStatus } from '@/constant/hotelStatus';

const { TextArea } = Input;
const RadioGroup = Radio.Group;
const RadioButton = Radio.Button;
const { MonthPicker, RangePicker } = DatePicker;
const { Option } = Select;
const radioStyle = {
  display: 'block',
  height: '30px',
  lineHeight: '30px',
};

const dateFormat = 'YYYY/MM/DD';
const monthFormat = 'YYYY/MM';
const formatString = 'YYYY-MM-DD';

const createOption = function() {
  return HOTEL_STATUS.map((item, index) => (
    <Radio style={radioStyle} value={item.status} key={index}>
      {item.name}
    </Radio>
  ));
};

// 编辑以及取消编辑的按钮组件 会接入权限
@connect(({ user }) => ({
  user,
}))
export default class ChangeStatusModal extends PureComponent {
  constructor(props) {
    super(props);
    this.state = {
      status: '',
      hotelId: '',
      oldStatus: '',
      startValue: null,
      endValue: null,
      content: null,
      confirmLoading: false,
      reasontructure: [],
      reasontructureLast: [],
      firstReason: undefined,
      lastReason: undefined,
    };
  }

  componentWillReceiveProps(nextProps) {
    let { status, hotelId, fromTime, toTime } = nextProps;
    status += '';
    let from = (status === '6' || status === '7') && fromTime ? moment(fromTime) : null;
    let to = (status === '6' || status === '7') && toTime ? moment(toTime) : null;
    this.setState({
      status,
      hotelId,
      oldStatus: status,
      startValue: from,
      endValue: to,
      oldStartValue: from,
      oldEndValue: to,
    });
  }

  componentDidMount() {
    let Reasontructure = [];
    getReasontructure()
      .then(r => {
        r.data.forEach(item => {
          if (item.hotelReasontructureVOList instanceof Array) {
            item.hotelReasontructureVOList.forEach(val => {
              if (val.hotelReasontructureVOList instanceof Array) {
                val.hotelReasontructureVOList.forEach(v => {
                  v.children = _.cloneDeep(v.hotelReasontructureVOList);
                  delete v.hotelReasontructureVOList;
                });
              }
            });
          }
        });

        this.setState({ reasontructure: r.data });
      })
      .catch(e => {
        console.log(e);
      });
  }

  setLastData(arr) {
    arr.forEach(v => {
      if (v.level !== '4') {
        if (v.children instanceof Array) {
          this.setLastData(v.hotelReasontructureVOList);
        }
      } else {
        v.children = _.cloneDeep(v.hotelReasontructureVOList);
        delete v.hotelReasontructureVOList;
      }
    });
  }

  handleOk = () => {
    let { callback, changeStatus } = this.props;
    let { status, hotelId, startValue, endValue, content, lastReason } = this.state;
    content = content || '';
    if (status === '6' || status === '7') {
      if (!startValue) {
        message.error('请选择起始时间');
        return;
      }
      if (!endValue) {
        message.error('请选择结束时间');
        return;
      }
    }
    if (status === '4') {
      if (!lastReason) {
        message.error('请选择结构化原因');
        return;
      }
    }
    if (!content.trim()) {
      message.error('请输入理由');
      return;
    }
    this.setState({
      confirmLoading: true,
    });

    this.changeStatus()
      .then(res => {
        callback && callback(false);
        this.initData();
        changeStatus &&
          changeStatus({
            status,
            hotelId,
          });
        // 跟新old
        this.setState({
          oldStatus: status,
          confirmLoading: false,
        });
      })
      .catch(e => {
        console.log(e);
        this.setState({
          confirmLoading: false,
        });
      });
  };

  changeStatus = () => {
    let { status, hotelId, oldStatus, startValue, endValue, content, lastReason } = this.state;
    let { accountId } = this.props.user;
    return changeHotelStatus({
      status,
      hotelId,
      oldStatus,
      operator: accountId,
      startDate: startValue ? startValue.format(formatString) : null,
      endDate: endValue ? endValue.format(formatString) : null,
      reason: content || null,
      tructureReasonId: lastReason,
    });
  };

  handleCancel = () => {
    let { callback } = this.props;
    callback && callback(false);
    this.initData();
  };

  initData = () => {
    let { oldStartValue, oldEndValue } = this.state;
    this.setState({
      startValue: oldStartValue,
      endValue: oldEndValue,
      content: null,
      reasontructureLast: [],
      lastReason: undefined,
      firstReason: undefined,
    });
  };

  onStatusChange = e => {
    let { oldStartValue, oldEndValue, oldStatus } = this.state;
    this.setState({
      status: e.target.value,
      startValue: oldStatus === e.target.value ? oldStartValue : null,
      endValue: oldStatus === e.target.value ? oldEndValue : null,
      content: null,
    });
  };

  disabledStartDate = startValue => {
    let { endValue, status } = this.state;
    if (status === '6' || status === '7') {
      // 不能早于操作当天日期
      if (!startValue) {
        return true;
      }
      if (endValue && startValue) {
        return (
          startValue.valueOf() < moment({ hour: 0, minute: 0, seconds: 0 }).valueOf() ||
          startValue.valueOf() > endValue.valueOf()
        );
      }
      if (startValue) {
        return startValue.valueOf() < moment({ hour: 0, minute: 0, seconds: 0 }).valueOf();
      }
    }
  };

  disabledEndDate = endValue => {
    const startValue = this.state.startValue;

    if (!endValue || !startValue) {
      return false;
    }
    if (startValue && endValue) {
      return endValue.valueOf() < startValue.valueOf();
    }
  };

  onChange = (field, value) => {
    this.setState({
      [field]: value,
    });
  };

  onStartChange = (value, valueString) => {
    this.onChange('startValue', value);
  };

  onEndChange = (value, valueString) => {
    let { startValue } = this.state;
    if (!startValue) {
      message.info('请先选择起始日期');
      return;
    }
    this.onChange('endValue', value);
  };

  onContentChange = ev => {
    this.setState({
      content: ev.target.value,
    });
  };

  onReasonChange = (v, op) => {
    this.setState({
      lastReason: undefined,
      firstReason: v,
      reasontructureLast: op.length !== 0 ? [...op[2].children] : [],
    });
  };

  onLastReason = v => {
    this.setState({
      lastReason: v,
    });
  };

  render() {
    const { visible } = this.props;
    const {
      status,
      startValue,
      endValue,
      endOpen,
      content,
      confirmLoading,
      reasontructure,
      reasontructureLast,
      firstReason,
      lastReason,
    } = this.state;

    return (
      <Modal
        width="700px"
        title="更新状态"
        confirmLoading={confirmLoading}
        visible={visible}
        onOk={this.handleOk}
        onCancel={this.handleCancel}
      >
        <RadioGroup buttonStyle="solid" onChange={this.onStatusChange} value={status}>
          {createOption.call(this)}
        </RadioGroup>
        {status === '6' || status === '7' ? (
          <Row style={{ marginTop: 20, textAlign: 'center' }}>
            <Col span={11}>
              <DatePicker
                style={{ width: '100%' }}
                disabledDate={this.disabledStartDate}
                format="YYYY-MM-DD"
                value={startValue}
                placeholder="Start"
                onChange={this.onStartChange}
                // showTime={{
                //   hideDisabledOptions: true,
                //   defaultValue: moment('00:00:00', 'HH:mm:ss'),
                // }}
              />
            </Col>
            <Col span={2} style={{ height: 32, padding: '5px 0' }}>
              至
            </Col>
            <Col span={11}>
              <DatePicker
                style={{ width: '100%' }}
                disabledDate={this.disabledEndDate}
                format="YYYY-MM-DD"
                disabled={!startValue}
                value={endValue}
                placeholder={startValue ? 'End' : '请先选择起始日期'}
                onChange={this.onEndChange}
                // showTime={{
                //   hideDisabledOptions: true,
                //   defaultValue: moment('11:59:59', 'HH:mm:ss'),
                // }}
              />
            </Col>
          </Row>
        ) : null}
        {status === '4' && (
          <Row style={{ marginTop: 20 }}>
            <Col span={4}>结构化原因:</Col>
            <Col span={20}>
              <Cascader
                placeholder="请选择"
                style={{ width: '100%' }}
                fieldNames={{ label: 'name', value: 'id', children: 'hotelReasontructureVOList' }}
                options={reasontructure}
                onChange={this.onReasonChange}
                value={firstReason}
              />
            </Col>
            <Col span={4} />
            <Col span={20} style={{ marginTop: 10 }}>
              <Select
                style={{ width: '100%' }}
                placeholder="请选择"
                onChange={this.onLastReason}
                value={lastReason}
              >
                {reasontructureLast.map(v => (
                  <Option key={v.id} value={v.id}>
                    {v.name}
                  </Option>
                ))}
              </Select>
            </Col>
          </Row>
        )}
        <TextArea
          style={{ marginTop: 20 }}
          placeholder="酒店状态变更原因(必填)"
          onChange={this.onContentChange}
          value={content}
        />
      </Modal>
    );
  }
}
