import React, { PureComponent } from 'react';
import { Layout, Button, message } from 'antd';
import { connect } from 'dva';
import { syncHotelInfo } from './services/index';
import CreateHotelStep1 from './components/CreateHotelStep1';
import CreateHotelStep2 from './components/CreateHotelStep2';
import CreateHotelStep3 from './components/CreateHotelStep3';
import CreateHotelStep4 from './components/CreateHotelStep4';
import CreateHotelStep5 from './components/CreateHotelStep5';
import CreateHotelStep6 from './components/CreateHotelStep6';
import {
  validateBatchPrice,
  validateBaseInfoChannels,
  stepTitles,
  sendMsg,
  dataBase,
  momentFormatHMS,
  momentFormat,
  commissionItem,
} from './helper';
import styles from './Create.less';

import PageHeaderWrapper from '@/components/PageHeaderWrapper';

const { Content } = Layout;
let globalDispatch;
@connect(({ user }) => user)
class CreateHotel extends PureComponent {
  state = {
    hotelId: '',
    step: 0,
    // 第二步：基础信息维护--自定义佣金及标准入离时间（临时存储，保存接口直接使用这里面的值即可）
    // dataHookStep2: {},
    // stateHotel: {},
    // hotelStatus: 0
  };

  // 下一步
  onClickNext = () => {
    const { step } = this.state;

    if (step === 1) {
      // 保存第二步的自定义佣金&标准入离时间
      this.onClickSaveBaseInfo();
    } else if (step === 2) {
      this.saveHotelRooms();
    } else {
      this.goNext();
    }
  };

  goNext = () => {
    const { step } = this.state;
    this.setState({ step: step + 1 });
  };

  // 上一步
  onClickPre = () => {
    const { step } = this.state;
    this.setState({ step: step - 1 });
  };

  componentDidMount() {
    dataBase.clear();
    globalDispatch = this.props.dispatch;
    this.fetchChannels();
    this.fetchAllOyoRoomType();
    this.fetchAllSellRoomType();
  }

  // 同步旧的信息之后拉起同步后的数据（/hotel/sync）
  syncHotelInfo = oyoId => {
    syncHotelInfo({ oyoId })
      .then(resp => {
        if (resp.code === '000') {
          message.success('同步信息酒店信息成功');
        }
      })
      .catch(e => {
        console.log(e);
        // message.error('失败');
        // message.error('失败');
      });
  };

  // 第二步：基础信息维护---自定义佣金&标准入离时间 保存接口(/hotel/updateHotelBaseInfo)
  onClickSaveBaseInfo = () => {
    const dataStep2 = dataBase.getStep2();
    if (validateBaseInfoChannels(dataStep2)) {
      const params = Object.assign(Object.create(null), dataStep2);
      params.checkinTime = params.checkinTime.format(momentFormat);
      params.checkoutTime = params.checkoutTime.format(momentFormat);
      sendMsg.call(
        this,
        this._dispatch('saveHotelBaseInfoAction', params),
        true,
        this.fetchPriceCategories
      );
    }
  };

  // 第三步：维护酒店房型(/roomType/saveRoomTypeList)
  saveHotelRooms = () => {
    const stateRooms = dataBase.getStep3();
    const bindInfoList = stateRooms.map(({ oldRoomTypeId, roomTypeId, saleRoomTypeId }) => ({
      oldRoomTypeId,
      roomTypeId,
      sellRoomTypeId: saleRoomTypeId,
    }));
    const cb = () => {
      this.fetchStep5();
      this.goNext();
    };

    sendMsg.call(this, this._dispatch('saveHotelRoomsAction', { bindInfoList }), false, cb);
  };

  // 第四步：基准价设置(/price/presetRate)
  saveHotelBatchPrice = params => {
    if (validateBatchPrice(params)) {
      sendMsg.call(this, this._dispatch('saveHotelBatchPriceAction', params));
    }
  };

  // 第四步：独立房价设置(/price/updateListRateByDay)
  updateHotelPriceByDay = params =>
    sendMsg.call(this, this._dispatch('updateHotelPriceByDayAction', params));

  // 第五步：房型关联房价(/roomType/roomTypeBindRateCodes)
  updateHotelCategories = params =>
    sendMsg.call(this, this._dispatch('updateHotelRoomTypeAction', params), false, this.fetchStep5);

  // 上线酒店(/hotel/hotelLive/)
  onClickSave = () => {
    const { status } = dataBase.getStep6();
    sendMsg.call(this, this._dispatch('upateHotelStatusAction', { status }), false, () => {
      message.success('操作成功');
    });
  };

  // 获取渠道(/channel/getAllValidatedChannel)
  fetchChannels = () => {
    this._dispatch('fetchChannelsAction').then(({ channels }) =>
      this.setData('channels', channels)
    );
  };

  // 获取oyo所有房型(/roomType/getAllOyoRoomType)
  fetchAllOyoRoomType = () => {
    this._dispatch('fetchAllOyoRoomTypeAction').then(({ oyoRoomTypes }) =>
      this.setData('oyoRoomTypes', oyoRoomTypes)
    );
  };

  // 获取所有销售房型(/roomType/getSellRoomTypeList)
  fetchAllSellRoomType = () => {
    this._dispatch('fetchAllSellRoomTypeAction').then(({ sellRoomTypes }) =>
      this.setData('sellRoomTypes', sellRoomTypes)
    );
  };

  setData = (key, data) => {
    if (data) {
      this.setState({ [key]: data });
    }
  };

  /**
   * 封装dispatch--减少冗余代码
   * @param {String|Number} param0
   * @param {Object} param1
   */
  _dispatch = (dispatchType, data) => {
    const { hotelId } = this.state;
    const { accountId, username } = this.props;
    return globalDispatch({
      type: `hotel/${dispatchType}`,
      params: { ...data, hotelId, operatorId: accountId, operator: username },
    });
  };

  // 酒店房型价格策略下拉列表 （/roomType/getRoomTypeRateCodeList）
  fetchPriceCategories = () => {
    this._dispatch('fetchPriceCategoriesAction').then(({ priceCategories }) =>
      this.setData('priceCategories', priceCategories)
    );
  };

  // 酒店房型列表(/roomType/getHotelBindRoomTypeList)
  fetchHotelRooms = () => {
    this._dispatch('fetchHotelRoomsAction').then(({ rooms }) => this.setData('rooms', rooms));
  };

  // 通过id获取酒店详情(/hotel/getHotelBaseInfo)
  fetchStep1 = () => {
    this._dispatch('fetchHotelAction').then(({ hotel }) => {
      if (hotel) {
        const dataHook = Object.create(null);
        dataHook.hotelId = hotel.id;
        dataHook.checkinTime = momentFormatHMS(hotel.checkinTime || '14:00:00');
        dataHook.checkoutTime = momentFormatHMS(hotel.checkoutTime || '12:00:00');
        dataHook.channelCommissions =
          hotel.channelCommissionList && hotel.channelCommissionList.length > 0
            ? hotel.channelCommissionList
            : [{ ...commissionItem }];
        dataBase.setStep2(dataHook);
        this.setData('hotel', hotel);
      }
    });
  };

  // 第四步：获取某月基准价(/roomType/roomTypeListWithRateCode)
  fetchStep4Batch = month =>
    this._dispatch('fetchMonthPricesAction', { month }).then(res => {
      /**
       * 组装了某一天的数据
       * item里面缺少roomTypeName
       * item: {rate: 9989, rateDate: "2018-10-15", roomTypeId: 13}
       * TODO 批量设置的数据要组装
       */
      const db = Object.create(null);
      res.forEach(item => {
        const key = `d${item.rateDate}`;
        if (db[key]) {
          db[key][`roomTypeId${item.roomTypeId}`] = item;
        } else {
          const roomTypeIdObj = Object.create(null);
          roomTypeIdObj[`roomTypeId${item.roomTypeId}`] = item;
          db[key] = roomTypeIdObj;
        }
      });
      return db;
    });

  // 酒店房型价格策略列表(/roomType/roomTypeListWithRateCode)
  fetchStep5 = () => {
    this._dispatch('fetchRoomTypeMatchPriceListAction').then(({ categories }) =>
      this.setData('categories', categories)
    );
  };

  render() {
    const {
      step,
      hotelId,
      hotel,
      priceCategories,
      channels,
      rooms,
      oyoRoomTypes,
      sellRoomTypes,
      categories,
    } = this.state;

    return (
      <PageHeaderWrapper>
        <Layout className={styles.hotelCreateLayout}>
          <Content>
            <h2>同步酒店</h2>
            {/* 同步酒店信息 */}
            <div>
              <CreateHotelStep1 handler={this.syncHotelInfo} />
              {/* {hotelId &&
                hotel && (
                  <p className="text-center">
                    {hotel.name}
                    酒店信息同步完成！请点击下一步继续相关操作
                  </p>
                )} */}
            </div>
            {/* 酒店基础信息维护 */}
            {/* {step === 1 && <CreateHotelStep2 initData={hotel} channels={channels} />} */}
            {/* 维护酒店房型 */}
            {/* {step === 2 && (
            <CreateHotelStep3
              initData={rooms}
              oyoRoomTypes={oyoRoomTypes}
              sellRoomTypes={sellRoomTypes}
            />
          )} */}
            {/* 基准价格设置 */}
            {/* {step === 3 && (
            <CreateHotelStep4
              saveHandler={this.saveHotelBatchPrice}
              updateHandler={this.updateHotelPriceByDay}
              fetchMonthPrice={this.fetchStep4Batch}
            />
          )} */}
            {/* 房型关联房价 */}
            {/* {step === 4 && (
            <CreateHotelStep5
              initData={categories}
              opts={priceCategories}
              updateHandler={this.updateHotelCategories}
              hotelName={hotel.name}
            />
          )} */}
            {/* 酒店上下线 */}
            {/* {step === 5 && <CreateHotelStep6 />} */}
            {/* 第一步没有上一页 最后一步没有下一步 */}
            {/* <div className="text-center" style={{ marginTop: 10 }}>
            {step === 0 && (
              <Button
                disabled={step === 0 && (!hotel || !hotel.id)}
                onClick={this.onClickNext}
                type="primary"
              >
                下一步
              </Button>
            )}
          </div> */}

            {/* {step > 0 && <Button onClick={this.onClickPre}>上一步</Button>} */}
            {/* <span className="hotel-wedges" /> */}
            {/* {step !== 0 &&
              step < 5 && (
                <Button onClick={this.onClickNext} type="primary">
                  保存下一步
                </Button>
              )} */}
            {/* {step === 5 && (
              <Button onClick={this.onClickSave} type="primary">
                保存
              </Button>
            )} */}
          </Content>
        </Layout>
      </PageHeaderWrapper>
    );
  }
}

export default CreateHotel;
