import React from 'react';
import { Form, Input, Row, Col, Layout, TimePicker, Select, Button, message } from 'antd';
import {
  dataBase,
  baseItems,
  commissionItem,
  statusOpts,
  customCommissionsOpts,
  momentFormat,
  formItemLayout,
  innerFormItemLayout,
} from '../../helper';

const { Content } = Layout;
const FormItem = Form.Item;
const Option = Select.Option;

// 输入框样式
const formItemStyle = {
  style: {
    width: '100%',
  },
};

class CreateHotelStep extends React.Component {
  state = {
    checkinTime: '',
    checkoutTime: '',
    channelCommissions: [],
  };

  setData = state => {
    this.setState(state, () => {
      dataBase.setStep2(this.state);
    });
  };

  // 处理到店时间
  handleStartInput = moment => {
    this.setData({ checkinTime: moment });
  };

  // 处理离店时间
  handleEndInput = moment => {
    this.setData({ checkoutTime: moment });
  };

  // 给自定义佣金某一项塞值
  setCustomCommissions = (idx, key, value) => {
    const { channelCommissions } = this.state;
    channelCommissions[idx][key] = value;
  };

  handleListInput = ({ target: { name, value } }, idx) => {
    if (!(/^[1-9][\d]{0,2}(?:\.[\d]{0,2})?$/.test(value) && value <= 100)) {
      message.error('佣金比例无效');
    }
    this.setCustomCommissions(idx, name, value);
  };

  handleListChange = ({ key, props: { name, value } }, idx) => {
    this.setCustomCommissions(idx, name, value);
    if (name === 'channelId') {
      const { channels } = this.props;

      const { channelName } = channels[key];
      this.setCustomCommissions(idx, 'channelName', channelName);
    }
  };

  componentDidMount() {
    this.setData(dataBase.getStep2());
  }

  addCustomCommission = () => {
    const { channelCommissions } = this.state;
    const list = [...channelCommissions, { ...commissionItem }];
    this.setData({ channelCommissions: list });
  };

  render() {
    const { initData, channels } = this.props;
    const { channelCommissions, checkinTime, checkoutTime } = this.state;
    if (checkinTime) {
      return (
        <div>
          {/* main item */}
          <Layout style={{ border: '1px solid #e8e8e8', backgroundColor: '#fff' }}>
            <Content>
              {baseItems.map(([first, second], idx) => (
                <Row key={idx}>
                  <Col span="12">
                    <FormItem label={first.label} {...formItemLayout}>
                      <div dangerouslySetInnerHTML={{ __html: initData[first.key] }} />
                    </FormItem>
                  </Col>
                  <Col span="12">
                    <FormItem label={second.label} {...formItemLayout}>
                      <div dangerouslySetInnerHTML={{ __html: initData[second.key] }} />
                    </FormItem>
                  </Col>
                </Row>
              ))}
            </Content>
          </Layout>

          <Layout
            style={{
              border: '1px solid #e8e8e8',
              backgroundColor: '#fff',
              padding: 10,
              marginTop: 10,
            }}
          >
            <Content>
              <Row>
                <Col span={22}>自定义佣金：</Col>
                <Col span={2}>
                  <Button onClick={this.addCustomCommission}>添加</Button>
                </Col>
              </Row>
              {channelCommissions.map((cc, k) => (
                <Row key={k} style={{ marginBottom: '24px' }}>
                  <Col span={6}>
                    <FormItem {...innerFormItemLayout} label="渠道名称：">
                      <Select
                        {...formItemStyle}
                        defaultValue={cc.channelId}
                        onChange={(val, evt) => this.handleListChange(evt, k)}
                        placeholder="渠道名称"
                      >
                        {channels.map((ch, ck) => (
                          <Option key={ck} name="channelId" value={ch.channelId}>
                            {ch.channelName}
                          </Option>
                        ))}
                      </Select>
                    </FormItem>
                  </Col>
                  <Col span={6}>
                    <FormItem {...innerFormItemLayout} label="佣金类型：">
                      <Select
                        {...formItemStyle}
                        defaultValue={cc.applyType}
                        onChange={(val, evt) => this.handleListChange(evt, k)}
                        placeholder="佣金类型"
                      >
                        {customCommissionsOpts.map((cco, cck) => (
                          <Option key={cck} name="applyType" value={cco.value}>
                            {cco.label}
                          </Option>
                        ))}
                      </Select>
                    </FormItem>
                  </Col>
                  <Col span={6}>
                    <FormItem {...innerFormItemLayout} label="佣金比例：">
                      <Input
                        {...formItemStyle}
                        defaultValue={cc.value}
                        name="value"
                        onInput={evt => this.handleListInput(evt, k)}
                        placeholder="佣金比例"
                      />
                    </FormItem>
                  </Col>
                  <Col span={6}>
                    <FormItem {...innerFormItemLayout} label="状态：">
                      <Select
                        {...formItemStyle}
                        defaultValue={cc.status}
                        name="status"
                        onChange={(val, evt) => this.handleListChange(evt, k)}
                        placeholder="状态"
                      >
                        {statusOpts.map((cco, cck) => (
                          <Option key={cck} name="status" value={cco.value}>
                            {cco.label}
                          </Option>
                        ))}
                      </Select>
                    </FormItem>
                  </Col>
                </Row>
              ))}
              <Row>
                <Col span={24}>标准入离时间：</Col>
              </Row>
              <Row>
                <Col span={12}>
                  <FormItem {...innerFormItemLayout} label="到店时间：">
                    <TimePicker
                      defaultValue={checkinTime}
                      name="checkinTime"
                      format={momentFormat}
                      onChange={this.handleStartInput}
                      placeholder="到店时间"
                    />
                  </FormItem>
                </Col>
                <Col span={12}>
                  <FormItem {...innerFormItemLayout} label="离店时间：">
                    <TimePicker
                      defaultValue={checkoutTime}
                      name="checkoutTime"
                      format={momentFormat}
                      onChange={this.handleEndInput}
                      placeholder="离店时间"
                    />
                  </FormItem>
                </Col>
              </Row>
            </Content>
          </Layout>
        </div>
      );
    }
    return <div />;
  }
}

export default CreateHotelStep;
