import React from 'react';
import {
  Table,
  Input,
  Modal,
  Form,
  Layout,
  Checkbox,
  Button,
  Calendar,
  DatePicker,
  Popconfirm,
  message,
} from 'antd';
import moment from 'moment';
import { dataBase } from '../../helper';

const formItemLayout = {
  labelCol: {
    xs: { span: 24 },
    sm: { span: 5 },
  },
  wrapperCol: {
    xs: { span: 24 },
    sm: { span: 12 },
  },
};
const FormItem = Form.Item;
const { Content } = Layout;
const dateFormat = 'YYYY-MM-DD';
const startDateDefault = moment(moment(), dateFormat);
const endDateDefault = moment(moment(), dateFormat);
endDateDefault.add(1, 'years');
const CheckboxGroup = Checkbox.Group;
// 不同房型最多可以选择多少个--PRD上最多三个
const max = 3;

const columnFactory = fn => [
  {
    title: '',
    dataIndex: 'p0',
    width: 120,
    key: 'p0',
  },
  {
    title: '周一',
    key: 'p1',
    render: (text, record, index) => (
      <Input
        name="p1"
        defaultValue={record.p1}
        onInput={evt => fn(evt, record)}
        placeholder="请输入房价"
      />
    ),
  },
  {
    title: '周二',
    dataIndex: 'p2',
    key: 'p2',
    render: (text, record, index) => (
      <Input
        name="p2"
        defaultValue={record.p2}
        onInput={evt => fn(evt, record)}
        placeholder="请输入房价"
      />
    ),
  },
  {
    title: '周三',
    key: 'p3',
    dataIndex: 'tags',
    render: (text, record, index) => (
      <Input
        name="p3"
        defaultValue={record.p3}
        onInput={evt => fn(evt, record)}
        placeholder="请输入房价"
      />
    ),
  },
  {
    title: '周四',
    key: 'p4',
    dataIndex: 'p4',
    render: (text, record, index) => (
      <Input
        name="p4"
        defaultValue={record.p4}
        onInput={evt => fn(evt, record)}
        placeholder="请输入房价"
      />
    ),
  },
  {
    title: '周五',
    key: 'p5',
    dataIndex: 'p5',
    render: (text, record, index) => (
      <Input
        name="p5"
        defaultValue={record.p5}
        onInput={evt => fn(evt, record)}
        placeholder="请输入房价"
      />
    ),
  },
  {
    title: '周六',
    key: 'p6',
    dataIndex: 'p6',
    render: (text, record, index) => (
      <Input
        name="p6"
        defaultValue={record.p6}
        onInput={evt => fn(evt, record)}
        placeholder="请输入房价"
      />
    ),
  },
  {
    title: '周日',
    key: 'p7',
    dataIndex: 'p7',
    render: (text, record, index) => (
      <Input
        name="p7"
        defaultValue={record.p7}
        onInput={evt => fn(evt, record)}
        placeholder="请输入房价"
      />
    ),
  },
];

function dateCellRender(context, persistentData, datePrice) {
  return function(value) {
    const newData = persistentData[value.format(dateFormat)];
    const curDate = datePrice[`d${value.format('YYYY-MM-DD')}`];
    let curPrice;
    if (curDate) {
      // curPrice = Object.values(curDate).filter(cd =>
      //   context.some(ct => cd.roomTypeId === ct.roomTypeId)
      // );
      curPrice = Object.keys(curDate).filter(cdKey =>
        context.some(ct => curDate[cdKey].roomTypeId === ct.roomTypeId)
      );
    }
    let str;
    if (newData) {
      str = newData.join('/');
    } else if (curPrice && curPrice.length > 0) {
      str = curPrice.map(cp => cp.rate).join('/');
    } else {
      str = context
        .map(ct => ct[`p${value.isoWeekday()}`])
        .filter(_ => _)
        .join('/');
    }
    return <div>{str}</div>;
  };
}

export default class CreateHotelStep extends React.Component {
  state = {
    datePrice: {},
    checkedValueGroup: [],
    batchDataSource: [],
    roomTypeGroup: {},
    isBatch: true,
    options: [],
    persistentData: {},
    startDate: startDateDefault.format(dateFormat),
    endDate: endDateDefault.format(dateFormat),
    visible: false,
    modalTitle: '',
    selectedDaySettings: [],
    checkedDay: moment(),
  };

  setData = (data, cb = _ => _) => {
    this.setState(data, () => {
      dataBase.setStep4(this.state);
      cb();
    });
  };

  componentDidMount() {
    this.setData({ ...dataBase.getStep4() });
    this.fetchMonthPrice(moment());
  }

  fetchMonthPrice = currMoment => {
    this.props.fetchMonthPrice(currMoment.format('YYYY-MM')).then(res => {
      if (res) {
        this.setData({ datePrice: res });
      }
    });
  };

  // 特定日期设置房价的模态框显示隐藏
  triggerModal = () => {
    this.setData({ visible: !this.state.visible });
  };

  // 保存特定日期的房价
  handleModalConfirm = evt => {
    const { checkedDay, selectedDaySettings, persistentData } = this.state;
    const { updateHandler } = this.props;
    const params = Object.create(null);
    params.rateDate = checkedDay.format(dateFormat);
    params.rateList = [...selectedDaySettings];
    updateHandler(params).then(({ msg }) => {
      if (msg) {
        const pData = { ...persistentData };
        pData[params.rateDate] = params.rateList.map(_ => _.rate);
        this.setData({ persistentData: pData });
        this.triggerModal();
      }
    });
  };

  // 批量设置房价的输入回调
  handleInput = ({ target }, record) => {
    const { name, value } = target;
    if (!/^[1-9][\d]{0,3}(?:\.[\d]{0,2})?$/.test(value)) {
      message.error('房价无效');
    }
    record[name] = value;
  };

  // 选择某个特定的日期
  handleDate = evt => {
    const { checkedValueGroup } = this.state;
    if (checkedValueGroup.length > 0) {
      this.setData(
        {
          modalTitle: moment(evt).format('YYYY-MM-DD'),
          checkedDay: evt,
        },
        () => {
          this.assembleForm();
          this.triggerModal();
        }
      );
    } else {
      message.error('请选择房型');
    }
  };

  assembleForm = () => {
    const { checkedDay, datePrice } = this.state;
    const selectedDaySettings = [];
    const array = this.assembleCellRender();
    const curDate = datePrice[`d${checkedDay.format('YYYY-MM-DD')}`];

    array.forEach(rtg => {
      let price;
      const setting = Object.create(null);
      if (curDate && curDate[`roomTypeId${rtg.roomTypeId}`]) {
        price = curDate[`roomTypeId${rtg.roomTypeId}`].rate;
      }
      // 房型name
      setting.roomTypeName = rtg.p0;
      // 房型id
      setting.roomTypeId = rtg.roomTypeId;
      // 价格
      setting.rate = price || rtg[`p${checkedDay.isoWeekday()}`];
      selectedDaySettings.push(setting);
    });
    this.setData({ selectedDaySettings });
  };

  triggerSetting = () => {
    const { isBatch } = this.state;
    this.setData({
      isBatch: !isBatch,
      selectedDaySettings: [],
      persistentData: {},
    });
  };

  handleModalChange = ({ target }, idx) => {
    const { selectedDaySettings } = this.state;
    const { name, value } = target;
    selectedDaySettings[idx][name] = value;
    this.setData({ selectedDaySettings });
  };

  saveBatchPrice = () => {
    const { saveHandler } = this.props;
    const params = Object.create(null);
    const iterators = [1, 2, 3, 4, 5, 6, 7];

    const { batchDataSource, startDate, endDate } = this.state;
    params.startDate = startDate;
    params.endDate = endDate;
    params.rateList = [];
    batchDataSource.forEach(ds => {
      const sub = Object.create(null);
      const rateValueList = [];
      sub.roomTypeId = ds.roomTypeId;
      iterators.forEach(it => {
        rateValueList.push(ds[`p${it}`]);
      });
      sub.rateValueList = rateValueList;
      params.rateList.push(sub);
    });
    saveHandler(params);
  };

  assembleCellRender = () => {
    const { batchDataSource, roomTypeGroup } = this.state;
    // const group = Object.values(roomTypeGroup);
    const group = Object.keys(roomTypeGroup).map(k => roomTypeGroup[k]);
    return batchDataSource.filter(bs => group.some(it => it.value === bs.roomTypeId));
  };

  handleDateChange = (key, cmoment, date) => {
    this.setData({ [key]: date });
  };

  disabledDate = current => moment() > moment(current);

  onChangeGroup = checkedValue => {
    if (checkedValue.length <= max) {
      const { options } = this.state;
      const roomTypeGroup = Object.create(null);
      const group = options.filter(op => checkedValue.includes(op.value));
      group.forEach(item => {
        roomTypeGroup[`g${item.value}`] = item;
        return item;
      });
      this.setData({ checkedValueGroup: checkedValue, roomTypeGroup });
    }
  };

  onPanelChange = (date, mode) => {
    if (mode === 'month') {
      this.fetchMonthPrice(moment());
    }
  };

  render() {
    const {
      batchDataSource,
      options,
      isBatch,
      modalTitle,
      selectedDaySettings,
      persistentData,
      startDate,
      endDate,
      datePrice,
      checkedValueGroup,
    } = this.state;
    return (
      <div>
        {isBatch ? (
          <div>
            <h6 className="text-right">
              <span className="float-left">
                预埋未来一年（
                <span className="hotel-wedges" />
                <DatePicker
                  onChange={(cmoment, date) => this.handleDateChange('startDate', cmoment, date)}
                  defaultValue={moment(startDate)}
                  format={dateFormat}
                />
                <span className="hotel-wedges" />-<span className="hotel-wedges" />
                <DatePicker
                  onChange={(cmoment, date) => this.handleDateChange('endDate', cmoment, date)}
                  defaultValue={moment(endDate)}
                  format={dateFormat}
                />
                <span className="hotel-wedges" />
                ）的房价
              </span>
              <Button onClick={this.triggerSetting}>设置独立房价</Button>
              {/* <span> 最近设置日期：2017/12/12</span> */}
            </h6>
            <Table
              bordered
              rowKey="roomTypeId"
              columns={columnFactory(this.handleInput)}
              dataSource={batchDataSource}
              pagination={false}
            />
            <p className="text-center" style={{ marginTop: 20 }}>
              <Popconfirm
                title="您确定要保存房价吗？"
                onConfirm={this.saveBatchPrice}
                okText="确定"
                cancelText="取消"
              >
                <a>保存房价</a>
              </Popconfirm>
              <span className="hotel-wedges" />
              设置完成后从明日开始生效
            </p>
          </div>
        ) : (
          <Layout style={{ backgroundColor: '#fff' }}>
            <h5>
              <CheckboxGroup
                options={options}
                value={checkedValueGroup}
                onChange={this.onChangeGroup}
              />
              <Button className="float-right" onClick={this.triggerSetting}>
                设置批量房价
              </Button>
            </h5>
            <Content>
              <div style={{ width: 860, border: '1px solid #d9d9d9', borderRadius: 4 }}>
                <Calendar
                  disabledDate={this.disabledDate}
                  dateCellRender={dateCellRender(
                    this.assembleCellRender(),
                    persistentData,
                    datePrice
                  )}
                  onSelect={this.handleDate}
                  onPanelChange={this.onPanelChange}
                />
              </div>
            </Content>
          </Layout>
        )}
        <Modal
          title={modalTitle}
          visible={this.state.visible}
          okText="保存"
          onOk={this.handleModalConfirm}
          onCancel={this.triggerModal}
        >
          <Form className="login-form">
            {selectedDaySettings.map((bds, idx) => (
              <FormItem key={bds.roomTypeName} label={bds.roomTypeName} {...formItemLayout}>
                <Input
                  onChange={evt => this.handleModalChange(evt, idx)}
                  name="rate"
                  value={bds.rate}
                />
              </FormItem>
            ))}
          </Form>
        </Modal>
      </div>
    );
  }
}
