import React, { Component } from 'react';
import { Table, message, Modal, Select, Divider, Row, Col, Icon } from 'antd';

const Option = Select.Option;

const columnsFactory = fn => [
  {
    title: '房型名称',
    dataIndex: 'roomTypeName',
    width: '30%',
    editable: true,
  },
  {
    title: '价格策略',
    dataIndex: 'rateCodeList',
    render: (text, record) => {
      const { rateCodeList = [] } = record;
      return (
        <ul>
          {rateCodeList.map((rcl, idx) => (
            <li key={idx}>{rcl.rateCodeName}</li>
          ))}
        </ul>
      );
    },
  },
  {
    title: '对应渠道',
    dataIndex: 'roomTypeId',
    render: (text, record) => {
      const { rateCodeList = [] } = record;
      return (
        <ul>
          {rateCodeList.map((rcl, idx) => (
            <li key={idx}>{rcl.channelList.join('、')}</li>
          ))}
        </ul>
      );
    },
  },
  {
    title: '操作',
    dataIndex: 'operation',
    render: (text, record) => <a onClick={() => fn(record)}>修改关联价格策略</a>,
  },
];

const defaultOpt = {
  description: '',
  rateCodeId: '',
  rateCodeName: '请选择',
};
export default class CreateHotelStep extends Component {
  state = {
    selectedRoom: {},
    selectedCategory: {},
    categories: [],
    visible: false,
  };

  // 操作列的处事件
  handleSelect = selectedRoom => {
    // deep clone
    const sr = { ...selectedRoom };
    const list = [];
    selectedRoom.rateCodeList.forEach(it => {
      list.push({ ...it });
    });
    sr.rateCodeList = list;
    this.setState({ selectedRoom: sr });
    this.triggerModal();
  };

  // 保存价格策略关系
  handleModalConfirm = item => {
    const { updateHandler } = this.props;
    const { selectedRoom } = this.state;
    const params = Object.create(null);
    params.roomTypeId = selectedRoom.roomTypeId;
    params.rateCodeIds = [];
    selectedRoom.rateCodeList.forEach(it => {
      params.rateCodeIds.push(it.rateCodeId);
    });
    updateHandler(params).then(({ msg }) => {
      if (msg) {
        this.triggerModal();
      }
    });
  };

  // 控制模态框显示隐藏及数据初始化
  triggerModal = () => {
    const temp = Object.create(null);
    const { visible } = this.state;
    if (visible) {
      temp.selectedRoom = {};
      temp.selectedCategory = {};
      temp.categories = [];
    } else {
      const { opts } = this.props;
      temp.selectedCategory = defaultOpt;
      temp.categories = [defaultOpt, ...opts];
    }
    temp.visible = !visible;
    this.setState(temp);
  };

  // select组件handler
  handleChange = (v, op) => {
    const { categories } = this.state;
    const { key } = op;
    const selectedCategory = categories[key];
    this.setState({ selectedCategory });
  };

  // 删除价格策略
  handleModalDel = idx => {
    const { selectedRoom } = this.state;
    selectedRoom.rateCodeList.splice(idx, 1);
    this.setState({ selectedRoom });
  };

  // 增加价格策略
  handleModalAdd = () => {
    const { selectedRoom, selectedCategory } = this.state;
    if (!selectedCategory.rateCodeId) {
      message.error('请选择价格策略');
    } else if (
      selectedRoom.rateCodeList.some(rc => rc.rateCodeId === selectedCategory.rateCodeId)
    ) {
      message.error('该策略已选，不可重复');
    } else {
      selectedRoom.rateCodeList.push({ ...selectedCategory });
      this.setState({
        selectedRoom,
      });
    }
  };

  render() {
    const { selectedRoom, visible, categories } = this.state;
    const { hotelName, initData } = this.props;
    return (
      <div>
        <Table
          bordered
          pagination={false}
          rowKey="roomTypeId"
          dataSource={initData}
          columns={columnsFactory(this.handleSelect)}
        />
        {visible && (
          <Modal
            title="关联价格策略"
            visible
            onOk={this.handleModalConfirm}
            onCancel={this.triggerModal}
          >
            <p>
              当前选择房型：
              <span>{selectedRoom.roomTypeName}</span> 当前选择酒店：
              <span>{hotelName}</span>
            </p>
            <div>
              <Row style={{ marginBottom: 15 }}>
                <Col span={6}>选择价格策略</Col>
                <Col span={10}>
                  <Select
                    style={{ width: '100%' }}
                    defaultValue={defaultOpt.rateCodeId}
                    onChange={this.handleChange}
                  >
                    {categories.map((ct, i) => (
                      <Option key={i} value={ct.rateCodeId}>
                        {ct.rateCodeName}
                      </Option>
                    ))}
                  </Select>
                </Col>
                <Col span={4} className="text-center">
                  <Icon onClick={this.handleModalAdd} type="plus" theme="outlined" />
                </Col>
              </Row>
            </div>
            <Divider />
            <div>
              {selectedRoom.rateCodeList &&
                selectedRoom.rateCodeList.map((rc, idx) => (
                  <Row style={{ marginBottom: 15 }} key={idx}>
                    <Col span={6}>{idx === 0 && <span>已关联价格策略：</span>}</Col>
                    <Col span={10}>
                      <span>{rc.rateCodeName}</span>
                    </Col>
                    <Col span={4} className="text-center">
                      <Icon
                        onClick={() => this.handleModalDel(idx)}
                        type="minus"
                        theme="outlined"
                      />
                    </Col>
                  </Row>
                ))}
            </div>
          </Modal>
        )}
      </div>
    );
  }
}
