import { message } from 'antd';
import moment from 'moment';
/**
 * 共用部分
 */

// promise then 处理函数
export function sendMsg(promiseInstance, next = false, ...injects) {
  return promiseInstance.then(({ msg = '' }) => {
    if (msg) {
      injects.forEach(inject => {
        inject();
      });
      if (next) {
        message.success(msg);
        this.goNext();
      }
    }
    return { msg };
  });
}

export const validateBaseInfoChannels = function validateBaseInfoChannels(params) {
  let isValid = true;
  if (
    !params.channelCommissions ||
    !params.channelCommissions.every(channel => !!channel.channelId)
  ) {
    message.error('请选择渠道');
    isValid = false;
  }
  if (
    isValid &&
    (!params.channelCommissions || !params.channelCommissions.some(channel => !!channel.status))
  ) {
    message.error('至少一个渠道状态为有效');
    isValid = false;
  }
  if (
    isValid &&
    (!params.channelCommissions ||
      !params.channelCommissions.some(
        channel => /^[1-9][\d]{0,2}(?:\.[\d]{0,2})?$/.test(channel.value) && channel.value <= 100
      ))
  ) {
    message.error('佣金比例无效');
    isValid = false;
  }
  return isValid;
};
// 基准价格校验
export const validateBatchPrice = params => {
  let isValid = true;
  if (!params.startDate) {
    message.error('开始时间不能为空');
    isValid = false;
  }
  if (isValid && !params.endDate) {
    message.error('结束时间不能为空');
    isValid = false;
  }
  if (
    isValid &&
    (!params.rateList ||
      !params.rateList.every(({ rateValueList }) =>
        rateValueList.every(it => /^[1-9][\d]{0,3}(?:\.[\d]{0,2})?$/.test(it) && it < 10000)
      ))
  ) {
    message.error('请检查基准房价是否在1至9999.99之间');
    isValid = false;
  }
  return isValid;
};

export const dataBase = {
  _store: Object.create(null),
  clear() {
    this._store = Object.create(null);
  },
  setData: function set(key, value) {
    if (!this.getData(key)) {
      this._store[key] = value;
    } else {
      Object.assign(this._store[key], value);
    }
  },
  getData: function get(key) {
    return key ? this._store[key] : this._store;
  },
  setStep2(value) {
    this.setData('step2', value);
  },
  getStep2() {
    return this.getData('step2');
  },
  setStep3(raw) {
    const batchDataSource = [];
    const options = [];
    // 使用原始数据生成符合页面渲染条件的数据
    raw.forEach(item => {
      const row = Object.create(null);
      const ckb = Object.create(null);
      row.roomTypeId = item.roomTypeId;
      ckb.value = item.roomTypeId;
      row.p0 = item.roomTypeName;
      ckb.label = item.roomTypeName;
      row.p1 = '';
      row.p2 = '';
      row.p3 = '';
      row.p4 = '';
      row.p5 = '';
      row.p6 = '';
      row.p7 = '';
      batchDataSource.push(row);
      options.push(ckb);
    });
    this.setData('step3', raw);
    this.setStep4({ batchDataSource, options });
  },
  getStep3() {
    return this.getData('step3');
  },
  setStep4(value) {
    this.setData('step4', value);
  },
  getStep4() {
    return this.getData('step4');
  },
  setStep6(value) {
    this.setData('step6', value);
  },
  getStep6() {
    return this.getData('step6');
  },
};
/**
 * 第一步
 * =============================================================================
 */
// 标题
export const stepTitles = [
  '第一步：同步酒店',
  '第二步：基础信息维护',
  '第三步：维护酒店房型',
  '第四步：基准价设置',
  '第五步：房型价格设置',
  '第六步：上线酒店',
];

/**
 * 第二步
 * =============================================================================
 */
// 用于迭代基本信息
export const baseItems = [
  [{ label: '酒店ID：', key: 'id' }, { label: '国家：', key: 'countryName' }],
  [{ label: '酒店名称：', key: 'name' }, { label: '省：', key: 'stateName' }],
  [{ label: '酒店替代名称：', key: 'alternateName' }, { label: '市：', key: 'cityName' }],
  [{ label: 'OYOID：', key: 'oyoId' }, { label: '区：', key: 'clusterName' }],
  [{ label: '描述：', key: 'description' }, { label: '邮编：', key: 'pincode' }],
  [{}, { label: '经度：', key: 'longitude' }],
  [{ label: '电子邮件：', key: 'email' }, { label: '纬度：', key: 'latitude' }],
  [{ label: '电话：', key: 'phone' }, { label: '主要联系人电话：', key: 'primaryContact' }],
  [{ label: '标志性建筑：', key: 'landmark' }, { label: '经理姓名：', key: 'managerName' }],
  [{ label: '地址：', key: 'street' }, { label: '房间总数量：', key: 'totalRooms' }],
  [{ label: '创建时间：', key: 'createTime' }, { label: 'Unique code：', key: 'uniqueCode' }],
];
// 佣金类型 select opts 前端hardcode
export const customCommissionsOpts = [{ label: '集团', value: 0 }, { label: '单店', value: 1 }];
// 状态 select opts 前端hardcode
export const statusOpts = [{ label: '无效', value: 0 }, { label: '有效', value: 1 }];
// 自定义佣金每一项包含的字段
export const commissionItem = {
  channelId: '',
  channelName: '',
  applyType: 0,
  value: '10',
  status: 1,
};
export const momentFormat = 'HH:mm:ss';
export const momentFormatHMS = dateString => moment(dateString, momentFormat);
// form item css基础配置
export const formItemLayout = {
  labelCol: {
    xs: { span: 6 },
    sm: { span: 6 },
  },
  wrapperCol: {
    xs: { span: 10 },
    sm: { span: 10 },
  },
};
// 内嵌form item css 配置
export const innerFormItemLayout = {
  labelCol: {
    xs: { span: 7 },
    sm: { span: 7 },
  },
  wrapperCol: {
    xs: { span: 14 },
    sm: { span: 14 },
  },
};
/**
 * 第三步
 * =============================================================================
 */
export const standardOptObj = {
  key: 'roomTypeId',
  value: 'roomTypeName',
};
export const sellOptsObj = {
  key: 'saleRoomTypeId',
  value: 'saleRoomTypeName',
};
export const columnsDefault = [
  {
    title: '原有房型',
    dataIndex: 'oldRoomTypeName',
  },
  {
    title: 'OYO标准房型名称',
    dataIndex: 'roomTypeName',
    editable: true,
  },
  {
    title: '房型代码',
    dataIndex: 'roomTypeCode',
  },
  {
    title: '销售房型名称',
    dataIndex: 'saleRoomTypeName',
    editable: true,
  },
  {
    title: '房间数量',
    dataIndex: 'roomCount',
  },
  // {
  //   title: '操作',
  //   dataIndex: 'operation',
  //   render: (text, record) => {
  //     // return <a href="javascript:;" onClick={() => this.handleSetting(record)}>修改</a>
  //     return text
  //   },
  // }
];
