import moment from 'moment';
import {
  fetchHotelBaseInfo,
  syncHotelInfo,
  fetchChannels,
  saveHotelBaseInfo,
  saveHotelBatchPrice,
  updateHotelPriceByDay,
  fetchHotelRooms,
  saveHotelRooms,
  upateHotelStatus,
  updateHotelRoomType,
  fetchRoomTypeMatchPriceList,
  fetchAllOyoRoomType,
  fetchAllSellRoomType,
  fetchPriceCategories,
  fetchMonthPrices,
  fetchDayPrice,
} from '../services/index';
import { safeCall } from '@/utils/requestStatus';

const momentFormat = 'HH:mm:ss';

const roomTypeDefault = {
  roomTypeCode: '',
  roomTypeId: '',
  roomTypeName: '请选择标准房型',
};

const sellRoomTypeDefault = {
  saleRoomTypeId: '',
  saleRoomTypeName: '请选择销售房型',
};
export default {
  namespace: 'hotel',

  state: {
    // 同步旧CRS酒店信息存储地址
    hotel: {},
    // 渠道
    channels: [],
    rooms: [],
    // 房型价格列表
    categories: [],
    // 房型价格策略下拉列表
    priceCategories: [],
    // 接口状态
    status: '',
    // 接口消息
    message: '',
  },

  effects: {
    /**
     * 同步旧CRS酒店信息
     * @param {Object} param0
     * @param {Object} param1
     * /hotel/sync
     */
    *syncHotelAction(
      {
        params: { hotelOyoId },
      },
      { call, put }
    ) {
      const { code, msg, data } = yield call(syncHotelInfo, hotelOyoId);
      const payload = { hotelId: data };
      // const payload = { hotelId: 36748 }
      // yield put({
      //   type: 'saveHotelReducer',
      //   payload
      // });
      return safeCall(code, msg, () => payload);
    },
    /**
     * 通过hotelId获取酒店信息
     * @param {Object} param0
     * @param {Object} param1
     * /hotel/getHotelBaseInfo
     */
    *fetchHotelAction(
      {
        params: { hotelId },
      },
      { call, put }
    ) {
      const payload = Object.create(null);

      const { code, msg, data: hotel } = yield call(fetchHotelBaseInfo, hotelId);
      // payload.hotel = hotel
      // yield put({
      //   type: 'saveHotelReducer',
      //   payload
      // });
      return safeCall(code, msg, () => {
        // 转化时间格式
        hotel.checkinTime = moment(hotel.checkinTime, momentFormat).format(momentFormat);
        hotel.checkoutTime = moment(hotel.checkoutTime, momentFormat).format(momentFormat);
        payload.hotel = hotel;
        return payload;
      });
    },

    /**
     * 上线酒店
     * @param {Object} param0
     * @param {Object} param1
     * /hotel/hotelLive/
     */
    *upateHotelStatusAction({ params }, { call, put }) {
      const { code, msg } = yield call(upateHotelStatus, params);
      return safeCall(code, msg, () => ({ msg }));
    },
    /**
     * 第三步：维护酒店房型
     * @param {Object} param0
     * @param {Object} param1
     * /roomType/saveRoomTypeList
     */
    *saveHotelRoomsAction({ params }, { call, put }) {
      const { code, msg } = yield call(saveHotelRooms, params);
      return safeCall(code, msg, () => ({ msg }));
    },
    /**
     * 酒店房型列表
     * @param {*} param0
     * @param {*} param1
     * /roomType/getHotelBindRoomTypeList
     */
    *fetchHotelRoomsAction(
      {
        params: { hotelId },
      },
      { call, put }
    ) {
      const { code, msg, data } = yield call(fetchHotelRooms, hotelId);
      // yield put({
      //   type: 'saveHotelReducer',
      //   payload: { rooms },
      // });
      return safeCall(code, msg, () => {
        const rooms = data.map(it => {
          it.roomTypeCode = it.roomTypeCode || '';
          it.roomTypeId = it.roomTypeId || '';
          it.roomTypeName = it.roomTypeName || '';
          it.saleRoomTypeId = it.saleRoomTypeId || '';
          it.saleRoomTypeName = it.saleRoomTypeName || '';
          return it;
        });
        return { rooms };
      });
    },
    /**
     * 获取oyo所有房型
     * @param {*} _
     * @param {*} param1
     * /roomType/getAllOyoRoomType
     */
    *fetchAllOyoRoomTypeAction(_, { call, put }) {
      const { code, msg, data } = yield call(fetchAllOyoRoomType);
      const oyoRoomTypes = [roomTypeDefault, ...data];
      // yield put({
      //   type: 'saveHotelReducer',
      //   payload: { oyoRoomTypes },
      // });
      // const [fir] = oyoRoomTypes
      // if (fir) {
      //   Object.assign(roomTypeDefault, fir)
      // }
      return safeCall(code, msg, () => ({ oyoRoomTypes }));
    },
    /**
     * 获取所有销售房型
     * @param {*} _
     * @param {*} param1
     * /roomType/getSellRoomTypeList
     */
    *fetchAllSellRoomTypeAction(_, { call, put }) {
      const { code, msg, data } = yield call(fetchAllSellRoomType);
      const sellRoomTypes = [sellRoomTypeDefault, ...data];
      // yield put({
      //   type: 'saveHotelReducer',
      //   payload: { sellRoomTypes },
      // });
      // const [fir] = sellRoomTypes
      // if (fir) {
      //   Object.assign(sellRoomTypeDefault, fir)
      // }
      return safeCall(code, msg, () => ({ sellRoomTypes }));
    },
    /**
     * 第二步：基础信息维护---自定义佣金&标准入离时间 保存接口
     * @param {Object} param0
     * @param {*} param1
     * /hotel/updateHotelBaseInfo
     */
    *saveHotelBaseInfoAction({ params }, { call, put }) {
      const { code, msg } = yield call(saveHotelBaseInfo, params);
      return safeCall(code, msg, () => ({ msg }));
    },
    /**
     * 第四步：基准价设置--批量设置价格
     * @param {Object} param0
     * @param {*} param1
     * /price/presetRate
     */
    *saveHotelBatchPriceAction({ params }, { call, put }) {
      const { code, msg } = yield call(saveHotelBatchPrice, params);
      return safeCall(code, msg, () => ({ msg }));
    },
    /**
     * 第四步：基准价设置--批量设置价格
     * @param {Object} param0
     * @param {*} param1
     * /price/updateListRateByDay
     */
    *updateHotelPriceByDayAction({ params }, { call, put }) {
      const { code, msg } = yield call(updateHotelPriceByDay, params);
      return safeCall(code, msg, () => ({ msg }));
    },
    /**
     * 第五步：基准价设置--批量设置价格
     * @param {Object} param0
     * @param {*} param1
     * /roomType/roomTypeBindRateCodes
     */
    *updateHotelRoomTypeAction({ params }, { call, put }) {
      const { code, msg } = yield call(updateHotelRoomType, params);
      return safeCall(code, msg, () => ({ msg }));
    },
    /**
     * 酒店房型价格策略列表
     * @param {String|Number} param0
     * @param {*} param1
     * /roomType/roomTypeListWithRateCode
     */
    *fetchRoomTypeMatchPriceListAction(
      {
        params: { hotelId },
      },
      { call, put }
    ) {
      const { code, msg, data: categories } = yield call(fetchRoomTypeMatchPriceList, hotelId);
      // yield put({
      //   type: 'saveHotelReducer',
      //   payload: { categories: res.data },
      // });
      return safeCall(code, msg, () => ({ categories }));
    },
    /**
     * 酒店房型价格策略下拉列表
     * @param {String|Number} param0
     * @param {*} param1
     * /roomType/getRoomTypeRateCodeList
     */
    *fetchPriceCategoriesAction(
      {
        params: { hotelId },
      },
      { call, put }
    ) {
      const { code, msg, data: priceCategories } = yield call(fetchPriceCategories, hotelId);
      // yield put({
      //   type: 'saveHotelReducer',
      //   payload: { priceCategories: data },
      // });
      return safeCall(code, msg, () => ({ priceCategories }));
    },
    /**
     * 获取渠道
     * @param {Object} _
     * @param {*} param1
     * /channel/getAllValidatedChannel
     */
    *fetchChannelsAction(_, { call, put }) {
      const { code, msg, data } = yield call(fetchChannels);
      const channels = [{ channelCode: '', channelId: '', channelName: '请选择渠道' }, ...data];
      const payload = { channels };
      // yield put({
      //   type: 'saveHotelReducer',
      //   payload
      // });
      return safeCall(code, msg, () => payload);
    },
    /**
     * 获取某月基准价
     * @param {*} param0
     * @param {*} param1
     * price/getListRateByMonth
     */
    *fetchMonthPricesAction(
      {
        params: { hotelId, month },
      },
      { call, put }
    ) {
      const { code, msg, data } = yield call(fetchMonthPrices, hotelId, month);
      return safeCall(code, msg, () => data);
    },
    /**
     * 获取某天基准价
     * @param {*} param0
     * @param {*} param1
     * price/getListRateByDay
     */
    *fetchDayPriceAction({ hotelId, date, roomTypeIdList }, { call, put }) {
      const { code, msg, data } = yield call(fetchDayPrice, hotelId, date, roomTypeIdList);
      return safeCall(code, msg, () => data);
    },
  },

  reducers: {
    saveHotelReducer(state, { payload }) {
      return {
        ...state,
        ...payload,
      };
    },
  },
};
