import { authFetch, transAuthFetch } from '@/utils/fetch';

function request(url, option) {
  return authFetch(url, option)
    .then(_ => _)
    .catch(({ response }) => response);
}
/**
 * 同步旧的crs酒店信息
 * @param {String} id
 */
export function syncHotelInfo(params) {
  // return request(`/hotel/sync?hotelOyoId=${id}`);
  return transAuthFetch(`/transfer/hotel/byOyoId`, { type: 1, method: 'GET', params });
}
/**
 * 获取同步之后的酒店信息
 * @param {String} id
 */
export async function fetchHotelBaseInfo(id) {
  // return request(`/hotel/getHotelBaseInfo?hotelId=${id}`);
  return request(`/api/crs/v1/hotel/getHotelBaseInfo?hotelId=${id}`);
}
/**
 * 获取oyo所有房型
 */
export async function fetchAllOyoRoomType() {
  // return request(`/roomType/getAllOyoRoomType`);
  return request(`/api/crs/v1/roomType/getAllOyoRoomType`);
}
/**
 * 获取所有销售房型
 */
export async function fetchAllSellRoomType(hotelId) {
  // return request(`/roomType/getSellRoomTypeList`);
  return request(`/api/crs/v1/roomType/getSellRoomTypeList`);
}

/**
 *
 * @param {Object} params
 */
export async function saveHotelBaseInfo(params) {
  // return request(`/hotel/updateHotelBaseInfo`, { params, method: "POST"});
  return request(`/api/crs/v1/hotel/updateHotelBaseInfo`, { params, method: 'POST' });
}
/**
 * 第三步：维护酒店房型--保存接口
 * @param {Object} params
 */
export async function saveHotelRooms(params) {
  // return request(`/roomType/saveRoomTypeList`, {params, method: "POST"});
  return request(`/api/crs/v1/roomType/saveRoomTypeList`, { params, method: 'POST' });
}
/**
 * 第四步：基准价设置--批量设置价格
 * @param {Object} params
 */
export async function saveHotelBatchPrice(params) {
  // return request(`/price/presetRate`, {params, method: "POST"});
  return request(`/api/crs/v1/price/presetRate`, { params, method: 'POST' });
}
/**
 * 第五步：房型价格设置
 * @param {Object} params
 */
export async function updateHotelRoomType(params) {
  // return request(`/roomType/roomTypeBindRateCodes`, {params, method: "POST"});
  return request(`/api/crs/v1/roomType/roomTypeBindRateCodes`, { params, method: 'POST' });
}
/**
 * 第六步：酒店上线
 * @param {Object} params
 */
export async function upateHotelStatus(params) {
  // return request(`/hotel/hotelLive/${params.hotelId}`, {params, method: "POST"});
  return request(`/api/crs/v1/hotel/hotelLive/${params.hotelId}`);
}
/**
 * 酒店房型价格策略列表
 * @param {String|Number} hotelId
 */
export async function fetchRoomTypeMatchPriceList(hotelId) {
  // return request(`/roomType/roomTypeListWithRateCode?hotelId=${hotelId}`);
  return request(`/api/crs/v1/roomType/roomTypeListWithRateCode?hotelId=${hotelId}`);
}
/**
 * 酒店价格策略下拉列表
 * @param {String|Number} hotelId
 */
export async function fetchPriceCategories(hotelId) {
  // return request(`/roomType/getRoomTypeRateCodeList?hotelId=${hotelId}`);
  return request(`/api/crs/v1/roomType/getRoomTypeRateCodeList?hotelId=${hotelId}`);
}
/**
 * 酒店房型列表
 * @param {String|Number} hotelId
 */
export async function fetchHotelRooms(hotelId) {
  // return request(`/roomType/getHotelBindRoomTypeList?hotelId=${hotelId}`);
  return request(`/api/crs/v1/roomType/getHotelBindRoomTypeList?hotelId=${hotelId}`);
}
/**
 * 获取所有有效渠道名称
 */
export async function fetchChannels() {
  // return request(`/channel/getAllValidatedChannel`);
  return request(`/api/crs/v1/channel/getAllValidatedChannel`);
}
/**
 * 更新某天基准价
 * @param {Object} params
 */
export async function updateHotelPriceByDay(params) {
  // return request(`/price/updateListRateByDay`, {params, method: "POST"});
  return request(`/api/crs/v1/price/updateListRateByDay`, { params, method: 'POST' });
}
/**
 * 获取某月基准价
 * @param {String} hotelId
 * @param {String} month
 */
export async function fetchMonthPrices(hotelId, month) {
  return request(`/api/crs/v1/price/getListRateByMonth?hotelId=${hotelId}&rateDate=${month}`);
}
/**
 * 获取某天基准价
 * @param {String} hotelId
 * @param {Date} rateDate
 * @param {Array} roomTypeIdList
 */
export async function fetchDayPrice(hotelId, rateDate, roomTypeIdList) {
  return request(
    `/api/crs/v1/price/getListRateByDay?hotelId=${hotelId}&rateDate=${rateDate}&roomTypeIdList=${roomTypeIdList}`
  );
}
