import React, { PureComponent } from 'react';
import { Badge, Button, Card, Col, Form, Input, message, Row, Select, Table, Tabs } from 'antd';
import { connect } from 'dva';
import { debounce } from '@/utils/decorator';
import ButtonAuthorized from '@/components/ButtonAuthorized';
import HotelInput from '@/components/HotelInput/HotelInput';
import OYOForm from '@/components/OyoForm/SearchForm';
import OYOTable from '@/components/OyoTable/OyoTable.tsx';
import { sendLockOptMessage } from './services/index';

const PageSize = 10;

@connect(({ hotelLists }) => ({
  hotelLists,
}))
export default class DoorLock extends PureComponent {
  constructor(props) {
    super(props);

    this.state = {
      searchHotelType: {},
    };

    this.columns = [
      {
        title: '序号',
        dataIndex: 'index',
        key: 'index',
        width: '5%',
      },
      {
        title: '酒店名称',
        dataIndex: 'hotelName',
        key: 'hotelName',
        width: '30%',
      },
      {
        title: '酒店ID',
        dataIndex: 'hotelId',
        key: 'hotelId',
        width: '15%',
      },
      {
        title: 'CRSID',
        dataIndex: 'oyoId',
        key: 'oyoId',
        width: '15%',
      },
      {
        title: '操作',
        render: (result, record) => {
          return (
            <>
              <Button onClick={() => this.setLock(record, 'LOCK_DECRYPT')}>远程解密</Button>
              <Button
                onClick={() => this.setLock(record, 'LOCK_ENCRYPT')}
                style={{ marginLeft: 10 }}
              >
                远程加密
              </Button>
            </>
          );
        },
      },
    ];
  }

  @debounce(300)
  setLock({ hotelId, hotelName }, type) {
    sendLockOptMessage({
      hotelId,
      hotelName,
      type,
    })
      .then(res => {
        message.success('操作成功');
      })
      .catch(e => {
        message.error('操作失败');
      });
  }

  handerHotel(val) {
    this.setState({
      searchHotelType: val,
    });
  }

  handlePageChange = ({ current, pageSize }) => {
    this.handlerHotelSearch(current - 1, pageSize);
  };

  handlerHotelSearch = (start = 0, hits = PageSize) => {
    const { searchHotelType } = this.state;

    this.props.dispatch({
      type: 'hotelLists/transHotelSearchGetList',
      payload: {
        searchHotelType,
        start,
        hits,
      },
    });
  };

  handlerResetHotelSearch = () => {
    this.setState({
      searchHotelType: {
        ...this.state.searchHotelType,
        val: '',
      },
    });

    this.props.dispatch({
      type: 'hotelLists/resetList',
    });

    this.HotelInputRef.resetVal();
  };

  render() {
    const { list, pagination, loading } = this.props.hotelLists;

    return (
      <>
        <Row style={{ display: 'flex' }}>
          <Col lg={8}>
            <HotelInput
              ref={ref => {
                this.HotelInputRef = ref;
              }}
              onChange={val => this.handerHotel(val)}
            />
          </Col>
          <Col lg={8}>
            <Button type="primary" onClick={this.handlerHotelSearch} style={{ marginLeft: 10 }}>
              搜索
            </Button>
            <Button onClick={this.handlerResetHotelSearch} style={{ marginLeft: 10 }}>
              重置
            </Button>
          </Col>
        </Row>
        <div style={{ height: 20 }} />
        <Table
          ref={re => {
            this.oyotable = re;
          }}
          rowKey="hotelId"
          bordered
          size="small"
          loading={loading}
          columns={this.columns}
          dataSource={list}
          onChange={this.handlePageChange}
          pagination={pagination}
        />
      </>
    );
  }
}
