import React, { PureComponent } from 'react';
import { Badge, Button, Card, Col, Form, Input, message, Row, Select, Table, Tabs } from 'antd';
import { connect } from 'dva';
import moment from 'moment';
import ButtonAuthorized from '@/components/ButtonAuthorized';
import PageHeaderWrapper from '@/components/PageHeaderWrapper';
import OYOTable from '@/components/OyoTable/OyoTable.tsx';
import { queryLogs } from './services/index';

const PAGE_SIZE = 10;

export default class DoorLock extends PureComponent {
  constructor(props) {
    super(props);

    this.state = {
      loading: false,
      tableParams: {},
      pageParams: ['pageNum', 'pageSize'],
    };

    this.OYOTableColumns = [
      {
        title: '序号',
        dataIndex: 'index',
        key: 'index',
        width: 70,
      },
      {
        title: '说明',
        dataIndex: 'info',
        key: 'info',
      },
    ];
  }

  componentDidMount() {
    this.oyotable.getPageList();
  }

  query() {}

  getResultsList = params => {
    return queryLogs(params)
      .then(res => {
        const { result, totalCount, pageNum } = res.data;

        if (Array.isArray(result)) {
          result.forEach((item, i) => {
            item.index = (pageNum - 1) * PAGE_SIZE + (i + 1);
            item.createTime = moment(item.createTime).format('YYYY年MM月DD日HH:mm:ss');
            item.info = `${item.createBy}, 在${item.createTime}对 [${item.hotelName}] (${
              item.hotelId
            }) ${item.behavior}${item.result === 'SUCCESS' ? '成功' : '失败'}`;
          });
        }

        return { data: result || [], total: totalCount };
      })
      .catch(err => {
        console.log(err);
      });
  };

  render() {
    const { loading, tableParams, pageParams } = this.state;

    return (
      <>
        <OYOTable
          ref={re => {
            this.oyotable = re;
          }}
          rowKey="index"
          bordered
          size="small"
          loading={loading}
          params={tableParams}
          pageParams={pageParams}
          columns={this.OYOTableColumns}
          getList={this.getResultsList}
          preventGetList
        />
      </>
    );
  }
}
