import React, { PureComponent, Component } from 'react';
import { DatePicker, InputNumber, Input, Button, Table, message, Select } from 'antd';
import moment from 'moment';
import OYOTable from '@/components/OyoTable/OyoTable.tsx';
import LogModal from '@/components/OyoModal/OyoLogTableModal';
import ButtonAuthorized from '@/components/ButtonAuthorized';
import { checkFloatNumber } from '@/utils/validate';
import {
  getBenchmarkCondition,
  modifyBenchmarkCondition,
  getOperateLogList,
} from '../services/index';
import { currentMonth } from '../utils/commonMethods';

const PAGESZIE = 5;
const VALUE_STATUS = [
  {
    value: '0',
    name: '大于等于',
  },
  {
    value: '1',
    name: '等于',
  },
  {
    value: '2',
    name: '小于等于',
  },
];

export default class baseCondition extends PureComponent {
  constructor(props) {
    super(props);
    this.state = {
      tableParams: {
        validMonth: '',
      },
      benchmarkList: [],

      dialogVisible: false,
      logParams: {
        page: 1,
        limit: 5,
      },
      pagination: {
        total: 0,
        pageSize: PAGESZIE,
      },
      logList: [],
    };
  }

  componentDidMount() {
    this.setState(
      {
        tableParams: {
          validMonth: currentMonth(),
        },
      },
      () => {
        this.getResultsList();
      }
    );
  }

  getResultsList = () => {
    let { tableParams } = this.state;
    return getBenchmarkCondition(tableParams)
      .then(res => {
        if (res && res.data) {
          res.data = res.data.map(item => {
            let defaultSelect = '0';
            let { targetValueFrom, targetValueTo } = item;
            if (targetValueFrom && !targetValueTo) {
              defaultSelect = '0';
            }
            if (targetValueFrom && targetValueTo) {
              defaultSelect = '1';
            }
            if (!targetValueFrom && targetValueTo) {
              defaultSelect = '2';
            }
            return {
              ...item,
              lastData: {
                ...item,
                selected: defaultSelect,
              },
              selected: defaultSelect,
            };
          });
          this.setState({
            benchmarkList: res.data,
          });
        } else {
          this.setState({
            benchmarkList: [],
          });
        }
      })
      .catch(err => {
        console.log(err);
      });
  };

  onMonthChange = (date, dateString) => {
    this.setState({
      tableParams: {
        validMonth: dateString,
      },
    });
  };

  query = () => {
    this.getResultsList();
  };

  changeEditStatus = (e, index) => {
    let { benchmarkList } = this.state;

    benchmarkList = benchmarkList.slice();

    benchmarkList[index] = {
      ...benchmarkList[index],
      edit: !benchmarkList[index].edit,
    };

    this.setState({
      benchmarkList,
    });
  };

  getTargetOptions = (from, to) => {
    if (from && !to) {
      return '0';
    }
    if (from && to) {
      return '1';
    }
    if (!from && to) {
      return '2';
    }
  };

  selectChange = (value, index) => {
    let { benchmarkList } = this.state;
    benchmarkList = benchmarkList.slice();
    let { targetValueFrom, targetValueTo } = benchmarkList[index];

    // eslint-disable-next-line default-case
    switch (value) {
      case '0':
        benchmarkList[index] = {
          ...benchmarkList[index],
          targetValueFrom: targetValueFrom || targetValueTo,
          targetValueTo: null,
        };
        break;
      case '1':
        benchmarkList[index] = {
          ...benchmarkList[index],
          targetValueFrom: targetValueFrom || targetValueTo,
          targetValueTo: targetValueFrom || targetValueTo,
        };
        break;
      case '2':
        benchmarkList[index] = {
          ...benchmarkList[index],
          targetValueTo: targetValueFrom || targetValueTo,
          targetValueFrom: null,
        };
        break;
    }

    benchmarkList[index] = {
      ...benchmarkList[index],
      selected: value,
    };

    this.setState({
      benchmarkList,
    });
  };

  valueChange = (e, index) => {
    let { value } = e.target;
    let benchmarkList = this.state.benchmarkList.slice();
    let { selected } = benchmarkList[index];

    value = value.replace(/^\s\s*/, '').replace(/\s\s*$/, '');

    if (!checkFloatNumber(value)) return;

    // eslint-disable-next-line default-case
    switch (selected) {
      case '0':
        benchmarkList[index] = {
          ...benchmarkList[index],
          targetValueFrom: value,
          targetValueTo: null,
        };
        break;
      case '1':
        benchmarkList[index] = {
          ...benchmarkList[index],
          targetValueFrom: value,
          targetValueTo: value,
        };
        break;
      case '2':
        benchmarkList[index] = {
          ...benchmarkList[index],
          targetValueTo: value,
          targetValueFrom: null,
        };
        break;
    }

    this.setState({
      benchmarkList,
    });
  };

  closeEdit = (e, index) => {
    let benchmarkList = this.state.benchmarkList.slice();
    const item = benchmarkList[index];

    benchmarkList[index] = {
      ...item,
      lastData: item.lastData,
      ...item.lastData,
    };

    this.setState(
      {
        benchmarkList,
      },
      () => {
        this.changeEditStatus(e, index);
      }
    );
  };

  commitBenchmarkCondition = () => {
    let { tableParams, benchmarkList } = this.state;
    let params = {
      validMonth: tableParams.validMonth,
      benchmarkConditionList: benchmarkList,
    };

    modifyBenchmarkCondition(params)
      .then(res => {
        if (res.code === '000') {
          // 保存配置成功之后所有输入框全都变为不可编辑状态
          benchmarkList = benchmarkList.slice();
          let arr = benchmarkList.map(item => {
            item.edit = false;
            return item;
          });

          this.setState({
            benchmarkList: arr,
          });
          message.success('保存配置成功！');
        }
      })
      .catch(err => {
        console.log(err);
      });
  };

  showLogInfo = (validMonth, materialCode) => {
    let { page, limit } = this.state.logParams;
    let params = {
      validMonth,
      materialCode,
      page,
      limit,
    };

    this.setState(
      {
        dialogVisible: true,
        logParams: { page, limit, validMonth, materialCode },
      },
      () => {
        this.getLogList(params);
      }
    );
  };

  getLogList = params => {
    let { validMonth, materialCode, limit } = this.state.logParams;
    let param = {
      validMonth,
      materialCode,
      limit,
      page: params.pageNum,
    };

    getOperateLogList(param)
      .then(res => {
        if (res && res.data) {
          let { operateLogList, pageNum, pageSize, totalCount, totalPages } = res.data;
          if (operateLogList && Array.isArray(operateLogList)) {
            this.setState({
              logList: operateLogList,
              pagination: {
                total: totalCount,
                pageSize: PAGESZIE,
              },
            });
          }
        } else {
          this.setState({
            logList: [],
            pagination: {
              total: 0,
              pageSize: PAGESZIE,
            },
          });
        }
      })
      .catch(err => {
        console.log(err);
      });
  };

  onClose = () => {
    this.setState({
      dialogVisible: false,
      logList: [],
      pagination: {
        total: 0,
        pageSize: PAGESZIE,
      },
    });
  };

  render() {
    let { tableParams, pagination, benchmarkList, dialogVisible, logList } = this.state;
    let {
      onMonthChange,
      query,
      getResultsList,
      commitBenchmarkCondition,
      getLogList,
      onClose,
    } = this;
    let preventGetList = true;
    const { MonthPicker } = DatePicker;

    let OYOTableColumns = [
      {
        title: '生效月份',
        dataIndex: 'validMonth',
        key: 'validMonth',
        width: '30%',
      },
      {
        title: '基准条件',
        dataIndex: 'benchmarkConditionName',
        key: 'benchmarkConditionName',
        width: '30%',
      },

      {
        title: '目标值',
        dataIndex: 'targetValueFrom',
        key: 'targetValueFrom',
        width: '30%',
        render: (targetValueFrom, record, index) => {
          let addonAfter = record.configKey === 'CID' ? '' : '%';
          return (
            <div style={{ display: 'flex' }}>
              <Select
                style={{ width: '50%' }}
                disabled={!record.edit}
                value={record.selected}
                defaultValue={this.getTargetOptions(record.targetValueFrom, record.targetValueTo)}
                onChange={value => {
                  this.selectChange(value, index);
                }}
              >
                {VALUE_STATUS.map((ele, i) => (
                  <Select.Option key={i} value={ele.value}>
                    {ele.name}
                  </Select.Option>
                ))}
              </Select>
              {targetValueFrom ? (
                <Input
                  style={{ width: '50%' }}
                  addonAfter={addonAfter}
                  disabled={!record.edit}
                  value={targetValueFrom}
                  onChange={value => this.valueChange(value, index)}
                />
              ) : (
                <Input
                  style={{ width: '50%' }}
                  addonAfter={addonAfter}
                  disabled={!record.edit}
                  value={record.targetValueTo}
                  onChange={value => this.valueChange(value, index)}
                />
              )}
            </div>
          );
        },
      },
      {
        title: '操作',
        dataIndex: 'xxx',
        key: 'xxx',
        width: '10%',
        render: (text, record, index) => {
          return (
            <div style={{ display: 'flex' }}>
              {!record.edit ? (
                <ButtonAuthorized
                  size="small"
                  type="primary"
                  code="CRS13.5.2"
                  onClick={e => this.changeEditStatus(e, index)}
                  style={{ cursor: 'pointer', marginRight: '10px' }}
                  myDisabled={moment(record.validMonth, 'YYYY-MM').isBefore(
                    moment(currentMonth(), 'YYYY-MM')
                  )}
                >
                  修改
                </ButtonAuthorized>
              ) : (
                <Button
                  size="small"
                  type="primary"
                  onClick={e => this.closeEdit(e, index)}
                  style={{ cursor: 'pointer', marginRight: '10px' }}
                >
                  取消
                </Button>
              )}
              <div>
                <Button
                  size="small"
                  type="primary"
                  onClick={() => this.showLogInfo(record.validMonth, record.materialCode)}
                  style={{ cursor: 'pointer' }}
                >
                  日志
                </Button>
              </div>
            </div>
          );
        },
      },
    ];

    let dialogColumns = [
      {
        title: '操作人',
        dataIndex: 'operatorName',
        key: 'operatorName',
        width: '30%',
      },
      {
        title: '操作时间',
        dataIndex: 'operateTime',
        key: 'operateTime',
        width: '30%',
      },
      {
        title: '操作详情',
        dataIndex: 'detail',
        key: 'detail',
        render: detail => {
          return detail.map((item, index) => {
            return (
              <p style={{ textAlign: 'center' }} key={index}>
                {item}
              </p>
            );
          });
        },
      },
    ];

    return (
      <>
        <div style={{ display: 'flex', marginTop: '10px', marginBottom: '20px' }}>
          <div style={{ marginRight: '10px', lineHeight: '30px' }}>生效月份</div>
          <div style={{ marginRight: '10px' }}>
            <MonthPicker
              placeholder="请选择生效月份"
              defaultValue={moment(currentMonth(), 'YYYY-MM')}
              onChange={onMonthChange}
            />
          </div>
          <Button type="primary" onClick={query}>
            查询
          </Button>
        </div>
        <Table
          ref={re => {
            this.oyotable = re;
          }}
          bordered
          size="small"
          rowKey="materialCode"
          params={tableParams}
          columns={OYOTableColumns}
          getList={getResultsList}
          dataSource={benchmarkList}
          preventGetList={preventGetList}
        />
        <ButtonAuthorized
          type="primary"
          code="CRS13.5.1"
          onClick={commitBenchmarkCondition}
          style={{ cursor: 'pointer' }}
        >
          保存配置
        </ButtonAuthorized>

        <LogModal
          title="日志"
          rowKey="operateTime"
          visible={dialogVisible}
          columns={dialogColumns}
          dataSource={logList}
          pagination={pagination}
          getLogList={getLogList}
          onCancel={onClose}
        />
      </>
    );
  }
}
