import React, { PureComponent } from 'react';
import { DatePicker, InputNumber, Input, Button, Table, message } from 'antd';
import moment from 'moment';
import OYOTable from '@/components/OyoTable/OyoTable.tsx';
import LogModal from '@/components/OyoModal/OyoLogTableModal';
import ButtonAuthorized from '@/components/ButtonAuthorized';
import { checkFloatNumber } from '@/utils/validate';

import { getBonusIndicator, modifyBonusIndicator, getOperateLogList } from '../services/index';
import { currentMonth } from '../utils/commonMethods';

const PAGESZIE = 5;

export default class bonusIndicators extends PureComponent {
  constructor(props) {
    super(props);
    this.state = {
      tableParams: {
        validMonth: '',
      },
      indicatorList: [],

      dialogVisible: false,
      logParams: {
        page: 1,
        limit: 5,
      },
      pagination: {
        total: 0,
        pageSize: PAGESZIE,
      },
      logList: [],
    };
  }

  componentDidMount() {
    this.setState(
      {
        tableParams: {
          validMonth: currentMonth(),
        },
      },
      () => {
        this.getResultsList();
      }
    );
  }

  getResultsList = () => {
    return getBonusIndicator(this.state.tableParams)
      .then(res => {
        if (res && res.data) {
          res.data = res.data.map(item => ({
            ...item,
            lastData: {
              ...item,
            },
          }));
          this.setState({
            indicatorList: res.data,
          });
        } else {
          this.setState({
            indicatorList: [],
          });
          message.error('没数据');
        }
      })
      .catch(err => {
        console.log(err);
      });
  };

  onMonthChange = (date, dateString) => {
    this.setState({
      tableParams: {
        validMonth: dateString,
      },
    });
  };

  query = () => {
    this.getResultsList();
  };

  changeEditStatus = (e, index) => {
    let { indicatorList } = this.state;

    indicatorList = indicatorList.slice();
    indicatorList[index] = {
      ...indicatorList[index],
      edit: !indicatorList[index].edit,
    };

    this.setState({
      indicatorList,
    });
  };

  valueChange = (e, index, key) => {
    let { value } = e.target;
    let indicatorList = this.state.indicatorList.slice();

    if (value) {
      value = value.replace(/^\s\s*/, '').replace(/\s\s*$/, '');

      if (!checkFloatNumber(value)) return;

      indicatorList[index][key] = value;
    }

    this.setState({
      indicatorList,
    });
  };

  closeEdit = (e, index) => {
    let indicatorList = this.state.indicatorList.slice();

    const item = indicatorList[index];

    indicatorList[index] = {
      ...item,
      lastData: item.lastData,
      ...item.lastData,
    };

    this.setState(
      {
        indicatorList,
      },
      () => {
        this.changeEditStatus(e, index);
      }
    );
  };

  commitBonusIndicator = () => {
    let { tableParams, indicatorList } = this.state;
    let weightTotal = 0;
    let isCanUpdate = true;

    indicatorList.forEach((item, index) => {
      weightTotal += Number(item.weight);
      if (Number(item.endRate) < Number(item.startRate)) {
        isCanUpdate = false;
      }
    });

    if (!isCanUpdate) return message.warning('截止值必须大于起始值!');

    if (weightTotal !== 100) {
      return message.warning(
        `${tableParams.validMonth}奖金指标权重相加不等于100%，请修改后重新保存配置`
      );
    }
    let params = {
      validMonth: tableParams.validMonth,
      bonusIndicatorList: indicatorList,
    };
    modifyBonusIndicator(params)
      .then(res => {
        if (res.code === '000') {
          // 保存配置成功之后所有输入框全都变为不可编辑状态
          indicatorList = indicatorList.slice();
          let arr = indicatorList.map(item => {
            item.edit = false;
            return item;
          });

          this.setState({
            indicatorList: arr,
          });
          message.success('保存配置成功！');
        }
      })
      .catch(err => {
        console.log(err);
      });
  };

  showLogInfo = (validMonth, materialCode) => {
    let { page, limit } = this.state.logParams;
    let params = {
      validMonth,
      materialCode,
      page,
      limit,
    };
    this.setState(
      {
        dialogVisible: true,
        logParams: { page, limit, validMonth, materialCode },
      },
      () => {
        this.getLogList(params);
      }
    );
  };

  getLogList = params => {
    let { validMonth, materialCode, limit } = this.state.logParams;

    let param = {
      validMonth,
      materialCode,
      limit,
      page: params.pageNum,
    };
    getOperateLogList(param)
      .then(res => {
        if (res && res.data) {
          let { operateLogList, pageNum, pageSize, totalCount, totalPages } = res.data;
          if (operateLogList && Array.isArray(operateLogList)) {
            this.setState({
              logList: operateLogList,
              pagination: {
                total: totalCount,
                pageSize: PAGESZIE,
              },
            });
          }
        } else {
          this.setState({
            logList: [],
            pagination: {
              total: 0,
              pageSize: PAGESZIE,
            },
          });
        }
      })
      .catch(err => {
        console.log(err);
      });
  };

  onClose = () => {
    this.setState({
      dialogVisible: false,
      logList: [],
      pagination: {
        total: 0,
        pageSize: PAGESZIE,
      },
    });
  };

  render() {
    let { tableParams, pagination, indicatorList, dialogVisible, logList } = this.state;
    let { onMonthChange, query, getResultsList, commitBonusIndicator, getLogList, onClose } = this;

    let preventGetList = true;
    const { MonthPicker } = DatePicker;

    let OYOTableColumns = [
      {
        title: '生效月份',
        dataIndex: 'validMonth',
        key: 'validMonth',
        width: '10%',
      },
      {
        title: '考核指标',
        dataIndex: 'indicatorName',
        key: 'indicatorName',
        width: '10%',
      },
      {
        title: '权重',
        dataIndex: 'weight',
        key: 'weight',
        width: '10%',
        render: (weight, record, index) => {
          return (
            <Input
              addonAfter="%"
              disabled={!record.edit}
              value={weight}
              onChange={value => this.valueChange(value, index, 'weight')}
            />
          );
        },
      },
      {
        title: '起始值',
        dataIndex: 'beginRate',
        key: 'beginRate',
        width: '10%',
        render: (beginRate, record, index) => {
          return (
            <Input
              addonAfter="%"
              disabled={!record.edit}
              value={beginRate}
              onChange={value => this.valueChange(value, index, 'beginRate')}
            />
          );
        },
      },
      {
        title: '起始分',
        dataIndex: 'beginScore',
        key: 'beginScore',
        width: '10%',
        render: (beginScore, record, index) => {
          return (
            <Input
              // addonAfter="%"
              disabled={!record.edit}
              value={beginScore}
              onChange={value => this.valueChange(value, index, 'beginScore')}
            />
          );
        },
      },
      {
        title: '截止值',
        dataIndex: 'endRate',
        key: 'endRate',
        width: '10%',
        render: (endRate, record, index) => {
          return (
            <Input
              addonAfter="%"
              disabled={!record.edit}
              value={endRate}
              onChange={value => this.valueChange(value, index, 'endRate')}
            />
          );
        },
      },
      {
        title: '截止分',
        dataIndex: 'endScore',
        key: 'endScore',
        width: '10%',
        render: (endScore, record, index) => {
          return (
            <Input
              // addonAfter="%"
              disabled={!record.edit}
              value={endScore}
              onChange={value => this.valueChange(value, index, 'endScore')}
            />
          );
        },
      },
      {
        title: '操作',
        dataIndex: 'xxx',
        key: 'xxx',
        width: '15%',
        render: (text, record, index) => {
          return (
            <div style={{ display: 'flex' }}>
              {!record.edit ? (
                <ButtonAuthorized
                  size="small"
                  type="primary"
                  code="CRS13.5.2"
                  onClick={e => this.changeEditStatus(e, index)}
                  style={{ cursor: 'pointer', marginRight: '10px' }}
                  myDisabled={moment(record.validMonth, 'YYYY-MM').isBefore(
                    moment(currentMonth(), 'YYYY-MM')
                  )}
                >
                  修改
                </ButtonAuthorized>
              ) : (
                <Button
                  size="small"
                  type="primary"
                  onClick={e => this.closeEdit(e, index)}
                  style={{ cursor: 'pointer', marginRight: '10px' }}
                >
                  取消
                </Button>
              )}
              <div>
                <Button
                  size="small"
                  type="primary"
                  onClick={() => this.showLogInfo(record.validMonth, record.materialCode)}
                  style={{ cursor: 'pointer' }}
                >
                  日志
                </Button>
              </div>
            </div>
          );
        },
      },
    ];

    let dialogColumns = [
      {
        title: '操作人',
        dataIndex: 'operatorName',
        key: 'operatorName',
        width: '30%',
      },
      {
        title: '操作时间',
        dataIndex: 'operateTime',
        key: 'operateTime',
        width: '30%',
      },
      {
        title: '操作详情',
        dataIndex: 'detail',
        key: 'detail',
        render: detail => {
          return detail.map((item, index) => {
            return (
              <p style={{ textAlign: 'center' }} key={index}>
                {item}
              </p>
            );
          });
        },
      },
    ];

    return (
      <>
        <div style={{ display: 'flex', marginTop: '10px', marginBottom: '20px' }}>
          <div style={{ marginRight: '10px', lineHeight: '30px' }}>生效月份</div>
          <div style={{ marginRight: '10px' }}>
            <MonthPicker
              placeholder="请选择生效月份"
              defaultValue={moment(currentMonth(), 'YYYY-MM')}
              onChange={onMonthChange}
            />
          </div>
          <Button type="primary" onClick={query}>
            查询
          </Button>
        </div>
        <Table
          ref={re => {
            this.oyotable = re;
          }}
          bordered
          size="small"
          rowKey="materialCode"
          params={tableParams}
          columns={OYOTableColumns}
          getList={getResultsList}
          dataSource={indicatorList}
          preventGetList={preventGetList}
        />
        <ButtonAuthorized
          type="primary"
          code="CRS13.5.1"
          onClick={commitBonusIndicator}
          style={{ cursor: 'pointer' }}
        >
          保存配置
        </ButtonAuthorized>

        <LogModal
          title="日志"
          rowKey="operateTime"
          visible={dialogVisible}
          columns={dialogColumns}
          dataSource={logList}
          pagination={pagination}
          getLogList={getLogList}
          onCancel={onClose}
        />
      </>
    );
  }
}
