import React, { PureComponent } from 'react';
import { DatePicker, InputNumber, Input, Button, Table, message } from 'antd';
import moment from 'moment';
import OYOTable from '@/components/OyoTable/OyoTable.tsx';
import LogModal from '@/components/OyoModal/OyoLogTableModal';
import ButtonAuthorized from '@/components/ButtonAuthorized';
import { checkFloatNumber } from '@/utils/validate';
import { getTotalBonus, modifyTotalBonus, getOperateLogList } from '../services/index';
import { currentMonth, tansformStr } from '../utils/commonMethods';

const PAGESZIE = 5;

export default class highestBonus extends PureComponent {
  constructor(props) {
    super(props);
    this.state = {
      tableParams: {
        validMonth: '',
      },
      totalBonusList: [],

      dialogVisible: false,
      logParams: {
        page: 1,
        limit: 5,
      },
      pagination: {
        total: 0,
        pageSize: PAGESZIE,
      },
      logList: [],
    };
  }

  componentDidMount() {
    this.setState(
      {
        tableParams: {
          validMonth: currentMonth(),
        },
      },
      () => {
        this.getResultsList();
      }
    );
  }

  getResultsList = () => {
    let { tableParams } = this.state;
    return getTotalBonus(tableParams)
      .then(res => {
        if (res && res.data) {
          res.data = res.data.map(item => ({
            ...item,
            lastData: {
              ...item,
            },
          }));
          this.setState({
            totalBonusList: res.data,
          });
        } else {
          this.setState({
            totalBonusList: [],
          });
        }
      })
      .catch(err => {
        console.log(err);
      });
  };

  onMonthChange = (date, dateString) => {
    this.setState({
      tableParams: {
        validMonth: dateString,
      },
    });
  };

  query = () => {
    this.getResultsList();
  };

  changeEditStatus = (e, index) => {
    let totalBonusList = this.state.totalBonusList.slice();

    totalBonusList[index] = {
      ...totalBonusList[index],
      edit: !totalBonusList[index].edit,
    };

    this.setState({
      totalBonusList,
    });
  };

  valueChange = (e, index, key) => {
    let { value } = e.target;
    let totalBonusList = this.state.totalBonusList.slice();

    // 去除前后空格
    if (value) {
      value = value.replace(/^\s\s*/, '').replace(/\s\s*$/, '');

      if (!checkFloatNumber(value)) return;

      totalBonusList[index][key] = value;
    }

    this.setState({
      totalBonusList,
    });
  };

  closeEdit = (e, index) => {
    let totalBonusList = this.state.totalBonusList.slice();

    const item = totalBonusList[index];

    totalBonusList[index] = {
      ...item,
      lastData: item.lastData,
      ...item.lastData,
    };

    this.setState(
      {
        totalBonusList,
      },
      () => {
        this.changeEditStatus(e, index);
      }
    );
  };

  commitTotalBonus = () => {
    let { tableParams, totalBonusList } = this.state;
    let params = {
      validMonth: tableParams.validMonth,
      totalBonusList,
    };

    modifyTotalBonus(params)
      .then(res => {
        if (res.code === '000') {
          // 保存配置成功之后所有输入框全都变为不可编辑状态
          totalBonusList = totalBonusList.slice();
          let arr = totalBonusList.map(item => {
            item.edit = false;
            return item;
          });

          this.setState({
            totalBonusList: arr,
          });
          message.success('保存配置成功！');
        }
      })
      .catch(err => {
        console.log(err);
      });
  };

  showLogInfo = (validMonth, materialCode) => {
    let { page, limit } = this.state.logParams;
    let params = {
      validMonth,
      materialCode,
      page,
      limit,
    };
    this.setState(
      {
        dialogVisible: true,
        logParams: { page, limit, validMonth, materialCode },
      },
      () => {
        this.getLogList(params);
      }
    );
  };

  getLogList = params => {
    let { validMonth, materialCode, limit } = this.state.logParams;
    let param = {
      validMonth,
      materialCode,
      limit,
      page: params.pageNum,
    };

    getOperateLogList(param)
      .then(res => {
        if (res && res.data) {
          let { operateLogList, pageNum, pageSize, totalCount, totalPages } = res.data;
          if (operateLogList && Array.isArray(operateLogList)) {
            this.setState({
              logList: operateLogList,
              pagination: {
                total: totalCount,
                pageSize: PAGESZIE,
              },
            });
          }
        } else {
          this.setState({
            logList: [],
            pagination: {
              total: 0,
              pageSize: PAGESZIE,
            },
          });
        }
      })
      .catch(err => {
        console.log(err);
      });
  };

  onClose = () => {
    this.setState({
      dialogVisible: false,
      logList: [],
      pagination: {
        total: 0,
        pageSize: PAGESZIE,
      },
    });
  };

  render() {
    let { tableParams, pagination, totalBonusList, dialogVisible, logList } = this.state;
    let { onMonthChange, query, getResultsList, commitTotalBonus, getLogList, onClose } = this;
    const { MonthPicker } = DatePicker;
    let preventGetList = true;

    let OYOTableColumns = [
      {
        title: '生效月份',
        dataIndex: 'validMonth',
        key: 'validMonth',
        width: '30%',
      },
      {
        title: '酒店房间数',
        dataIndex: 'hotelRoomCountFrom',
        key: 'hotelRoomCountFrom',
        width: '30%',
        render: (hotelRoomCountFrom, record) => {
          return (
            <p style={{ margin: 0 }}>
              {tansformStr(hotelRoomCountFrom, record.hotelRoomCountTo)}间
            </p>
          );
        },
      },
      {
        title: '最高奖金金额（元/月）',
        dataIndex: 'totalBonusAmount',
        key: 'totalBonusAmount',
        width: '30%',
        render: (totalBonusAmount, record, index) => {
          return (
            <Input
              disabled={!record.edit}
              value={totalBonusAmount}
              onChange={value => this.valueChange(value, index, 'totalBonusAmount')}
            />
          );
        },
      },
      {
        title: '操作',
        dataIndex: 'xxx',
        key: 'xxx',
        width: '10%',
        render: (text, record, index) => {
          return (
            <div style={{ display: 'flex' }}>
              {!record.edit ? (
                <ButtonAuthorized
                  size="small"
                  type="primary"
                  code="CRS13.5.2"
                  onClick={e => this.changeEditStatus(e, index)}
                  style={{ cursor: 'pointer', marginRight: '10px' }}
                  myDisabled={moment(record.validMonth, 'YYYY-MM').isBefore(
                    moment(currentMonth(), 'YYYY-MM')
                  )}
                >
                  修改
                </ButtonAuthorized>
              ) : (
                <Button
                  size="small"
                  type="primary"
                  onClick={e => this.closeEdit(e, index)}
                  style={{ cursor: 'pointer', marginRight: '10px' }}
                >
                  取消
                </Button>
              )}
              <div>
                <Button
                  size="small"
                  type="primary"
                  onClick={() => this.showLogInfo(record.validMonth, record.materialCode)}
                  style={{ cursor: 'pointer' }}
                >
                  日志
                </Button>
              </div>
            </div>
          );
        },
      },
    ];

    let dialogColumns = [
      {
        title: '操作人',
        dataIndex: 'operatorName',
        key: 'operatorName',
        width: '30%',
      },
      {
        title: '操作时间',
        dataIndex: 'operateTime',
        key: 'operateTime',
        width: '30%',
      },
      {
        title: '操作详情',
        dataIndex: 'detail',
        key: 'detail',
        render: detail => {
          return detail.map((item, index) => {
            return (
              <p style={{ textAlign: 'center' }} key={index}>
                {item}
              </p>
            );
          });
        },
      },
    ];

    return (
      <>
        <div style={{ display: 'flex', marginTop: '10px', marginBottom: '20px' }}>
          <div style={{ marginRight: '10px', lineHeight: '30px' }}>生效月份</div>
          <div style={{ marginRight: '10px' }}>
            <MonthPicker
              placeholder="请选择生效月份"
              defaultValue={moment(currentMonth(), 'YYYY-MM')}
              onChange={onMonthChange}
            />
          </div>
          <Button type="primary" onClick={query}>
            查询
          </Button>
        </div>
        <Table
          ref={re => {
            this.oyotable = re;
          }}
          bordered
          size="small"
          rowKey="materialCode"
          params={tableParams}
          columns={OYOTableColumns}
          getList={getResultsList}
          dataSource={totalBonusList}
          preventGetList={preventGetList}
        />
        <ButtonAuthorized
          type="primary"
          code="CRS13.5.1"
          onClick={commitTotalBonus}
          style={{ cursor: 'pointer' }}
        >
          保存配置
        </ButtonAuthorized>

        <LogModal
          title="日志"
          rowKey="operateTime"
          visible={dialogVisible}
          columns={dialogColumns}
          dataSource={logList}
          pagination={pagination}
          getLogList={getLogList}
          onCancel={onClose}
        />
      </>
    );
  }
}
