import React from 'react';
import {
  Tabs,
  Layout,
  Button,
  Table,
  Input,
  Switch,
  Select,
  Badge,
  Modal,
  Form,
  Row,
  Col,
  message,
  Upload,
  Popconfirm,
  Card,
} from 'antd';
import { connect } from 'dva';
import moment from 'moment';
import PageHeaderWrapper from '@/components/PageHeaderWrapper';
import styles from './index.less';

import { debounce } from '@/utils/decorator';
import { downloadApplication } from './service';
import { downloadFile } from '@/utils/downloadFile';
import Success from '@/pages/Result/Success';

const { Content } = Layout;
const { TextArea } = Input;
const FormItem = Form.Item;
const Option = Select.Option;

@connect(({ managePmsApp }) => ({ managePmsApp }))
export default class ManagePmsApp extends React.PureComponent {
  tableColumn = [
    {
      title: '类型',
      dataIndex: 'typeName',
      key: 'typeName',
    },
    {
      title: '应用名称',
      dataIndex: 'applicationName',
      key: 'applicationName',
    },
    {
      title: '说明',
      dataIndex: 'remark',
      key: 'remark',
      render: text => {
        return <p className={styles.mpaTableBreak}>{text}</p>;
      },
    },
    {
      title: '网址访问',
      dataIndex: 'visitUrl',
      key: 'visitUrl',
      render: text => {
        return <p className={styles.mpaTableBreak}>{text}</p>;
      },
    },
    {
      title: '更新时间',
      dataIndex: 'updateTime',
      key: 'updateTime',
    },
    {
      title: '操作',
      dataIndex: 'action',
      key: 'action',
      render: (text, record, index) => {
        return (
          <div>
            <Button style={{ marginRight: 7 }} size="small" onClick={() => this.handleEdit(record)}>
              修改
            </Button>
            <Button
              style={{ marginRight: 7 }}
              size="small"
              onClick={() => this.handleDelete(record)}
            >
              删除
            </Button>
            <Button
              style={{ marginRight: 7, display: record.downFlag ? '' : 'none' }}
              size="small"
              // loading={this.state.loadingList[index]}
              onClick={() => this.handleDownLoad(record, index)}
            >
              下载
            </Button>
          </div>
        );
      },
    },
  ];

  state = {
    // modal框的input值
    modalInputValList: {
      typeName: '',
      applicationName: '',
      remark: '',
      visitUrl: '',
    },
    // modal状态
    isShowModal: '',
    files: null,
    fileList: [],
    submitTest: '发布应用',
    deleteAppId: null,
    submitBtnStatus: false, // 发布应用按钮状态
    // loadingList: [],
  };

  // 加载完成请求列表接口
  componentDidMount() {
    this.initListData();
  }

  // 获取列表数据
  initListData() {
    const params = {
      pageSize: 10,
      pageNum: 1,
    };
    this._dispatch('applicationList', params, data => {
      /*  const length = data.totalCount;
      const loadingList = new Array(length).fill(false);
      this.setState({
        loadingList,
      }); */
    });
  }

  // 切换页码
  handlePageChange = pagination => {
    const params = {
      pageNum: pagination.current,
      pageSize: pagination.pageSize,
    };
    // 列表请求渲染
    this._dispatch('applicationList', params, data => {});
  };

  // 新增应用
  handleCreateApp = () => {
    this.setState({
      files: null,
      fileList: [],
      isShowModal: 'appDetailStatus',
      modalInputValList: {},
    });
  };

  // 修改操作
  handleEdit = val => {
    this.setState({
      files: null,
      fileList: [],
      isShowModal: 'appDetailStatus',
      modalInputValList: val,
    });
    console.log(val);
  };

  onChangeAppName = e => {
    this.handleInputValue('applicationName', e);
  };

  onChangeTypeName = e => {
    this.handleInputValue('typeName', e);
  };

  onChangeNetEntry = e => {
    this.handleInputValue('visitUrl', e);
  };

  onChangeExplain = e => {
    this.handleInputValue('remark', e);
  };

  // 公用方法处理
  handleInputValue = (name, e) => {
    const { modalInputValList } = this.state;
    e.persist();
    // console.log(e.target, 'val');
    let data = {
      ...modalInputValList,
    };
    data[name] = e.target.value;
    // console.log(data, 'data');
    this.setState({
      modalInputValList: data,
    });
  };

  // 删除操作
  handleDelete = value => {
    this.setState({
      isShowModal: 'deleteAppStatus',
      deleteAppId: value.id,
    });
  };

  // 下载操作
  handleDownLoad = async (value, index) => {
    // 第一种直接通过href请求方式
    const { url } = value;
    window.location.href = url;
    // 第二种接口请求方式
    // console.log(value, index)

    /* const {
      managePmsApp: { pageNum },
    } = this.props;
    const { loadingList } = this.state;
    const currentIndex = Number((pageNum - 1) * 10 + index);
    console.log(currentIndex, 'currentIndex')
    loadingList[currentIndex] = true;
     this.setState({
      loadingList: JSON.parse(JSON.stringify(loadingList))
    })
    this.setState({
      loadingList: [...loadingList],
    });
    const { url } = value;
    const param = {
      url,
    };
    try {
      const res = await downloadFile(`/api/crs/downloadApplication`, param, '');
      loadingList[currentIndex] = false;
      this.setState({
        loadingList: [...loadingList],
      });
    } catch (error) {
      console.log(error);
    } */
  };

  onCancel = () => {
    this.setState({
      isShowModal: '',
    });
  };

  // 确认发布应用
  onConfirm = () => {
    const {
      modalInputValList: { typeName, applicationName, remark, visitUrl, id },
      files,
    } = this.state;
    // console.log(this.state, 'state');
    // 校验不能为空
    const isNullFlag = [typeName, applicationName, remark, visitUrl].every(item => item);
    if (!isNullFlag) {
      message.error('请完成必填内容');
      return;
    }

    // console.log(modalInputValList)
    let formData = new FormData();
    const appManInfo = {
      typeName,
      applicationName,
      remark,
      visitUrl,
    };
    // 判断属于新增or编辑
    if (id || id === 0) {
      appManInfo.id = id;
    }
    const params = {};
    formData.append('appManInfo', JSON.stringify({ ...appManInfo }));
    formData.append('files', files);
    this.setState({
      submitTest: '发布中...',
      submitBtnStatus: true,
    });
    this._dispatch('uploadApplication', { formData, params }, data => {
      console.log(data);
      // 上传成功初始化列表数据
      this.setState(
        {
          submitTest: '发布应用',
          isShowModal: '',
          submitBtnStatus: false,
        },
        this.initListData()
      );
    });
  };

  // 删除确定
  onConfirmDeleteAPP = () => {
    const { deleteAppId } = this.state;
    const param = {
      id: deleteAppId,
    };
    this._dispatch('deleteApplication', param, data => {
      console.log(data, 'delete');
      // 删除成功后关闭窗口并重新渲染数据
      this.setState(
        {
          isShowModal: '',
        },
        this.initListData()
      );
    });
  };

  // 公共请求调用
  _dispatch = (url, payload, fn) => {
    const { dispatch } = this.props;
    const param = {
      type: `managePmsApp/${url}`,
      payload,
    };

    dispatch(param)
      .then(({ code, data }) => {
        fn && fn(data);
      })
      .catch(er => {
        // console.log(er);
        fn && fn(er);
      });
  };

  beforeUpload = file => {
    // console.log(file, 'file');
    const { files } = this.state;
    // console.log(file, 'beforeUpload');
    const isExe = file.type === 'application/x-msdownload';
    /* if (!isExe) {
      message.error('仅支持.exe文件上传');
      return;
    } */
    const isLtSize = file.size / 1024 / 1024 < 150;
    if (!isLtSize) {
      message.error('文件大小不超过150M');
      return false;
    }
    // message.success('上传成功');
    this.setState({
      files: file,
    });
    // 阻止接口请求
    return false;
  };

  // 移除文件
  onRemove = () => {
    this.setState({
      files: null,
    });
  };

  // 上传change时只保留最后一条数据
  onChangeUpload = info => {
    // console.log(info, 'info')
    // 文件大小获取
    const fileSize = info && info.file.size;
    // 文件大小判断是否超过150M
    const isLtSize = fileSize / 1024 / 1024 < 150;
    if (isLtSize) {
      let fileList = [...info.fileList];
      fileList = fileList.slice(-1);
      this.setState({
        fileList,
      });
    }
  };

  // 添加红点
  renderLable = text => (
    <span>
      <span style={{ color: 'red' }}>*</span>
      {text}
    </span>
  );

  render() {
    const { managePmsApp } = this.props;
    // console.log(managePmsApp, 'managePmsApp');
    const { isShowModal, modalInputValList, fileList, submitTest, submitBtnStatus } = this.state;
    // console.log(getResData)
    return (
      <PageHeaderWrapper>
        <Card className="managePmsApp">
          <section style={{ backgroundColor: '#fff', padding: 10 }}>
            <Layout>
              <Content style={{ backgroundColor: '#fff' }}>
                <p>
                  <Button onClick={this.handleCreateApp} type="primary">
                    新增应用
                  </Button>
                </p>
                <Table
                  rowKey="id"
                  bordered
                  size="small"
                  dataSource={managePmsApp.getAppList}
                  columns={this.tableColumn}
                  pagination={{
                    showSizeChanger: true,
                    current: managePmsApp.pageNum,
                    pageSize: managePmsApp.pageSize,
                    total: managePmsApp.totalCount,
                  }}
                  onChange={this.handlePageChange}
                />
              </Content>
            </Layout>

            {/* modal弹框 */}
            <Modal
              width={700}
              className="appModal"
              title="PMS应用详情"
              visible={isShowModal === 'appDetailStatus'}
              onCancel={this.onCancel}
              onOk={this.onConfirm}
              footer={[
                // 定义右下角 按钮的地方 可根据需要使用 一个或者 2个按钮
                <Button
                  key="submit"
                  type="primary"
                  disabled={submitBtnStatus}
                  onClick={this.onConfirm}
                >
                  {submitTest}
                </Button>,
              ]}
            >
              <Form>
                <FormItem
                  label={this.renderLable('应用名称')}
                  labelCol={{ span: 5 }}
                  wrapperCol={{ span: 19 }}
                >
                  <Row>
                    <Col span={14}>
                      <Input
                        placeholder="请输入应用名称"
                        maxLength={40}
                        value={modalInputValList.applicationName}
                        onChange={this.onChangeAppName}
                      />
                    </Col>
                    <Col span={10} className={styles.tipText}>
                      <span>40个中文字符以内</span>
                    </Col>
                  </Row>
                </FormItem>
                <FormItem
                  label={this.renderLable('类型')}
                  labelCol={{ span: 5 }}
                  wrapperCol={{ span: 19 }}
                >
                  <Row>
                    <Col span={14}>
                      <Input
                        placeholder="请填写应用类型"
                        maxLength={20}
                        value={modalInputValList.typeName}
                        onChange={this.onChangeTypeName}
                      />
                    </Col>
                    <Col span={10} className={styles.tipText}>
                      <span>20个中文字符以内</span>
                    </Col>
                  </Row>
                </FormItem>
                <FormItem
                  label={this.renderLable('访问网址')}
                  labelCol={{ span: 5 }}
                  wrapperCol={{ span: 19 }}
                >
                  <Row>
                    <Col span={14}>
                      <Input
                        placeholder="请填写相关访问网址"
                        maxLength={500}
                        value={modalInputValList.visitUrl}
                        onChange={this.onChangeNetEntry}
                      />
                    </Col>
                    <Col span={10} className={styles.tipText}>
                      <span>500个字符以内</span>
                    </Col>
                  </Row>
                </FormItem>
                <FormItem
                  label={this.renderLable('说明')}
                  labelCol={{ span: 5 }}
                  wrapperCol={{ span: 19 }}
                >
                  <Row>
                    <Col span={14}>
                      <TextArea
                        placeholder="请输入应用说明"
                        size="small"
                        rows={4}
                        maxLength={200}
                        value={modalInputValList.remark}
                        onChange={this.onChangeExplain}
                      />
                    </Col>
                    <Col span={10} className={styles.tipText}>
                      <span>200个中文字符以内</span>
                    </Col>
                  </Row>
                </FormItem>
                <FormItem>
                  <Row>
                    <Col span={5} className={styles.uploadBtn}>
                      应用上传:
                      <p className={styles.markText}>(选填项)</p>
                    </Col>
                    <Col span={4}>
                      <Upload
                        onChange={this.onChangeUpload}
                        showUploadList
                        // customRequest={this.customRequest}
                        fileList={fileList}
                        beforeUpload={this.beforeUpload}
                        onRemove={this.onRemove}
                      >
                        <Button type="primary" style={{ marginLeft: 10 }}>
                          上传文件
                        </Button>
                      </Upload>
                    </Col>
                    <Col span={15} className={styles.tipText}>
                      <span>只能上传一个文件,文件大小不超过150M</span>
                    </Col>
                  </Row>
                </FormItem>
              </Form>
            </Modal>
            {/* 删除应用modal */}
            <Modal
              width={400}
              className="appModal"
              title="删除应用"
              visible={isShowModal === 'deleteAppStatus'}
              onCancel={this.onCancel}
              onOk={this.onConfirmDeleteAPP}
            >
              <div>确认删除应用,删除后不可恢复！</div>
            </Modal>
          </section>
        </Card>
      </PageHeaderWrapper>
    );
  }
}
