import React, { PureComponent } from 'react';
import { Spin, Button, Modal, Input, Radio, Divider, message } from 'antd';
import { connect } from 'dva';
import ButtonAuthorized from '@/components/ButtonAuthorized';
import OYOForm from '@/components/OyoForm/SearchForm';

const { TextArea } = Input;
const { Group } = Radio;

export default class EditConfig extends PureComponent {
  constructor(props) {
    super(props);

    this.OYOFormConfig = [
      {
        type: 'funcName',
        label: '功能名称',
        options: {
          rules: [
            {
              required: true,
              max: 200,
              message: '请填写功能名称（长度小于200）',
            },
          ],
        },
        component: <Input />,
      },
      {
        type: 'funcKey',
        label: '功能code',
        component: <Input disabled />,
      },
      {
        type: 'funcDesc',
        label: '功能说明',
        options: {
          rules: [
            {
              required: true,
              max: 200,
              message: '请填写功能说明（长度小于200）',
            },
          ],
        },
        component: <TextArea />,
      },
    ];
  }

  handleOk = () => {
    this.OYOForm.validateFields((errors, values) => {
      if (errors) return;

      // dispatch 由父组件传入，内部不使用connect，否则外部无法获取到this.OYOForm
      this.props
        .dispatch({
          type: 'PMSFuncWhiteList/editFuncInfo',
          payload: values,
        })
        .then(res => {
          const { afterOk, hiden } = this.props;
          message.success('保存成功');
          afterOk && afterOk();
          hiden && hiden();
        })
        .catch(err => console.log('保存功能出错', err));
    });
  };

  handleCancel = () => {
    const { hiden } = this.props;

    hiden && hiden();
  };

  render() {
    const { visible, initialData, loading = { effects: {} } } = this.props;

    return (
      <Modal
        title="修改功能"
        visible={this.props.visible}
        onCancel={this.handleCancel}
        footer={
          <div style={{ textAlign: 'right' }}>
            <Button
              loading={loading.effects['PMSFuncWhiteList/editFuncInfo']}
              onClick={this.handleOk}
              type="primary"
            >
              保存
            </Button>
          </div>
        }
      >
        <OYOForm
          noSubmit
          fields={this.OYOFormConfig}
          column={1}
          initialData={initialData}
          ref={ref => {
            this.OYOForm = ref;
          }}
        />
      </Modal>
    );
  }
}
