import React, { PureComponent } from 'react';
import { Row, Col, Modal, Form, Input, Button } from 'antd';
import { connect } from 'dva';
import OYOTable from '@/components/OyoTable/OyoTable.tsx';
import ButtonAuthorized from '@/components/ButtonAuthorized';
import { getFuncOnlineHotel } from '../service';

@connect(({ PMSFuncWhiteList }) => ({ PMSFuncWhiteList }))
export default class HotelListModal extends PureComponent {
  constructor(props) {
    super(props);

    this.state = {
      tableParams: {
        hotelName: '',
      },
      pageParams: ['pageNum', 'pageSize'],
    };
  }

  OYOFormColumns = [
    {
      title: '序号',
      dataIndex: 'No',
      key: 'No',
      render: (text, record, index) => {
        const { current, pageSize } = this.oyotable.getCurrentPagination();
        return (current - 1) * pageSize + index + 1;
      },
    },
    {
      title: '酒店名称',
      dataIndex: 'hotelName',
      key: 'hotelName',
    },
    {
      title: '酒店ID',
      dataIndex: 'hotelId',
      key: 'hotelId',
    },
    {
      title: 'CRSID',
      dataIndex: 'oyoId',
      key: 'oyoId',
    },
    {
      title: '操作',
      key: 'operation',
      render: record => (
        <ButtonAuthorized code="CRS13.7.1" size="small" onClick={() => this.setOffline(record)}>
          下线
        </ButtonAuthorized>
      ),
    },
  ];

  getResultsList = params => {
    const { selectedHotel = {} } = this.props.PMSFuncWhiteList;
    const { funcKey } = selectedHotel;

    return getFuncOnlineHotel({ ...params, funcKey })
      .then(({ data }) => {
        if (!data) data = {}; // 参数上面解构赋值对null不适用

        return { data: data.openHotelInfoList || [], total: data.totalCount };
      })
      .catch(err => {
        console.log(err);
      });
  };

  componentWillReceiveProps(nextProps) {
    const { visible } = this.props;
    const { visible: nextVisible } = nextProps;

    // 从隐藏到展示
    if (visible === false && nextVisible === true && this.oyotable) {
      const { pageSize } = this.oyotable.getCurrentPagination();
      this.oyotable.handlePageChange({ current: 1, pageSize });
    }
  }

  setOffline = record => {
    const { hotelId } = record;
    const { selectedHotel = {} } = this.props.PMSFuncWhiteList;
    const { funcKey } = selectedHotel;

    this.props
      .dispatch({
        type: 'PMSFuncWhiteList/closeHotelFunc',
        payload: { funcKey, hotelId },
      })
      .then(res => {
        this.oyotable.handlePageChange(this.oyotable.getCurrentPagination());
      })
      .catch(err => {
        console.log(err);
      });
  };

  onSearch = () => {
    const { pageSize } = this.oyotable.getCurrentPagination();
    this.oyotable.handlePageChange(1, pageSize);
  };

  onHotelNameChange = e => this.setState({ tableParams: { hotelName: e.target.value } });

  onCancel = () => {
    const { hideHotelListModal } = this.props;
    hideHotelListModal && hideHotelListModal();
    // 由于公用，在关闭时清除数据，回到第一页
    this.setState({ tableParams: { hotelName: '' } });
    const pagination = this.oyotable.getCurrentPagination();
    this.oyotable.setState({
      dataSource: [],
      pagination: {
        ...pagination,
        current: 1,
        total: 0,
      },
    });
  };

  render() {
    const { visible } = this.props;
    const { tableParams, pageParams } = this.state;

    return (
      <Modal footer={null} onCancel={this.onCancel} visible={visible} width={700} title="酒店列表">
        <Row gutter={20}>
          <Col span={20}>
            <Form.Item label="酒店名称" labelCol={{ span: 6 }} wrapperCol={{ span: 18 }}>
              <Input value={tableParams.hotelName} onChange={this.onHotelNameChange} width="100%" />
            </Form.Item>
          </Col>
          <Col span={4}>
            <Form.Item>
              <Button onClick={this.onSearch} type="primary">
                查询
              </Button>
            </Form.Item>
          </Col>
        </Row>

        <OYOTable
          ref={re => {
            this.oyotable = re;
          }}
          bordered
          size="small"
          params={tableParams}
          pageParams={pageParams}
          columns={this.OYOFormColumns}
          getList={this.getResultsList}
          // preventGetList
        />
      </Modal>
    );
  }
}
