import React, { PureComponent } from 'react';
import { Spin, Form, Button, Modal, Input, Radio, Tabs, Select, message } from 'antd';
import { connect } from 'dva';
import ButtonAuthorized from '@/components/ButtonAuthorized';
import OYOForm from '@/components/OyoForm/SearchForm';
import CitySelect from '@/components/CitySelect';
import OyoBatchUpload from '@/components/OyoBatchUpload';
import HotelModelConfig from './HotelModelConfig';
import { HOTEL_TYPE_OPTION, COOPERATION_TYPE_OPTION } from '@/constant/allHotelType';
import { downloadHotelFuncConfig } from '../service';
import styles from './HotelModel.less';

const { TabPane } = Tabs;
const { TextArea } = Input;
const { Group } = Radio;
const { Option } = Select;

@connect(({ PMSFuncWhiteList, loading }) => ({
  PMSFuncWhiteList,
  searchLoading: loading.effects['PMSFuncWhiteList/getHotelCount'],
}))
export default class HotelModel extends PureComponent {
  constructor(props) {
    super(props);
    this.state = {
      tabValue: '2',
      queryParams: {}, // 保存查询的参数，下载的时候也用
    };
    this.OYOFormSwitchConfig = [
      {
        type: 'control',
        label: '功能控制',
        options: {
          initialValue: '1',
        },
        component: (
          <Group>
            <Radio value="1">上线</Radio>
            <Radio value="0">下线</Radio>
          </Group>
        ),
      },
    ];
    this.OYOFormHotelConfig = [
      {
        type: 'hotelName',
        label: '酒店名称',
        component: <Input />,
      },
      {
        type: 'code',
        label: '酒店所属区域',
        options: {
          initialValue: [],
          rules: [
            {
              required: true,
              message: '请选择',
            },
          ],
        },
        component: (
          <CitySelect
            style={{ width: '100%' }}
            type="cityList"
            onChange={this.cityChange}
            changeOnSelect
            ref={re => {
              this.citySelect = re;
            }}
          />
        ),
      },
      {
        type: 'hotelType',
        label: '酒店类型',
        options: {
          initialValue: null,
        },
        render: () => <Select placeholder="请选择酒店类型">{HOTEL_TYPE_OPTION}</Select>,
      },
      {
        type: 'cooperationType',
        label: '酒店协议类型',
        options: {
          initialValue: null,
        },
        component: (
          <Select placeholder="请选择酒店协议类型">
            <Option value={null}>全部</Option>
            <Option value="SOUTH_DIST_PILOT">china2.0</Option>
          </Select>
        ),
      },
    ];
  }

  handleCancel = () => {
    const { hidenHotelModel } = this.props;
    hidenHotelModel && hidenHotelModel();
    this.setState({ tabValue: '2' });
    // 默认打开上传页面的话form没有渲染，this.queryCountForm是undefined，所以这里判空一下
    this.queryCountForm && this.queryCountForm.resetFields();
  };

  downloadQueryResult = () =>
    downloadHotelFuncConfig(
      this.state.queryParams,
      `【${this.props.PMSFuncWhiteList.selectedHotel.funcName}】查询酒店名称.xls`
    );

  queryCount = values => {
    const { dispatch, PMSFuncWhiteList = {} } = this.props;
    const { selectedHotel = {} } = PMSFuncWhiteList;
    // funcKey必传
    const { funcKey } = selectedHotel;
    // 表单中的值，其中区域必传
    const { hotelName, code = [], hotelType, cooperationType } = values;
    const [stateId, cityId, clusterId] = code;

    if (!funcKey) {
      message.error('功能code缺失，无法获取数据');
      return;
    }
    if (stateId === undefined || stateId === null) {
      message.error('请选择酒店所属区域');
      return;
    }

    const queryParams = {
      funcKey,
      stateId,
      cityId,
      clusterId,
      hotelName,
      hotelType,
      cooperationType,
    };

    this.setState({ queryParams });
    dispatch({ type: 'PMSFuncWhiteList/getHotelCount', payload: queryParams });
  };

  // CitySelect不能受OYOForm重置，利用钩子进行reset
  reset = () => {
    this.queryCountForm.setFieldsValue({
      code: [],
    });
  };

  onTabChange = tabValue => {
    this.setState({ tabValue });
  };

  render() {
    const { visible, type, feature, PMSFuncWhiteList = {}, searchLoading } = this.props;
    const { hotelCount = 0, selectedHotel = {} } = PMSFuncWhiteList;
    const { tabValue } = this.state;

    return (
      <Modal
        title="选择酒店配置功能项"
        visible={this.props.visible}
        onOk={this.handleOk}
        onCancel={this.handleCancel}
        width="700px"
        cancelText="关闭"
        okButtonProps={{ style: { display: 'none' } }}
      >
        <p className={styles.feature}>{selectedHotel.funcName}</p>
        <Tabs
          activeKey={tabValue}
          onChange={this.onTabChange}
          type="card"
          style={{ marginBottom: 15 }}
        >
          <TabPane tab="查询酒店" key="1">
            <p className={styles.title}>1. 请查询或上传需要关联配置的酒店</p>
            {/* 这里不转Boolean的话undefined会直接loading，有可能是Spin内部实现的问题 */}
            <Spin spinning={!!searchLoading}>
              <OYOForm
                fields={this.OYOFormHotelConfig}
                onSearch={this.queryCount}
                onReset={this.reset}
                column={1}
                ref={ref => {
                  this.queryCountForm = ref;
                }}
              />
            </Spin>
            <p className={styles.hotelNumber}>已查询符合条件酒店: {hotelCount}家</p>
            <p className={styles.title}>2. 查询后, 下载查询的酒店</p>
            <Button
              onClick={this.downloadQueryResult}
              disabled={hotelCount === 0 || !!searchLoading}
            >
              下载查询结果
            </Button>
          </TabPane>
          <TabPane tab="上传酒店" key="2">
            <p className={styles.title}>1. 选择该功能需要上线/下线的酒店</p>
            <OYOForm
              noSubmit
              fields={this.OYOFormSwitchConfig}
              column={1}
              ref={ref => {
                this.OYOForm = ref;
              }}
            />
            <p className={styles.title}>2. 上传需上线/下线的酒店</p>
            <OyoBatchUpload {...HotelModelConfig(this)} />
          </TabPane>
        </Tabs>
      </Modal>
    );
  }
}
