import React, { PureComponent } from 'react';
import { connect } from 'dva';
import { Input, Button, Row, Col, Card } from 'antd';
import PageHeaderWrapper from '@/components/PageHeaderWrapper';
import OYOForm from '@/components/OyoForm/SearchForm';
import OYOTable from '@/components/OyoTable/OyoTable.tsx';
import EditConfig from './components/EditConfig';
import HotelModel from './components/HotelModel';
import HotelListModal from './components/HotelListModal';
import ButtonAuthorized from '@/components/ButtonAuthorized';
import { getPMSFuncList } from './service';

@connect(({ PMSFuncWhiteList, loading }) => ({ PMSFuncWhiteList, dvaLoading: loading }))
export default class HotelListIndex extends PureComponent {
  constructor(props) {
    super(props);

    this.state = {
      isHotelModelShow: false,
      isEditConfigShow: false,
      isHotelListModalShow: false,
      loading: false,
      tableParams: {
        funcName: '',
      },
      pageParams: ['pageNum', 'pageSize'],
    };

    this.OYOFormConfig = [
      {
        type: 'funcName',
        label: '功能名称',
        options: [],
        component: <Input />,
      },
    ];

    this.OYOTableColumns = [
      {
        title: '功能名称',
        dataIndex: 'funcName',
        key: 'funcName',
      },
      {
        title: '功能code',
        dataIndex: 'funcKey',
        key: 'funcKey',
      },
      {
        title: '功能说明',
        dataIndex: 'funcDesc',
        key: 'funcDesc',
      },
      {
        title: '功能开启酒店数量',
        dataIndex: 'openHotelCount',
        key: 'openHotelCount',
        render: (text, record, index) => (
          <a
            href="javascript:;"
            style={{ textDecoration: 'underline', color: 'black' }}
            onClick={() => {
              this.setSelectedHotel(record);
              setTimeout(() => {
                // 等record上去dva再显示弹框
                this.showHotelListModal();
              }, 1);
            }}
          >
            {text}
          </a>
        ),
      },
      {
        title: '操作',
        render: record => {
          return (
            <span>
              <ButtonAuthorized
                code="CRS13.7.1"
                size="small"
                onClick={() => {
                  this.setSelectedHotel(record);
                  this.showEditConfig();
                  setTimeout(() => {
                    // 首次点击修改时，Modal未渲染，所以用定时器做异步任务
                    this.configModal.OYOForm && this.configModal.OYOForm.setFieldsValue(record);
                  }, 1);
                }}
              >
                修改功能
              </ButtonAuthorized>
              <ButtonAuthorized
                code="CRS13.7.1"
                size="small"
                style={{ marginLeft: 10 }}
                onClick={() => {
                  this.setSelectedHotel(record);
                  this.showHotelModel();
                }}
              >
                选择酒店
              </ButtonAuthorized>
            </span>
          );
        },
      },
    ];
  }

  setSelectedHotel = hotel => {
    this.props.dispatch({
      type: 'PMSFuncWhiteList/setSelectedHotel',
      payload: hotel,
    });
  };

  query = ({ funcName }) => {
    const tableParams = { funcName };
    this.setState({ tableParams }, () => {
      this.refreshCurrentPage();
    });
  };

  refreshCurrentPage = () => {
    this.oyotable.handlePageChange(this.oyotable.getCurrentPagination());
  };

  getResultsList(params) {
    return getPMSFuncList(params).then(({ data = {} }) => {
      return { data: data.hotelFuncList || [], total: data.totalCount };
    });
  }

  showEditConfig = () => this.setState({ isEditConfigShow: true });

  hideEditConfig = () => this.setState({ isEditConfigShow: false });

  showHotelModel = () => this.setState({ isHotelModelShow: true });

  hideHotelModel = () => this.setState({ isHotelModelShow: false });

  showHotelListModal = () => this.setState({ isHotelListModalShow: true });

  hideHotelListModal = () => {
    // 关闭后刷新，因为数量不一样了
    this.refreshCurrentPage();
    this.setState({ isHotelListModalShow: false });
  };

  render() {
    const { dispatch, PMSFuncWhiteList, dvaLoading } = this.props;
    const {
      loading,
      tableParams,
      pageParams,
      isHotelModelShow,
      isEditConfigShow,
      isHotelListModalShow,
    } = this.state;

    return (
      <PageHeaderWrapper>
        <Card>
          <OYOForm fields={this.OYOFormConfig} onSearch={this.query} column={4} />
          <br />
          <OYOTable
            ref={re => {
              this.oyotable = re;
            }}
            bordered
            size="small"
            loading={loading}
            params={tableParams}
            pageParams={pageParams}
            columns={this.OYOTableColumns}
            getList={this.getResultsList}
            // preventGetList
          />
          <EditConfig
            ref={ref => {
              this.configModal = ref;
            }}
            PMSFuncWhiteList={PMSFuncWhiteList}
            dispatch={dispatch}
            loading={dvaLoading}
            visible={isEditConfigShow}
            hiden={this.hideEditConfig}
            afterOk={this.refreshCurrentPage}
          />
          <HotelModel
            visible={isHotelModelShow}
            feature="hmi看板"
            hidenHotelModel={this.hideHotelModel}
          />
          <HotelListModal
            visible={isHotelListModalShow}
            hideHotelListModal={this.hideHotelListModal}
          />
        </Card>
      </PageHeaderWrapper>
    );
  }
}
