import React, { PureComponent } from 'react';
import { connect } from 'dva';
import Link from 'umi/link';
import moment from 'moment';
import {
  Card,
  Table,
  Row,
  Col,
  Form,
  Input,
  Select,
  Button,
  DatePicker,
  Modal,
  message,
} from 'antd';
import ButtonAuthorized from '@/components/ButtonAuthorized';
import { tableWidthDecorator } from '@/utils/decorator';

import styles from './Complaint.less';
import {
  rowProps,
  col1Props,
  col3Props,
  col4Props,
  formItemLayout,
  widthStyle,
} from '@/utils/formProps';
import { downloadFile } from '@/utils/downloadFile';

const FormItem = Form.Item;
const { Option } = Select;

@connect(({ complaint, user, loading }) => ({
  complaint,
  user,
  loading: loading.models.complaint,
}))
@Form.create()
@tableWidthDecorator(true)
export default class OrderList extends PureComponent {
  state = {
    formValues: {
      checkInBeg: moment().format('YYYY-MM-DD'),
      checkInEnd: moment().format('YYYY-MM-DD'),
      // hotelId: null,
      // hotelName: '',
      bookingSn: '',
      scheduleDate: null,
      scheduleMemberName: '',
      scheduleMemberPhone: '',
      appealSubStatus: 'IN_APPEAL',
    },
    journalVisible: false,
    page: 1,
    limit: 10,
    journalPage: 1,
    journalLimit: 10,
    tableWidth: 0,
  };

  componentWillMount() {
    const columns = [
      {
        title: '申诉时间',
        dataIndex: 'appealDate',
        key: 'appealDate',
        width: 105,
      },
      {
        title: '酒店id/名称',
        dataIndex: 'hotelName',
        key: 'hotelName',
        width: 250,

        render: (hotelName, record) => (
          <span>
            {record.hotelId}
            <br />
            <Link to={`/hotel/hotelCreateEdit/index?hotelId=${record.hotelId}`}>{hotelName}</Link>
          </span>
        ),
      },
      {
        title: 'OYO订单号',
        dataIndex: 'bookingSn',
        key: 'bookingSn',
        width: 140,
      },
      {
        title: 'OYO房单号',
        dataIndex: 'orderSn',
        key: 'orderSn',
        width: 140,
      },
      {
        title: '订单来源',
        dataIndex: 'sourceName',
        key: 'sourceName',
        width: 118,
      },
      {
        title: '入住/离店',
        dataIndex: 'checkin',
        key: 'checkin',
        width: 118,

        render: (checkin, record) => {
          const { checkout } = record;
          return (
            <span>
              {moment(checkin).format('YYYY-MM-DD')} <br />至 <br />
              {moment(checkout).format('YYYY-MM-DD')}
            </span>
          );
        },
      },
      {
        title: '入住天数',
        dataIndex: 'days',
        key: 'days',
        width: 80,
      },
      {
        title: '预订人',
        dataIndex: 'scheduleMemberName',
        key: 'scheduleMemberName',
        width: 98,
      },
      {
        title: '申诉状态',
        dataIndex: 'appealSubStatus',
        key: 'appealSubStatus',
        width: 118,

        render: appealSubStatus => {
          let result = '';
          if (appealSubStatus === 'IN_APPEAL') {
            result = '申诉中';
          } else if (appealSubStatus === 'CANCELED') {
            result = '申诉通过-申诉不确认收入';
          } else if (appealSubStatus === 'CONFIRMED') {
            result = '申诉驳回-申诉确认收入';
          } else if (appealSubStatus === 'APPEAL_OVER') {
            result = '申诉过期-系统确认收入';
          } else if (appealSubStatus === 'EXAMIME_OVER') {
            result = '审批过期-系统不确认收入';
          } else {
            result = '';
          }
          return result;
        },
      },
      {
        title: '结算(元)',
        dataIndex: 'actualPrice',
        key: 'actualPrice',
        width: 80,
      },
      {
        title: '消费(元)',
        dataIndex: 'receivablePrice',
        key: 'receivablePrice',
        width: 80,
      },
      {
        title: '操作',
        dataIndex: 'id',
        key: 'id',
        width: 180,
        fixed: 'right',
        render: (id, record) => {
          let results = null;
          if (record.appealSubStatus === 'IN_APPEAL') {
            results = (
              <span>
                <ButtonAuthorized
                  code="CRS3.4.1"
                  size="small"
                  onClick={e => this.handleComplaint(id, 'CANCELED')}
                >
                  申诉通过
                </ButtonAuthorized>
                <ButtonAuthorized
                  code="CRS3.4.2"
                  size="small"
                  style={{ marginLeft: 8 }}
                  onClick={e => this.handleComplaint(id, 'CONFIRMED')}
                >
                  申诉驳回
                </ButtonAuthorized>
              </span>
            );
          } else {
            results = (
              <Button type="primary" onClick={e => this.handleJournal(id)}>
                日志
              </Button>
            );
          }
          return results;
        },
      },
    ];
    this.setState({ columns });
  }

  componentDidMount() {
    const { complaint } = this.props;
    // 请求：订单列表的参数
    const params = complaint.complaintListData.defaultParams;
    // 请求：申诉列表
    this.fetchComplaintList(params);
  }

  // 请求：申诉列表
  fetchComplaintList = params => {
    const payload = this.removeNull(params);
    const { dispatch } = this.props;

    dispatch({
      type: 'complaint/fetchComplaintList',
      payload,
    });
  };

  // 酒店相关
  handleHotelId = () => {
    const { form } = this.props;
    form.setFieldsValue({ hotelName: '' });
  };

  handleHotelNameFocus = () => {
    const { dispatch } = this.props;
    dispatch({
      type: 'complaint/setSuggestHotelList',
      payload: [],
    });
  };

  handleHotelNameSearch = value => {
    const { dispatch } = this.props;
    dispatch({
      type: 'complaint/fetchSuggestHotel',
      payload: {
        hotelName: value,
        searchType: 'hotelNameSearch',
      },
    });
  };

  handleHotelNameSelect = value => {
    const { form } = this.props;
    form.setFieldsValue({ hotelId: value });
  };

  // 表单查询条件重置
  handleFormReset = () => {
    const { form, complaint } = this.props;
    form.resetFields();
    this.setState({
      formValues: {
        checkInBeg: moment().format('YYYY-MM-DD'),
        checkInEnd: moment().format('YYYY-MM-DD'),
        bookingSn: '',
        scheduleDate: null,
        scheduleMemberName: '',
        scheduleMemberPhone: '',
        appealSubStatus: 'IN_APPEAL',
      },
      page: 1,
      limit: 10,
    });

    let params = complaint.complaintListData.defaultParams;
    this.fetchComplaintList(params);
  };

  // 表单查询
  handleFormSearch = e => {
    e.preventDefault();

    const { form } = this.props;

    form.validateFields((err, fieldsValue) => {
      if (err) return;

      // 处理：条件查询中无hotelName字段，删除
      delete fieldsValue.hotelName;

      if (fieldsValue.scheduleDate !== undefined && fieldsValue.scheduleDate !== null) {
        fieldsValue.scheduleDate = fieldsValue.scheduleDate.format('YYYY-MM-DD');
      }
      if (fieldsValue.checkInBeg !== undefined && fieldsValue.checkInBeg !== null) {
        fieldsValue.checkInBeg = fieldsValue.checkInBeg.format('YYYY-MM-DD');
      }
      if (fieldsValue.checkInEnd !== undefined && fieldsValue.checkInEnd !== null) {
        fieldsValue.checkInEnd = fieldsValue.checkInEnd.format('YYYY-MM-DD');
      }

      // 处理：查询参数未输入时候undefined转成空字符串。
      Object.keys(fieldsValue).forEach(key => {
        if (fieldsValue[key] === undefined) fieldsValue[key] = '';
      });

      // 处理：查询订单参数设置
      const params = { page: 1, limit: 10, ...fieldsValue };
      this.setState({
        formValues: {
          ...fieldsValue,
        },
      });

      console.log('fieldsValue', fieldsValue);
      this.fetchComplaintList(params);
    });
  };

  // 处理：移除空字段
  removeNull = obj => {
    Object.keys(obj).forEach(
      key =>
        (obj[key] && typeof obj[key] === 'object' && this.removeNull(obj[key])) ||
        ((obj[key] === undefined || obj[key] === null || obj[key] === '') && delete obj[key])
    );
    return obj;
  };

  // 操作+请求：申诉通过/驳回
  handleComplaint = (id, status) => {
    const {
      user: { accountId },
      dispatch,
      complaint,
    } = this.props;
    const { formValues, page, limit } = this.state;

    dispatch({
      type: 'complaint/fetchComplaint',
      payload: {
        operatorId: accountId,
        orderId: id,
        appealSubStatus: status,
      },
    })
      .then(data => {
        if (data.code === '000') {
          message.success('申诉操作成功');

          const params = {
            ...formValues,
            page,
            limit,
          };
          // 请求：申诉列表
          this.fetchComplaintList(params);
        }
      })
      .catch(e => {
        console.log(e);
      });
  };

  // 表格分页pageSize和PageNum
  handlePageChange = pagination => {
    let { formValues } = this.state;

    const params = {
      page: pagination.current,
      limit: pagination.pageSize,
      ...formValues,
    };
    this.fetchComplaintList(params);
    this.setState({
      page: pagination.current,
      limit: pagination.pageSize,
    });
  };

  // 请求：查看日志
  fetchJournal = params => {
    const { dispatch } = this.props;

    dispatch({
      type: 'complaint/fetchJournalList',
      payload: params,
    });
  };

  // 操作：导出申诉
  handleExport = () => {
    downloadFile(
      '/api/crs/roomReservation/noshow/appeal/list/download',
      {},
      `${moment().format('YYYYMMDDHHmmss')}.xls`
    );
  };

  // 操作：查看日志
  handleJournal = id => {
    const params = {
      page: 1,
      limit: 10,
      orderId: id,
    };

    this.setState({ journalVisible: true });
    this.fetchJournal(params);
  };

  // 操作：日志分页
  handleModalPage = pagination => {
    const params = {
      page: pagination.current,
      limit: pagination.pageSize,
    };
    this.fetchJournal(params);
    this.setState({
      journalPage: pagination.current,
      journalLimit: pagination.pageSize,
    });
  };

  // 操作：日志modal关闭
  handleCancel = () => {
    this.setState({
      journalVisible: false,
    });
  };

  renderForm() {
    const {
      form: { getFieldDecorator },
    } = this.props;
    // const formItemLayout = {
    //   labelCol: { span: 5 },
    //   wrapperCol: { span: 12 },
    // };

    return (
      <Form onSubmit={this.handleFormSearch} layout="inline">
        <Row {...rowProps}>
          <Col {...col4Props}>
            <FormItem label="预订日期" {...formItemLayout}>
              {getFieldDecorator('scheduleDate')(
                <DatePicker
                  format="YYYY-MM-DD"
                  style={{ width: '100%' }}
                  placeholder="请选择预定日期"
                />
              )}
            </FormItem>
          </Col>
          <Col {...col4Props}>
            <FormItem label="开始日期" {...formItemLayout}>
              {getFieldDecorator('checkInBeg', {
                initialValue: moment(),
                rules: [
                  { required: true, message: '请选择开始日期' },
                  {
                    validator: (rule, value, callback) => {
                      const { getFieldValue } = this.props.form;
                      let checkout = getFieldValue('checkInEnd');
                      if (checkout && value) {
                        if (value.format('YYYY-MM-DD') > checkout.format('YYYY-MM-DD')) {
                          callback('开始日期不能晚于结束日期');
                        }
                      }

                      callback();
                    },
                  },
                ],
              })(
                <DatePicker
                  format="YYYY-MM-DD"
                  style={{ width: '100%' }}
                  placeholder="请选择开始日期"
                />
              )}
            </FormItem>
          </Col>
          <Col {...col4Props}>
            <FormItem label="结束日期" {...formItemLayout}>
              {getFieldDecorator('checkInEnd', {
                initialValue: moment(),
                rules: [
                  { required: true, message: '请选择结束日期' },
                  {
                    validator: (rule, value, callback) => {
                      const { getFieldValue } = this.props.form;
                      let checkin = getFieldValue('checkInBeg');
                      if (checkin && value) {
                        if (checkin.format('YYYY-MM-DD') > value.format('YYYY-MM-DD')) {
                          callback('结束日期不能早于开始日期');
                        }
                      }

                      callback();
                    },
                  },
                ],
              })(
                <DatePicker
                  format="YYYY-MM-DD"
                  style={{ width: '100%' }}
                  placeholder="请选择结束日期"
                />
              )}
            </FormItem>
          </Col>
          <Col {...col4Props}>
            <FormItem label="订单号" {...formItemLayout}>
              {getFieldDecorator('bookingSn', {
                initialValue: '',
              })(<Input style={{ width: '100%' }} placeholder="请输入订单号" />)}
            </FormItem>
          </Col>
          {/* <Col md={8} sm={24}>
            <FormItem label="房单号" {...formItemLayout}>
              {getFieldDecorator('orderSn', {
                initialValue: '',
              })(<Input style={{ width: '100%' }} placeholder="请输入订单号" />)}
            </FormItem>
          </Col> */}
          <Col {...col4Props}>
            <FormItem label="预订人" {...formItemLayout}>
              {getFieldDecorator('scheduleMemberName', {
                initialValue: '',
              })(<Input style={{ width: '100%' }} placeholder="请输入预订人" />)}
            </FormItem>
          </Col>
          <Col {...col4Props}>
            <FormItem label="联系电话" {...formItemLayout}>
              {getFieldDecorator('scheduleMemberPhone', {
                initialValue: '',
                rules: [
                  {
                    required: false,
                    message: '请输入正确的手机号码',
                    pattern: '^1(3|4|5|7|8)\\d{9}$',
                  },
                ],
              })(<Input style={{ width: '100%' }} placeholder="请输入11位的联系电话" />)}
            </FormItem>
          </Col>

          <Col {...col4Props}>
            <FormItem label="申诉状态" {...formItemLayout}>
              {getFieldDecorator('appealSubStatus', {
                initialValue: 'IN_APPEAL',
              })(
                <Select placeholder="请选择" style={{ width: '100%' }}>
                  <Option value="IN_APPEAL">申诉中</Option>
                  <Option value="CANCELED">申诉通过</Option>
                  <Option value="CONFIRMED">申诉驳回</Option>
                  <Option value="APPEAL_OVER">申诉过期</Option>
                  <Option value="EXAMIME_OVER">审批过期</Option>
                </Select>
              )}
            </FormItem>
          </Col>
        </Row>
        <Row gutter={{ md: 8, lg: 24, xl: 48 }}>
          <Col md={24} sm={24}>
            <span className={styles.submitButtons} style={{ marginBottom: 0 }}>
              <Button type="primary" htmlType="submit">
                查询
              </Button>
              <ButtonAuthorized
                type="primary"
                code="CRS3.4.3"
                style={{ marginLeft: 20 }}
                onClick={this.handleExport}
              >
                {/* <a href={downloadURL} target="_blank"> */}
                导出
                {/* </a> */}
              </ButtonAuthorized>
              <Button style={{ marginLeft: 20 }} onClick={this.handleFormReset}>
                重置
              </Button>
            </span>
          </Col>
        </Row>
      </Form>
    );
  }

  renderJournalModal() {
    const { journalVisible, journalPage, journalLimit } = this.state;
    const { complaint } = this.props;
    const columns = [
      {
        title: '操作时间',
        dataIndex: 'createTime',
        key: 'createTime',
      },
      {
        title: '操作人',
        dataIndex: 'operatorName',
        key: 'operatorName',
      },
      {
        title: '操作内容',
        dataIndex: 'appealSubStatus',
        key: 'appealSubStatus',
        render: (appealSubStatus, record) => {
          const { bookingSn } = record;
          let status = '';
          if (appealSubStatus === 'CANCELED') {
            status = '操作申诉通过-申诉不确认收入';
          } else if (appealSubStatus === 'CONFIRMED') {
            status = '操作申诉驳回-申诉确认收入';
          } else if (appealSubStatus === 'APPEAL_OVER') {
            status = '申诉过期-系统确认收入';
          } else if (appealSubStatus === 'EXAMIME_OVER') {
            status = '审批过期-系统不确认收入';
          } else {
            status = '';
          }

          return <span>{`OYO订单号：${bookingSn}, ${status}`}</span>;
        },
      },
    ];

    return (
      <Modal
        title="日志"
        width={800}
        footer={null}
        visible={journalVisible}
        onCancel={this.handleCancel}
        bodyStyle={{ maxHeight: 500 }}
      >
        <Table
          columns={columns}
          // bordered
          size="small"
          dataSource={complaint.journalListData.journalList}
          pagination={
            complaint.journalListData.totalCount < 10
              ? false
              : {
                  showSizeChanger: false,
                  current: journalPage,
                  pageSize: journalLimit,
                  total: complaint.journalListData.totalCount,
                }
          }
          onChange={this.handleModalPage}
          onShowSizeChange={this.handleModalPage}
        />
      </Modal>
    );
  }

  render() {
    const { columns, page, limit, tableWidth } = this.state;
    const { complaint, loading } = this.props;

    return (
      <div>
        <Card bordered={false}>
          <div className={styles.tableList}>
            <div className={styles.tableListForm}>{this.renderForm()}</div>
          </div>
        </Card>
        <Card bordered={false} style={{ marginTop: 15 }}>
          <Table
            loading={loading}
            size="small"
            bordered
            scroll={{ x: tableWidth }}
            columns={columns}
            dataSource={complaint.complaintListData.complaintList}
            expandedRowRender={record => (
              <p style={{ margin: 0 }}>
                {`申诉原因：${record.appealTypeName ? record.appealTypeName : '无'} 申诉说明：${
                  record.appealRemark ? record.appealRemark : '无'
                }`}
              </p>
            )}
            expandedRowKeys={complaint.complaintListData.complaintList.map((item, index) => index)}
            pagination={{
              showSizeChanger: true,
              current: page,
              pageSize: limit,
              total: complaint.complaintListData.totalCount,
            }}
            onChange={this.handlePageChange}
            onShowSizeChange={this.handlePageChange}
          />
          {this.renderJournalModal()}
        </Card>
      </div>
    );
  }
}
