import React, { PureComponent } from 'react';
import { connect } from 'dva';
import moment from 'moment';
import { Input, Select, Icon, DatePicker, Button, message } from 'antd';
import { checkPhone, checkFloatNumber } from '@/utils/validate';
import RoomBox from './components/RoomBox';
import CitySelect from '@/components/CitySelect/index';
import HotelInput from '@/components/HotelInput/HotelInput';
import FooterToolbar from '@/components/FooterToolbar';

import PageHeaderWrapper from '@/components/PageHeaderWrapper';
import HotelsTable from './components/HotelsTable';
import styles from './Create.less';
import { typeCheck } from '@/utils/utils';

import { widthStyle } from '@/utils/formProps';

const Option = Select.Option;
const PageSize = 10;
/**
 * 创建订单页面
 * url: /#/order/create 新建订单
 * 功能: 酒店定位后 进行对应房型的预定
 */
@connect(({ user, createOrder, hotelSearch, hotelLists, loading }) => ({
  user,
  createOrder,
  hotelSearch,
  hotelLists,
  loading,
}))
export default class Create extends PureComponent {
  constructor() {
    super();
    this.state = {
      searchCityId: [], // 搜索的城市Id
      searchHotelType: {
        type: '0',
        val: '',
      },
      selectHotel: {}, // 选择的酒店
      productIndex: 0, // 房型列表选择的当前房型Index(会变绿)
      isCreateLoading: false,
      isShowTable: false,
      totalDays: 0, // 共住天数
      checkinDay: '', // 入住时间
      checkoutDay: '', // 离店时间
      roomRate: 0, // 房价
      roomLength: 0, // 数量
      totalAmount: 0, // 总费用
    };
  }

  componentDidMount() {
    // 获取下单渠道列表
    this.props.dispatch({
      type: 'createOrder/fetchChannelList',
    });

    this.props.dispatch({
      type: 'createOrder/fetchQueryChannelList',
    });
  }

  handleAmount = e => {
    const reg = /^(-)*(\d+)\.(\d\d).*$/;
    let totalAmount = e.target.value.replace(/[^\-?\d.]/g, '').replace(reg, '$1$2.$3');

    this.setState({ totalAmount });
  };

  render() {
    let { productIndex, searchCityId, isCreateLoading, isShowTable, totalAmount } = this.state;
    let {
      amount,
      channelList,
      isCanRateCode,
      channelId,
      extBookingSn,
      bookingGuest,
      checkin,
      checkout,
      retentionTime,
      remark,
      rateCodeList,
      rateCode,
      paymentType,
      bookingPayment,
      bookingRoomTypeList,
      salesId,
      accountType,
      queryChannelList,
    } = this.props.createOrder;

    return (
      <PageHeaderWrapper>
        <div className={styles.createHotelPage}>
          <div className={styles.createHotelHd}>
            <p className={styles.hdTag}>所在城市:</p>
            <CitySelect
              type="cityList"
              value={searchCityId}
              onChange={val => this.onCityChange(val)}
              changeOnSelect
            />
            <p className={styles.hdTag}>酒店:</p>
            <HotelInput
              ref={ref => {
                this.HotelInputRef = ref;
              }}
              onChange={val => this.handerHotel(val)}
            />
            <Button type="primary" className={styles.hotelSearch} onClick={this.handlerHotelSearch}>
              搜索
            </Button>
            <Button className={styles.hotelSearch} onClick={this.handlerResetHotelSearch}>
              重置
            </Button>
          </div>
          {isShowTable ? (
            <HotelsTable
              handlePageChange={current => this.handlePageChange(current)}
              handlerHoltelSelect={this.handlerHoltelSelect}
            />
          ) : null}
          <p className={styles.createHotelSeleted}>
            已选择酒店: <span>{this.state.selectHotel.hotelName}</span>
          </p>
          <ul className={styles.createHotelFroms}>
            <li>
              <div>
                <span className={styles.fromsTag}>订单来源:</span>
                <Select
                  value={channelId}
                  ref={ref => {
                    this.channelId = ref;
                  }}
                  onChange={e => this.handlerChannelId(e)}
                >
                  {channelList.map((item, index) => (
                    <Option value={item.channelId} key={index}>
                      {item.channelName}
                    </Option>
                  ))}
                </Select>
              </div>
              <div>
                <span className={styles.fromsTag}>渠道订单号:</span>
                <Input
                  value={extBookingSn}
                  ref={ref => {
                    this.ExtBookingSn = ref;
                  }}
                  placeholder={
                    channelId && queryChannelList.includes(channelId) ? '请输入渠道订单号' : ''
                  }
                  onChange={e => this.handlerFromVal(e, 'extBookingSn')}
                />
              </div>
              <div>
                <span className={styles.fromsTag}>入账主体:</span>
                <Select
                  value={accountType}
                  ref={ref => {
                    this.accountType = ref;
                  }}
                  onChange={e => this.handlerFromVal(e, 'accountType')}
                  placeholder="请选择入账主体"
                >
                  <Option value="HOTEL">酒店账户</Option>
                  <Option value="OYO">OYO账户</Option>
                  <Option value="">未知账户</Option>
                </Select>
              </div>
            </li>
            <li>
              <div>
                <span className={styles.fromsTag}>联系电话:</span>
                <Input
                  placeholder="请输入联系电话"
                  value={bookingGuest.phone}
                  ref={ref => {
                    this.bookingGuestPhone = ref;
                  }}
                  onChange={e => this.handlerBookingGuestVal(e, 'phone')}
                  maxLength={11}
                />
              </div>
              <div>
                <span className={styles.fromsTag}>预定人:</span>
                <Input
                  placeholder="请输入预定人"
                  ref={ref => {
                    this.bookingGuestName = ref;
                  }}
                  value={bookingGuest.name}
                  onChange={e => this.handlerBookingGuestVal(e, 'name')}
                />
              </div>
              <div>
                <span className={styles.fromsTag}>客源类型:</span>
                <Select
                  value={bookingGuest.member ? '0' : '1'}
                  disabled
                  onChange={e => this.handlerFromVal(e, 'channelId')}
                >
                  <Option value="0">会员</Option>
                  <Option value="1">非会员</Option>
                </Select>
              </div>
            </li>
            <li>
              <div>
                <span className={styles.fromsTag}>入住日期:</span>
                <DatePicker
                  value={checkin}
                  format="YYYY-MM-DD HH:mm"
                  disabledDate={current => this.checkinDisable(current)}
                  // disabledTime={current => this.disabledTime(current)}
                  onChange={val => this.handlerTime('checkin', val)}
                  ref={ref => {
                    this.checkin = ref;
                  }}
                />
              </div>
              <div>
                <span className={styles.fromsTag}>离店日期:</span>
                <DatePicker
                  value={checkout}
                  format="YYYY-MM-DD HH:mm"
                  disabledDate={current => current && current < moment().startOf('day')}
                  // disabledTime={current => this.disabledTime(current)}
                  onChange={val => this.handlerTime('checkout', val)}
                  ref={ref => {
                    this.checkout = ref;
                  }}
                />
              </div>
              <div>
                <span className={styles.fromsTag}>保留时间:</span>
                <DatePicker
                  value={retentionTime}
                  format="YYYY-MM-DD HH:mm:ss"
                  // showTime
                  disabledDate={current => current && current < moment().startOf('day')}
                  disabledTime={current => this.disabledTime(current)}
                  onChange={val => this.handlerTime('retentionTime', val)}
                  ref={ref => {
                    this.retentionTime = ref;
                  }}
                  disabled={this.state.isMorningBooking}
                />
              </div>
            </li>
            <li>
              <div>
                <span className={styles.fromsTag}>支付类型:</span>
                <Select value={paymentType} onChange={e => this.handlerFromVal(e, 'paymentType')}>
                  <Option value={1}>预付</Option>
                  <Option value={0}>到付</Option>
                </Select>
              </div>
              <div>
                <span className={styles.fromsTag}>房价类型:</span>
                <Select
                  value={rateCode === null ? '' : rateCode}
                  ref={ref => {
                    this.rateCode = ref;
                  }}
                  onChange={val => this.handlerRateCodeId(val)}
                  disabled={!isCanRateCode}
                >
                  {rateCodeList.map((item, index) => (
                    <Option value={item.rateCodeId} key={index}>
                      {item.rateCodeName}
                    </Option>
                  ))}
                </Select>
              </div>
              <div>
                <span className={styles.fromsTag}>销售员:</span>
                <Input
                  placeholder="请输入销售员"
                  value={salesId}
                  onChange={e => this.handlerFromVal(e, 'salesId')}
                />
              </div>
            </li>
            <li>
              <span className={styles.fromsTag}>订单备注:</span>
              <Input
                placeholder="请输入订单备注"
                value={remark}
                ref={ref => {
                  this.remark = ref;
                }}
                onChange={e => this.handlerFromVal(e, 'remark')}
              />
            </li>
          </ul>
          <div className={styles.createHotelType}>
            <div className={styles.hotelTypeHd}>
              <Icon type="file-done" theme="outlined" />
              <span>请选择房型</span>
            </div>
            <ul className={styles.hotelTypeList}>
              {this.props.createOrder.productList.map((item, index) => (
                <RoomBox
                  {...item}
                  index={index}
                  key={index}
                  productIndex={productIndex}
                  onChange={val => this.handlerProductList(val)}
                />
              ))}
            </ul>
          </div>
          <div className={styles.createHotelPrice}>
            <div>
              <span className={styles.priceTag}>房费:</span>
              <Input
                addonBefore="¥"
                defaultValue={totalAmount}
                value={totalAmount}
                onChange={this.handleAmount}
              />
            </div>
            <div>
              <span className={styles.priceTag}>支付金额:</span>
              <Input
                value={paymentType === 0 ? 0 : totalAmount}
                disabled
                onChange={e => this.handlerPreAmount(e)}
              />
            </div>
          </div>
          <FooterToolbar style={widthStyle}>
            <Button
              type="primary"
              loading={isCreateLoading}
              disabled={!(bookingRoomTypeList instanceof Array && bookingRoomTypeList[0].number)}
              onClick={() => this.requestSave()}
            >
              新建订单
            </Button>
            <Button onClick={() => this.cancelPage()}>取消</Button>
          </FooterToolbar>
        </div>
      </PageHeaderWrapper>
    );
  }

  /**
   * 房价(策略)类型被切换后触发
   * @param  {String}  val 房价策略的id
   */
  async handlerRateCodeId(val) {
    await this.props.dispatch({
      type: 'createOrder/saveKey',
      payload: {
        rateCode: val,
      },
    });

    // 由于房价类型被更换后
    await this.props.dispatch({
      type: 'createOrder/resetRoom',
    });

    // 改变策略后将发起产品列表
    this.requestProduct();
  }

  /**
   * 订单来源(渠道)切换后触发
   * @param  {String}  val 切换的渠道id
   */
  async handlerChannelId(val) {
    await this.props.dispatch({
      type: 'createOrder/saveKey',
      payload: {
        channelId: val,
      },
    });

    this.requestRateCode(); // 变更渠道之后切换房价类型(策略)
  }

  checkinDisable(current) {
    if (!current) return;

    let nowDate = moment();

    if (nowDate.hours() < 4) {
      return current < nowDate.subtract(1, 'days').startOf('day');
    }
    return current < nowDate.startOf('day');
  }

  /**
   * 保留日期筛选不可选择的时间(不得保存至目前之前)
   * @param  {Moment} current
   * @return {[type]}         [description]
   */
  disabledTime(current) {
    if (!current) return;

    let nowDate = moment();

    // 选择日期为当日的时候才使用时间筛选
    if (current.format('YYYYMMDD') === nowDate.format('YYYYMMDD')) {
      let nowHour = nowDate.hour();

      // 返回不可用的小时:4点为判断依据
      return {
        disabledHours: () =>
          Array.from(new Array(24), (item, index) => index).filter(
            hour => hour <= nowHour || hour >= 4
          ),
      };
    }

    return {};
  }

  // 请求房型列表
  async requestProduct() {
    let { dispatch, createOrder } = this.props;
    let { checkin, checkout, channelId, hotelId, rateCode } = createOrder;

    // 缺少如下字段时不发请求
    if (!checkin || !checkout || !channelId || !hotelId || !rateCode) return false;

    let payload = {
      hotelId,
      rateCodeId: rateCode,
      channelId,
      checkInDate: checkin.format('YYYY-MM-DD'), // 转换为后台需要的格式
      checkOutDate: checkout.format('YYYY-MM-DD'), // 转换为后台需要的格式
    };

    // 发送请求
    await dispatch({
      type: 'createOrder/fetchProductList',
      payload,
    });

    this.setState({
      productIndex: 0,
    });

    message.warn('房型数据被重置,请重新设置'); // 由于房型请求后 数据(房型或者价格会变动) 所以之前选择的房型数据会被清空
  }

  // 变更渠道之后切换房价类型
  async requestRateCode() {
    let { dispatch, createOrder } = this.props;
    let {
      checkin,
      checkout,
      retentionTime,
      bookingGuest,
      channelId,
      hotelId,
      paymentType,
    } = createOrder;
    let isCanRateCode = this.validateRateCode(); // 进行数据校验 返回fase则不进行请求

    if (isCanRateCode) {
      if (checkout.isBefore(checkin)) {
        this.resetRateAndRoom();

        return message.error('离店日期请晚于入住时间');
      }

      let params = {
        checkInType: 1, // 1全天 0钟点 (目前只做全天)
        guestSourceType: bookingGuest.member ? 2 : 1, // 客源类型 1: 非会员 2：会员
        channelId, // 渠道来源
        hotelId, // 酒店id
        payType: paymentType, // 支付方式 0到付 1预付
      };

      if (checkin) params.checkInDate = checkin.format('YYYY-MM-DD HH:mm');
      if (checkout) params.checkOutDate = checkout.format('YYYY-MM-DD HH:mm');
      if (retentionTime) params.reservationDate = retentionTime.format('YYYY-MM-DD HH:mm:ss');

      let res = await dispatch({
        type: 'createOrder/fetchRateCode',
        payload: params,
      });

      res.info && message.info(res.info); // 进行提示

      if (res.statue === 1) this.requestProduct(); // 变更渠道之后切换房型
    } else {
      dispatch({
        type: 'createOrder/saveKey',
        payload: {
          isCanRateCode: false,
          rateCode: null,
          rateCodeList: [],
        },
      });
    }
  }

  // 验证是否可以发送查询策略的请求
  validateRateCode() {
    let { hotelId, checkin, checkout, retentionTime } = this.props.createOrder;

    if (!hotelId || !checkin || !checkout || !retentionTime) return false;

    return true;
  }

  /**
   * 入住离店保留时间
   * @param  {String}  key 需要改变的key
   * @param  {Moment}  val Moment对象
   * @return {Promise}     [description]
   */
  async handlerTime(key, val) {
    let isEffectAmount = false;
    let { amount, retentionTime } = this.props.createOrder;
    let payload = {};

    // 设置入离时间的时候
    if (key !== 'retentionTime') {
      isEffectAmount = true; // 改变入离时间之后会影响房源产品列表的数据 所以需要清空已选房源的数据

      val &&
        val
          .hour(12)
          .minute(0)
          .second(0); // 默认为12点
    }

    payload = {
      [key]: val,
    };

    // 判断：调整checkin后若是前一天表示4点前，配置保留时间
    if (key === 'checkin') {
      this.setState({
        checkinDay: moment(val).format('YYYY-MM-DD'),
        roomLength: 0,
      });
      if (val < moment().startOf('day')) {
        this.setState({ isMorningBooking: true });
        payload.retentionTime = moment()
          .hour(4)
          .minute(0)
          .second(0);
      } else {
        this.setState({ isMorningBooking: false });

        const currentParams = moment().format('YYYYMMDD');
        const afterTodayParams = val.format('YYYYMMDD');
        const today = moment()
          .hour(18)
          .minute(0)
          .second(0);
        const afterToday = moment(afterTodayParams)
          .hour(18)
          .minute(0)
          .second(0);

        // 判断：当天取moment日期，后一天取参数传参日期
        if (currentParams === afterTodayParams) {
          payload.retentionTime = today;
        } else {
          payload.retentionTime = afterToday;
        }
      }
    }

    if (key === 'checkout') {
      this.setState({ checkoutDay: moment(val).format('YYYY-MM-DD'), roomLength: 0 });
    }

    await this.props.dispatch({
      type: 'createOrder/saveKey',
      payload,
    });

    if (!val) return this.resetRateAndRoom(); // 删除时间的时候

    if (isEffectAmount && amount) {
      await this.props.dispatch({
        type: 'createOrder/resetRoom',
      });
    }

    this.requestRateCode(); // 变更渠道之后切换房价类型

    this.calculateDiff(val, key);
  }

  // 计算共住几晚
  calculateDiff(val, key) {
    const { roomRate, roomLength } = this.state;
    const timestramp = 24 * 60 * 60 * 1000;
    const diff =
      (new Date(key === 'checkout' ? val.format('YYYY-MM-DD') : this.state.checkoutDay) -
        new Date(key === 'checkin' ? val.format('YYYY-MM-DD') : this.state.checkinDay)) /
      timestramp;

    if (diff) {
      this.setState({ totalDays: diff });

      // const value = this.props.form.getFieldsValue(['bookingRoomTypes.count', 'roomPrice']);
      this.setTotalPrice(roomLength, roomRate, diff);
    }
  }

  // 计算总房价
  setTotalPrice = (count, price, days) => {
    const countIsNum = typeCheck('isNum', +count);
    const priceIsNum = typeCheck('isNum', +price);
    const daysIsNum = typeCheck('isNum', +days);
    if (countIsNum && priceIsNum && daysIsNum) {
      const totalAmount = count * Number(price) * days;
      this.setState({ totalAmount: totalAmount.toFixed(2) });
    }
  };

  // 发起新增订单请求
  async requestSave() {
    let isCanSave = this.validateForm(); // 上传前的字段校验

    if (this.state.isCreateLoading) return;

    if (!isCanSave.state) {
      message.error(isCanSave.msg);

      isCanSave.input && this[isCanSave.input].focus(); // 校验不通过的inpt进行焦点
      isCanSave.ref && this[isCanSave.ref].focus(); // 校验不通过的大模块
      return;
    }

    let createOrder = this.props.createOrder;
    let payload = {
      ...createOrder,
    };
    const { totalAmount } = this.state;

    payload.operatorId = this.props.user.accountId; // 操作员的id
    payload.payType = payload.paymentType;
    payload.salesmanId = payload.salesId;
    payload.checkin = payload.checkin.format('YYYY-MM-DD HH:mm:ss'); // Moment对象改为时间戳
    payload.checkout = payload.checkout.format('YYYY-MM-DD HH:mm:ss');
    payload.reserve = payload.retentionTime.format('YYYY-MM-DD HH:mm:ss');
    payload.createType = 'NORMAL';
    payload.status = 0;
    payload.amount = totalAmount;
    payload.bookingRoomTypes = [
      {
        count: payload.bookingRoomTypeList[0].number,
        roomTypeId: payload.bookingRoomTypeList[0].roomType,
        rateCode: payload.rateCode,
        roomTypeDesc: payload.bookingRoomTypeList[0].roomTypeDesc,
      },
    ];
    payload.seed = `${moment().valueOf()}${Math.round(Math.random() * 99999999)}`;

    delete payload.channelList; // 删除不需要上传的数据
    delete payload.productList;
    delete payload.rateCodeList;
    delete payload.createBooking;
    delete payload.salesList;
    delete payload.bookingGuest.memberCode;
    delete payload.bookingGuest.member;
    delete payload.retentionTime;
    delete payload.paymentType;
    delete payload.isCanRateCode;
    delete payload.createBookingType;
    delete payload.bookingType;
    delete payload.salesId;
    delete payload.rateCode;
    delete payload.bookingRoomTypeList;
    delete payload.bookingPayment; // 预定的金额

    this.setState({
      isCreateLoading: true,
    });

    let res = await this.props.dispatch({
      // 发送请求
      type: 'createOrder/createBooking',
      payload,
    });

    if (res.statue) {
      message.success('新建订单成功');

      this.props.history.push('/order/list');
    } else {
      message.error('新建订单失败');

      this.setState({
        isCreateLoading: false,
      });
    }
  }

  // 上传保存前所有字段校验
  validateForm() {
    let createOrder = this.props.createOrder;
    let { member, name, phone } = createOrder.bookingGuest;
    let {
      extBookingSn,
      checkin,
      checkout,
      retentionTime,
      hotelId,
      remark,
      bookingRoomTypeList,
      rateCode,
      channelId,
      queryChannelList,
      queryChannelListSwitch,
      accountType,
    } = createOrder;
    // let nowTime = new Date();

    if (!queryChannelListSwitch) {
      return {
        state: false,
        msg: '指定渠道接口出现问题,暂时不能下单',
      };
    }

    if (!hotelId) {
      return {
        state: false,
        msg: '请选择酒店',
        ref: 'HotelSearch',
      };
    }

    if (accountType === undefined) {
      return {
        state: false,
        msg: '请选择入账主体',
        ref: 'accountType',
      };
    }

    if (channelId === null) {
      return {
        state: false,
        msg: '请选择订单来源',
        input: 'channelId',
      };
    }

    if (channelId && queryChannelList.includes(channelId) && !extBookingSn) {
      return {
        state: false,
        msg: '该渠道请写渠道订单号',
        input: 'ExtBookingSn',
      };
    }

    // if (!checkPhone(phone)) {
    //   return {
    //     state: false,
    //     msg: '请填写正确的联系电话',
    //     input: 'bookingGuestPhone',
    //   };
    // }

    if (!name) {
      return {
        state: false,
        msg: '请填写正确的预订人',
        input: 'bookingGuestName',
      };
    }

    if (!checkin) {
      return {
        state: false,
        msg: '请填写入店时间',
        ref: 'checkin',
      };
    }

    if (!checkout) {
      return {
        state: false,
        msg: '请填写离店时间',
        ref: 'checkout',
      };
    }

    if (!retentionTime) {
      return {
        state: false,
        msg: '请填写保留时间',
        ref: 'retentionTime',
      };
    }

    if (checkout.isBefore(checkin)) {
      return {
        state: false,
        msg: '离店时间需大于入住时间',
        ref: 'checkout',
      };
    }

    if (rateCode === null) {
      return {
        state: false,
        msg: '请选择房价类型',
        ref: 'rateCode',
      };
    }

    if (bookingRoomTypeList[0].number === 0) {
      return {
        state: false,
        msg: '请选择房型',
      };
    }

    if (!bookingRoomTypeList[0].price) {
      return {
        state: false,
        msg: '房间单价范围:0-9999',
      };
    }

    return {
      state: true,
    };
  }

  getDefaultValue(val, key) {
    if (key === 'extBookingSn') {
      /** 渠道订单号过滤特殊字符 */
      return val.target.value.replace(/[^a-zA-Z0-9]/g, '');
    }
    return val.target.value;
  }

  /**
   * 处理一些表单的数据改变
   * @param  {[Object, String]}  val 需要改变的值event对象或者string
   * @param  {[type]}  key
   */
  async handlerFromVal(val, key) {
    /** 过滤特殊字符 */
    let { dispatch } = this.props;

    val = val instanceof Object ? this.getDefaultValue(val, key) : val;

    await dispatch({
      type: 'createOrder/saveKey',
      payload: {
        [key]: val,
      },
    });

    if (key === 'paymentType') {
      this.setState({ roomRate: 0 });
      this.requestRateCode();
      this.setTotalPrice(0, 0, 0);
    } // 更换支付类型的情况需要重新请求房源策略
  }

  /**
   * 处理预定人联系电话
   * @param  {Object}  e   event对象
   * @param  {String}  key 需要改变的key值
   */
  async handlerBookingGuestVal(e, key) {
    let { dispatch, createOrder } = this.props;
    let val = e.target.value;

    if (key === 'phone') {
      // 当手机号位数达到11位的时候发起是否是会员的请求
      if (val.length === 11) {
        let res = await dispatch({
          type: 'createOrder/verifyNumber',
          payload: {
            phone: val,
          },
        });

        this.requestRateCode(); // 会员变成非会员后请求价格策略
      } else {
        let lastIsNumber = createOrder.bookingGuest.member;

        await dispatch({
          type: 'createOrder/saveBookingGuest',
          payload: {
            name: '',
            memberCode: '',
            member: false,
          },
        });

        lastIsNumber && this.requestRateCode(); // 会员变成非会员后请求价格策略
      }
    }

    dispatch({
      type: 'createOrder/saveBookingGuest',
      payload: {
        [key]: val,
      },
    });
  }

  /**
   * 搜索酒店
   * @param  {Object} val type: 类型 val: 数据
   */
  handerHotel(val) {
    console.log('handerHotel:', val);
    this.setState({
      searchHotelType: val,
    });
  }

  // 重置策略以及房屋
  resetRateAndRoom() {
    this.props.dispatch({
      type: 'createOrder/resetRateCode',
    });

    this.props.dispatch({
      type: 'createOrder/resetRoom',
    });
  }

  handlerHoltelSelect = async info => {
    let { hotelId, hotelName } = info;

    this.setState({
      selectHotel: {
        hotelId,
        hotelName,
      },
    });

    await this.props.dispatch({
      type: 'createOrder/saveKey',
      payload: {
        hotelId,
      },
    });

    this.setState({
      isShowTable: false,
    });

    this.requestRateCode(); // 变更渠道之后切换放价类型
  };

  // 城市id变更时触发
  onCityChange(val) {
    this.setState({
      searchCityId: val,
    });
  }

  // 酒店搜索
  handlerHotelSearch = () => {
    this.setState({
      isShowTable: true,
    });

    this.requestHotelList();
  };

  handlerResetHotelSearch = () => {
    this.setState({
      isShowTable: false,
      searchCityId: [],
      searchHotelType: {
        ...this.state.searchHotelType,
        val: '',
      },
    });

    this.HotelInputRef.resetVal();
  };

  handlePageChange = info => {
    this.requestHotelList({
      start: info.current - 1,
      hits: info.pageSize,
    });
  };

  requestHotelList = ({ start = 0, hits = PageSize } = {}) => {
    const { dispatch } = this.props;
    const { searchHotelType, searchCityId } = this.state;

    dispatch({
      type: 'hotelLists/transHotelSearchGetList',
      payload: {
        searchHotelType,
        searchCityId,
        start,
        hits,
      },
    });
  };

  // 处理产品选择
  handlerProductList({ index, roomType, number, roomTypeDesc, price }) {
    let productList = this.props.createOrder.productList;
    let bookingRoomType = {
      roomType,
      roomTypeDesc,
      price,
      number,
    };

    let amount = this.calAmount({ price, number }) || 0;
    let product = productList[index];

    // 一个product选择之后将其他的product选择改为0
    productList = productList.map((item, i) => {
      let count = i === index ? number : 0;
      let rate = i === index ? price : item.rate;

      return {
        ...item,
        number: count,
        rate,
      };
    });

    let payload = {
      bookingRoomTypeList: [bookingRoomType],
      amount,
      productList,
    };

    if (this.props.createOrder.paymentType === 1) {
      payload.bookingPayment = {
        ...this.props.createOrder.bookingPayment,
        amount,
      };
    }

    this.props.dispatch({
      type: 'createOrder/saveKey',
      payload,
    });

    const { totalDays } = this.state;
    this.setState({
      productIndex: index,
      roomRate: price,
      roomLength: number,
    });

    this.setTotalPrice(number, price, totalDays);
  }

  /**
   * 用于最终订单总价格的计算
   * @param  {Object} [op={}] 单价以及数量的对象
   * @return {Number}         返回最终计算的金额
   */
  calAmount(op = {}) {
    let { checkin, checkout } = this.props.createOrder;
    let diffDay = Math.round(checkout.diff(checkin, 'day', true)); // 入住时间与离店时间相差日期
    let { price, number } = op;

    return Number((Number(price) * number * diffDay).toFixed(2)); // 单价 * 数量 * 天数
  }

  /**
   * 预支付金额
   * @param  {Event} e Event对象
   */
  handlerPreAmount(e) {
    let val = e.target.value;

    if (!checkFloatNumber(val)) return false;

    this.props.dispatch({
      type: 'createOrder/saveKey',
      payload: {
        bookingPayment: {
          type: 1,
          method: 15, // 支付方式：小米支付、微信支付、现金支付等
          amount: val,
        },
      },
    });
  }

  handlerSalesId(e, id) {}

  // 取消回退至首页
  cancelPage() {
    console.log(this.props.createOrder.extBookingSn);
    // this.props.history.push('/');
  }
}
