/* eslint-disable import/order */
import React, { PureComponent } from 'react';
import { Card, Button, Form, Icon, Select } from 'antd';
import { connect } from 'dva';
import router from 'umi/router';
import { stringify } from 'qs';
import moment from 'moment';
import { getFormConfig, getTableConfig, LOG_CONFIG } from './config/daily';
import PageHeaderWrapper from '@/components/PageHeaderWrapper';
import OYOForm from '@/components/OyoForm/SearchForm';
import OYOTable from '@/components/OyoTable/OyoTable.tsx';
import OYOLogModal from '@/components/OyoModal/OyoLogTableModal';
import HotelSearch from '@/components/HotelSearch/HotelSearch';
import { queryExceptionList } from './services/daily';
import { downloadFile } from '@/utils/downloadFile';
import ButtonAuthorized from '@/components/ButtonAuthorized';
import omit from 'omit.js';

const { Option } = Select;
@connect(({ daily, orderSource, loading }) => ({
  daily,
  orderSource,
  loading: loading.models.daily,
}))
@Form.create()
export default class ExceptionList extends PureComponent {
  constructor(props) {
    super(props);

    this.state = {
      tableParams: {},
      pageParams: ['page', 'limit'],
      logVisible: false,
      appealId: null,
      hotelId: null,
      isPermitExport: true,
      SOURCE_LIST_OPTION: [],
    };
  }

  componentDidMount() {
    const { dispatch } = this.props;

    dispatch({
      type: 'orderSource/fetchChannelList',
      payload: {},
    }).then(res => {
      const SOURCE_LIST = res.data;
      const SOURCE_LIST_OPTION =
        Array.isArray(SOURCE_LIST) &&
        SOURCE_LIST.map((channel, key) => (
          <Option key={`CRSChannelList-${channel.channelId}`} value={channel.channelId}>
            {channel.channelName}
          </Option>
        ));
      this.setState({ SOURCE_LIST_OPTION });
    });

    dispatch({
      type: 'daily/fetchAllAppealReason',
      payload: {},
    });
  }

  // // 操作：酒店名称模糊查询->酒店id
  // handleHotelNameSelect = value => {
  //   this.setState({ hotelId: value ? value.id : null });
  // };

  // 操作+请求：表单参数查询列表数据
  query = fieldsValue => {
    const params = {
      ...fieldsValue,
      startDate: fieldsValue.startDate ? fieldsValue.startDate.format('YYYY-MM-DD') : null,
      endDate: fieldsValue.endDate ? fieldsValue.endDate.format('YYYY-MM-DD') : null,
    };

    if (fieldsValue.hotelParams && fieldsValue.hotelParams.hotelId) {
      params.hotelId = fieldsValue.hotelParams.hotelId;
    }

    let omitParams = omit(params, ['hotelParams']);

    this.setState({ tableParams: omitParams }, () => this.oyotable.getPageList());
  };

  // 操作：重置查询条件，列表项清空
  reset = () => {
    this.oyotable.clearTable();
    this.setState({ isPermitExport: true });
  };

  // 操作：跳转至操作异常申诉任务
  toHandleExceptionTasks = (type, bookingSn, appealId) => {
    router.push({
      pathname: '/order/handleExceptionTask',
      query: {
        type, // 1：新增；2：编辑
        bookingSn: bookingSn || null,
        appealId: appealId || null,
      },
    });
  };

  // 请求：导出近7天列表数据
  exportList = () => {
    const { tableParams } = this.state;

    downloadFile(
      `/api/crs/appeal/getAppealList/down?${stringify(tableParams)}`,
      {},
      `${moment().format('YYYYMMDDHHmmss')}.xls`
    );
  };

  // 请求：table列表数据
  getList = params =>
    queryExceptionList(params)
      .then(res => {
        if (!res.data || res.data.result.length === 0) {
          this.setState({ isPermitExport: true });
          this.oyotable.clearTable();
        } else {
          this.setState({ isPermitExport: false });
        }
        const {
          data: { result, totalCount },
        } = res;
        return { data: result, total: totalCount };
      })
      .catch(e => {
        console.log(e);
        if (!e.data) {
          this.oyotable.clearTable();
          this.setState({ isPermitExport: true });
        }
      });

  // 查看操作日志
  showLogModal = appealId => {
    this.setState(
      {
        appealId,
      },
      () => {
        this.getLogList();
      }
    );
  };

  // 请求：操作日志
  getLogList = () => {
    const { dispatch } = this.props;
    const { appealId } = this.state;
    dispatch({
      type: 'daily/fetchLogList',
      payload: appealId,
    })
      .then(res => {
        if (res.code === '000') {
          this.setState({ logVisible: true });
        }
      })
      .catch(err => {
        console.log(err);
      });
  };

  render() {
    const { tableParams, pageParams, logVisible, isPermitExport, SOURCE_LIST_OPTION } = this.state;
    const {
      loading,
      daily: { logList, ALL_REASON_OPTION },
    } = this.props;
    const preventGetList = true;

    const hotelCpn = (
      <HotelSearch
        type="0"
        // onSearch={val => this.handleHotelNameSelect(val)}
        // ref={target => {
        //   this.hotelSearch = target;
        // }}
      />
    );
    this.OYOFormConfig = getFormConfig(SOURCE_LIST_OPTION, hotelCpn, ALL_REASON_OPTION);
    this.OYOTableConfig = getTableConfig(this.toHandleExceptionTasks, this.showLogModal);

    return (
      <PageHeaderWrapper>
        <Card>
          <OYOForm
            fields={this.OYOFormConfig}
            onSearch={this.query}
            onReset={this.reset}
            column={4}
          />
        </Card>
        <Card style={{ marginTop: 10 }}>
          <ButtonAuthorized
            code="CRS3.8.1"
            style={{ marginRight: 20 }}
            onClick={() => this.toHandleExceptionTasks(1, null, null)}
            icon="right"
          >
            新增处理任务
          </ButtonAuthorized>

          <ButtonAuthorized
            code="CRS3.8.2"
            icon="download"
            onClick={this.exportList}
            myDisabled={isPermitExport}
          >
            导出
          </ButtonAuthorized>
          <OYOTable
            size="small"
            bordered
            style={{ marginTop: 10 }}
            loading={loading}
            rowKey="appealId"
            params={tableParams}
            pageParams={pageParams}
            columns={this.OYOTableConfig}
            preventGetList={preventGetList}
            getList={this.getList}
            ref={target => {
              this.oyotable = target;
            }}
          />
        </Card>
        <OYOLogModal
          title="日志"
          rowKey="id"
          visible={logVisible}
          columns={LOG_CONFIG}
          dataSource={logList}
          getLogList={this.getLogList}
          onCancel={e => {
            this.setState({ logVisible: false });
          }}
        />
      </PageHeaderWrapper>
    );
  }
}
