import PageHeaderWrapper from '@/components/PageHeaderWrapper';
import { xlsx } from '@/constant/mimeType';
import {
  Badge,
  Button,
  Card,
  Col,
  Icon,
  Input,
  message,
  Row,
  Spin,
  Table,
  Timeline,
  Upload,
} from 'antd';
import { connect } from 'dva';
import React, { PureComponent } from 'react';
import router from 'umi/router';
import { getExcelFile, IgetExcelFile, uploadFile } from './services/errorHandle.ts';

const styles = require('./style.less');

@connect(({ global, user }) => ({
  global,
  user,
}))
export default class BatchAdd extends PureComponent<any, any> {
  constructor(props) {
    super(props);
    this.state = {
      res: null,
      loading: false,
    };
  }

  public componentDidMount() {}

  public customRequest = file => {
    const formData: FormData = new FormData();
    formData.append('files', file.file);
    // formData.append('field', 'file');
    this.setState({
      loading: true,
      res: null,
    });
    uploadFile({ formData, params: {} })
      .then(res => {
        if (res.code === '000') {
          this.setState({
            res: res.data,
          });
        } else {
          message.error(res.message || '上传出错');
        }
        this.setState({
          loading: false,
        });
        message.success('上传成功');
      })
      .catch(er => {
        console.log(er);
        this.setState({
          loading: false,
        });
      });
  };
  public down = (): void => {
    window.open('./cpg-template-2.xlsx');
  };

  public render() {
    const { down } = this;
    const { loading } = this.state;
    return (
      <PageHeaderWrapper title="">
        <Card className={styles.box}>
          <Timeline>
            <Timeline.Item dot={<Badge count={1} />}>
              <Button type="primary" style={{ marginLeft: 10 }} onClick={down}>
                下载模板
              </Button>{' '}
              （请参考表格完成信息采集）
            </Timeline.Item>
            <Timeline.Item dot={<Badge count={2} />}>
              <p style={{ marginLeft: 15 }}>
                上传EXCEL模板为房单号、正确金额，支付方式，且每次修改数据不得超过500条
              </p>
            </Timeline.Item>
            <Timeline.Item dot={<Badge count={3} />}>
              <Upload showUploadList={false} customRequest={this.customRequest} accept={xlsx}>
                <Button type="primary" style={{ marginLeft: 10 }}>
                  上传表格
                </Button>{' '}
              </Upload>
              （上传成功后可去订单列表等待数据更新结果）
            </Timeline.Item>
          </Timeline>
          {loading ? <Spin /> : null}
        </Card>
      </PageHeaderWrapper>
    );
  }
}
