import React, { PureComponent } from 'react';
import { Card, Form, Row, Col, Input, Button, Modal, Table, Select, message } from 'antd';
import { connect } from 'dva';
import router from 'umi/router';
import Link from 'umi/link';
import { rowProps, col4Props, formItemLayout, widthStyle } from '@/utils/formProps';
import OYOLogModal from '@/components/OyoModal/OyoLogTableModal';
import FooterToolbar from '@/components/FooterToolbar';
import PageHeaderWrapper from '@/components/PageHeaderWrapper';
import ExceptionCpn from './components/ExceptionCpn';
import ButtonAuthorized from '@/components/ButtonAuthorized';
import { getProcessingConfig, LOG_CONFIG } from './config/daily';
import { queryProcessingList } from './services/daily';
import { getUUID } from '@/utils/utils';

const FormItem = Form.Item;
const { TextArea } = Input;
const { Option } = Select;
const defaulInitV = {
  appealDetailRequest: {
    roomReservationAppealReason: {
      newReservationStatus: null,
      paymentType: null,
      newReservationAmount: null,
    },
    bookingAppealReason: {
      newBookingSource: null,
      newBookingAccount: null,
      newExtBooking: null,
      newBookingContact: null,
      newBookingContactPhone: null,
      newRemark: null,
      newBookingSn: null,
      otherContent: null,
    },
  },
};

@connect(({ global, daily, orderSource, loading }) => ({
  global,
  daily,
  orderSource,
  loading: loading.models.daily,
}))
@Form.create()
export default class HandleExceptionTask extends PureComponent {
  constructor(props) {
    super(props);
    this.tableConfig = getProcessingConfig(this.showLogModal, this.operateClick);
  }

  state = {
    logVisible: false,
    rejectModalVisible: false,
    isOrderPermit: false,
    committerRole: 'CUSTOMER_SERVICE', // 先写死默认是客服
    defaultAppealObj: {},
    appealList: [],
    APPEAL_TYPE_OPTION: [],
    bookingMsg: {},
    remark: '',
    processingList: [],
    channelList: [],
    appealDetailList: [],
    operateShow: false,
    orderDetailData: {},
  };

  componentDidMount() {
    const { type, bookingSn, appealId } = this.props.location.query;
    this.setState({
      bookingMsg: {
        type: Number(type),
        bookingSn,
        appealId,
      },
    });
    const { committerRole } = this.state;
    const params = {
      bookingSn,
      appealId,
      committerRole,
    };
    if (Number(type) === 2) {
      this.getProcessingList({ bookingSn });
      this.getEditSection(params);
    }
  }

  // 操作：创建申诉单
  handleCreate = e => {
    if (e) {
      e.preventDefault();
    }
    const { committerRole } = this.state;
    const { form } = this.props;
    form.validateFields((err, values) => {
      if (err) return;

      const params = {
        bookingSn: values.bookingSn,
        committerRole,
      };
      this.requestCreate(params);
    });
  };

  // 请求：新增-创建申诉单
  requestCreate = params => {
    const { bookingSn } = params;
    const { dispatch } = this.props;
    const { bookingMsg } = this.state;

    dispatch({
      type: 'daily/fetchCreateAppeal',
      payload: params,
    }).then(res => {
      this.setState({ bookingMsg: { ...bookingMsg, bookingSn } });
      if (res.code === '000') {
        this.getProcessingList({ bookingSn });
        message.success(res.msg);
        this.dataProcessing(res.data);
      }
    });
  };

  getOrderDetail = () => {
    let { form, dispatch } = this.props;
    let { bookingMsg } = this.state;
    dispatch({
      type: 'daily/fetchOrderDetail',
      payload: {
        source: 1,
        bookingId: bookingMsg.bookingId,
      },
    }).then(res => {
      this.setState({
        orderDetailData: res.data,
      });
    });
  };

  // 请求：操作-拉取默认数据
  getEditSection = params => {
    const { dispatch } = this.props;

    dispatch({
      type: 'daily/fetchCheckOrder',
      payload: params,
    }).then(res => {
      if (res.code === '000') {
        this.dataProcessing(res.data);
      }
    });
  };

  // 请求：根据id拉取渠道列表
  getChannelList = params => {
    const { dispatch } = this.props;
    dispatch({
      type: 'orderSource/fetchChannelListMatchId',
      payload: params,
    }).then(res => {
      const SOURCE_LIST = res.data || [];
      const SOURCE_LIST_OPTION =
        Array.isArray(SOURCE_LIST) &&
        SOURCE_LIST.map((channel, key) => (
          <Option key={`CRSChannelList-${channel.channelId}`} value={channel.channelId}>
            {channel.channelName}
          </Option>
        ));
      this.setState({ channelList: SOURCE_LIST_OPTION || [] });
    });
  };

  // 新增/操作：数据处理
  dataProcessing = data => {
    const { bookingMsg } = this.state;
    const { appealId, bookingId, hotelId } = data;
    this.getChannelList(hotelId);
    const appealReasonList = data ? data.appealReasonList || [] : [];
    const appealReason = appealReasonList.map((item, key) => (
      <Option value={item.appealReasonCode} key={`COMPLAINT_TYPE-${key}`}>
        {item.appealReasonName}
      </Option>
    ));
    const defaultList = [];
    defaultList.push({ appealReasonList, key: getUUID(), ...defaulInitV });
    this.setState(
      {
        isOrderPermit: bookingMsg.type === 1,
        appealList: defaultList,
        APPEAL_TYPE_OPTION: appealReason,
        defaultAppealObj: {
          appealReasonList,
          status: '',
          ...defaulInitV,
        },
        bookingMsg: {
          ...bookingMsg,
          appealId: +(bookingMsg.type === 1 ? appealId : bookingMsg.appealId),
          bookingId,
          hotelId,
        },
      },
      () => {
        this.getOrderDetail();
      }
    );
  };

  // 操作：重置并隐藏操作区
  handleReset = () => {
    const { form } = this.props;
    form.resetFields();
    this.setState({ isOrderPermit: false, processingList: [] });
  };

  // 请求：table列表数据
  getProcessingList = params => {
    const { dispatch } = this.props;
    dispatch({
      type: 'daily/fetchProcessingList',
      payload: params,
    }).then(res => {
      const processingList = res.data || [];
      this.setState({ processingList });
    });
  };

  // 查看操作日志
  showLogModal = appealId => {
    this.setState(
      {
        appealId,
      },
      () => {
        this.getLogList();
      }
    );
  };

  // 请求：操作日志
  getLogList = () => {
    const { dispatch } = this.props;
    const { appealId } = this.state;
    dispatch({
      type: 'daily/fetchLogList',
      payload: appealId,
    })
      .then(res => {
        if (res.code === '000') {
          this.setState({ logVisible: true });
        }
      })
      .catch(err => {
        console.log(err);
      });
  };

  // 操作：添加申诉项
  handleAddReason = () => {
    const { appealList, defaultAppealObj } = this.state;
    this.setState({
      appealList: [
        ...appealList,
        {
          ...defaultAppealObj,
          key: getUUID(),
        },
      ],
    });
  };

  // 操作：删除申诉项
  handleDeleteReason = index => {
    const { appealList } = this.state;
    const newList = appealList;
    newList.splice(index, 1);
    this.setState({ appealList: [...newList] });
  };

  // 列表操作事件
  operateClick = appealId => {
    const { appealList, defaultAppealObj, bookingMsg } = this.state;
    const { dispatch } = this.props;
    dispatch({
      type: 'daily/fetchQueryAppealDetail',
      payload: appealId,
    }).then(res => {
      let list = [];
      let isAlready = true;
      let data = res.data || [];
      data.forEach(v => {
        list.push({ ...defaultAppealObj, ...v, isAlready, key: getUUID() });
      });
      this.setState({
        operateShow: true,
        appealList: list,
      });
    });
  };

  // 请求：申诉通过/驳回
  requestAppeal = type => {
    const { committerRole, remark, bookingMsg } = this.state;
    const { dispatch } = this.props;
    if (type === 'REJECTED' && remark === '') {
      message.warn('请输入驳回原因');
      return;
    }
    if (type === 'REJECTED' && remark === '') {
      message.warn('请输入驳回原因');
      return;
    }
    dispatch({
      type: 'daily/fetchAppeal',
      payload: {
        operateType: type,
        bookingSn: bookingMsg.bookingSn,
        appealId: +bookingMsg.appealId,
        committerRole,
        remark,
      },
    }).then(res => {
      if (res.code === '000') {
        this.setState({ rejectModalVisible: false });
        message.success(res.msg);
        router.push('/order/daily');
      }
    });
  };

  render() {
    const {
      bookingMsg,
      appealId,
      logVisible,
      isOrderPermit,
      APPEAL_TYPE_OPTION,
      appealList,
      processingList,
      channelList,
      operateShow,
      orderDetailData,
    } = this.state;
    const {
      form: { getFieldDecorator },
      daily: { logList, refundDetail },
      history,
      global,
    } = this.props;
    const { type, bookingSn } = this.props.location.query;
    const handleType = Number(type);
    const showHandleSection = handleType === 1 && isOrderPermit;
    let orderStatus = global.ORDER_STATUS[orderDetailData.status];
    let orderStatusStr = orderStatus ? `(${orderStatus})` : '';

    return (
      <PageHeaderWrapper>
        <Card>
          <Form onSubmit={this.handleCreate} layout="inline">
            <Row {...rowProps}>
              <Col>
                {handleType === 1 ? (
                  <FormItem label="订单号" style={widthStyle} {...formItemLayout}>
                    {getFieldDecorator('bookingSn', {
                      initialValue: bookingSn,
                      rules: [
                        {
                          required: true,
                          message: '请输入正确的订单号',
                          pattern: '^[0-9a-zA-Z_]{1,}$',
                        },
                      ],
                    })(<Input disabled={handleType === 2} />)}
                  </FormItem>
                ) : (
                  <div>
                    <span style={{ color: '#000000d9', marginLeft: 60 }}>
                      <span style={{ color: '#f5222d', marginRight: 4, fontFamily: 'SimSun' }}>
                        *
                      </span>
                      订单号:&nbsp;&nbsp;
                    </span>
                    <Link to={`/order/detail/order?bookingId=${bookingMsg.bookingId}`}>
                      {bookingSn}
                    </Link>
                    {` ${orderStatusStr}`}
                  </div>
                )}
              </Col>
              {handleType === 1 ? (
                <Col style={{ paddingTop: 3, paddingLeft: 20 }}>
                  <Button type="primary" htmlType="submit">
                    创建申诉单
                  </Button>
                  <Button style={{ marginLeft: 20 }} onClick={this.handleReset}>
                    重置
                  </Button>
                </Col>
              ) : null}
            </Row>
          </Form>
        </Card>

        <Card title="订单处理中的任务" style={{ marginTop: 10 }}>
          <Table
            size="small"
            bordered
            scroll={{ x: true }}
            rowKey="appealId"
            columns={this.tableConfig}
            dataSource={processingList}
            pagination={false}
          />
        </Card>

        {operateShow || showHandleSection ? (
          <Card title="订单申诉操作" style={{ margin: '10px 0 20px' }}>
            {appealList.map((item, index) => (
              <ExceptionCpn
                key={item.key}
                bookingMsg={bookingMsg}
                appealDetail={item}
                itemIndex={index}
                appealReason={APPEAL_TYPE_OPTION}
                handleDelete={e => this.handleDeleteReason(index)}
                getProcessingList={this.getProcessingList}
                channelList={channelList}
                refundDetail={refundDetail}
                orderDetailData={orderDetailData}
              />
            ))}
            <ButtonAuthorized
              code="CRS3.8.9"
              icon="plus"
              onClick={this.handleAddReason}
              style={{ borderRadius: 16, padding: '0 30px', marginTop: 10 }}
            >
              添加申诉原因
            </ButtonAuthorized>
          </Card>
        ) : null}

        {operateShow || showHandleSection ? (
          <FooterToolbar>
            <ButtonAuthorized
              code="CRS3.8.10"
              onClick={e => this.requestAppeal('DONE')}
              type="primary"
            >
              全部处理完成
            </ButtonAuthorized>
          </FooterToolbar>
        ) : null}

        <OYOLogModal
          title="日志"
          visible={logVisible}
          columns={LOG_CONFIG}
          dataSource={logList}
          getLogList={this.getLogList}
          onCancel={e => {
            this.setState({ logVisible: false });
          }}
        />
      </PageHeaderWrapper>
    );
  }
}
