import React, { PureComponent } from 'react';
import { connect } from 'dva';
import { Table } from 'antd';

const columns = [
  {
    title: '操作时间',
    dataIndex: 'createTime',
    width: 200,
  },
  {
    title: '操作人',
    dataIndex: 'operatorName',
    width: 150,
  },
  {
    title: '行为',
    dataIndex: 'action',
    width: 95,
  },
  {
    title: '房单号',
    dataIndex: 'orderSn',
    width: 150,
  },
  {
    title: '详情',
    dataIndex: 'detail',
    render: (detail, record) => {
      let results = null;
      if (record.operateType === 'INVILID') {
        results = detail;
      } else if (record.operateType === 'CANCEL') {
        results = detail;
      } else if (record.operateType === 'ADD') {
        const list = JSON.parse(detail.split(','));

        results =
          list &&
          list.map((item, index) =>
            item.display === true ? (
              <p style={{ marginBottom: 0 }} key={index}>
                {item.fieldDesc} : {item.after ? item.after : '(空)'}
              </p>
            ) : null
          );
      } else if (record.operateType === 'DELETE') {
        const list = JSON.parse(detail.split(','));

        results =
          list &&
          list.map((item, index) =>
            item.display === true ? (
              <p style={{ marginBottom: 0 }} key={index}>
                {item.fieldDesc} : {item.after ? item.after : '(空)'}
              </p>
            ) : null
          );
      } else if (record.operateType === 'UPDATE') {
        const list = JSON.parse(detail.split(','));

        results =
          list &&
          list.map((item, index) =>
            item.display === true ? (
              <p style={{ marginBottom: 0 }} key={index}>
                {`${item.fieldDesc} : ${item.pre ? item.pre : '(空)'} --> ${
                  item.after ? item.after : '(空)'
                }`}
              </p>
            ) : null
          );
      }

      return results;
    },
  },
  {
    title: 'IP',
    dataIndex: 'ip',
    width: 100,
  },
];

@connect(({ order, loading }) => ({
  order,
  loading: loading.models.order,
}))
export default class JournalList extends PureComponent {
  state = {
    defaultParams: {
      bookingId: '',
      page: 1,
      limit: 10,
    },
    journalList: [],
    totalCount: 0,
  };

  componentWillMount() {
    const { defaultParams } = this.state;
    const { location } = this.props;
    const bookingId = location.query.bookingId || '';

    const params = {
      ...defaultParams,
      bookingId,
    };

    this.fetchJournalList(params);
  }

  // 请求：日志
  fetchJournalList(params) {
    this.setState({ defaultParams: params });
    const { dispatch } = this.props;

    dispatch({
      type: 'order/fetchJournalList',
      payload: params,
    })
      .then(res => {
        const journalList = res.data.result;
        const totalCount = res.data.totalCount;

        this.setState({ journalList, totalCount });
      })
      .catch(e => {
        console.log(e);
      });
  }

  // 表格分页PageNum和pageSize改变
  handlePageChange = pagination => {
    const { defaultParams } = this.state;
    const params = {
      ...defaultParams,
      page: pagination.current,
      limit: pagination.pageSize,
    };

    this.fetchJournalList(params);
  };

  render() {
    const { defaultParams, journalList, totalCount } = this.state;
    const { loading } = this.props;

    return (
      <div style={{ backgroundColor: '#fff', padding: '20px' }}>
        <Table
          loading={loading}
          rowKey={(record, index) => `${index}-${record.orderSn}-${record.createTime}`}
          bordered
          columns={columns}
          dataSource={journalList}
          pagination={{
            current: defaultParams.page,
            pageSize: defaultParams.limit,
            total: totalCount,
          }}
          onChange={this.handlePageChange}
          onShowSizeChange={this.handlePageChange}
        />
      </div>
    );
  }
}
