import React, { PureComponent, Fragment } from 'react';
import { connect } from 'dva';
import Link from 'umi/link';
import moment from 'moment';
import router from 'umi/router';
import Animate from 'rc-animate';
import {
  Row,
  Col,
  Card,
  Form,
  Input,
  Select,
  Button,
  Table,
  DatePicker,
  Badge,
  Radio,
  Tag,
  Icon,
} from 'antd';
import omit from 'omit.js';
import { PHONE, NUMBER } from '@/constant/reg';
import PageHeaderWrapper from '@/components/PageHeaderWrapper';
import HotelSearch from '@/components/HotelSearch/HotelSearch';
import ButtonAuthorized from '@/components/ButtonAuthorized';
import CitySelect from '@/components/CitySelect';
import { HOTEL_TYPE_OPTION, COOPERATION_TYPE } from '@/constant/allHotelType';
import { CHECK_IN_TYPE_OPTION } from '@/constant/checkInType';
import { PAY_TYPE_OPTION } from '@/constant/payType';

import { omitValue } from '@/utils/utils';
import {
  rowProps,
  col1Props,
  col3Props,
  col4Props,
  formItemLayout,
  formItemWithoutLabel,
  widthStyle,
} from '@/utils/formProps';

import { accSub } from '@/utils/cal';
import styles from './List.less';

const FormItem = Form.Item;
const RadioGroup = Radio.Group;
const { Option } = Select;
const { RangePicker } = DatePicker;

@connect(({ global, order, loading, user, orderSource }) => ({
  order,
  user,
  global,
  orderSource,
  loading: loading.models.order,
}))
@Form.create()
export default class OrderList extends PureComponent {
  constructor(props) {
    super(props);
    this.state = {
      showRange: [],
      rangeDefaultData: [[], [], []],
      orderSourceData: [],
      orderStatusColor: ['#f50', '#87d068', '#2db7f5', '', ''],
      tableParams: {},
      showSlide: true,
      slideName: '收起',
      slideType: 'up',
    };
    this.OYOTableColumns = [
      {
        title: '序号',
        dataIndex: 'No',
        key: 'No',
        width: 70,
      },
      {
        title: '酒店id/名称',
        dataIndex: 'hotelName',
        key: 'hotelName',
        width: 270,
        render: (hotelName, record) => (
          <span>
            {record.hotelId}
            <br />
            <Link to={`/hotel/hotelCreateEdit/index?hotelId=${record.hotelId}`}>{hotelName}</Link>
          </span>
        ),
      },
      {
        title: 'OYO订单号',
        dataIndex: 'bookingSn',
        key: 'bookingSn',
        width: 150,
      },
      {
        title: '订单来源/渠道订单号',
        dataIndex: 'channelName',
        key: 'channelName',
        width: 190,

        render: (channelName, record) => {
          const { extBookingSn } = record;
          return (
            <span style={{ wordWrap: 'break-word', wordBreak: 'break-all' }}>
              {channelName ? <p> {channelName}</p> : ''}
              {extBookingSn ? `渠道订单号：${extBookingSn}` : ''}
            </span>
          );
        },
      },
      {
        title: '房型',
        dataIndex: 'bookingRoomList',
        key: 'bookingRoomList',
        width: 150,

        render: (bookingRoomList, record) =>
          bookingRoomList &&
          bookingRoomList.map((room, key) => (
            <p key={room.id} style={{ wordWrap: 'break-word', wordBreak: 'break-all' }}>
              {room.roomTypeDesc}
              <br />
              {`${room.number}间`}
            </p>
          )),
      },
      {
        title: '入住/离店',
        dataIndex: 'checkin',
        key: 'checkin',
        width: 130,

        render: (checkin, record) => {
          const { checkout } = record;
          return (
            <span style={{ wordWrap: 'break-word', wordBreak: 'break-all' }}>
              {moment(checkin).format('YYYY-MM-DD')} <br />至 <br />
              {moment(checkout).format('YYYY-MM-DD')}
            </span>
          );
        },
      },
      {
        title: '价格',
        dataIndex: 'amount',
        key: 'amount',
        width: 150,

        render: (amount, record) => {
          const { paidAmount, actualAmount } = record;
          let payAmount = paidAmount === null ? 0 : paidAmount;

          return (
            <span style={{ wordWrap: 'break-word', wordBreak: 'break-all' }}>
              {`总价：${actualAmount}元`}
              {/* <br />
              {actualAmount - payAmount > 0
                ? `(未支付${accSub(actualAmount, payAmount)}元)`
                : `(已支付${payAmount}元)`} */}
            </span>
          );
        },
      },
      {
        title: '房价类型',
        dataIndex: 'rateType',
        key: 'rateType',
        width: 170,
        render: (amount, record) => {
          if (
            !record.bookingRoomList ||
            (record.bookingRoomList && record.bookingRoomList.length === 0)
          ) {
            return '';
          }

          return record.bookingRoomList[0].rateCodeName;
        },
      },
      {
        title: '预订人',
        dataIndex: 'guestName',
        key: 'guestName',
        width: 150,

        render: (guestName, record) => {
          const { phone } = record;
          return (
            <span style={{ wordWrap: 'break-word', wordBreak: 'break-all' }}>
              {guestName}
              <br />
              {phone}
            </span>
          );
        },
      },
      {
        title: '订单状态',
        dataIndex: 'bookingStatus',
        key: 'bookingStatus',
        width: 100,

        render: bookingStatus => (
          <Tag color={this.state.orderStatusColor[bookingStatus]}>
            {this.props.global.ORDER_STATUS[bookingStatus]}
          </Tag>
        ),
      },
      {
        title: '是否补录订单',
        dataIndex: 'createType',
        key: 'createType',
        width: 110,

        render: createType => {
          const type = createType === 'SUPPLEMENT' ? '是' : '否';
          return <span style={{ wordWrap: 'break-word', wordBreak: 'break-all' }}>{type}</span>;
        },
      },
      {
        title: '是否团队',
        dataIndex: 'isGroup',
        key: 'isGroup',
        width: 100,
        render: isGroup => (isGroup === 1 ? '是' : '否'),
      },
      {
        title: '是否有效',
        dataIndex: 'isDeleted',
        key: 'isDeleted',
        width: 150,
        render(val) {
          return (
            <Badge
              status={`${val}` === '0' ? 'success' : 'error'}
              text={`${val}` === '0' ? '订单正常' : '订单失效'}
            />
          );
        },
      },
      {
        title: '操作',
        dataIndex: 'bookingId',
        key: 'bookingId',
        fixed: 'right',
        width: 130,
        render: (bookingIdParam, record) => (
          <>
            <Button
              // code="CRS7.1.2"
              style={{ marginRight: 10 }}
              onClick={() => this.solveLink(bookingIdParam, 'detail')}
              size="small"
            >
              详 情
            </Button>
            <ButtonAuthorized
              code="CRS3.1.5"
              // style={{ marginLeft: 10 }}
              onClick={() =>
                this.props.history.push({
                  pathname: '/order/handleExceptionTask',
                  query: { type: 1, bookingSn: record.bookingSn },
                  state: {},
                })
              }
              size="small"
            >
              申诉
            </ButtonAuthorized>
            {/* <Button
              onClick={() => this.showModal(item.hotelId, item.status)}
              style={{ marginLeft: 10 }}
              size="small"
            >
              更新状态
            </Button> */}
            {record.bookingStatus === '2' && record.isRated === '0' && (
              <ButtonAuthorized
                onClick={() => this.solveLink(bookingIdParam, 'comment')}
                style={{ marginTop: 4 }}
                size="small"
                code="CRS3.1.2"
              >
                评 论
              </ButtonAuthorized>
            )}
          </>
        ),
      },
    ];
  }

  componentDidMount() {
    const { order, dispatch, form } = this.props;
    const { orderSourceData } = this.state;

    // 请求：订单列表历史的参数
    const params = order.orderListData.defaultParams;
    // 请求：订单列表(如果是非第一次进入，则重新请求数据)
    if (JSON.stringify(params) !== '{}') {
      const omitValueParams = this.setTableParam(params);
      this.setState(
        {
          tableParams: omitValueParams,
        },
        () => {
          this.queryOrderList(omitValueParams);
        }
      );
    }
    // 设置 表单默认数据
    let range = [];
    // let zone = [];

    if (params) {
      if (params.beginDate && params.endDate) {
        range = [moment(params.beginDate), moment(params.endDate)];
      }
      // if (params.cityId) {
      //   zone = [params.zoneId, params.hubId, params.cityId];
      // } else if (params.hubId) {
      //   zone = [params.zoneId, params.hubId];
      // } else if (params.zoneId) {
      //   zone = [params.zoneId];
      // }
    }

    if (range.length === 0) {
      range = [moment().subtract(30, 'day'), moment()];
    }

    form.setFieldsValue({ ...params, range });

    // 获取订单渠道来源
    if (!orderSourceData.length) {
      dispatch({
        type: 'orderSource/fetchChannelList',
      })
        .then(data => {
          this.setState({
            orderSourceData: data.data,
          });
        })
        .catch(e => {
          console.log(e);
        });
    }
  }

  // 差错订单修复入口
  handleErrorOrder = () => {
    router.push('/order/errorHandle');
  };

  // 详情链接跳转
  solveLink(id, type) {
    router.push(
      type === 'detail'
        ? `/order/detail/order?bookingId=${id}`
        : `/hotel/customerService?bookingId=${id}`
    );
  }

  // 搜索重置功能
  handleFormReset = () => {
    const { form, order, dispatch } = this.props;
    form.resetFields();
    // 重置城市选择框;
    form.setFieldsValue({
      range: [moment().subtract(30, 'day'), moment()],
    });

    dispatch({
      type: 'order/resetOrderList',
      payload: {
        pageNum: 1,
        pageSize: 10,
        totalCount: 0,
        orderList: [],
      },
    });
  };

  setTableParam = fieldsValue => {
    let paramsStr = {};
    // 时间控件用的是range需要分离为开始和截止两个字段
    if (fieldsValue && fieldsValue.range && fieldsValue.range[0] && fieldsValue.range[1]) {
      paramsStr.beginDate = fieldsValue.range[0].format('YYYY-MM-DD');
      paramsStr.endDate = fieldsValue.range[1].format('YYYY-MM-DD');
    }
    // 城市form返回的时一个数组需要剥离出三级三个字段
    // if (fieldsValue && fieldsValue.zone) {
    //   const zoneLength = fieldsValue.zone.length;
    //   if (zoneLength > 0) {
    //     paramsStr.zoneId = fieldsValue.zone[0];
    //   }
    //   if (zoneLength > 1) {
    //     paramsStr.hubId = fieldsValue.zone[1];
    //   }
    //   if (zoneLength > 2) {
    //     paramsStr.cityId = fieldsValue.zone[2];
    //   }
    // }

    if (fieldsValue.hotelParams && fieldsValue.hotelParams.hotelId) {
      fieldsValue.hotelId = fieldsValue.hotelParams.hotelId;
    }

    let params = { ...fieldsValue, ...paramsStr };
    let omitParams = omit(params, ['range', 'hotelName', 'hotelParams']);

    if (fieldsValue && fieldsValue.range && fieldsValue.range.length === 0) {
      omitParams = omit(omitParams, ['dateType']);
    }

    let omitValueParams = omitValue(omitParams, ['', undefined, null]);
    if (fieldsValue && `${fieldsValue.bookingStatus}` === '0') {
      omitValueParams.bookingStatus = 0;
    }

    return omitValueParams;
  };

  // 查询条件
  query = e => {
    if (e) {
      e.preventDefault();
    }
    const { form } = this.props;
    let fieldsValue = form.getFieldsValue();
    const omitValueParams = this.setTableParam(fieldsValue);
    console.log(omitValueParams);
    this.setState(
      {
        tableParams: omitValueParams,
      },
      () => {
        this.queryOrderList(omitValueParams);
      }
    );
  };

  // handleHotelNameSelect = value => {
  // const { form } = this.props;
  // form.setFieldsValue({
  //   hotelId: value.id,
  // });
  // };

  // 城市id变更时触发
  // onCityChange(val) {
  //   this.setState({
  //     searchCityId: val,
  //   });
  // }

  // 改变日期
  onChangeDate = e => {
    // const { form } = this.props;
    // const { rangeDefaultData } = this.state;
    // form.setFieldsValue({
    //   range: rangeDefaultData[e.target.value - 1],
    // });
  };

  // 改变日期选择范围
  onChangeRangePicker = (date, dateString) => {
    const { form } = this.props;

    form.setFieldsValue({
      range: date,
    });
  };

  // 请求：列表
  queryOrderList = params => {
    const { dispatch } = this.props;
    const payload = { page: 1, limit: 10, ...params };
    dispatch({
      type: 'order/setCustomerComment',
      payload,
    });
    dispatch({
      type: 'order/fetchOrderList',
      payload,
    }).then(res => {
      if (res && !res.data) {
        dispatch({
          type: 'order/resetOrderList',
          payload: {
            pageNum: 1,
            pageSize: 10,
            totalCount: 0,
            orderList: [],
          },
        });
      }
    });
  };

  // 表格分页pageSize和PageNum
  handlePageChange = pagination => {
    let { tableParams } = this.state;

    const params = {
      ...tableParams,
      page: pagination.current,
      limit: pagination.pageSize,
    };
    this.queryOrderList(params);
  };

  handleSlide = () => {
    const { showSlide } = this.state;
    this.setState({
      showSlide: !showSlide,
      slideName: showSlide ? '展开' : '收起',
      slideType: 'down',
    });
  };

  validator = (rule, val, callback) => {
    const { field } = rule;
    const pattern = /^[0-9a-zA-Z\s]+$/;
    if (!pattern.test(val) && val !== '') {
      callback('不可输入特殊字符');
    }
    // let str = val.replace(/^\s*|\s*$/g,"")
    // console.log(field, str)
    // this.props.form.setFieldsValue({bookingSn: str})
    callback();
  };

  changeToHandleSpaceTrim = event => {
    return event.target.value.replace(/\s+/g, '');
  };

  renderForm() {
    const {
      global,
      order,
      form: { getFieldDecorator },
    } = this.props;

    const { showRange, orderSourceData, showSlide, slideName, slideType } = this.state;
    const slideStyle = { display: showSlide ? 'block' : 'none' };

    return (
      <Form onSubmit={this.query} layout="inline" className={styles.tableList}>
        <Row {...rowProps}>
          <Col {...col4Props}>
            <FormItem style={widthStyle} label="订单号" {...formItemLayout}>
              {getFieldDecorator('bookingSn', {
                initialValue: '',
                validateTrigger: ['onChange'],
                rules: [
                  {
                    required: true,
                    validator: this.validator,
                  },
                ],
                getValueFromEvent: this.changeToHandleSpaceTrim,
              })(<Input style={{ width: '100%' }} placeholder="请输入订单号" />)}
            </FormItem>
          </Col>
          <Col {...col4Props}>
            <FormItem style={widthStyle} label="房单号" {...formItemLayout}>
              {getFieldDecorator('orderSn', {
                initialValue: '',
                getValueFromEvent: this.changeToHandleSpaceTrim,
              })(<Input style={{ width: '100%' }} placeholder="请输入房单号" />)}
            </FormItem>
          </Col>
          <Col {...col4Props}>
            <FormItem style={widthStyle} label="渠道订单号" {...formItemLayout}>
              {getFieldDecorator('extBookingSn', {
                initialValue: '',
                validateTrigger: ['onChange'],
                getValueFromEvent: this.changeToHandleSpaceTrim,
              })(<Input style={{ width: '100%' }} placeholder="请输入渠道订单号" />)}
            </FormItem>
          </Col>
          <Col {...col4Props}>
            <FormItem style={widthStyle} label="订单状态" {...formItemLayout}>
              {getFieldDecorator('bookingStatus', {
                initialValue: '',
              })(
                <Select placeholder="请选择" style={{ width: '100%' }}>
                  <Option value="">全部</Option>
                  {global.ORDER_STATUS.map((status, key) => (
                    <Option key={`ORDER_STATUS-${key}`} value={key}>
                      {status}
                    </Option>
                  ))}
                </Select>
              )}
            </FormItem>
          </Col>
        </Row>
        <Animate component="" showProp="slide" transitionAppear transitionName="slide-up">
          <div slide={showSlide.toString()} style={slideStyle}>
            <Row {...rowProps}>
              <Col {...col4Props}>
                <FormItem style={widthStyle} label="酒店OYOID" {...formItemLayout}>
                  {getFieldDecorator('hotelOyoId', {
                    initialValue: '',
                    getValueFromEvent: this.changeToHandleSpaceTrim,
                  })(<Input style={{ width: '100%' }} placeholder="请输入酒店OYOID" />)}
                </FormItem>
              </Col>
              <Col {...col4Props}>
                <FormItem style={widthStyle} label="酒店类型" {...formItemLayout}>
                  {getFieldDecorator('hotelType', {
                    initialValue: null,
                  })(<Select style={{ width: '100%' }}>{HOTEL_TYPE_OPTION}</Select>)}
                </FormItem>
              </Col>
              <Col {...col4Props}>
                <FormItem style={widthStyle} label="酒店名称" {...formItemLayout}>
                  {getFieldDecorator('hotelParams', {
                    initialValue: '',
                  })(<HotelSearch type="0" />)}
                </FormItem>
              </Col>
              <Col {...col4Props}>
                <FormItem style={widthStyle} label="酒店ID" {...formItemLayout}>
                  {getFieldDecorator('hotelId', {
                    rules: [
                      {
                        pattern: NUMBER,
                        message: '酒店ID只能是数字',
                      },
                    ],
                    getValueFromEvent: this.changeToHandleSpaceTrim,
                  })(<Input style={{ width: '100%' }} placeholder="请输入酒店ID" />)}
                </FormItem>
              </Col>
            </Row>
            <Row {...rowProps}>
              <Col {...col4Props}>
                <FormItem style={widthStyle} label="订单来源" {...formItemLayout}>
                  {getFieldDecorator('channelId', {
                    initialValue: '',
                  })(
                    <Select placeholder="请选择" style={{ width: '100%' }}>
                      <Option value="" key="CRSChannelList-all">
                        全部
                      </Option>
                      {orderSourceData.map((channel, key) => (
                        <Option
                          key={`CRSChannelList-${channel.channelId}`}
                          value={channel.channelId}
                        >
                          {channel.channelName}
                        </Option>
                      ))}
                    </Select>
                  )}
                </FormItem>
              </Col>
              <Col {...col4Props}>
                <FormItem style={widthStyle} label="酒店协议类型" {...formItemLayout}>
                  {getFieldDecorator('cooperationType', {
                    initialValue: 0,
                  })(
                    <Select placeholder="请选择" style={{ width: '100%' }}>
                      {COOPERATION_TYPE.map((cooperation, index) => (
                        <Option key={index} value={cooperation.value}>
                          {cooperation.label}
                        </Option>
                      ))}
                    </Select>
                  )}
                </FormItem>
              </Col>
              <Col {...col4Props}>
                <FormItem style={widthStyle} label="入住类型" {...formItemLayout}>
                  {getFieldDecorator('bookingType', {
                    initialValue: null,
                  })(<Select style={{ width: '100%' }}>{CHECK_IN_TYPE_OPTION}</Select>)}
                </FormItem>
              </Col>
              <Col {...col4Props}>
                <FormItem style={widthStyle} label="支付类型" {...formItemLayout}>
                  {getFieldDecorator('paymentType', {
                    initialValue: null,
                  })(<Select style={{ width: '100%' }}>{PAY_TYPE_OPTION}</Select>)}
                </FormItem>
              </Col>
            </Row>
            <Row {...rowProps}>
              {/* <Col {...col4Props}>
                <FormItem style={widthStyle} label="区域" {...formItemLayout}>
                  {getFieldDecorator('zone', {
                    initialValue: '',
                  })(
                    <CitySelect
                      type="areaList"
                      style={{ width: '100%' }}
                      onChange={val => this.onCityChange(val)}
                      changeOnSelect
                    />
                  )}
                </FormItem>
              </Col> */}
              <Col {...col4Props}>
                <FormItem style={widthStyle} label="客人姓名" {...formItemLayout}>
                  {getFieldDecorator('bookingGuestName', {
                    initialValue: '',
                  })(<Input style={{ width: '100%' }} placeholder="预订人/联系人/入住人" />)}
                </FormItem>
              </Col>
              <Col {...col4Props}>
                <FormItem style={widthStyle} label="客人手机号" {...formItemLayout}>
                  {getFieldDecorator('phone', {
                    initialValue: '',
                    rules: [
                      {
                        required: false,
                        pattern: PHONE,
                        message: '请输入正确的11位联系电话',
                      },
                    ],
                  })(<Input style={{ width: '100%' }} placeholder="请输入手机号" />)}
                </FormItem>
              </Col>
              <Col {...col4Props}>
                <FormItem style={widthStyle} label="SALES ID" {...formItemLayout}>
                  {getFieldDecorator('salesmanId', {
                    initialValue: '',
                    getValueFromEvent: this.changeToHandleSpaceTrim,
                  })(<Input placeholder="请输入SALES ID" />)}
                </FormItem>
              </Col>
              <Col {...col4Props}>
                <FormItem style={widthStyle} label="是否有效" {...formItemLayout}>
                  {getFieldDecorator('isDeleted', {
                    initialValue: '',
                  })(
                    <Select placeholder="请选择" style={{ width: '100%' }}>
                      <Option value="" key="IS_DELETED_ALL">
                        全部订单
                      </Option>
                      <Option value="0" key="IS_DELETED_0">
                        正常订单
                      </Option>
                      <Option value="1" key="IS_DELETED_1">
                        失效订单
                      </Option>
                    </Select>
                  )}
                </FormItem>
              </Col>
            </Row>
            <Row {...rowProps}>
              <Col {...col4Props}>
                <FormItem style={widthStyle} label="日期类型" {...formItemLayout}>
                  {getFieldDecorator('dateType', {
                    initialValue: 1,
                  })(
                    <RadioGroup className={styles.dateRadioGroup} onChange={this.onChangeDate}>
                      <Radio value={1}>预订</Radio>
                      <Radio value={2}>入住</Radio>
                      <Radio value={3}>离店</Radio>
                    </RadioGroup>
                  )}
                </FormItem>
              </Col>
              <Col {...col4Props}>
                <FormItem style={widthStyle} {...formItemWithoutLabel}>
                  {getFieldDecorator('range', {
                    initialValue: showRange,
                  })(
                    <RangePicker
                      allowClear={false}
                      style={{ width: '100%' }}
                      format="YYYY-MM-DD"
                      onChange={this.onChangeRangePicker}
                    />
                  )}
                </FormItem>
              </Col>
              <Col {...col4Props}>
                <FormItem style={widthStyle} label="是否补录" {...formItemLayout}>
                  {getFieldDecorator('createType', {
                    initialValue: '',
                  })(
                    <Select style={{ width: '100%' }}>
                      <Option value="" key="ORDER_STATUS-0">
                        全部
                      </Option>
                      <Option value="NORMAL" key="ORDER_STATUS-1">
                        非补录订单
                      </Option>
                      <Option value="SUPPLEMENT" key="ORDER_STATUS-2">
                        补录订单
                      </Option>
                    </Select>
                  )}
                </FormItem>
              </Col>
              <Col {...col4Props}>
                <FormItem style={widthStyle} label="是否团单" {...formItemLayout}>
                  {getFieldDecorator('isGroup', {
                    initialValue: null,
                  })(
                    <Select style={{ width: '100%' }}>
                      <Option value={null} key="IS_GROUP_ALL">
                        全部
                      </Option>
                      <Option value={0} key="IS_GROUP_0">
                        非团单
                      </Option>
                      <Option value={1} key="IS_GROUP_1">
                        团单
                      </Option>
                    </Select>
                  )}
                </FormItem>
              </Col>
            </Row>
          </div>
        </Animate>

        <Row {...rowProps} style={{ textAlign: 'center' }}>
          <Col {...col1Props}>
            <span className={styles.submitButtons}>
              <Button type="primary" htmlType="submit">
                查询
              </Button>
              <Button style={{ marginLeft: 20 }} onClick={this.handleFormReset}>
                重置
              </Button>
              <span className={styles.slideBtn} onClick={this.handleSlide}>
                {slideName}
                <Icon type={slideType} style={{ fontSize: 12, marginLeft: 8 }} />
              </span>
            </span>
          </Col>
        </Row>
      </Form>
    );
  }

  render() {
    const {
      order: { orderListData },
      loading,
    } = this.props;
    const { pageNum, pageSize, totalCount, orderList } = orderListData;
    const { params, channelData } = this.state;
    const preventGetList = true;
    return (
      <PageHeaderWrapper>
        <Card>{this.renderForm()}</Card>
        <Card style={{ marginTop: 15 }}>
          <Table
            size="small"
            bordered
            loading={loading}
            rowKey="bookingId"
            scroll={{ x: 2000 }}
            columns={this.OYOTableColumns}
            dataSource={orderList}
            pagination={
              totalCount > 10
                ? {
                    showSizeChanger: true,
                    current: pageNum,
                    pageSize,
                    total: totalCount,
                    showTotal: total =>
                      total === 1000 ? `查询结果最多只显示1000条` : `当前条件下，共${total}条结果`,
                  }
                : false
            }
            onChange={this.handlePageChange}
            onShowSizeChange={this.handlePageChange}
            expandedRowRender={record => (
              <p style={{ margin: 0 }}>{`备注：${record.remark ? record.remark : '无'}`}</p>
            )}
          />
        </Card>
      </PageHeaderWrapper>
    );
  }
}
