import React, { PureComponent, Fragment, Component } from 'react';
import {
  Card,
  Button,
  Form,
  Col,
  Row,
  DatePicker,
  Input,
  Select,
  Modal,
  Message,
  Radio,
  Popover,
  Empty,
  Table,
} from 'antd';
import { connect } from 'dva';
import router from 'umi/router';
import moment from 'moment';
import { RULES } from '@/utils/validateRule';
import { PHONE } from '@/constant/reg';
import { disabledDate, typeCheck } from '@/utils/utils';
import BookingRoom from './components/BookingRoom';
import { accSub, accMul } from '@/utils/cal';
import ButtonAuthorized from '@/components/ButtonAuthorized';
import FooterToolbar from '@/components/FooterToolbar';
import OrderDeleteModal from './components/OrderDeleteModal';
import styles from './Order.less';
import CidHandleModel from './components/CidHandle';
import VOCHandleModel from './components/VOCHandle';

import {
  formItemLayout,
  formItemLayout2,
  formLayout,
  wrapperCol,
  rowProps,
  col1Props,
  col3Props,
  col4Props,
  widthStyle,
} from '@/utils/formProps';

const { Option } = Select;
const RadioGroup = Radio.Group;
const { TextArea } = Input;

@connect(({ loading, order, global, user }) => ({
  global,
  order,
  user,
  loading: loading.models.order,
  deleteLoading: loading.effects['order/cancel'],
  cancelLoading: loading.effects['order/delete'],
  queringCIDHandle: loading.effects['preventCID/queryCIDHandle'],
}))
@Form.create()
export default class OrderDetail extends Component {
  state = {
    bookingId: '',
    updatingVisible: true,
    bookingRoomList: [],
    source: 1,
    price: null,
    number: null,
    reasonList: [],
    cancelModalVisiable: false,
    deleteModalVisiable: false,
    amount: null,
    cancelReasonId: 0,
    cancelReasonText: null,
    arrivalTime: null,
    departureTime: null,
    actualAmount: 0,
    cidModalVisiable: false,
    vocModalVisiable: false,
  };

  componentWillMount() {
    const { dispatch, location } = this.props;
    const { source } = this.state;
    const bookingId = location.query.bookingId || '';
    this.setState({ bookingId });
    if (bookingId === '') {
      router.push('/order/list');
      return;
    }
    dispatch({ type: 'order/fetchOrderDetail', payload: { bookingId, source } }).then(resp => {
      if (resp.code === '000') {
        const { bookingRoomList, arrivalTime, departureTime } = resp.data;
        this.setState({
          bookingRoomList,
          source,
          arrivalTime,
          departureTime,
          price: bookingRoomList[0].price,
          number: bookingRoomList[0].number,
        });

        const channelId = resp.data.source;
        const { hotelId, updateTime } = resp.data;
        // by huang, 获取房价范围接口新增
        const roomTypeId = bookingRoomList[0].roomType;
        const rateCodeId = bookingRoomList[0].rateCode;
        // this.handleHotelDepartureTime(resp.data.hotelId);
        this.handleRangePrice({
          hotelId,
          channelId,
          roomTypeId,
          rateCodeId,
          historyDate: updateTime,
        });
      }
    });
  }

  componentDidMount() {
    const { dispatch } = this.props;
    // 获取订单来源列表
    dispatch({
      type: 'order/fetchCRSChannelList',
      // payload: {},
    });

    // 获取酒店名称列表
    // dispatch({
    //   type: 'order/fetchSuggestHotel',
    // });
  }

  handleHotelNameSelect = value => {
    const { form, dispatch } = this.props;

    this.handleHotelDepartureTime(value);
  };

  handleHotelNameFocus = () => {
    const { form, dispatch } = this.props;
    dispatch({
      type: 'order/setSuggestHotelList',
      payload: [],
    });
  };

  // 获取酒店标准离店时间
  handleHotelDepartureTime = value => {
    const { dispatch, order, form } = this.props;
    dispatch({
      type: 'order/fetchHotelBaseInfo',
      payload: {
        hotelId: value,
      },
    }).then(resp => {
      if (resp && resp.code === '000') {
        const { checkoutTime } = resp.data;
        const baseCheckoutTime = moment(checkoutTime).format('YYYY-MM-DD HH:mm:ss');

        const hours = moment(baseCheckoutTime).get('hour');
        const minutes = moment(baseCheckoutTime).get('minute');
        const defaultTime = form.getFieldValue('departureTime');
        form.setFieldsValue({ departureTime: defaultTime.hour(hours).minute(minutes) });
      }
    });
  };

  // 处理：改变订单来源
  // handleChannel = channelId => {
  //   this.setState({ channelId });
  //   const {
  //     order: { orderDetailData },
  //   } = this.props;
  //   const { hotelId } = orderDetailData;
  //   const { roomType, rateCode } = orderDetailData.bookingRoomList[0];
  //   this.handleRangePrice({ hotelId, channelId, roomTypeId: roomType, rateCodeId: rateCode });
  // };

  // 获取：房价策略的限制条件参数
  handleRangePrice = ({
    hotelId = '',
    roomTypeId = '',
    rateCodeId = '',
    channelId = '',
    historyDate = null,
  }) => {
    const { dispatch } = this.props;
    if (hotelId === '' || roomTypeId === '' || rateCodeId === '' || channelId === '') {
      return;
    }
    dispatch({
      type: 'order/fetchRangePrice',
      payload: {
        hotelId,
        channelId,
        roomTypeId,
        rateCodeId,
        historyDate,
      },
    }).then(resp => {
      if (resp && resp.code === '000') {
        this.setState({
          rangePrice: resp.data,
        });
      }
    });
  };

  // 获取离店时间限制
  disabledReserveTime = current => {
    const { orderDetailData } = this.props.order;
    const checkin = moment(
      orderDetailData && (orderDetailData.arrivalTime || orderDetailData.arrivalDate)
    );

    const today = moment().endOf('day');
    const yestoday = today.subtract(1, 'days').endOf('day');
    const tomorrow = today.add(1, 'days').endOf('day');
    return current && current < yestoday;
  };

  // 改变支付类型
  // handlePaymentType(e) {
  //   const { setFieldsValue } = this.props.form;
  //   const { bookingRoomList } = this.state;
  //   e === 0
  //     ? setFieldsValue({ paidAmount: 0 })
  //     : setFieldsValue({ paidAmount: bookingRoomList[0].price });
  // }

  handleUpdatingVisible = () => {
    const { updatingVisible } = this.state;
    this.setState({ updatingVisible: !updatingVisible });
  };

  // 取消订单 按钮点击事件：获取取消理由和打开modal层
  handleOrderCancel = () => {
    const { dispatch, order } = this.props;
    const { bookingId, source } = this.state;

    dispatch({ type: 'order/fetchCancelReason' })
      .then(resp => {
        const reasonList = resp.data;
        this.setState({ reasonList, cancelModalVisiable: true });
      })
      .catch(e => {
        console.log(e);
      });
  };

  // 失效订单 按钮点击事件：打开modal层
  handleOrderDelete = open => {
    if (open === undefined) return;
    this.formRef.props.form.resetFields();
    this.setState({
      deleteModalVisiable: open,
    });
  };

  handleRoomTypeChange = (value, roomTypeListIndex) => {
    // console.log('handleRoomTypeChange:', value, roomTypeListIndex);
    const roomType = value;
    const { dispatch, order } = this.props;
    let { bookingRoomList } = this.state;
    const { roomTypeList } = order;

    const room = roomTypeList.find(item => item.id === roomType);
    bookingRoomList[roomTypeListIndex].roomType = roomType;
    bookingRoomList[roomTypeListIndex].roomTypeDesc = room.name;
    bookingRoomList[roomTypeListIndex].price = +room.rate; // 价格
    bookingRoomList[roomTypeListIndex].listRate = room.listRate; // 门市价格
    bookingRoomList[roomTypeListIndex].inventory = room.inventory; // 门市价格

    this.setState({ bookingRoomList });
  };

  handleRoomNumberChange = (value, index) => {
    const number = value;
    let { bookingRoomList } = this.state;
    // console.log('handleRoomNumberChange:', bookingRoomList);
    bookingRoomList[index].number = number;
    this.setState({ bookingRoomList });
  };

  handleRoomPriceChange = (price, roomTypeListIndex) => {
    const { dispatch } = this.props;
    if (price <= 0) {
      Message.warn('房价不能小于0');
      return;
    }

    dispatch({
      type: 'order/updateRoomTypePrice',
      payload: {
        price,
        roomTypeListIndex,
      },
    });
  };

  onCancelReasonChange = e => {
    this.setState({
      cancelReasonId: e.target.value,
    });
  };

  cancelReasonText = e => {
    this.setState({ cancelReasonText: e.target.value });
  };

  // 取消订单弹框 确认操作事件
  onOkCancel = () => {
    const { bookingId, cancelReasonId, cancelReasonText, reasonList, source } = this.state;
    const {
      order: { orderDetailData },
      dispatch,
      form,
    } = this.props;
    const { operatorId } = orderDetailData;

    let cancelReason = cancelReasonId === 5 ? cancelReasonText : reasonList[cancelReasonId].name;

    dispatch({
      type: 'order/cancel',
      payload: { bookingId: +bookingId, operatorId, reasonCode: cancelReasonId, cancelReason },
    }).then(data => {
      if (data.code === '000') {
        this.setState({
          cancelModalVisiable: false,
        });
        Message.success('订单取消成功');
        dispatch({ type: 'order/fetchOrderDetail', payload: { bookingId, source } }).then(res => {
          const { cancelTime, otaRemark } = res.data;
          const reason = res.data.cancelReason;
          if (cancelTime && reason && otaRemark) {
            form.setFieldsValue({
              otaRemark: `${otaRemark}\n${cancelTime}客服取消，取消原因：${reason}`,
            });
          }
        });
      }
    });
  };

  // 取消订单弹框 取消操作事件
  onCancelCancel = () => {
    this.setState({
      cancelModalVisiable: false,
    });
  };

  // 删除订单弹框 确认操作事件
  onOkDelete = () => {
    const { dispatch, order } = this.props;
    const { bookingId, source } = this.state;

    const form = this.formRef.props.form;

    const valuesF = form.getFieldsValue(['sysRemark']);
    const { sysRemark } = valuesF;
    const rules = /^.{1,50}$/;
    const result = rules.test(sysRemark);

    if (sysRemark === undefined) {
      Message.error('备注信息必填');
      return;
    }
    if (!result) {
      Message.error('最多50个字符');
      return;
    }

    dispatch({
      type: 'order/delete',
      payload: {
        bookingId,
        source,
        operatorId: order.orderDetailData.operatorId,
        sysRemark,
      },
    })
      .then(data => {
        Message.success('订单删除成功');
        this.handleOrderDelete(false);
        dispatch({
          type: 'order/fetchOrderDetail',
          payload: { bookingId, source },
        });
      })
      .catch(e => {
        this.handleOrderDelete(false);
        console.log(e);
      });
  };

  // 删除订单弹框 取消操作事件
  onCancelDelete = () => {
    this.setState({
      deleteModalVisiable: false,
    });
  };

  checkHasEmptyPrice = () => {
    const {
      order: { orderDetailData },
    } = this.props;

    const bookingRoomList = orderDetailData.bookingRoomList;

    const hasEmptyPrice =
      bookingRoomList.length > 0 &&
      bookingRoomList.some(room => room.price === null || room.price === undefined);
    return hasEmptyPrice;
  };

  // 计算总房价
  setTotalPrice = (count, price, days) => {
    const {
      order: { orderDetailData },
    } = this.props;
    const countIsNum = typeCheck('isNum', count);
    const priceIsNum = typeCheck('isNum', +price);
    const daysIsNum = typeCheck('isNum', days);
    if (countIsNum && priceIsNum && daysIsNum) {
      let amount = accMul(accMul(count, price), days);

      if (Number.isNaN(amount)) {
        amount = '???';
      }

      this.setState({
        amount,
        // actualAmount: Math.max(accSub(amount, orderDetailData.memberTotalPrice || 0), 0),
      });
      this.props.form.setFieldsValue({
        amount,
        actualAmount: Math.max(accSub(amount, orderDetailData.memberTotalPrice || 0), 0),
      });
    }
  };

  calculateDay = (arrivalTime, departureTime) => {
    // const { arrivalTime, departureTime } = this.state;
    const checkin = moment(arrivalTime).format('YYYY-MM-DD');
    const checkout = moment(departureTime).format('YYYY-MM-DD');
    const timestramp = 24 * 60 * 60 * 1000;
    const diff = (new Date(checkout) - new Date(checkin)) / timestramp;

    return diff;
  };

  // 计算共住几晚
  calculateDiff = (type, index, val) => {
    const {
      order: { orderDetailData },
    } = this.props;
    // const bookingRoomList = orderDetailData.bookingRoomList;
    let { arrivalTime, departureTime, bookingRoomList } = this.state;
    let diff = this.calculateDay(arrivalTime, departureTime);
    if (type === 'checkout') {
      departureTime = val;
      diff = this.calculateDay(arrivalTime, departureTime);
      this.setState({ departureTime }, () => {
        let { number, price } = this.state;

        this.setTotalPrice(number, price, diff);
      });
    }

    if (type === 'price') {
      // bookingRoomList[index].price = val;
      // this.setState({price: val});
      this.setState({ price: val }, () => {
        let { number, price } = this.state;
        this.setTotalPrice(number, price, diff);
      });
    }

    if (type === 'number') {
      // bookingRoomList[index].number = val;
      this.setState({ number: val }, () => {
        let { number, price } = this.state;
        this.setTotalPrice(number, price, diff);
      });
    }
  };

  // 修改保存订单
  handleFormUpdate = e => {
    e.preventDefault();
    const {
      dispatch,
      form,
      order: { orderDetailData },
    } = this.props;

    const { bookingId, bookingRoomList, number, amount } = this.state;
    const bookingRoomList2 = orderDetailData.bookingRoomList;

    const { hotelId, operatorId, bookingSn, source } = orderDetailData;

    form.validateFields((err, fieldsValue) => {
      let isCanUpdate = true;

      if (err) {
        isCanUpdate = false;
      }

      if (this.bookingRoomRef) {
        this.bookingRoomRef.getForm().validateFields(error => {
          if (error) {
            isCanUpdate = false;
          }
        });
      }

      if (!isCanUpdate) {
        this.setState({ updatingVisible: false });
        return;
      }
      console.log(fieldsValue);
      // const hasEmptyPrice = this.checkHasEmptyPrice();
      // if (hasEmptyPrice) {
      //   Message.error('请输入房价，同时房价不能为0');
      //   return;
      // }
      const { otaRemark, remark, bookingGuest, paymentType, extBookingSn } = fieldsValue;
      const checkin = fieldsValue.arrivalTime.format('YYYY-MM-DD HH:mm:ss');
      const checkout = fieldsValue.departureTime.format('YYYY-MM-DD HH:mm:ss');
      const nameTrim = fieldsValue.bookingGuest.name;

      if (!nameTrim) {
        return;
      }

      const params = {
        bookingGuest: {
          name: bookingGuest.name.trim(),
          phone: bookingGuest.phone,
          memberId: bookingGuest.id,
        },
        bookingRoomTypes: [
          {
            count: number || bookingRoomList[0].number,
            rateCode: bookingRoomList[0].rateCode,
            roomTypeId: bookingRoomList[0].roomType,
            roomTypeDesc: bookingRoomList[0].roomTypeDesc,
          },
        ],
        accountType: fieldsValue.accountType,
        checkin,
        checkout,
        id: +bookingId,
        hotelId,
        channelId: source,
        extBookingSn,
        bookingSn,
        payType: paymentType,
        amount: amount ? `${amount.toFixed(2)}` : `${orderDetailData.amount.toFixed(2)}`,
        remark,
        otaRemark,
        operatorId,
      };

      // 全 天房
      if (orderDetailData.type === 1 && fieldsValue.retentionTime) {
        params.reserve = fieldsValue.retentionTime.format('YYYY-MM-DD HH:mm:ss');
      }

      dispatch({ type: 'order/updateOrderDetail', payload: params }).then(data => {
        if (data.code === '000') {
          this.setState({ updatingVisible: true });
          Message.success(data.msg || '订单更新成功');
        }
      });
    });
  };

  renderBookingRoomList = () => {
    const { form, order } = this.props;
    const { orderDetailData, roomTypeList } = order;
    const { bookingRoomList } = this.state;
    const { updatingVisible, rangePrice } = this.state;

    return (
      bookingRoomList.length !== 0 &&
      bookingRoomList.map((room, bookingRoomListIndex) => (
        <BookingRoom
          ref={ref => {
            this.bookingRoomRef = ref;
          }}
          key={bookingRoomListIndex}
          rangePrice={rangePrice}
          room={room}
          roomNumber={room.number}
          bookingRoomListIndex={bookingRoomListIndex}
          updatingVisible={updatingVisible}
          roomTypeList={roomTypeList}
          onSelectRoomType={this.handleRoomTypeChange}
          onSelectRoomNumber={this.handleRoomNumberChange}
          onChangeRoomPrice={this.handleRoomPriceChange}
          getDiffParams={this.calculateDiff}
        />
      ))
    );
  };

  renderEmptyForm = () => (
    <Card>
      <Empty />
    </Card>
  );

  renderNotEmptyForm = () => {
    const { order, form, global, queringCIDHandle } = this.props;
    const { orderDetailData } = order;
    const { updatingVisible } = this.state;
    const { discountInfo } = orderDetailData;
    const { MEMBER, OYO, OYO_MEMBER, HOTEL, COUPON } = discountInfo;
    const buttonTxt = !updatingVisible ? '保存订单' : '修改订单';
    const { changeOrderStatus, cancelOrderStatus } = this.orderIsChange(orderDetailData);

    let optRemarkInitial = '';
    if (orderDetailData.cancelReason && orderDetailData.otaRemark) {
      optRemarkInitial = `${orderDetailData.otaRemark}\n${
        orderDetailData.cancelTime
      }客服取消，取消原因：${orderDetailData.cancelReason}`;
    } else if (orderDetailData.cancelReason && !orderDetailData.otaRemark) {
      optRemarkInitial = `${orderDetailData.cancelTime}客服取消，取消原因：${
        orderDetailData.cancelReason
      }`;
    } else {
      optRemarkInitial = orderDetailData.otaRemark;
    }

    const arrivalEarliestTime =
      orderDetailData && orderDetailData.arrivalEarliestTime
        ? `${orderDetailData.arrivalEarliestTime} - `
        : null;
    const arrivalLatestTime = orderDetailData && orderDetailData.arrivalLatestTime;
    const times =
      arrivalEarliestTime || arrivalLatestTime ? arrivalEarliestTime + arrivalLatestTime : null;
    const remarkFormItemLayout = {
      labelCol: { span: 2 },
      wrapperCol: { span: 22 },
    };

    const refundOrderType =
      orderDetailData && orderDetailData.showRefundStatus && orderDetailData.payStatusDesc
        ? `| ${orderDetailData.payStatusDesc}`
        : null;

    return (
      <Fragment>
        <Form layout={formLayout.horizontal} hideRequiredMark className={styles.order}>
          {/* 基本信息 */}
          <Card
            title="基本信息"
            style={{ marginBottom: '24px' }}
            extra={
              <span style={{ color: '#ff4d4f', fontWeight: '800' }}>
                订单状态：
                {global.ORDER_STATUS[orderDetailData.status]} {refundOrderType}
              </span>
            }
            bordered={false}
          >
            <Row {...rowProps}>
              <Col {...col4Props}>
                <Form.Item label="OYO订单号" {...formItemLayout}>
                  {form.getFieldDecorator('bookingSn', {
                    initialValue: (orderDetailData && orderDetailData.bookingSn) || '',
                  })(<Input disabled />)}
                </Form.Item>
              </Col>
              <Col {...col4Props}>
                <Form.Item label="订单来源" {...formItemLayout}>
                  {form.getFieldDecorator('channelName', {
                    initialValue: (orderDetailData && orderDetailData.channelName) || '',
                    rules: [{ required: true, message: '请选择订单来源' }],
                  })(
                    <Input disabled />
                    // <Select
                    //   placeholder="请选择"
                    //   style={{ width: '100%' }}
                    //   disabled={updatingVisible}
                    //   onChange={e => this.handleChannel(e)}
                    // >
                    //   {order.CRSChannelList.map((channel, key) => (
                    //     <Option
                    //       key={`CRSChannelList-${channel.channelId}`}
                    //       value={channel.channelId}
                    //     >
                    //       {channel.channelName}
                    //     </Option>
                    //   ))}
                    // </Select>
                  )}
                </Form.Item>
              </Col>
              <Col {...col4Props}>
                <Form.Item label="渠道订单号" {...formItemLayout}>
                  {form.getFieldDecorator('extBookingSn', {
                    initialValue: (orderDetailData && orderDetailData.extBookingSn) || '',
                    rules: [
                      {
                        required: true,
                        message: '请输入正确的渠道订单号',
                        pattern: '^[0-9a-zA-Z_]{1,}$',
                      },
                    ],
                  })(<Input disabled={updatingVisible} />)}
                </Form.Item>
              </Col>
            </Row>
            <Row {...rowProps}>
              {/* <Col {...col4Props}>
                <Form.Item label="创建人" {...formItemLayout}>
                  {form.getFieldDecorator('creator', {
                    initialValue: (orderDetailData && orderDetailData.creator) || '',
                  })(<Input disabled />)}
                </Form.Item>
              </Col> */}
              <Col {...col4Props}>
                <Form.Item label="预订人" {...formItemLayout}>
                  {form.getFieldDecorator('bookingGuest.name', {
                    rules: [
                      {
                        required: true,
                        message: '请输入预订人',
                        pattern: '^(?!(\\s+$))',
                      },
                    ],
                    initialValue:
                      orderDetailData &&
                      orderDetailData.bookingGuest &&
                      orderDetailData.bookingGuest.name,
                  })(<Input disabled={updatingVisible} />)}
                </Form.Item>
              </Col>
              <Col {...col4Props}>
                <Form.Item label="预订人手机" {...formItemLayout}>
                  {form.getFieldDecorator('bookingGuest.phone', {
                    initialValue:
                      orderDetailData &&
                      orderDetailData.bookingGuest &&
                      orderDetailData.bookingGuest.phone,
                    rules: [
                      {
                        message: '请输入正确的手机号码',
                        pattern: PHONE,
                      },
                    ],
                  })(
                    <Input
                      // disabled
                      disabled={updatingVisible}
                      type="tel"
                      maxLength={11}
                    />
                  )}
                </Form.Item>
              </Col>
              <Col {...col4Props}>
                <Form.Item label="联系人" {...formItemLayout}>
                  {form.getFieldDecorator('bookingContact.name', {
                    initialValue:
                      orderDetailData &&
                      orderDetailData.bookingContact &&
                      orderDetailData.bookingContact.name,
                  })(<Input disabled />)}
                </Form.Item>
              </Col>
              <Col {...col4Props}>
                <Form.Item label="联系人手机" {...formItemLayout}>
                  {form.getFieldDecorator('bookingContact.phone', {
                    initialValue:
                      orderDetailData &&
                      orderDetailData.bookingContact &&
                      orderDetailData.bookingContact.phone,
                  })(<Input disabled />)}
                </Form.Item>
              </Col>
              {/* <Col {...col4Props} style={{ display: 'none' }}>
                <Form.Item label="预订人id">
                  {form.getFieldDecorator('bookingGuest.id', {
                    initialValue:
                      orderDetailData &&
                      orderDetailData.bookingGuest &&
                      orderDetailData.bookingGuest.id,
                  })(<Input disabled />)}
                </Form.Item>
              </Col> */}
            </Row>
            <Row {...rowProps}>
              <Col {...col4Props}>
                <Form.Item label="入账主体" {...formItemLayout}>
                  {form.getFieldDecorator('accountType', {
                    initialValue: orderDetailData && orderDetailData.accountType,
                  })(
                    <Select disabled={updatingVisible || orderDetailData.paymentType === 0}>
                      <Option value="">未知账户</Option>
                      <Option value="OYO">OYO账户</Option>
                      <Option value="HOTEL">酒店账户</Option>
                    </Select>
                  )}
                </Form.Item>
              </Col>
              <Col {...col4Props}>
                <Form.Item label="酒店名称" {...formItemLayout}>
                  {form.getFieldDecorator('hotelName', {
                    initialValue: (orderDetailData && orderDetailData.hotelName) || '',
                  })(
                    <Input disabled />
                    // <Select
                    //   style={{ width: '100%' }}
                    //   placeholder="请输入酒店名称"
                    //   showSearch
                    //   allowClear
                    //   notFoundContent={null}
                    //   defaultActiveFirstOption={false}
                    //   showArrow={false}
                    //   filterOption={false}
                    //   disabled={updatingVisible}
                    //   onSearch={this.handleHotelNameSearch}
                    //   onSelect={this.handleHotelNameSelect}
                    //   onFocus={this.handleHotelNameFocus}
                    // >
                    //   {order.suggestHotelList.length !== 0 &&
                    //     order.suggestHotelList.map((hotel, key) => (
                    //       <Option key={`suggestHotelList-${hotel.id}`} value={hotel.id}>
                    //         {hotel.hotel_name}
                    //       </Option>
                    //     ))}
                    // </Select>
                  )}
                </Form.Item>
              </Col>
              <Button style={{ marginTop: 4 }} onClick={this.toHotelDetail}>
                酒店详情
              </Button>
            </Row>
            <Row {...rowProps}>
              <Col {...col4Props}>
                <Form.Item label="预订时间" {...formItemLayout}>
                  {form.getFieldDecorator('createTime', {
                    initialValue: moment(orderDetailData && orderDetailData.createTime),
                  })(
                    <DatePicker
                      style={widthStyle}
                      showTime
                      format="YYYY-MM-DD HH:mm:ss"
                      disabled
                      suffixIcon={<span />}
                    />
                  )}
                </Form.Item>
              </Col>
              <Col {...col4Props}>
                <Form.Item label="预订入住" {...formItemLayout}>
                  {form.getFieldDecorator('arrivalTime', {
                    initialValue: moment(
                      orderDetailData &&
                        (orderDetailData.arrivalTime || orderDetailData.arrivalDate)
                    ),
                  })(
                    <DatePicker
                      style={widthStyle}
                      showTime
                      format="YYYY-MM-DD HH:mm:ss"
                      disabledDate={disabledDate}
                      suffixIcon={<span />}
                      disabled
                    />
                  )}
                </Form.Item>
              </Col>
              <Col {...col4Props}>
                <Form.Item label="预订离店" {...formItemLayout}>
                  {form.getFieldDecorator('departureTime', {
                    rules: [
                      { type: 'object', required: true, message: '请选择时间' },
                      {
                        validator: (rule, value, callback) => {
                          const { getFieldValue } = this.props.form;
                          const defaulrTime = moment(
                            orderDetailData &&
                              (orderDetailData.departureTime || orderDetailData.departureDate)
                          );
                          let checkin = getFieldValue('arrivalTime');

                          if (checkin && value) {
                            if (checkin.format('YYYY-MM-DD') >= value.format('YYYY-MM-DD')) {
                              callback('离店时间不能早于入住时间');
                            }
                          }

                          if (defaulrTime && value) {
                            if (defaulrTime.format('YYYY-MM-DD') < value.format('YYYY-MM-DD')) {
                              callback('不能选择大于修改前的时间');
                            }
                          }

                          callback();
                        },
                      },
                    ],
                    initialValue: moment(
                      orderDetailData &&
                        (orderDetailData.departureTime || orderDetailData.departureDate)
                    ),
                  })(
                    <DatePicker
                      allowClear={false}
                      suffixIcon={<span />}
                      style={widthStyle}
                      disabled={
                        orderDetailData && orderDetailData.type === 2 ? true : updatingVisible
                      }
                      format="YYYY-MM-DD HH:mm:ss"
                      showTime={{ defaultValue: moment('12:00:00', 'HH:mm:ss') }}
                      onChange={val => this.calculateDiff('checkout', null, val)}
                    />
                  )}
                </Form.Item>
              </Col>
              {orderDetailData && orderDetailData.type === 1 ? (
                <Col {...col4Props}>
                  <Form.Item label="保留时间" {...formItemLayout}>
                    {form.getFieldDecorator('retentionTime', {
                      initialValue: moment(
                        orderDetailData &&
                          (orderDetailData.retentionTime || orderDetailData.retentionDate)
                      ),
                      rules: [
                        { type: 'object', required: true, message: '请选择时间' },
                        {
                          validator: (rule, value, callback) => {
                            const { getFieldValue } = this.props.form;
                            let checkin = getFieldValue('arrivalTime');

                            if (checkin && value) {
                              if (checkin.format('YYYY-MM-DD') < value.format('YYYY-MM-DD')) {
                                callback('保留日期不能晚于入住日期');
                              }
                            }

                            callback();
                          },
                        },
                      ],
                    })(
                      <DatePicker
                        allowClear={false}
                        suffixIcon={<span />}
                        style={widthStyle}
                        format="YYYY-MM-DD HH:mm:ss"
                        showTime={{ defaultValue: moment('18:00:00', 'HH:mm:ss') }}
                        disabled={updatingVisible}
                      />
                    )}
                  </Form.Item>
                </Col>
              ) : null}
              {orderDetailData && orderDetailData.type === 2 ? (
                <Col {...col4Props}>
                  <Form.Item label="预订时长" {...formItemLayout}>
                    {form.getFieldDecorator('hours', {
                      initialValue:
                        orderDetailData && orderDetailData.hours
                          ? `${orderDetailData.hours}小时`
                          : null,
                    })(<Input disabled />)}
                  </Form.Item>
                </Col>
              ) : null}
              {orderDetailData && orderDetailData.type === 2 ? (
                <Col {...col4Props}>
                  <Form.Item label="可入住时间段" {...formItemLayout}>
                    {form.getFieldDecorator('arrivalEarliestTime', {
                      initialValue: times,
                    })(<Input disabled />)}
                  </Form.Item>
                </Col>
              ) : null}
              <Col {...col4Props}>
                <Form.Item label="团名" {...formItemLayout}>
                  {form.getFieldDecorator('groupName', {
                    initialValue: (orderDetailData && orderDetailData.groupName) || '',
                  })(<Input disabled />)}
                </Form.Item>
              </Col>
              <Col {...col4Props}>
                <Form.Item label="销售员" {...formItemLayout}>
                  {form.getFieldDecorator('salesName', {
                    initialValue: (orderDetailData && orderDetailData.salesName) || '',
                  })(<Input disabled />)}
                </Form.Item>
              </Col>
              <Col {...col4Props}>
                <Form.Item label="MM-Sales" {...formItemLayout}>
                  {form.getFieldDecorator('mMSalesName', {
                    initialValue: (orderDetailData && orderDetailData.mMSalesName) || '',
                  })(<Input disabled />)}
                </Form.Item>
              </Col>
            </Row>
            <Row {...rowProps}>
              {/* <Col {...col4Props}>
                  <Form.Item label="客源类型" {...formItemLayout}>
                    {form.getFieldDecorator('otaRemark', {
                      initialValue:
                        global.GUEST_TYPE[
                          (orderDetailData.bookingGuest &&
                            orderDetailData.bookingGuest.guestType) ||
                            1
                        ],
                    })(<Input disabled={true} onChange={this.handlePhoneChange} />)}
                  </Form.Item>
                </Col> */}
            </Row>
          </Card>
          {/* 预定信息 */}
          <Card title="房型信息" style={{ marginBottom: '24px' }} bordered={false}>
            {this.renderBookingRoomList()}
          </Card>
          {/* 房费信息 */}
          <Card title="房费信息" style={{ marginBottom: '24px' }} bordered={false}>
            <Row {...rowProps}>
              <Col {...col4Props}>
                <Form.Item label="房费" {...formItemLayout}>
                  {form.getFieldDecorator('amount', {
                    initialValue: orderDetailData.amount,
                  })(<Input disabled style={{ width: 100 }} />)}
                </Form.Item>
              </Col>
              <Col {...col4Props}>
                <Form.Item label="会员折扣(酒店承担)" {...formItemLayout2}>
                  {form.getFieldDecorator('memberTotalPrice', {
                    initialValue: (MEMBER && MEMBER.discountMoney) || 0,
                  })(<Input disabled style={{ width: 100 }} />)}
                  {MEMBER && (
                    <Popover content={this.renderDiscountDetail(MEMBER)} title="">
                      <span style={{ paddingLeft: 10, color: '#F5222D' }}>明细</span>
                    </Popover>
                  )}
                </Form.Item>
              </Col>
              <Col {...col4Props}>
                <Form.Item label="酒店优惠" {...formItemLayout}>
                  {form.getFieldDecorator('memberTotalPrice', {
                    initialValue: (HOTEL && HOTEL.discountMoney) || 0,
                  })(<Input disabled style={{ width: 100 }} />)}
                  {HOTEL && (
                    <Popover content={this.renderDiscountDetail(HOTEL)} title="">
                      <span style={{ paddingLeft: 10, color: '#F5222D' }}>明细</span>
                    </Popover>
                  )}
                </Form.Item>
              </Col>
              <Col {...col4Props}>
                <Form.Item label="优惠后房费" {...formItemLayout}>
                  {form.getFieldDecorator('actualAmount', {
                    value: this.state.actualAmount,
                    initialValue: orderDetailData.actualAmount,
                  })(<Input disabled style={{ width: 100 }} />)}

                  {orderDetailData.roomReservationRoomList.length !== 0 && (
                    <Popover
                      placement="left"
                      content={this.renderRoomReservationRoomDetail()}
                      title="明细"
                    >
                      <span style={{ paddingLeft: 10, color: '#F5222D' }}>明细</span>
                    </Popover>
                  )}
                </Form.Item>
              </Col>
            </Row>
          </Card>
          {/* 支付信息 */}
          <Card title="支付信息" style={{ marginBottom: '24px' }} bordered={false}>
            <Row {...rowProps}>
              <Col {...col4Props}>
                <Form.Item label="支付类型" {...formItemLayout}>
                  {form.getFieldDecorator('paymentType', {
                    initialValue: orderDetailData.paymentType,
                  })(
                    <Select placeholder="请选择" style={widthStyle} disabled>
                      {global.ORDER_PAYMENT_TYPE &&
                        global.ORDER_PAYMENT_TYPE.map((status, key) => (
                          <Option value={key} key={`ORDER_PAYMENT_TYPE-${status}`}>
                            {status}
                          </Option>
                        ))}
                    </Select>
                  )}
                </Form.Item>
              </Col>
              <Col {...col4Props}>
                <Form.Item label="会员折扣(OYO承担)" {...formItemLayout2}>
                  {form.getFieldDecorator('couponTotalPrice', {
                    initialValue: (OYO_MEMBER && OYO_MEMBER.discountMoney) || 0,
                  })(<Input disabled style={{ width: 100 }} />)}
                  {OYO && (
                    <Popover content={this.renderDiscountDetail(OYO)} title="">
                      <span style={{ paddingLeft: 10, color: '#F5222D' }}>明细</span>
                    </Popover>
                  )}
                </Form.Item>
              </Col>
              <Col {...col4Props}>
                <Form.Item label="OYO优惠" {...formItemLayout2}>
                  {form.getFieldDecorator('couponTotalPrice', {
                    initialValue: (OYO && OYO.discountMoney) || 0,
                  })(<Input disabled style={{ width: 100 }} />)}
                  {OYO && (
                    <Popover content={this.renderDiscountDetail(OYO)} title="">
                      <span style={{ paddingLeft: 10, color: '#F5222D' }}>明细</span>
                    </Popover>
                  )}
                </Form.Item>
              </Col>
              <Col {...col4Props}>
                <Form.Item label="优惠券" {...formItemLayout2}>
                  {form.getFieldDecorator('couponTotalPrice', {
                    initialValue: (COUPON && COUPON.discountMoney) || 0,
                  })(<Input disabled style={{ width: 100 }} />)}
                  {COUPON && (
                    <Popover content={this.renderDiscountDetail(COUPON)} title="">
                      <span style={{ paddingLeft: 10, color: '#F5222D' }}> 明细</span>
                    </Popover>
                  )}
                </Form.Item>
              </Col>
              <Col {...col4Props}>
                <Form.Item label="支付金额" {...formItemLayout}>
                  {form.getFieldDecorator('paidAmount', {
                    initialValue:
                      orderDetailData.paymentType === 0 ? 0 : orderDetailData.paidAmount,
                  })(<Input disabled style={{ width: 100 }} />)}
                </Form.Item>
              </Col>
              <Col {...col4Props}>
                <Form.Item label="预收款" {...formItemLayout2}>
                  {form.getFieldDecorator('prePayment.amount', {
                    initialValue: orderDetailData.prePayment
                      ? orderDetailData.prePayment.amount
                      : null,
                  })(<Input disabled />)}
                </Form.Item>
              </Col>
              <Col {...col4Props}>
                <Form.Item label="支付方式" {...formItemLayout2}>
                  {form.getFieldDecorator('prePayment.payTypeName', {
                    initialValue: orderDetailData.prePayment
                      ? orderDetailData.prePayment.payTypeName
                      : null,
                  })(<Input disabled />)}
                </Form.Item>
              </Col>
            </Row>
          </Card>
          <Card title="备注" style={{ marginBottom: '24px' }} bordered={false}>
            <Row {...rowProps}>
              <Col {...col1Props}>
                <Form.Item label="订单备注" {...remarkFormItemLayout}>
                  {form.getFieldDecorator('otaRemark', {
                    initialValue: optRemarkInitial || '无',
                  })(<TextArea autosize="true" disabled={updatingVisible} />)}
                </Form.Item>
              </Col>
            </Row>
            <Row {...rowProps}>
              <Col {...col1Props}>
                <Form.Item label="接待备注" {...remarkFormItemLayout}>
                  {form.getFieldDecorator('remark', {
                    initialValue: orderDetailData.remark || '无',
                  })(<Input disabled={updatingVisible} />)}
                </Form.Item>
              </Col>
            </Row>
            {/* <Row {...rowProps}>
                <Col {...col4Props}>
                  <Form.Item label="发票信息" {...formItemLayout}>
                    {form.getFieldDecorator('guestRequest', {
                      initialValue: orderDetailData.guestRequest,
                    })(<Input disabled={true} style={{ width: '100%' }} />)}
                  </Form.Item>
                </Col>
              </Row> */}
          </Card>
          {/* 操作区域 */}
          <FooterToolbar style={widthStyle}>
            <ButtonAuthorized
              type="primary"
              htmlType="button"
              code="CRS3.2.1.1"
              myDisabled={changeOrderStatus}
              onClick={
                this.state.updatingVisible ? this.handleUpdatingVisible : this.handleFormUpdate
              }
            >
              {buttonTxt}
            </ButtonAuthorized>
            <ButtonAuthorized
              code="CRS3.2.1.2"
              style={{ marginLeft: 20 }}
              myDisabled={cancelOrderStatus}
              onClick={this.handleOrderCancel}
            >
              取消订单
            </ButtonAuthorized>
            <ButtonAuthorized
              code="CRS3.2.1.3"
              style={{ marginLeft: 20 }}
              onClick={() => this.handleOrderDelete(true)}
            >
              失效订单
            </ButtonAuthorized>
            <Button
              style={{ marginLeft: 20 }}
              onClick={this.handleOrderCID}
              loading={queringCIDHandle}
            >
              CID处理
            </Button>
            <ButtonAuthorized
              code="CRS3.2.1.5"
              style={{ marginLeft: 20 }}
              onClick={() => this.handleOrderVOC(true)}
            >
              VOC赔付
            </ButtonAuthorized>
          </FooterToolbar>
        </Form>
      </Fragment>
    );
  };

  renderOrderDetail = () => {
    const { order } = this.props;
    const { orderDetailData } = order;
    return orderDetailData === null || JSON.stringify(orderDetailData) === '{}'
      ? this.renderEmptyForm()
      : this.renderNotEmptyForm();
  };

  // 不写成组件了，保持和这里的代码风格一致
  renderDeleteModal = () => {};

  renderCancelModal = () => {
    const { reasonList, cancelModalVisiable, cancelReasonId } = this.state;
    return (
      <Modal
        visible={cancelModalVisiable}
        title="请选择取消原因"
        onCancel={this.onCancelCancel}
        onOk={this.onOkCancel}
      >
        <RadioGroup
          style={{ width: '100%' }}
          onChange={this.onCancelReasonChange}
          value={cancelReasonId}
        >
          {reasonList.map((item, index) =>
            item.id !== 5 ? (
              <div key={index} style={{ marginBottom: 10 }}>
                <Radio key={item.id} value={item.id} name={item.name}>
                  {item.name}
                </Radio>
              </div>
            ) : (
              <div key={100} />
            )
          )}
          <div style={{ marginBottom: 10 }}>
            <Radio value={5} name="其他">
              其他
            </Radio>
            <Input
              style={{
                marginTop: 10,
                marginLeft: 24,
                width: '70%',
                display: cancelReasonId !== 5 ? 'none' : 'block',
              }}
              placeholder="请输入取消原因"
              onChange={this.cancelReasonText}
            />
          </div>
        </RadioGroup>
      </Modal>
    );
  };

  orderIsChange = orderDetailData => {
    let changeOrderStatus = false;
    let cancelOrderStatus = true;

    if (orderDetailData.cancelFlag === 1) {
      cancelOrderStatus = false;
    } else {
      cancelOrderStatus = true;
    }

    // 判断：非直连订单才可以取消和修改订单
    // isDirect：1或者null，不可修改和取消
    if (orderDetailData.isDirect === 0) {
      if (orderDetailData.status === 0) {
        // 判断：订单状态处于未入住时候，是否排房。排房了就不能取消订单和修改订单

        const hasRoomNum = orderDetailData.orderDetailList.some(
          item => item.roomNo !== null && item.roomNo !== ''
        );
        changeOrderStatus = hasRoomNum;
      } else if (
        orderDetailData.status === 1 ||
        orderDetailData.status === 2 ||
        orderDetailData.status === 3 ||
        orderDetailData.status === 4
      ) {
        changeOrderStatus = true;
      } else {
        changeOrderStatus = false;
      }
    } else {
      changeOrderStatus = true;
    }

    // 判断:该订单是否可删除，默认可以删除
    // isDeleted：0 订单正常，可删除;
    // isDeleted：1 订单失效，不可删除;
    if (orderDetailData.isDeleted === 1) {
      changeOrderStatus = true;
    }

    return { changeOrderStatus, cancelOrderStatus };
  };

  toHotelDetail = () => {
    const { order } = this.props;
    const { orderDetailData } = order;
    const { hotelId } = orderDetailData;

    router.push({
      pathname: '/hotel/hotelCreateEdit/index',
      query: { hotelId },
    });
  };

  deleteFormRef = formRef => {
    this.formRef = formRef;
  };

  // CID处理弹窗 取消操作事件
  onCancelCID = () => {
    this.setState({
      cidModalVisiable: false,
    });
  };

  // 显示CID处理弹窗
  handleOrderCID = () => {
    const { bookingId } = this.state;
    this.props
      .dispatch({ type: 'preventCID/queryCIDHandle', payload: { bookingId } })
      .then(({ data }) => this.setState({ cidModalVisiable: true }))
      .catch(err => console.log(err));
  };

  // VOC处理弹窗 取消操作事件
  onCancelVOC = () => {
    this.setState({
      vocModalVisiable: false,
    });
  };

  handleOrderVOC = () => {
    this.setState({
      vocModalVisiable: true,
    });
  };

  render() {
    const {
      reasonList,
      cancelModalVisiable,
      cancelReasonId,
      onCancelCancel,
      onOkCancel,
      onCancelReasonChange,
      cancelReasonText,
      deleteModalVisiable,
      cidModalVisiable,
      bookingId,
      vocModalVisiable,
    } = this.state;
    const { deleteLoading, form } = this.props;
    return (
      <div>
        {this.renderOrderDetail()}
        {this.renderCancelModal()}
        <VOCHandleModel
          visible={vocModalVisiable}
          bookingId={bookingId}
          onCancel={this.onCancelVOC}
        />
        <CidHandleModel
          visible={cidModalVisiable}
          bookingId={bookingId}
          onCancel={this.onCancelCID}
        />
        <OrderDeleteModal
          wrappedComponentRef={this.deleteFormRef}
          title="删除订单"
          visible={deleteModalVisiable}
          onOk={this.onOkDelete}
          onCancel={this.onCancelDelete}
          form={form}
          loading={deleteLoading}
        />
      </div>
    );
  }

  renderRoomReservationRoomDetail = () => {
    let { roomReservationRoomList } = this.props.order.orderDetailData;

    return (
      <ul style={{ maxWidth: 400, maxHeight: 300, overflow: 'scroll' }}>
        {roomReservationRoomList.map((item, index) => (
          <li key={index} style={{ display: 'flex', alignItems: 'top', paddingBottom: 6 }}>
            <p style={{ minWidth: 130 }}>{item.time}</p>
            <div style={{ flex: 1 }}>
              {item.child.map((room, i) => (
                <span
                  key={i}
                  style={{
                    width: 90,
                    paddingRight: 10,
                    float: 'left',
                    color: '#888',
                    paddingBottom: 4,
                  }}
                >
                  {room.count} * ¥{room.price}
                </span>
              ))}
            </div>
          </li>
        ))}
      </ul>
    );
  };

  // renderDiscountDetail = () => {
  //   let { MEMBERList } = this.props.order.orderDetailData;

  //   return (
  //     <ul style={{ maxHeight: 300, overflow: 'scroll' }}>
  //       {MEMBERList.map((item, index) => (
  //         <li key={index}>会员折扣 —— {item.discountMoney}元</li>
  //       ))}
  //     </ul>
  //   );
  // };

  renderDiscountDetail = discountItem => {
    if (!discountItem) return; // discountItem不存在时候

    let dataSource = [];
    dataSource.push(discountItem);

    const columns = [
      {
        title: '优惠项目',
        dataIndex: 'discountName',
      },
      { title: '金额', dataIndex: 'discountMoney' },
    ];

    const tableProp = {
      columns,
      dataSource,
      rowKey: 'id',
      pagination: false,
      bordered: true,
    };

    return <Table {...tableProp} />;
  };
}
