import React, { PureComponent, Fragment } from 'react';
import { connect } from 'dva';
import Link from 'umi/link';
import moment from 'moment';
import router from 'umi/router';
import {
  Row,
  Col,
  Card,
  Form,
  Input,
  Select,
  Button,
  Table,
  DatePicker,
  Badge,
  Radio,
  Tag,
  Icon,
  message,
} from 'antd';
import PageHeaderWrapper from '@/components/PageHeaderWrapper';
import OYOForm from '@/components/OyoForm/SearchForm';
import OYOTable from '@/components/OyoTable/OyoTable.tsx';
import { getSearchFormConfig, getTableConfig } from '../config/preventCID';
import CidCallModel from '../components/CidCall';
import { querylistBooking, queryCallDetail, addCall } from '../services/preventCID';

@connect(({ global, order, loading, user, orderSource, preventCID }) => ({
  orderSource,
  preventCID,
}))
export default class PreventCID extends PureComponent {
  constructor(props) {
    super(props);
    this.state = {
      orderSourceData: [],
      tableParams: {},
      pageParams: ['page', 'limit'],
      preventGetList: true,
      isVisible: false,
      isDisabled: false,
      CidDetail: {},
      actTotalNum: 0,
    };
  }

  componentDidMount() {
    const {
      order,
      dispatch,
      form,
      preventCID: { defaultParams },
    } = this.props;
    const { orderSourceData } = this.state;
    // 获取订单渠道来源
    if (!orderSourceData.length) {
      dispatch({
        type: 'orderSource/fetchChannelList',
      })
        .then(data => {
          this.setState({
            orderSourceData: data.data,
          });
        })
        .catch(e => {
          console.log(e);
        });
    }

    if (defaultParams.beginDate) {
      this.setState({ tableParams: defaultParams }, () => {
        let current = defaultParams.page || 1;
        this.oyotable.getPageList({ current });
      });
    }
  }

  query = fieldsValue => {
    const { hotelId } = this.state;
    let params = {
      ...fieldsValue,
      beginDate: fieldsValue.beginDate ? fieldsValue.beginDate.format('YYYY-MM-DD') : null,
      queryType: 1,
    };
    if (!params.beginDate) {
      message.warn('请选择入住日期！');
      return;
    }

    let selAreaL = params.area ? params.area.length : 0;
    switch (selAreaL) {
      case 1:
        params.stateId = params.area[selAreaL - 1];
        break;
      case 2:
        params.cityId = params.area[selAreaL - 1];
        break;
      case 3:
        params.clusterId = params.area[selAreaL - 1];
        break;
      default:
        params.stateId = null;
    }

    this.setState({ tableParams: params }, () => this.oyotable.getPageList());
  };

  reset = () => {
    let { dispatch } = this.props;
    this.setState({
      actTotalNum: 0,
    });
    dispatch({
      type: 'preventCID/setSearchParams',
      payload: {},
    });
    this.oyotable.clearTable();
    this.oyoSearch.setFieldsValue({
      area: [],
    });
  };

  getList = params => {
    let { dispatch } = this.props;
    dispatch({
      type: 'preventCID/setSearchParams',
      payload: params,
    });

    return querylistBooking(params).then(res => {
      const {
        data: { result = [], totalCount },
      } = res;
      // 页面查询展示限制一千条
      let num = totalCount > 1000 ? 1000 : totalCount;
      this.setState({
        actTotalNum: totalCount,
      });

      return { data: result, total: num };
    });
  };

  // 创建Cid记录
  createCidCallRecord = bookingId => {
    this.setState({
      isVisible: true,
      CidDetail: { bookingId },
      isDisabled: false,
    });
  };

  // 查看Cid记录
  seeCidCallRecord = id => {
    this.queryCidDetail(id).then(res => {
      this.setState({
        CidDetail: res.data || {},
        isVisible: true,
        isDisabled: true,
      });
    });
  };

  // 提交Cid记录
  sumbitCid = params => {
    let { dispatch } = this.props;
    dispatch({
      type: 'preventCID/fetchAddCall',
      payload: params,
    })
      .then(res => {
        message.success('记录成功');
        this.oyotable.getPageList();
        this.setState({
          isVisible: false,
        });
      })
      .catch(res => {
        message.error(res.msg);
      });
  };

  // 查询CID详情
  queryCidDetail = bookingId => {
    let { dispatch } = this.props;
    return dispatch({
      type: 'preventCID/fetchCallDetail',
      payload: { bookingId },
    });
  };

  closeCidCallModel = () => {
    this.setState({
      isVisible: false,
    });
  };

  render() {
    let {
      orderSourceData,
      tableParams,
      pageParams,
      preventGetList,
      isVisible,
      isDisabled,
      CidDetail,
      actTotalNum,
    } = this.state;

    let {
      preventCID: { defaultParams },
    } = this.props;

    let searchFormConfig = getSearchFormConfig({ orderSourceData, defaultParams });
    let OYOTableConfig = getTableConfig(this);
    return (
      <PageHeaderWrapper>
        <Card>
          <OYOForm
            ref={target => {
              this.oyoSearch = target;
            }}
            fields={searchFormConfig}
            onSearch={this.query}
            onReset={this.reset}
            column={4}
          />
        </Card>
        <Card>
          <p>当前查询条件下，共{actTotalNum}条当日待入住的订单</p>
          <OYOTable
            size="small"
            bordered
            rowKey="bookingId"
            style={{ marginTop: 10 }}
            params={tableParams}
            pageParams={pageParams}
            columns={OYOTableConfig}
            preventGetList={preventGetList}
            getList={this.getList}
            ref={target => {
              this.oyotable = target;
            }}
          />
        </Card>
        <CidCallModel
          visible={isVisible}
          disabled={isDisabled}
          CidDetail={CidDetail}
          onOK={this.sumbitCid}
          onCancel={this.closeCidCallModel}
        />
      </PageHeaderWrapper>
    );
  }
}
