import React, { PureComponent, Fragment } from 'react';
import {
  Card,
  Button,
  Form,
  Icon,
  Col,
  Row,
  DatePicker,
  TimePicker,
  Input,
  Select,
  Popover,
  Divider,
  Empty,
  message,
} from 'antd';
import { connect } from 'dva';
import router from 'umi/router';
import ButtonAuthorizedTimer from '@/components/ButtonAuthorizedTimer';
import styles from './Order.less';

import {
  formLayout,
  rowProps,
  col1Props,
  col2Props,
  col3Props,
  col4Props,
  formItemLayout,
  widthStyle,
} from '@/utils/formProps';

export const formItemLayout2 = {
  labelCol: {
    xs: { span: 24 },
    sm: { span: 5 },
  },
  wrapperCol: {
    xs: { span: 24 },
    sm: { span: 19 },
  },
};

@connect(({ loading, global, order }) => ({
  global,
  order,
  loading: loading.models.order,
}))
@Form.create()
export default class RoomDetail extends PureComponent {
  componentWillMount() {
    const {
      dispatch,
      location,
      order: { roomReservationData },
    } = this.props;
    const bookingId = location.query.bookingId || '';

    if (bookingId === '') {
      router.push('/order/list');
      return;
    }
    // Room和Bill两块只调用一次服务器数据
    // if (roomReservationData !== null && roomReservationData.length !== 0) {
    //   return;
    // }
    dispatch({
      type: 'order/fetchRoomReservationList',
      payload: { bookingId },
    });
  }

  // componentDidMount() {
  //   window.addEventListener('resize', this.resizeFooterToolbar, { passive: true });
  // }

  // componentWillUnmount() {
  //   window.removeEventListener('resize', this.resizeFooterToolbar);
  // }

  // resizeFooterToolbar = () => {
  //   requestAnimationFrame(() => {
  //     const sider = document.querySelectorAll('.ant-layout-sider')[0];
  //     if (sider) {
  //       const width = `calc(100% - ${sider.style.width})`;
  //       const { width: stateWidth } = this.state;
  //       if (stateWidth !== width) {
  //         this.setState({ width });
  //       }
  //     }
  //   });
  // };

  renderRoomCard = (room, key) => {
    const { form, global } = this.props;

    return (
      <Card
        title="房单信息"
        style={{ marginBottom: '24px' }}
        className={styles.room}
        bordered={false}
        key={room.orderId}
      >
        <Row {...rowProps}>
          <Col {...col4Props}>
            <Form.Item label="房单号" {...formItemLayout}>
              {form.getFieldDecorator('orderSn', {
                initialValue: room.orderSn,
              })(<Input disabled />)}
            </Form.Item>
          </Col>
          <Col {...col4Props}>
            <Form.Item label="状态" {...formItemLayout}>
              {form.getFieldDecorator('orderStatus', {
                initialValue: global.ORDER_STATUS[room.orderStatus],
              })(<Input disabled />)}
            </Form.Item>
          </Col>
        </Row>
        <Row {...rowProps}>
          <Col {...col4Props}>
            <Form.Item label="房间号码" {...formItemLayout}>
              {form.getFieldDecorator('roomNo', {
                initialValue: room.roomNo,
              })(<Input disabled />)}
            </Form.Item>
          </Col>
          <Col {...col4Props}>
            <Form.Item label="房间类型" {...formItemLayout}>
              {form.getFieldDecorator('roomTypeDesc', {
                initialValue: room.roomTypeDesc,
              })(<Input disabled />)}
            </Form.Item>
          </Col>
          <Col {...col4Props}>
            <Form.Item label="房间价格" {...formItemLayout}>
              {form.getFieldDecorator('curDayRoomRate', {
                initialValue: room.curDayRoomRate,
              })(<Input disabled />)}
            </Form.Item>
          </Col>
          <Col {...col4Props}>
            <Form.Item label="实际入住" {...formItemLayout}>
              {form.getFieldDecorator('checkInTime', {
                initialValue: room && room.checkInTime,
              })(<Input disabled />)}
            </Form.Item>
          </Col>
          <Col {...col4Props}>
            <Form.Item label="实际离店" {...formItemLayout}>
              {form.getFieldDecorator('checkOutTime', {
                initialValue: room && room.checkOutTime,
              })(<Input disabled />)}
            </Form.Item>
          </Col>
          {/**
            <Col {...col4Props}>
              <Form.Item label="入住天数" {...formItemLayout}>
                {form.getFieldDecorator('durationOfStay', { initialValue: room.durationOfStay })(
                  <Input disabled />
                )}
              </Form.Item>
            </Col>
             * */}
        </Row>
        <Divider
          style={
            room.guestList && room.guestList.length !== 0
              ? { display: 'block' }
              : { display: 'none' }
          }
        />
        {this.renderGuestCard(room.guestList, room)}
      </Card>
    );
  };

  renderGuestCard = (guestList, room) => {
    const { form, global } = this.props;
    const { orderStatus } = room;

    if (!guestList || guestList.length === 0) return;

    const list = guestList.map((guest, key) => (
      <Row {...rowProps} key={guest.id}>
        <Col {...col4Props}>
          <Form.Item label="入住人" {...formItemLayout}>
            {form.getFieldDecorator('name', {
              initialValue: guest.name,
            })(<Input disabled />)}
          </Form.Item>
        </Col>
        <Col {...col4Props}>
          <Form.Item label="联系电话" {...formItemLayout}>
            {form.getFieldDecorator('phone', {
              initialValue: guest.phone,
            })(<Input disabled />)}
          </Form.Item>
        </Col>
        <Col {...col4Props}>
          <Form.Item label="证件类型" {...formItemLayout}>
            {form.getFieldDecorator('cardType', {
              initialValue: global.CARD_TYPE[guest.cardType],
            })(<Input disabled />)}
          </Form.Item>
        </Col>
        <Col {...col4Props}>
          <Form.Item label="证件号码" {...formItemLayout}>
            {form.getFieldDecorator('cardNo', {
              initialValue: guest.cardNo,
            })(<Input disabled />)}
          </Form.Item>
        </Col>
        {orderStatus === 1 && (
          <>
            <Col {...col2Props}>
              <Form.Item label="临时密码" {...formItemLayout2}>
                {form.getFieldDecorator('cardNo', {
                  initialValue: guest.offLineInfo,
                })(<Input disabled />)}
              </Form.Item>
            </Col>
            <Col {...col4Props}>
              <ButtonAuthorizedTimer
                myDisabled={!guest.phone}
                intervalTime={30}
                ref={ref => {
                  this[`timeBtn-${guest.id}`] = ref;
                }}
                timeText="$<time>s后可再次下发临时密码"
                style={{ width: '88%', marginTop: 4, marginLeft: '12%' }}
                onClick={() => this.generateOfflinePassword(guest || {}, room)}
              >
                点击生成临时密码
              </ButtonAuthorizedTimer>
            </Col>
          </>
        )}
      </Row>
    ));
    return list;
  };

  generateOfflinePassword = async ({ name, phone, id }, { hotelId, orderId }) => {
    if (!phone) return message.error('该用户没有手机号');

    const res = await this.props.dispatch({
      type: 'order/generateOfflinePassword',
      payload: {
        roomReservationId: orderId,
        hotelId,
        phone,
        guestName: name,
        bookingId: this.props.location.query.bookingId,
      },
    });

    if (res) {
      const surplusSendNum = res.surplusSendNum;

      this[`timeBtn-${id}`].setStartTime();

      message.success(`临时密码下发成功, 您还有${surplusSendNum}次生成次数`);
    }
  };

  renderNotEmptyRoom = () => {
    const {
      order: { roomReservationData },
    } = this.props;
    const card =
      roomReservationData &&
      roomReservationData.length !== 0 &&
      roomReservationData.map(this.renderRoomCard);
    return (
      <Form layout={formLayout.horizontal} hideRequiredMark>
        {card}{' '}
      </Form>
    );
  };

  renderEmptyRoom = () => (
    <Card>
      <Empty />
    </Card>
  );

  renderRoomInfo = () => {
    const {
      order: { roomReservationData },
    } = this.props;

    return roomReservationData && roomReservationData.length !== 0
      ? this.renderNotEmptyRoom()
      : this.renderEmptyRoom();
  };

  render() {
    return <Fragment>{this.renderRoomInfo()}</Fragment>;
  }
}
