import React, { PureComponent } from 'react';
import { connect } from 'dva';
import {
  Cascader,
  Card,
  Form,
  Row,
  Col,
  Input,
  Button,
  Radio,
  DatePicker,
  Select,
  message,
  InputNumber,
} from 'antd';
import moment from 'moment';
import CitySelect from '@/components/CitySelect/index';
import HotelInput from '@/components/HotelInput/HotelInput';
import HotelsTable from './components/HotelsTable';
import PageHeaderWrapper from '@/components/PageHeaderWrapper';
import SupplementBoxForm from './components/SupplementBox';
import styles from './Supplement.less';
import { typeCheck } from '@/utils/utils';
import { PHONE } from '@/constant/reg';

/**
 * 补录订单页面
 * url: /#/order/supplement
 * 功能: 酒店定位后 进行对应房型的补录
 */

const FormItem = Form.Item;
const Option = Select.Option;
const PageSize = 10;
@Form.create()
@connect(({ hotelSearch, hotelLists, supplementOrder, global, user, loading }) => ({
  hotelSearch,
  hotelLists,
  supplementOrder,
  global,
  user,
  saveLoading: loading.effects['supplementOrder/requestCreateBooking'],
}))
export default class Supplement extends PureComponent {
  constructor(props) {
    super(props);
    this.state = {
      searchCityId: [], // 搜索的城市Id
      searchHotelType: {
        type: '0',
        val: '',
      },
      selectHotel: {}, // 选择的酒店
      isShowTable: false,
      orderChecked: true,
      displaySupplement: false, // 房单信息列表
      productIndex: 0, // 房型列表选择的当前房型Index(会变绿)
      totalDays: 0, // 共住天数
      checkinDay: '', // 入住时间
      checkoutDay: '', // 离店时间
      roomRate: 0, // 房价
      roomType: null, // 房间类型
      roomLength: 0, // 数量
      memberName: '', // 会员名
      memberCode: null, // 会员id
      checkinOut: null, // 入住时间带出保留时间
      singlePrice: 0, // 每间夜房价
      roomTypeDesc: '', // 房型名称
      accountType: undefined,
    };
  }

  componentDidMount() {
    const { dispatch } = this.props;

    // 获取下单渠道列表
    dispatch({
      type: 'supplementOrder/fetchChannelList',
    });

    // 获取下单渠道列表
    dispatch({
      type: 'supplementOrder/fetchQueryChannelList',
    });
  }

  validatorExtBookingSn = (rule, val, callback) => {
    const pattern = /^[0-9a-zA-Z\s]+$/;
    if (!pattern.test(val) && val !== '') {
      callback('不可输入特殊字符');
    }
    callback();
  };

  changeToHandleSpaceTrim = event => {
    return event.target.value.replace(/\s+/g, '');
  };

  // 保存生成对应数量房单数据
  handleCreateOrder = e => {
    e.preventDefault();
    const { form } = this.props;

    form.validateFields((err, values) => {
      if (this.state.selectHotel.hotelId === undefined) return;
      console.log(err);
      if (err) return;

      const payload = {
        roomTypeId: +values.bookingRoomTypes.roomTypeId,
        hotelId: +this.state.selectHotel.hotelId,
        num: +values.bookingRoomTypes.count,
        status: +values.status,
      };
      this.requestSave(payload);
    });
  };

  // 保存生成对应数量房单数据-发起请求
  async requestSave(payload) {
    this.supplementBoxRef.resetFields && this.supplementBoxRef.resetFields();

    this.props
      .dispatch({
        type: 'supplementOrder/requestCreateBooking',
        payload,
      })
      .then(e => {
        if (e.code === '000') {
          message.success('查询房间号成功');
          this.setState({ displaySupplement: true });
          return;
        }
        this.setState({ displaySupplement: false });
      })
      .catch(e => {
        this.setState({ displaySupplement: false });
        console.log(e);
      });
  }

  // 发起补录订单
  async requestSupplement(payload) {
    console.log('requestSupplement', payload);
    this.props
      .dispatch({
        type: 'supplementOrder/requestSupplementOrder',
        payload,
      })
      .then(e => {
        if (e.code === '000') {
          message.success('补录订单成功');
          this.props.history.push('/order/list');
        }
      })
      .catch(e => {
        console.log(e);
      });
  }

  // 补录订单信息
  renderOrder() {
    const { getFieldDecorator } = this.props.form;
    const { supplementOrder, saveLoading } = this.props;
    const formItemLayout = {
      labelCol: { span: 5 },
      wrapperCol: { span: 12 },
    };
    let { checkinOut, productIndex } = this.state;

    const rulesConfigObject = {
      rules: [{ type: 'object', required: true, message: '请选择日期' }],
    };
    const { queryChannelList } = supplementOrder;
    let channelId = this.props.form.getFieldValue('channelId');

    return (
      <Form onSubmit={this.handleCreateOrder} layout="inline">
        <Row gutter={{ xs: 36, md: 36, lg: 36, xl: 36 }} type="flex">
          <Col md={8} sm={24}>
            <FormItem label="入住类型" {...formItemLayout}>
              {getFieldDecorator('checkinType', {
                initialValue: '全天房',
                rules: [{ required: true, message: '必填项' }],
              })(<Radio checked={this.state.orderChecked}>全天房</Radio>)}
            </FormItem>
          </Col>
        </Row>
        <Row gutter={{ xs: 36, md: 36, lg: 36, xl: 36 }} type="flex">
          <Col md={8} sm={24}>
            <FormItem label="订单来源" {...formItemLayout}>
              {getFieldDecorator('channelId', {
                rules: [{ required: true, message: '请选择订单来源' }],
              })(
                <Select placeholder="请选择订单来源" onChange={e => this.handlerChannelId(e)}>
                  {supplementOrder.channelList.map((item, index) => (
                    <Option key={index} value={item.channelId}>
                      {item.channelName}
                    </Option>
                  ))}
                </Select>
              )}
            </FormItem>
          </Col>
          <Col md={8} sm={24}>
            <FormItem label="渠道订单号" {...formItemLayout}>
              {getFieldDecorator('extBookingSn', {
                validateTrigger: ['onChange'],
                rules: [
                  {
                    required: true,
                    validator: this.validatorExtBookingSn,
                  },
                  {
                    required: true,
                    message: '请输入渠道订单号',
                    validator: (rule, value, callback) => {
                      const { getFieldValue } = this.props.form;
                      if (
                        channelId &&
                        supplementOrder.queryChannelList.includes(channelId) &&
                        !value
                      ) {
                        callback('该渠道必须填写渠道号');
                      }

                      callback();
                    },
                  },
                ],
                getValueFromEvent: this.changeToHandleSpaceTrim,
              })(
                <Input
                  style={{ width: '100%' }}
                  placeholder={queryChannelList.includes(channelId) ? '请输入渠道订单号' : ''}
                />
              )}
            </FormItem>
          </Col>
          <Col md={8} sm={24}>
            <FormItem label="入账主体" {...formItemLayout}>
              {getFieldDecorator('accountType', {
                initialValue: this.state.accountType,
                rules: [
                  {
                    required: true,
                    message: '请选择入账主体',
                    validator: (rule, value, callback) => {
                      const { getFieldValue } = this.props.form;

                      if (value === '') {
                        callback();
                      }

                      if (value === undefined) {
                        callback('请选择入账主体');
                      }

                      callback();
                    },
                  },
                ],
              })(
                <Select placeholder="请选择入账主体">
                  <Option value="HOTEL">酒店账户</Option>
                  <Option value="OYO">OYO账户</Option>
                  <Option value="">未知账户</Option>
                </Select>
              )}
            </FormItem>
          </Col>
        </Row>
        <Row gutter={{ xs: 36, md: 36, lg: 36, xl: 36 }} type="flex">
          <Col md={8} sm={24}>
            <FormItem label="联系电话" {...formItemLayout}>
              {getFieldDecorator('bookingGuest.phone', {
                rules: [
                  {
                    required: true,
                    message: '请输入正确的手机号码',
                    pattern: PHONE,
                  },
                ],
              })(
                <Input
                  placeholder="输入手机号查询会员"
                  onChange={e => this.handlerBookingGuestVal(e, 'phone')}
                  maxLength={11}
                />
              )}
            </FormItem>
          </Col>
          <Col md={8} sm={24}>
            <FormItem label="预定人" {...formItemLayout}>
              {getFieldDecorator('bookingGuest.name', {
                initialValue: this.state.memberName,
                rules: [{ required: true, message: '请输入预定人' }],
              })(<Input placeholder="请输入预定人" />)}
            </FormItem>
          </Col>
          <Col md={8} sm={24}>
            <FormItem label="客源类型" {...formItemLayout}>
              {getFieldDecorator('bookingGuest.memberId', {
                initialValue: supplementOrder.bookingGuest.member ? 0 : 1,
                rules: [{ required: true, message: '请选择客源类型' }],
              })(
                <Select disabled onChange={e => this.handlerFromVal(e, 'channelId')}>
                  <Option value={0}>会员</Option>
                  <Option value={1}>非会员</Option>
                </Select>
              )}
            </FormItem>
          </Col>
          <Col md={8} sm={24}>
            <FormItem label="入住日期" {...formItemLayout}>
              {getFieldDecorator('checkin', {
                initialValue: null,
                rules: [
                  { type: 'object', required: true, message: '请选择日期' },
                  {
                    validator: (rule, value, callback) => {
                      const { getFieldValue } = this.props.form;
                      let checkout = getFieldValue('checkout');

                      if (checkout && value) {
                        if (value.format('YYYY-MM-DD') >= checkout.format('YYYY-MM-DD')) {
                          callback('入住日期不能晚于离店日期');
                        }
                      }

                      // Note: 必须总是返回一个 callback，否则 validateFieldsAndScroll 无法响应
                      callback();
                    },
                  },
                ],
              })(
                <DatePicker
                  allowClear={false}
                  format="YYYY-MM-DD HH:mm"
                  disabledDate={current => current && current > moment().startOf('day')}
                  style={{ width: '100%' }}
                  placeholder="请选择日期"
                  onChange={val => this.handleTime('checkin', val)}
                />
              )}
            </FormItem>
          </Col>
          <Col md={8} sm={24}>
            <FormItem label="离店日期" {...formItemLayout}>
              {getFieldDecorator('checkout', {
                initialValue: null,
                rules: [
                  { type: 'object', required: true, message: '请选择日期' },
                  {
                    validator: (rule, value, callback) => {
                      const { getFieldValue } = this.props.form;
                      let checkin = getFieldValue('checkin');

                      if (checkin && value) {
                        // callback('请选择入住日期');
                        if (checkin.format('YYYY-MM-DD') >= value.format('YYYY-MM-DD')) {
                          callback('离店日期不能早于入住日期');
                        }
                      }

                      // Note: 必须总是返回一个 callback，否则 validateFieldsAndScroll 无法响应
                      callback();
                    },
                  },
                ],
              })(
                <DatePicker
                  allowClear={false}
                  format="YYYY-MM-DD HH:mm"
                  style={{ width: '100%' }}
                  placeholder="请选择日期"
                  onChange={val => this.handleTime('checkout', val)}
                />
              )}
            </FormItem>
            <div className={styles.showTotal}>
              <span>{this.state.totalDays}</span>晚
            </div>
          </Col>
          <Col md={8} sm={24}>
            <FormItem label="保留时间" {...formItemLayout}>
              {getFieldDecorator('reserve', {
                initialValue: checkinOut,
                rules: [
                  { type: 'object', required: true, message: '请选择日期' },
                  {
                    validator: (rule, value, callback) => {
                      const { getFieldValue } = this.props.form;
                      let checkin = getFieldValue('checkin');

                      if (checkin && value) {
                        // callback('请选择入住日期');
                        // return;
                        if (checkin.format('YYYY-MM-DD') < value.format('YYYY-MM-DD')) {
                          callback('保留日期不能晚于入住日期');
                        }
                      }

                      callback();
                    },
                  },
                ],
              })(
                <DatePicker
                  allowClear={false}
                  format="YYYY-MM-DD HH:mm"
                  disabledDate={current => current && current > moment().startOf('day')}
                  showTime={{ defaultValue: moment('18:00:00', 'HH:mm:ss') }}
                  disabledTime={current => this.disabledTime(current)}
                  style={{ width: '100%' }}
                  placeholder="请选择日期"
                  onChange={val => this.handleTime('reserve', val)}
                />
              )}
            </FormItem>
          </Col>
          <Col md={8} sm={24}>
            <FormItem label="支付类型" {...formItemLayout}>
              {getFieldDecorator('payType', {
                initialValue: 1,
                rules: [{ required: true, message: '请选择支付类型' }],
              })(
                <Select
                  placeholder="请选择支付类型"
                  onChange={e => this.handlerFromVal(e, 'payType')}
                >
                  <Option value={1}>预付</Option>
                  <Option value={0}>到付</Option>
                </Select>
              )}
            </FormItem>
          </Col>
          <Col md={8} sm={24}>
            <FormItem label="房价类型" {...formItemLayout}>
              {getFieldDecorator('bookingRoomTypes.rateCode', {
                rules: [
                  {
                    required: true,
                    message: '请选择房价类型',
                  },
                ],
              })(
                <Select
                  placeholder="请选择房价类型"
                  onChange={val => this.handlerRateCodeId(val)}
                  disabled={!supplementOrder.isCanRateCode}
                >
                  {supplementOrder.rateCodeList.map((item, index) => (
                    <Option value={item.rateCodeId} key={index}>
                      {item.rateCodeName}
                    </Option>
                  ))}
                </Select>
              )}
            </FormItem>
          </Col>
          <Col md={8} sm={24}>
            <FormItem label="销售员" {...formItemLayout}>
              {getFieldDecorator('salesmanId', {
                initialValue: null,
              })(<Input placeholder="非必填" disabled />)}
            </FormItem>
          </Col>
          <Col md={8} sm={24}>
            <FormItem label="房型" {...formItemLayout}>
              {getFieldDecorator('bookingRoomTypes.roomTypeId', {
                rules: [
                  {
                    required: true,
                    message: '请选择房型',
                  },
                ],
              })(
                <Select placeholder="请选择房型" onChange={this.handleRoomType}>
                  {supplementOrder.roomTypeList.map((item, index) => (
                    <Option key={index} value={item.id} product={item}>
                      {item.saleRoomTypeName || '未知房型'}
                    </Option>
                  ))}
                </Select>
              )}
            </FormItem>
          </Col>
          <Col md={8} sm={24}>
            <FormItem label="数量" {...formItemLayout}>
              {getFieldDecorator('bookingRoomTypes.count', {
                initialValue: null,
                rules: [{ required: true, message: '请输入数量' }],
              })(
                <InputNumber
                  style={{ width: '100%' }}
                  placeholder="请输入数量"
                  step={1}
                  min={1}
                  max={20}
                  onChange={val => this.getRoomCount(val)}
                />
              )}
            </FormItem>
          </Col>
          <Col md={8} sm={24}>
            <FormItem label="总房费" {...formItemLayout}>
              {getFieldDecorator('roomPrice', {
                initialValue: null,
                rules: [
                  {
                    required: true,
                    message: '请输入正确的总房费',
                    pattern: new RegExp('^\\d+\\.?\\d{0,2}$'),
                  },
                ],
              })(<Input addonBefore="¥" placeholder="请输入总房费" onChange={this.getRoomPrice} />)}
            </FormItem>
          </Col>
          <Col md={8} sm={24}>
            <FormItem label="订单状态" {...formItemLayout}>
              {getFieldDecorator('status', {
                initialValue: '2',
                rules: [{ required: true }],
              })(
                <Select disabled>
                  <Option value="1">在住</Option>
                  <Option value="2">离店</Option>
                </Select>
              )}
            </FormItem>
          </Col>
          <Col md={8} sm={24}>
            <FormItem label="创建日期" {...formItemLayout}>
              {getFieldDecorator('createTime', {
                initialValue: moment('12:00:00', 'HH:mm:ss'),
                rules: [{ type: 'object', required: true, message: '请选择日期' }],
              })(
                <DatePicker
                  allowClear={false}
                  format="YYYY-MM-DD HH:mm:ss"
                  showTime={{ defaultValue: moment('12:00:00', 'HH:mm:ss') }}
                  disabledDate={current => current && current > moment().startOf('day')}
                  style={{ width: '100%' }}
                  placeholder="请选择日期"
                />
              )}
            </FormItem>
          </Col>
          <Col md={8} sm={24}>
            <FormItem label="预付总金额" {...formItemLayout}>
              {getFieldDecorator('amount', {
                initialValue: null,
                rules: [{ required: true, message: '必需项' }],
              })(<Input addonBefore="¥" disabled />)}
            </FormItem>
          </Col>
        </Row>
        <Row type="flex">
          <Col md={24} sm={24}>
            <FormItem label="订单备注" {...formItemLayout}>
              {getFieldDecorator('remark', {
                initialValue: null,
              })(<Input placeholder="非必填" />)}
            </FormItem>
          </Col>
        </Row>
        <Row className={styles.submitBtn}>
          <Button htmlType="submit" loading={saveLoading}>
            保存生成订单
          </Button>
        </Row>
      </Form>
    );
  }

  // 补录订单
  onSubmit = fieldsValue => {
    console.log('------子传父组件fieldsValue------', fieldsValue);
    const { roomInfos } = fieldsValue;
    const { selectHotel, memberCode, roomTypeDesc } = this.state;
    const { form, user } = this.props;

    form.validateFields((err, fieldsValues) => {
      console.log(fieldsValues);
      fieldsValues.bookingRoomTypes.roomTypeDesc = roomTypeDesc;
      let payload = {
        ...fieldsValues,
        hotelId: +selectHotel.hotelId,
        channelId: +fieldsValues.channelId,
        bookingGuest: {
          memberId: memberCode ? +memberCode : null,
          name: fieldsValues.bookingGuest.name,
          phone: fieldsValues.bookingGuest.phone,
        },
        roomInfos,
        operatorId: +user.accountId,
        checkin: fieldsValues.checkin.format('YYYY-MM-DD HH:mm:ss'),
        checkout: fieldsValues.checkout.format('YYYY-MM-DD HH:mm:ss'),
        reserve: fieldsValues.reserve.format('YYYY-MM-DD HH:mm:ss'),
        bookingRoomTypes: [fieldsValues.bookingRoomTypes],
        status: +fieldsValues.status,
        createTime: fieldsValues.createTime.format('YYYY-MM-DD HH:mm:ss'),
        amount: +fieldsValues.roomPrice,
      };

      delete payload.checkinType;
      delete payload.roomPrice;
      payload.createType = 'SUPPLEMENT';
      payload.seed = `${moment().valueOf()}${Math.round(Math.random() * 99999999)}`;

      console.log('---SUPPLEMENT---', payload);

      this.requestSupplement(payload);
    });
  };

  render() {
    let {
      searchCityId,
      cityId,
      roomRate,
      roomType,
      roomLength,
      displaySupplement,
      isShowTable,
      singlePrice,
    } = this.state;
    let { bookingRoomList } = this.props.supplementOrder;

    return (
      <PageHeaderWrapper>
        <div className={styles.supplementPage}>
          <Card bordered={false}>
            <div className={styles.createHotelHd}>
              <p className={styles.hdTag}>所在城市:</p>
              <CitySelect
                type="cityList"
                value={searchCityId}
                onChange={val => this.onCityChange(val)}
                changeOnSelect
              />
              <p className={styles.hdTagRequired}>酒店:</p>
              <HotelInput
                ref={ref => {
                  this.HotelInputRef = ref;
                }}
                onChange={val => this.handerHotel(val)}
              />
              <Button
                type="primary"
                className={styles.hotelSearch}
                onClick={this.handlerHotelSearch}
              >
                搜索
              </Button>
              <Button className={styles.hotelSearch} onClick={this.handlerResetHotelSearch}>
                重置
              </Button>
            </div>
            {isShowTable ? (
              <HotelsTable
                handlePageChange={current => this.handlePageChange(current)}
                handlerHoltelSelect={this.handlerHoltelSelect}
              />
            ) : null}
            <p className={styles.createHotelSeleted}>
              已选择酒店: <span>{this.state.selectHotel.hotelName}</span>
            </p>
            {this.renderOrder()}
          </Card>
          <Card
            style={{ display: displaySupplement === true ? 'block' : 'none' }}
            bordered={false}
            className={styles.changeItemMargin}
          >
            <h2 className={styles.formTitle}>补录房单信息</h2>
            <SupplementBoxForm
              ref={ref => {
                this.supplementBoxRef = ref;
              }}
              roomRate={roomRate}
              singlePrice={singlePrice}
              roomType={roomType}
              roomLength={displaySupplement === true ? roomLength : 0}
              bookingRoomList={bookingRoomList}
              onSubmit={value => this.onSubmit(value)}
            />
          </Card>
        </div>
      </PageHeaderWrapper>
    );
  }

  handlerHoltelSelect = async info => {
    let { hotelId, hotelName } = info;
    const { form } = this.props;

    this.setState({
      selectHotel: {
        hotelId,
        hotelName,
      },
    });

    form.setFieldsValue({ 'bookingRoomTypes.roomTypeId': '' });

    await this.props.dispatch({
      type: 'supplementOrder/saveKey',
      payload: {
        hotelId,
      },
    });

    this.setState({
      isShowTable: false,
    });

    this.requestRateCode(); // 变更渠道之后切换房价类型

    // 获取酒店房型列表
    this.props.dispatch({
      type: 'supplementOrder/fetchRoomTypeList',
      payload: {
        hotel_id: hotelId,
      },
    });
  };

  // 城市id变更时触发
  onCityChange(val) {
    this.setState({
      searchCityId: val,
    });
  }

  // 获取房型
  handleRoomType = (item, option) => {
    this.setState({ roomTypeDesc: option.props.children });
  };

  // 获取房间数量
  getRoomCount = val => {
    this.setState({ roomLength: val, displaySupplement: false });
    const value = this.props.form.getFieldsValue(['bookingRoomTypes.count', 'roomPrice']);
    //   this.setTotalPrice(val, value.roomPrice, this.state.totalDays);
    this.calcPrice(val, value.roomPrice, this.state.totalDays);
  };

  // 获取总房费-房价
  getRoomPrice = val => {
    const { form } = this.props;
    const value = form.getFieldsValue(['bookingRoomTypes.count', 'roomPrice', 'payType']);
    // const reg = /^(-)*(\d+)\.(\d\d).*$/;
    // let totalAmount = val.target.value.replace(/[^\-?\d.]/g, '').replace(reg, '$1$2.$3');
    // console.log(val.target.value, totalAmount);
    form.setFieldsValue({
      roomPrice: val.target.value,
      amount: value.payType === 1 ? val.target.value : 0,
    });
    this.calcPrice(value.bookingRoomTypes.count, val.target.value, this.state.totalDays);
  };

  // 计算总房价
  // setTotalPrice = (count, price, days) => {
  //   const countIsNum = typeCheck('isNum', count);
  //   const priceIsNum = typeCheck('isNum', price);
  //   const daysIsNum = typeCheck('isNum', days);
  //   if (countIsNum && priceIsNum && daysIsNum) {
  //     const totalAmount = count * price * days;
  //     this.props.form.setFieldsValue({ amount: totalAmount.toFixed(2) });
  //   }
  // };

  // 计算单间房价
  calcPrice = (count, totalAmount, days) => {
    console.log('count, totalAmount, days', count, totalAmount, days);
    const countIsNum = typeCheck('isNum', +count);
    const priceIsNum = typeCheck('isNum', +totalAmount);
    const daysIsNum = typeCheck('isNum', +days);
    console.log(countIsNum && priceIsNum && daysIsNum);
    if (countIsNum && priceIsNum && daysIsNum) {
      const price = totalAmount / count / days;
      console.log('单间房价', price);
      this.setState({ singlePrice: price.toFixed(2) });
      // this.props.form.setFieldsValue({ amount: totalAmount });
    }
  };

  // 计算共住几晚
  calculateDiff(val, key) {
    const timestramp = 24 * 60 * 60 * 1000;
    const diff =
      (new Date(key === 'checkout' ? val.format('YYYY-MM-DD') : this.state.checkoutDay) -
        new Date(key === 'checkin' ? val.format('YYYY-MM-DD') : this.state.checkinDay)) /
      timestramp;

    if (diff) {
      this.setState({ totalDays: diff });

      const value = this.props.form.getFieldsValue(['bookingRoomTypes.count', 'roomPrice']);
      // this.setTotalPrice(value.bookingRoomTypes.count, value.roomPrice, diff);
      this.calcPrice(value.bookingRoomTypes.count, value.roomPrice, diff);
    }
  }

  /**
   * 搜索酒店
   * @param  {String} val 酒店的id
   */
  handerHotel(val) {
    this.setState({
      searchHotelType: val,
    });
  }

  // 酒店搜索
  handlerHotelSearch = () => {
    this.setState({
      isShowTable: true,
    });

    this.requestHotelList();
  };

  handlerResetHotelSearch = () => {
    this.setState({
      isShowTable: false,
      searchCityId: [],
      searchHotelType: {
        ...this.state.searchHotelType,
        val: '',
      },
    });

    this.HotelInputRef.resetVal();
  };

  handlePageChange = info => {
    this.requestHotelList({
      start: info.current - 1,
      hits: info.pageSize,
    });
  };

  requestHotelList = ({ start = 0, hits = PageSize } = {}) => {
    const { dispatch } = this.props;
    const { searchHotelType, searchCityId } = this.state;

    dispatch({
      type: 'hotelLists/getList',
      payload: {
        start: start * hits,
        hits,
        oyoId:
          searchHotelType.type === '2' && searchHotelType.val ? searchHotelType.val.trim() : null,
        hotelId:
          searchHotelType.type === '1' && searchHotelType.val ? searchHotelType.val.trim() : null,
        hotelName:
          searchHotelType.type === '0' && searchHotelType.val ? searchHotelType.val.trim() : null,
        status: '3',
        stateId: searchCityId[0] || null,
        cityId: searchCityId[1] || null,
        clusterId: searchCityId[2] || null,

        uniqueCode: null,
        type: null,
      },
    });
  };

  /**
   * 处理一些表单的数据改变
   * @param  {[Object, String]}  val 需要改变的值event对象或者string
   * @param  {[type]}  key
   */
  async handlerFromVal(val, key) {
    let { dispatch } = this.props;

    const targetVal = val instanceof Object ? val.target.value : val;

    await dispatch({
      type: 'supplementOrder/saveKey',
      payload: {
        [key]: targetVal,
      },
    });

    if (key === 'payType') {
      const { form } = this.props;
      const totalAmount = form.getFieldsValue(['roomPrice']);
      form.setFieldsValue({ amount: targetVal === 1 ? totalAmount.roomPrice : 0 });
      this.requestRateCode();
    } // 更换支付类型的情况需要重新请求房源策略
  }

  /**
   * 订单来源(渠道)切换后触发
   * @param  {String}  val 切换的渠道id
   */
  async handlerChannelId(val) {
    if (val === undefined) return;
    await this.props.dispatch({
      type: 'supplementOrder/saveKey',
      payload: {
        channelId: +val,
      },
    });

    this.props.form.setFieldsValue({ extBookingSn: '' });

    this.props.form.validateFields(err => {
      console.log(err);
    });
    this.requestRateCode(); // 变更渠道之后切换房价类型(策略)
  }

  /**
   * 处理预定人联系电话
   * @param  {Object}  e   event对象
   * @param  {String}  key 需要改变的key值
   */
  async handlerBookingGuestVal(e, key) {
    let { dispatch, supplementOrder } = this.props;
    let val = e.target.value;

    if (key === 'phone') {
      // 当手机号位数达到11位的时候发起是否是会员的请求
      if (val.length === 11) {
        dispatch({
          type: 'supplementOrder/verifyNumber',
          payload: {
            phone: val,
          },
        }).then(res => {
          if (e.code === '000') {
            this.setState({ memberName: res.data.memberName, memberCode: res.data.memberCode });
          }
        });

        this.requestRateCode(); // 会员变成非会员后请求价格策略
      } else {
        let lastIsNumber = supplementOrder.bookingGuest.member;

        await dispatch({
          type: 'supplementOrder/saveBookingGuest',
          payload: {
            name: '',
            memberCode: null,
            member: false,
          },
        });

        lastIsNumber && this.requestRateCode(); // 会员变成非会员后请求价格策略
      }
    }

    dispatch({
      type: 'supplementOrder/saveBookingGuest',
      payload: {
        [key]: val,
      },
    });
  }

  /**
   * 入住离店保留时间
   * @param  {String}  key 需要改变的key
   * @param  {Moment}  val Moment对象
   * @return {Promise}     [description]
   */
  async handleTime(key, val) {
    // let isEffectAmount = false;
    let { supplementOrder, dispatch } = this.props;
    let { amount } = supplementOrder;

    // 设置入离时间的时候
    if (key !== 'reserve') {
      // isEffectAmount = true; // 改变入离时间之后会影响房源产品列表的数据 所以需要清空已选房源的数据
      val &&
        val
          .hour(12)
          .minute(0)
          .second(0); // 默认为12点
    }

    if (key === 'checkin') {
      this.setState({
        checkinDay: moment(val).format('YYYY-MM-DD'),
        // checkinOut: moment(val)
        //   .hour(18)
        //   .minute(0)
        //   .second(0),
      });
      // this.props.form.setFieldsValue({
      //   reserve: moment(val)
      //     .hour(18)
      //     .minute(0)
      //     .second(0),
      // });
    }

    if (key === 'checkout') {
      this.setState({ checkoutDay: moment(val).format('YYYY-MM-DD') });

      val.format('YYYY-MM-DD') > moment().format('YYYY-MM-DD')
        ? this.props.form.setFieldsValue({ status: '1' })
        : this.props.form.setFieldsValue({ status: '2' });
    }

    await dispatch({
      type: 'supplementOrder/saveKey',
      payload: {
        [key]: val,
      },
    });

    if (!val) return this.resetRateAndRoom(); // 删除时间的时候

    // if (isEffectAmount && amount) {
    //   await this.props.dispatch({
    //     type: 'supplementOrder/resetRoom',
    //   });
    // }

    this.requestRateCode(); // 变更渠道之后切换房价类型

    this.calculateDiff(val, key);
  }

  /**
   * 保留日期筛选不可选择的时间(不得保存至目前之前)
   * @param  {Moment} current
   * @return {[type]}         [description]
   */
  disabledTime(current) {
    if (!current) return;

    let nowDate = moment();

    // 选择日期为当日的时候才使用时间筛选
    if (current.format('YYYYMMDD') === nowDate.format('YYYYMMDD')) {
      let hour = nowDate.hour();

      // 返回不可用的小时
      return {
        disabledHours: () => Array.from(new Array(24), (item, index) => index).slice(0, hour + 1),
      };
    }

    return {};
  }

  /**
   * 房价(策略)类型被切换后触发
   * @param  {String}  val 房价策略的id
   */
  async handlerRateCodeId(val) {
    await this.props.dispatch({
      type: 'supplementOrder/saveKey',
      payload: {
        rateCode: val,
      },
    });

    // 由于房价类型被更换后
    // await this.props.dispatch({
    //   type: 'supplementOrder/resetRoom',
    // });
  }

  // 变更渠道之后切换房价类型
  async requestRateCode() {
    let { dispatch, supplementOrder, form } = this.props;
    let { checkin, checkout, reserve, bookingGuest, channelId, hotelId, payType } = supplementOrder;
    let isCanRateCode = this.validateRateCode(); // 进行数据校验 返回fase则不进行请求
    form.setFieldsValue({ 'bookingRoomTypes.rateCode': '' });

    if (isCanRateCode) {
      // if (checkout.isBefore(checkin)) {
      //   this.resetRateAndRoom();

      //   return message.error('离店日期请晚于入住时间');
      // }
      console.log('-------请求房价类型--------', checkin, checkout, reserve);
      let params = {
        checkInType: 1, // 1全天 0钟点 (目前只做全天)
        guestSourceType: !bookingGuest.member ? 1 : 2, // 客源类型 1: 非会员 2：会员
        channelId, // 渠道来源
        hotelId, // 酒店id
        payType, // 支付方式 0到付 1预付
      };

      if (checkin) params.checkInDate = checkin.format('YYYY-MM-DD HH:mm');
      if (checkout) params.checkOutDate = checkout.format('YYYY-MM-DD HH:mm');
      if (reserve) params.reservationDate = reserve.format('YYYY-MM-DD HH:mm:ss');

      let res = await dispatch({
        type: 'supplementOrder/fetchRateCode',
        payload: params,
      });

      res.info && message.info(res.info); // 进行提示
    } else {
      dispatch({
        type: 'supplementOrder/saveKey',
        payload: {
          isCanRateCode: false,
          rateCode: null,
          rateCodeList: [],
        },
      });
    }
  }

  // 验证是否可以发送查询策略的请求
  validateRateCode() {
    const { supplementOrder } = this.props;
    let { hotelId, checkin, checkout, reserve } = supplementOrder;

    if (!hotelId || !checkin || !checkout || !reserve) return false;

    return true;
  }

  // 重置策略以及房屋
  resetRateAndRoom() {
    this.props.dispatch({
      type: 'supplementOrder/resetRateCode',
    });

    // this.props.dispatch({
    //   type: 'supplementOrder/resetRoom',
    // });
  }
}
