import React, { PureComponent } from 'react';
import { Input, Form, Col, Row, Select, Message, Tooltip, Icon } from 'antd';
import { checkFloatNumber } from '@/utils/validate';

const { Option } = Select;
const formItemLayout = {
  labelCol: { span: 6 },
  wrapperCol: { span: 18 },
};
@Form.create()
export default class BookingRoom extends PureComponent {
  constructor(props) {
    super(props);

    const {
      room,
      bookingRoomListIndex,
      roomNumber,
      updatingVisible,
      roomTypeList,
      rangePrice,
    } = props;

    this.state = {
      room,
      bookingRoomListIndex,
      roomNumber,
      updatingVisible,
      roomTypeList,
      inventoryListOpt: [],
      rangePrice,
    };
  }

  handleRoomTypeSelect = (value, opt) => {
    const { onSelectRoomType } = this.props;
    const { bookingRoomListIndex } = this.state;

    typeof onSelectRoomType === 'function' && onSelectRoomType(value, bookingRoomListIndex);
  };

  handleRoomNumberSelect = (value, opt) => {
    // console.log('房间数量', value, opt);

    const { onSelectRoomNumber } = this.props;
    const { bookingRoomListIndex } = this.state;
    typeof onSelectRoomNumber === 'function' && onSelectRoomNumber(value, bookingRoomListIndex);
  };

  handleRoomPriceChange = (e, min, max, key) => {
    const { form } = this.props;
    const value = Number(e.target.value);

    if (!checkFloatNumber(value)) return;

    if (value && min) {
      if (value < min) {
        Message.error(`请输入大于等于${min}的数`);
      }
    }
    if (value && max) {
      if (value > max) {
        Message.error(`请输入小于等于${max}的数`);
      }
    }
    const { onChangeRoomPrice, getDiffParams } = this.props;
    const { bookingRoomListIndex } = this.state;
    // typeof onChangeRoomPrice === 'function' && onChangeRoomPrice(value, bookingRoomListIndex);

    typeof getDiffParams === 'function' && getDiffParams('price', key, value);
  };

  handleNumber(e, key) {
    const { getDiffParams } = this.props;
    const value = Number(e.target.value);
    // if (Number.isNaN(value)) return false;

    typeof getDiffParams === 'function' && getDiffParams('number', key, value);
  }

  componentWillReceiveProps(props) {
    let { updatingVisible, roomTypeList, room, roomNumber, rangePrice } = props;
    let inventoryListOpt = [];
    let roomTypeListLength = roomTypeList.length;
    if (roomTypeListLength > 0) {
      for (let i = 0; i < roomTypeListLength; i += 1) {
        let roomType = roomTypeList[i];
        if (roomType.id === room.roomType) {
          const inventory = [];
          for (let index = 1; index <= roomNumber; index += 1) {
            inventory.push(index);
          }
          inventoryListOpt = inventory.map((num, key) => (
            <Option value={num} key={`inventoryList-${key}`}>
              {num}
            </Option>
          ));
        }
      }
    }

    this.setState({ updatingVisible, roomTypeList, room, inventoryListOpt, rangePrice });
  }

  render() {
    const { form } = this.props;
    const {
      room,
      bookingRoomListIndex,
      roomNumber,
      updatingVisible,
      roomTypeList,
      inventoryListOpt,
      rangePrice = {},
    } = this.state;

    let { priceCustomizable = true, rangePriceMax = 99999, rangePriceMin = 0 } = rangePrice;

    // console.log(updatingVisible === false && priceCustomizable === true);

    let priceDisabled = true;
    if (updatingVisible === false && priceCustomizable === true) {
      priceDisabled = false;
    } else {
      priceDisabled = true;
    }
    // console.log('priceDisabled', priceDisabled);

    const key = bookingRoomListIndex;
    const config = {};
    if (rangePriceMin) {
      config.min = rangePriceMin;
    }
    if (rangePriceMax) {
      config.max = rangePriceMax;
    }

    let shareDetial = () => {
      if (room.roomType && room.occupyRoomType && room.roomType !== room.occupyRoomType) {
        return (
          <Tooltip
            title={
              <div style={{ fontSize: 10 }}>
                客人预订的房型为<span style={{ color: '#e6a125' }}>{room.occupyRoomTypeDesc}</span>
                ，系统占用了
                <span style={{ color: '#e6a125' }}>{room.roomTypeDesc}</span>
                的库存， 客人到店实际入住的房型以酒店前台安排的房型为准
              </div>
            }
          >
            <Icon type="exclamation-circle" style={{ color: '#faad14' }} />
          </Tooltip>
        );
      }
    };

    return (
      <Row gutter={16} key={room.id}>
        <Col lg={8} md={12} sm={24} style={{ display: 'none' }}>
          <Form.Item label="房间id" {...formItemLayout}>
            {form.getFieldDecorator(`bookingRoomList[${key}].id`, {
              initialValue: room.id,
            })(<Input disabled />)}
          </Form.Item>
        </Col>
        <Col lg={8} md={12} sm={24} style={{ display: 'none' }}>
          <Form.Item label="订单号" {...formItemLayout}>
            {form.getFieldDecorator(`bookingRoomList[${key}].bookingId`, {
              initialValue: room.bookingId,
            })(<Input disabled />)}
          </Form.Item>
        </Col>
        <Col lg={6} md={12} sm={24} style={{ display: 'none' }}>
          <Form.Item label="房价类型" {...formItemLayout}>
            {form.getFieldDecorator(`bookingRoomList[${key}].rateCode`, {
              initialValue: room.rateCode,
            })(<Input style={{ width: '100%' }} disabled />)}
          </Form.Item>
        </Col>
        <Col lg={6} md={12} sm={24}>
          <Form.Item label="房价类型" {...formItemLayout}>
            {form.getFieldDecorator(`bookingRoomList[${key}].rateCodeName`, {
              initialValue: room.rateCodeName,
            })(<Input style={{ width: '100%' }} disabled />)}
          </Form.Item>
        </Col>
        <Col lg={6} md={12} sm={24} style={{ display: 'none' }}>
          <Form.Item label="房间类型" {...formItemLayout}>
            {form.getFieldDecorator(`bookingRoomList[${key}].roomType`, {
              initialValue: room.roomType,
            })(<Input style={{ width: '100%' }} disabled />)}
          </Form.Item>
        </Col>
        <Col lg={6} md={12} sm={24}>
          <Form.Item label="房间类型" {...formItemLayout}>
            {form.getFieldDecorator(`bookingRoomList[${key}].roomTypeDesc`, {
              initialValue: room.roomTypeDesc,
            })(<Input style={{ width: '100%' }} addonAfter={shareDetial()} disabled />)}
          </Form.Item>
        </Col>
        <Col lg={6} md={12} sm={24}>
          <Form.Item label="间数" {...formItemLayout}>
            {form.getFieldDecorator(`bookingRoomList[${key}].number`, {
              rules: [
                {
                  validator: (rule, value, callback) => {
                    if (value === '' || !/^\d+$/.test(value)) {
                      callback('请输入正确的间数');
                    }

                    callback();
                  },
                },
              ],
              initialValue: room.number,
            })(
              <Input
                style={{ width: '100%' }}
                disabled={updatingVisible}
                type="number"
                precision={0}
                onChange={e => this.handleNumber(e, key)}
              />
            )}
          </Form.Item>
        </Col>
        <Col lg={6} md={12} sm={24}>
          <Form.Item label="房价" {...formItemLayout}>
            {form.getFieldDecorator(`bookingRoomList[${key}].price`, {
              initialValue: room.price,
              rules: [
                {
                  validator: (rule, value, callback) => {
                    if (value === '' || !checkFloatNumber(value)) {
                      callback('请输入正确的间数');
                    }

                    callback();
                  },
                },
              ],
            })(
              <Input
                style={{ width: '100%' }}
                disabled={priceDisabled}
                precision={2}
                {...config}
                onChange={e => this.handleRoomPriceChange(e, rangePriceMin, rangePriceMax, key)}
              />
            )}
          </Form.Item>
        </Col>
      </Row>
    );
  }
}
