import React, { PureComponent } from 'react';
import { connect } from 'dva';
import { Card, Form, Row, Col, Input, Button, message, Select, Modal, Radio } from 'antd';
import moment from 'moment';
import { opResultList, cidConfrimResultList } from '../config/preventCID';
import styles from '../PreventCID/index.less';

const FormItem = Form.Item;
const Option = Select.Option;
const { TextArea } = Input;
const RadioGroup = Radio.Group;
@Form.create()
@connect(({ preventCID }) => ({
  preventCID,
}))
export default class CidCallModel extends PureComponent {
  constructor(props) {
    super(props);
    const { title, visible, CidDetail } = props;
    this.state = {
      visible,
      title: title || '',
      CidDetail,
    };
  }

  static getDerivedStateFromProps(nextProps, prevState) {
    const { visible, bookingId, form } = nextProps;

    if (!visible) {
      form.resetFields();
    }
    if (visible !== prevState.visible) {
      return { ...nextProps };
    }

    return null;
  }

  handleOk = () => {
    const { onOK, form } = this.props;
    let {
      CidDetail: { bookingId },
    } = this.state;
    form
      .validateFields()
      .then(res => {
        let params = { ...res, bookingId };
        typeof onOK === 'function' && onOK(params);
      })
      .catch(err => {
        message.warn('信息未填写完整或格式不正确！');
      });
  };

  handleCancel = () => {
    const visible = false;
    const { onCancel, form } = this.props;

    form.resetFields();
    this.setState({
      visible,
    });

    typeof onCancel === 'function' && onCancel(visible);
  };

  handleSubmit = () => {};

  render() {
    const { visible, title, CidDetail } = this.state;
    const { disabled, form } = this.props;
    const { getFieldDecorator } = form;
    const formItemLayout = {
      labelCol: {
        span: 6,
      },
      wrapperCol: {
        span: 16,
      },
    };

    let footer = disabled
      ? null
      : [
          <Button type="primary" onClick={this.handleOk} key="submit">
            确定
          </Button>,
          <Button onClick={this.handleCancel} key="back">
            取消
          </Button>,
        ];

    CidDetail.opResult = CidDetail.opResult === -1 ? '' : CidDetail.opResult;

    return (
      <Modal
        width={500}
        maskClosable={false}
        visible={visible}
        title={`${disabled ? '查看' : '记录'}预防CID外呼结果`}
        footer={footer}
        onCancel={this.handleCancel}
      >
        <Form onSubmit={this.handleSubmit} className={styles.order}>
          <FormItem label="酒店确认结果" {...formItemLayout}>
            {getFieldDecorator('confirmResult', {
              initialValue: CidDetail.confirmResult,
              rules: [{ required: true, message: '请选择酒店确认结果!' }],
            })(
              <Select disabled={disabled}>
                {cidConfrimResultList.map(v => (
                  <Option value={v.value} key={v.value}>
                    {v.label}
                  </Option>
                ))}
              </Select>
            )}
          </FormItem>
          <FormItem label="OP协调结果" {...formItemLayout}>
            {getFieldDecorator('opResult', {
              initialValue: CidDetail.opResult,
            })(
              <Select disabled={disabled}>
                {opResultList.map(v => (
                  <Option value={v.value} key={v.value}>
                    {v.label}
                  </Option>
                ))}
              </Select>
            )}
          </FormItem>
          <FormItem label="升级CID工单" {...formItemLayout}>
            {getFieldDecorator('upgrateCid', {
              initialValue: CidDetail.upgrateCid,
              rules: [{ required: true, message: '请选择是否升级CID工单!' }],
            })(
              <RadioGroup disabled={disabled}>
                <Radio value={0}>是</Radio>
                <Radio value={1}>否</Radio>
              </RadioGroup>
            )}
          </FormItem>
          <FormItem label="备注" labelCol={{ span: 4 }} wrapperCol={{ span: 18 }}>
            {getFieldDecorator('remark', {
              initialValue: CidDetail.remark,
              rules: [
                {
                  max: 500,
                  message: '备注不可超过500字',
                },
              ],
            })(<TextArea disabled={disabled} rows={4} />)}
          </FormItem>
        </Form>
      </Modal>
    );
  }
}
