/*
 * @Description: In User Settings Edit
 * @Author: your name
 * @Date: 2019-08-06 15:10:11
 * @LastEditTime: 2019-08-13 11:40:05
 * @LastEditors: Please set LastEditors
 */
import React, { PureComponent } from 'react';
import { connect } from 'dva';
import {
  Card,
  Form,
  Row,
  Col,
  Icon,
  Select,
  Popover,
  Button,
  Radio,
  Input,
  DatePicker,
  message,
  Modal,
} from 'antd';
import moment from 'moment';
import { cloneDeep } from 'lodash';
import { rowProps, widthStyle, formItemWithoutLabel } from '@/utils/formProps';
import styles from './ExceptionCpn.less';
import { PMS_PAYMENT_TYPE_OPTION } from '@/constant/pmsPaymentType';
import RoomDayPrice from './RoomDayPrice';
import ButtonAuthorized from '@/components/ButtonAuthorized';
import { CANCEL_REASON, CANCEL_REASON_OPTION } from '@/constant/appealCancelReason';

const FormItem = Form.Item;
const { Option } = Select;
const { TextArea } = Input;
const RadioGroup = Radio.Group;
const { RangePicker } = DatePicker;
const colProps = { span: 20 };
const formItemLayout = {
  labelCol: {
    xs: { span: 24 },
    sm: { span: 8 },
  },
  wrapperCol: {
    xs: { span: 24 },
    sm: { span: 16 },
  },
};
@connect(({ daily }) => ({ daily }))
@Form.create()
export default class ExceptionCpn extends PureComponent {
  constructor(props) {
    super(props);
    this.state = {
      committerRole: 'CUSTOMER_SERVICE', // 先写死默认是客服
      reasonChosen: null,
      orderSnList: [],
      amount: null,
      reasonChosenName: null,
      reasonChosenValue: null,
      newCheckInDate: null,
      newCheckOutDate: null,
      dayPriceVisible: false,
      eidtPrice: false,
      isOrigin: true,
      dayPriceList: [],
      initDayPriceList: [],
      OriginDayPriceList: [],
      rejectModalVisible: false,
      remark: '',
      roomOrderSnList: [],
      initDate: [],
    };
  }

  componentDidMount() {
    let { form, appealDetail, dispatch, bookingMsg } = this.props;
    let {
      appealDetailRequest: { roomReservationAppealReason, bookingAppealReason },
    } = appealDetail;
    let arr = [];
    let date = [];
    if (
      roomReservationAppealReason &&
      roomReservationAppealReason.dailyPriceList &&
      roomReservationAppealReason.dailyPriceList.length !== 0
    ) {
      arr = roomReservationAppealReason.dailyPriceList.map(v => ({
        price: v.rate,
        date: v.rateDate,
        originalPrice: v.originRate,
        roomTypeId: v.roomTypeId,
      }));
      this.setState({
        dayPriceList: arr,
        initDayPriceList: cloneDeep(arr),
      });
    }

    if (bookingAppealReason && bookingAppealReason.newCheckInDate) {
      date = [
        moment(bookingAppealReason.newCheckInDate),
        moment(bookingAppealReason.newCheckOutDate),
      ];

      this.setState({
        initDate: date,
        newCheckInDate: bookingAppealReason.newCheckInDate,
        newCheckOutDate: bookingAppealReason.newCheckOutDate,
      });
    }

    this.handleReason(appealDetail.appealCode);
  }

  // 请求：房单信息+处理
  requestRoomMsg = value => {
    const { committerRole } = this.state;
    const { dispatch, bookingMsg, appealDetail } = this.props;
    const params = { appealReasonCode: value, bookingSn: bookingMsg.bookingSn, committerRole };

    dispatch({
      type: 'daily/fetchOrderSnList',
      payload: params,
    }).then(res => {
      const orderSnList = res.data && Array.isArray(res.data) ? res.data : [];
      const ORDERSN_OPTION = orderSnList.map((item, key) => (
        <Option value={item.roomReservationId} key={key} amount={item.amount}>
          {item.orderSn ? item.orderSn : null} {item.roomNo ? `房间号：${item.roomNo}` : null}{' '}
          {item.guestNames ? `客人姓名：${item.guestNames}` : null}
        </Option>
      ));

      this.setState({ orderSnList: ORDERSN_OPTION, roomOrderSnList: orderSnList }, () => {
        if (appealDetail.appealCode) {
          this.getInitAmount(appealDetail.roomReservationId);
        }
      });
    });
  };

  // 请求：订单信息+处理
  requestOrderMsg = value => {
    const { dispatch, bookingMsg, orderDetailData } = this.props;
    if (value === 'BOOKING_SOURCE') {
      this.setState({
        reasonChosenName: '订单来源',
        reasonChosenValue: orderDetailData.channelName,
      });
    } else if (value === 'BOOKING_ACCOUNT_TYPE') {
      this.setState({
        reasonChosenName: '入账主体',
        reasonChosenValue: orderDetailData.accountType,
      });
    } else if (value === 'BOOKING_EXT_BOOKING_SN') {
      this.setState({
        reasonChosenName: '渠道订单号',
        reasonChosenValue: orderDetailData.extBookingSn,
      });
    } else if (value === 'BOOKING_CONTACT_PHONE') {
      this.setState({
        reasonChosenName: '联系电话',
        reasonChosenValue: orderDetailData.bookingGuest.phone,
      });
    } else if (value === 'BOOKING_CONTACT') {
      this.setState({
        reasonChosenName: '预订人姓名',
        reasonChosenValue: orderDetailData.bookingGuest.name,
      });
    } else if (value === 'REMARK') {
      this.setState({
        reasonChosenName: '预订单备注',
        reasonChosenValue: orderDetailData.remark,
      });
    } else if (value === 'BOOKING_CHECK_IN_OUT_DATE') {
      const times = `${orderDetailData.arrivalTime.slice(
        0,
        -9
      )} ~ ${orderDetailData.departureTime.slice(0, -9)}`;
      this.setState({
        reasonChosenName: '入离日期',
        reasonChosenValue: times,
      });
    } else {
      this.setState({ reasonChosenName: null });
    }
  };

  // 请求：退款信息+处理
  requestRefundMsg = value => {
    const { dispatch, bookingMsg } = this.props;
    const { committerRole } = this.state;

    dispatch({
      type: 'daily/fetchRefundDetail',
      payload: {
        appealReasonCode: value,
        bookingId: bookingMsg.bookingId,
        committerRole,
      },
    });
  };

  // 操作：选择申诉原因
  handleReason = value => {
    this.setState({ reasonChosen: value, amount: null });
    const { form } = this.props;
    form.setFieldsValue({
      roomReservationId: undefined,
      newReservationStatus: null,
      newReservationAmount: null,
    });

    if (
      value === 'ROOM_RESERVATION_CANCEL' ||
      value === 'ROOM_RESERVATION_NOSHOW' ||
      value === 'HIGHT_PRICE' ||
      value === 'ROOM_RESERVATION_AMOUNT' ||
      value === 'ROOM_RESERVATION_DAILY_PRICE'
    ) {
      this.setState({ reasonChosenName: '房单总房价' });
      this.requestRoomMsg(value);
    } else if (value === 'CANCEL_BOOKING_FULL_REFUND') {
      this.requestRefundMsg(value);
    } else {
      this.requestOrderMsg(value);
    }
  };

  // 获取房单房价
  handleChangeRoom = (value, opt) => {
    let { dispatch } = this.props;
    dispatch({
      type: 'daily/fetchRoomPriceDetail',
      payload: value,
    }).then(res => {
      let roomPriceList = res.data.roomPriceList || [];
      let arr = roomPriceList.map(v => ({
        ...v,
        roomTypeId: res.data.roomType,
      }));

      this.setState({
        OriginDayPriceList: arr,
      });
    });
    this.setState({ amount: opt.props.amount });
  };

  handleDate = (data, dataString) => {
    this.setState({ newCheckInDate: dataString[0], newCheckOutDate: dataString[1] });
  };

  // 操作：处理完成
  handleFinish = e => {
    if (e) {
      e.preventDefault();
    }
    const {
      committerRole,
      newCheckInDate,
      newCheckOutDate,
      dayPriceList,
      OriginDayPriceList,
    } = this.state;
    const {
      form,
      dispatch,
      bookingMsg: { appealId, hotelId, bookingSn },
      getProcessingList,
    } = this.props;
    const formParams = form.getFieldsValue();
    formParams &&
      Object.keys(formParams).forEach(key => {
        if (typeof formParams[key] === 'string') {
          formParams[key] = formParams[key].trim();
        }
      });
    const {
      appealReasonCode,
      newBookingSn,
      newReservationAmount,
      newReservationStatus,
      cancelReasonCode,
    } = formParams;
    let roomReservationAppealReason = {};
    let bookingAppealReason = {};
    let refundReasonCode = null;
    if (!appealReasonCode) {
      message.warn('请选申择诉原因！');
      return;
    }
    if (appealReasonCode === 'ROOM_RESERVATION_CANCEL' && !cancelReasonCode) {
      message.warn('选择申诉取消原因！');
      return;
    }
    if (
      appealReasonCode === 'ROOM_RESERVATION_CANCEL' ||
      appealReasonCode === 'ROOM_RESERVATION_NOSHOW' ||
      appealReasonCode === 'HIGHT_PRICE' ||
      appealReasonCode === 'ROOM_RESERVATION_AMOUNT'
    ) {
      roomReservationAppealReason = formParams;
    } else if (appealReasonCode === 'ROOM_RESERVATION_DAILY_PRICE') {
      if (!newReservationAmount) {
        message.warn('请输入正确房价！');
        return;
      }
      let arr = dayPriceList.map((v, i) => ({
        rate: v.price,
        rateDate: v.date,
        originRate: OriginDayPriceList[i] ? OriginDayPriceList[i].price : v.originalPrice,
        roomTypeId: v.roomTypeId,
      }));
      roomReservationAppealReason = formParams;
      roomReservationAppealReason.dailyPriceList = arr;
    } else if (appealReasonCode === 'BOOKING_CHECK_IN_OUT_DATE') {
      bookingAppealReason = { ...formParams, newCheckInDate, newCheckOutDate };
      if (!newBookingSn) {
        message.warn('请输入新订单号！');
        return;
      }
    } else if (appealReasonCode === 'CANCEL_BOOKING_FULL_REFUND') {
      refundReasonCode = formParams.refundReasonCode;
    } else {
      bookingAppealReason = formParams;
    }

    if (appealReasonCode === 'ROOM_RESERVATION_CANCEL') {
      delete roomReservationAppealReason.newStatusView;
      roomReservationAppealReason.newReservationStatus = 3;
    } else if (appealReasonCode === 'ROOM_RESERVATION_NOSHOW') {
      roomReservationAppealReason.newReservationStatus = 4;
      delete roomReservationAppealReason.newStatusView;
    }
    const params = {
      appealDetailList: [
        { appealReasonCode, refundReasonCode, roomReservationAppealReason, bookingAppealReason },
      ],
      committerRole,
      appealId,
      hotelId,
      bookingSn,
    };

    delete params.appealDetailList[0].roomReservationAppealReason.appealReasonCode;
    delete params.appealDetailList[0].bookingAppealReason.appealReasonCode;

    dispatch({
      type: 'daily/fetchSingleAppeal',
      payload: params,
    }).then(res => {
      if (res.code === '000') {
        message.success(res.msg);
        getProcessingList({ bookingSn });
      }
    });
  };

  // 显示每天房价
  showDayPrice = (isEidet, isOrigin, list) => {
    let { initDayPriceList, dayPriceVisible, dayPriceList } = this.state;
    const {
      dispatch,
      form,
      bookingMsg: { appealId, hotelId, bookingSn },
    } = this.props;
    let totalPrice = 0;
    if (list) {
      list.forEach(v => {
        totalPrice += v.price;
      });
      form.setFieldsValue({
        newReservationAmount: totalPrice,
      });
      this.setState({
        dayPriceList: list,
        initDayPriceList: cloneDeep(list),
        dayPriceVisible: !dayPriceVisible,
        eidtPrice: isEidet,
        isOrigin,
      });
    } else {
      let formDate = form.getFieldsValue();
      if (!formDate.roomReservationId) {
        message.warn('请选择房单！');
        return;
      }
      if (isOrigin || (initDayPriceList.length === 0 && !isOrigin)) {
        dispatch({
          type: 'daily/fetchRoomPriceDetail',
          payload: formDate.roomReservationId,
        }).then(res => {
          if (res.code === '000') {
            let roomPriceList = res.data.roomPriceList || [];
            let arr = roomPriceList.map(v => ({
              ...v,
              roomTypeId: res.data.roomType,
            }));

            this.setState({
              dayPriceList: arr,
              dayPriceVisible: !dayPriceVisible,
              eidtPrice: isEidet,
              isOrigin,
            });
          }
        });
      } else {
        this.setState({
          dayPriceList: cloneDeep(initDayPriceList),
          dayPriceVisible: !dayPriceVisible,
          eidtPrice: isEidet,
          isOrigin,
        });
      }
    }
  };

  // 操作：申诉驳回弹窗
  showRejectModal = () => {
    this.setState({ rejectModalVisible: true });
  };

  hideRejectModal = () => {
    this.setState({ rejectModalVisible: false, remark: '' });
  };

  // 申诉驳回弹窗
  renderRejectModal = () => {
    const { rejectModalVisible, remark } = this.state;
    return (
      <Modal
        visible={rejectModalVisible}
        title="申诉驳回"
        onOk={this.requestAppeal}
        onCancel={this.hideRejectModal}
      >
        <TextArea
          value={remark}
          rows={3}
          maxLength={50}
          placeholder="请输入驳回原因"
          onChange={this.handleChangeRemark}
        />
      </Modal>
    );
  };

  handleChangeRemark = e => {
    const remark = e.target.value.trim();
    this.setState({ remark });
  };

  // 请求：申诉驳回
  requestAppeal = () => {
    const { committerRole, remark } = this.state;
    const { dispatch, bookingMsg, appealDetail, form } = this.props;
    const formParams = form.getFieldsValue();
    const { appealReasonCode, roomReservationId } = formParams;
    if (remark === '') {
      message.warn('请输入驳回原因！');
      return;
    }

    if (!appealReasonCode) {
      message.warn('请选择申诉原因！');
      return;
    }

    let params = {
      roomReservationId,
      operateType: 'REJECTED',
      bookingSn: bookingMsg.bookingSn,
      appealId: +bookingMsg.appealId,
      appealCode: appealReasonCode,
      committerRole,
      remark,
    };
    dispatch({
      type: 'daily/fetchRejectAppeal',
      payload: params,
    }).then(res => {
      if (res.code === '000') {
        this.setState({ rejectModalVisible: false, remark: '' });
        message.success(res.msg);
      }
    });
  };

  // 赋值时计算总价
  getInitAmount = value => {
    let { roomOrderSnList } = this.state;
    roomOrderSnList.forEach(v => {
      if (value === v.roomReservationId) {
        this.setState({
          amount: v.amount,
        });
      }
    });
  };

  render() {
    const {
      form: { getFieldDecorator },
      channelList,
      itemIndex,
      appealReason,
      handleDelete,
      refundDetail,
      appealDetail,
    } = this.props;
    const {
      reasonChosen,
      orderSnList,
      amount,
      reasonChosenName,
      reasonChosenValue,
      dayPriceList,
      eidtPrice,
      dayPriceVisible,
      isOrigin,
      initDate,
    } = this.state;
    const { appealDetailRequest } = appealDetail;
    const presentStatus = reasonChosenName ? `当前${reasonChosenName}` : '当前状态';
    const updatedStatus = reasonChosenName ? `修改后的${reasonChosenName}` : '修改后的状态';
    const popoverContent =
      refundDetail &&
      Array.isArray(refundDetail.offerDetailList) &&
      refundDetail.offerDetailList.map((item, index) => (
        <div key={index}>{`${item.name} --- ${item.amount}元`}</div>
      ));

    // 房单价详情按钮
    const roomDayDetial = <span onClick={e => this.showDayPrice(false, true)}>¥明细</span>;

    // 房单价编辑按钮
    const roomDayEidet = isEidt => (
      <span onClick={e => this.showDayPrice(isEidt, false)}>
        <Icon type="edit" />
        改价
      </span>
    );
    let isInProcess = appealDetail.status === 'IN_PROCESS' || appealDetail.status === '';
    let isEidt = appealDetail.isAlready && !isInProcess;

    return (
      <div className={styles.exceptionSection}>
        <Card>
          <Form layout="inline" onSubmit={this.handleFinish}>
            <Row style={{ textAlign: 'right' }}>
              <Button
                onClick={handleDelete}
                style={{
                  border: 'none',
                  boxShadow: 'none',
                  fontSize: 18,
                  padding: 0,
                  display: appealDetail.isAlready ? 'none' : 'display',
                }}
              >
                <Icon type="delete" />
              </Button>
            </Row>
            <Row {...rowProps}>
              <Col {...colProps}>
                <FormItem label="申诉原因" style={widthStyle} {...formItemLayout}>
                  {getFieldDecorator('appealReasonCode', { initialValue: appealDetail.appealCode })(
                    <Select
                      placeholder="请选择申诉原因"
                      onChange={value => this.handleReason(value)}
                      notFoundContent="该订单当前暂无可申诉原因"
                      disabled={appealDetail.isAlready}
                    >
                      {appealReason || []}
                    </Select>
                  )}
                </FormItem>
              </Col>

              {/* 选择房单  onChange={this.handleChangeRoom} */}
              {reasonChosen === 'ROOM_RESERVATION_CANCEL' ||
              reasonChosen === 'ROOM_RESERVATION_NOSHOW' ||
              reasonChosen === 'HIGHT_PRICE' ||
              reasonChosen === 'ROOM_RESERVATION_AMOUNT' ||
              reasonChosen === 'ROOM_RESERVATION_DAILY_PRICE' ? (
                <Col {...colProps}>
                  <FormItem label="选择房单" style={widthStyle} {...formItemLayout}>
                    {getFieldDecorator('roomReservationId', {
                      initialValue: appealDetail.roomReservationId,
                    })(
                      <Select
                        placeholder="请选择房单"
                        disabled={appealDetail.isAlready}
                        onSelect={(value, opt) => this.handleChangeRoom(value, opt)}
                      >
                        {orderSnList}
                      </Select>
                    )}
                  </FormItem>
                </Col>
              ) : null}

              {/* 房间状态/门店跳高单调整 */}
              {reasonChosen === 'HIGHT_PRICE' ? (
                <Col {...colProps}>
                  <FormItem label="修改后状态" style={widthStyle} {...formItemLayout}>
                    {getFieldDecorator('newReservationStatus', {
                      initialValue:
                        appealDetailRequest.roomReservationAppealReason.newReservationStatus,
                    })(
                      <RadioGroup disabled={isEidt}>
                        <Radio value={3}>取消</Radio>
                        <Radio value={4}>noshow</Radio>
                      </RadioGroup>
                    )}
                  </FormItem>
                </Col>
              ) : null}
              {/* 房单取消 */}
              {reasonChosen === 'ROOM_RESERVATION_CANCEL' ? (
                <>
                  <Col {...colProps}>
                    <FormItem label="修改后状态" style={widthStyle} {...formItemLayout}>
                      {getFieldDecorator('newStatusView', {
                        initialValue: '取消',
                      })(<Input disabled />)}
                    </FormItem>
                  </Col>
                  <Col {...colProps}>
                    <FormItem label="取消原因" style={widthStyle} {...formItemLayout}>
                      {getFieldDecorator('cancelReasonCode', {
                        initialValue:
                          appealDetailRequest.roomReservationAppealReason.cancelReasonCode,
                      })(<Select disabled={isEidt}>{CANCEL_REASON_OPTION}</Select>)}
                    </FormItem>
                  </Col>
                </>
              ) : null}
              {/* 房单noshow */}
              {reasonChosen === 'ROOM_RESERVATION_NOSHOW' ? (
                <Col {...colProps}>
                  <FormItem label="修改后状态" style={widthStyle} {...formItemLayout}>
                    {getFieldDecorator('newStatusView', {
                      initialValue: 'noshow',
                    })(<Input disabled />)}
                  </FormItem>
                </Col>
              ) : null}
              {/* 当前状态展示 */}
              {!reasonChosen ||
              reasonChosen === 'ROOM_RESERVATION_STATUS' ||
              reasonChosen === 'ROOM_RESERVATION_CANCEL' ||
              reasonChosen === 'ROOM_RESERVATION_NOSHOW' ||
              reasonChosen === 'HIGHT_PRICE' ||
              reasonChosen === 'ROOM_RESERVATION_AMOUNT' ||
              reasonChosen === 'OTHER' ||
              reasonChosen === 'ROOM_RESERVATION_DAILY_PRICE' ? null : (
                <Col {...colProps}>
                  <FormItem label={presentStatus} style={widthStyle} {...formItemLayout}>
                    {reasonChosen === 'ROOM_RESERVATION_AMOUNT' ? amount : reasonChosenValue}
                  </FormItem>
                </Col>
              )}
              {/* 修改后的房单总房价 */}
              {reasonChosen === 'ROOM_RESERVATION_AMOUNT' ? (
                <Col {...colProps}>
                  <FormItem label="正确房单总房价" style={widthStyle} {...formItemLayout}>
                    {getFieldDecorator('newReservationAmount', {
                      initialValue:
                        appealDetailRequest.roomReservationAppealReason.newReservationAmount,
                      rules: [
                        {
                          message: '请输入正确房单总房价',
                          pattern: new RegExp('^\\d+\\.?\\d{0,2}$'),
                        },
                      ],
                    })(
                      <Input addonBefore="¥" placeholder="请输入正确房单总房价" disabled={isEidt} />
                    )}
                  </FormItem>
                </Col>
              ) : null}
              {reasonChosen === 'ROOM_RESERVATION_AMOUNT' ? (
                <Col {...colProps}>
                  <FormItem label="支付类型" style={widthStyle} {...formItemLayout}>
                    {getFieldDecorator('paymentType', {
                      initialValue: appealDetailRequest.roomReservationAppealReason.paymentType,
                    })(
                      <Select placeholder="请选择支付类型" disabled={isEidt}>
                        {PMS_PAYMENT_TYPE_OPTION}
                      </Select>
                    )}
                  </FormItem>
                </Col>
              ) : null}
              {/* 房单房价错误 */}
              {reasonChosen === 'ROOM_RESERVATION_DAILY_PRICE' ? (
                <Col {...colProps}>
                  <FormItem label="当前房价" style={widthStyle} {...formItemLayout}>
                    <Input
                      placeholder="当前房价"
                      value={amount}
                      addonAfter={roomDayDetial}
                      disabled
                    />
                  </FormItem>
                  <FormItem label="正确房价" style={widthStyle} {...formItemLayout}>
                    {getFieldDecorator('newReservationAmount', {
                      initialValue:
                        appealDetailRequest.roomReservationAppealReason.newReservationAmount,
                    })(
                      <Input placeholder="正确房价" addonAfter={roomDayEidet(!isEidt)} disabled />
                    )}
                  </FormItem>
                  <FormItem label="收款方式" style={widthStyle} {...formItemLayout}>
                    {getFieldDecorator('paymentType', {
                      initialValue: appealDetailRequest.roomReservationAppealReason.paymentType,
                    })(
                      <Select placeholder="请选择收款方式" disabled={isEidt}>
                        {PMS_PAYMENT_TYPE_OPTION}
                      </Select>
                    )}
                  </FormItem>
                </Col>
              ) : null}
              {!reasonChosen ||
              reasonChosen === 'ROOM_RESERVATION_STATUS' ||
              reasonChosen === 'ROOM_RESERVATION_CANCEL' ||
              reasonChosen === 'ROOM_RESERVATION_NOSHOW' ||
              reasonChosen === 'HIGHT_PRICE' ||
              reasonChosen === 'ROOM_RESERVATION_AMOUNT' ||
              reasonChosen === 'CANCEL_BOOKING_FULL_REFUND' ||
              reasonChosen === 'OTHER' ||
              reasonChosen === 'ROOM_RESERVATION_DAILY_PRICE' ? null : (
                <Col {...colProps}>
                  <FormItem label={updatedStatus} style={widthStyle} {...formItemLayout}>
                    {/* 订单来源 */}
                    {reasonChosen === 'BOOKING_SOURCE'
                      ? getFieldDecorator('newBookingSource', {
                          initialValue: appealDetailRequest.bookingAppealReason.newBookingSource,
                        })(
                          <Select placeholder="请选择订单来源" disabled={isEidt}>
                            {channelList}
                          </Select>
                        )
                      : null}
                    {/* 入账主体 */}
                    {reasonChosen === 'BOOKING_ACCOUNT_TYPE'
                      ? getFieldDecorator('newBookingAccount', {
                          initialValue: appealDetailRequest.bookingAppealReason.newBookingAccount,
                        })(
                          <Select placeholder="请选择入账主体" disabled={isEidt}>
                            <Option value="OYO">OYO账户</Option>
                            <Option value="HOTEL">酒店账户</Option>
                          </Select>
                        )
                      : null}
                    {/* 渠道订单号 */}
                    {reasonChosen === 'BOOKING_EXT_BOOKING_SN'
                      ? getFieldDecorator('newExtBooking', {
                          initialValue: appealDetailRequest.bookingAppealReason.newExtBooking,
                          rules: [
                            {
                              message: '请输入正确的渠道订单号',
                              pattern: '^[0-9a-zA-Z_]{1,}$',
                            },
                          ],
                        })(<Input placeholder="请输入渠道订单号" disabled={isEidt} />)
                      : null}
                    {/* 预订人姓名 */}
                    {reasonChosen === 'BOOKING_CONTACT'
                      ? getFieldDecorator('newBookingContact', {
                          initialValue: appealDetailRequest.bookingAppealReason.newBookingContact,
                        })(<Input placeholder="请输入预订人姓名" disabled={isEidt} />)
                      : null}
                    {/* 联系电话 */}
                    {reasonChosen === 'BOOKING_CONTACT_PHONE'
                      ? getFieldDecorator('newBookingContactPhone', {
                          initialValue:
                            appealDetailRequest.bookingAppealReason.newBookingContactPhone,
                          rules: [
                            {
                              message: '请输入11位的联系电话',
                              pattern: '^1\\d{10}$',
                            },
                          ],
                        })(<Input placeholder="请输入联系电话" disabled={isEidt} />)
                      : null}
                    {/* 预订单备注 */}
                    {reasonChosen === 'REMARK'
                      ? getFieldDecorator('newRemark', {
                          initialValue: appealDetailRequest.bookingAppealReason.newRemark,
                        })(
                          <TextArea
                            placeholder="请输入预订单备注"
                            rows={3}
                            maxLength={50}
                            disabled={isEidt}
                          />
                        )
                      : null}
                    {/* 入离日期 */}
                    {reasonChosen === 'BOOKING_CHECK_IN_OUT_DATE'
                      ? getFieldDecorator('newCheckInDate', {
                          initialValue: initDate,
                        })(
                          <RangePicker
                            onChange={this.handleDate}
                            disabled={appealDetail.isAlready}
                          />
                        )
                      : null}
                  </FormItem>
                </Col>
              )}
              {reasonChosen === 'BOOKING_CHECK_IN_OUT_DATE' ? (
                <Col {...colProps}>
                  <FormItem label="新订单号" style={widthStyle} {...formItemLayout}>
                    {getFieldDecorator('newBookingSn', {
                      initialValue: appealDetailRequest.bookingAppealReason.newBookingSn,
                      rules: [
                        {
                          message: '请输入正确的订单号',
                          pattern: '[0-9a-zA-Z_]',
                        },
                      ],
                    })(<Input placeholder="请输入新订单号" disabled={isEidt} />)}
                  </FormItem>
                </Col>
              ) : null}
              {/* 取消订单并全额退款 */}
              {reasonChosen === 'CANCEL_BOOKING_FULL_REFUND' ? (
                <Col {...colProps}>
                  <FormItem label="更改订单状态" style={widthStyle} {...formItemLayout}>
                    <Input style={{ width: '50%' }} value="取消" disabled />
                  </FormItem>
                  <FormItem label="退款金额" style={widthStyle} {...formItemLayout}>
                    <Input
                      style={{ width: '50%' }}
                      addonBefore="¥"
                      disabled
                      value={refundDetail.refundAmount}
                    />
                  </FormItem>
                  <FormItem label="退优惠" style={widthStyle} {...formItemLayout}>
                    <Input
                      style={{ width: '50%' }}
                      addonBefore="¥"
                      disabled
                      value={refundDetail.discountTotal}
                    />
                    <div className={styles.popBtn}>
                      <Popover placement="bottom" content={popoverContent} trigger="click">
                        <Button>
                          <Icon
                            type="question-circle"
                            theme="filled"
                            style={{ color: '#faad14' }}
                          />
                        </Button>
                      </Popover>
                    </div>
                  </FormItem>
                  <FormItem label="退款原因" style={widthStyle} {...formItemLayout}>
                    {getFieldDecorator('refundReasonCode', {
                      initialValue: appealDetailRequest.refundReasonCode,
                    })(
                      <Select placeholder="请选择退款原因" disabled={isEidt}>
                        {Array.isArray(refundDetail.refundReasonList) &&
                          refundDetail.refundReasonList.map((item, index) => (
                            <Option value={item.code} key={index}>
                              {item.value}
                            </Option>
                          ))}
                      </Select>
                    )}
                  </FormItem>
                </Col>
              ) : null}
              {/* 其它 */}
              {reasonChosen === 'OTHER' ? (
                <Col {...colProps}>
                  <FormItem label="" style={widthStyle} {...formItemWithoutLabel}>
                    {getFieldDecorator('otherContent', {
                      initialValue: appealDetailRequest.bookingAppealReason.otherContent,
                    })(
                      <TextArea
                        style={{ marginTop: 10, width: '82%', float: 'right' }}
                        placeholder="请输入"
                        rows={5}
                        maxLength={50}
                        disabled={isEidt}
                      />
                    )}
                  </FormItem>
                </Col>
              ) : null}
            </Row>
            <Row style={{ textAlign: 'right', marginTop: 10 }}>
              <ButtonAuthorized code="CRS3.8.7" htmlType="submit" myDisabled={isEidt}>
                通过
              </ButtonAuthorized>
              <ButtonAuthorized
                code="CRS3.8.8"
                style={{ marginLeft: 10 }}
                myDisabled={isEidt}
                onClick={e => this.showRejectModal(e)}
              >
                驳回
              </ButtonAuthorized>
            </Row>
          </Form>
          <RoomDayPrice
            dataList={dayPriceList}
            isEidt={eidtPrice}
            isOrigin={isOrigin}
            visible={dayPriceVisible}
            operateF={this.showDayPrice}
          />
          {this.renderRejectModal()}
        </Card>
      </div>
    );
  }
}
