import React, { PureComponent } from 'react';
import { connect } from 'dva';
import { Table, Icon } from 'antd';
import styled from 'styled-components';

import defaultSettings from '@/defaultSettings';

const HotelSearchTable = styled.div`
  margin-top: 30px;
`;
const BookingButton = styled.span`
  color: ${defaultSettings.primaryColor};
  cursor: pointer;
`;

@connect(({ hotelLists }) => ({
  hotelLists,
}))
export default class HotelsTable extends PureComponent {
  constructor(props) {
    super(props);

    this.columns = [
      {
        title: 'OYO ID',
        dataIndex: 'oyoId',
        width: '10%',
      },
      {
        title: '酒店ID',
        dataIndex: 'hotelId',
        width: '10%',
      },
      {
        title: '酒店名称',
        dataIndex: 'hotelName',
        width: '30%',
      },
      {
        title: '地址',
        dataIndex: 'street',
      },
      {
        title: '操作',
        dataIndex: 'operation',
        width: 80,

        render: (text, record) => (
          <BookingButton onClick={() => this.handlerHoltelSelect(record)}>选择</BookingButton>
        ),
      },
    ];

    this.state = {};
  }

  handlePageChange = info => {
    let { handlePageChange } = this.props;

    handlePageChange && handlePageChange(info);
  };

  handlerHoltelSelect = record => {
    let { handlerHoltelSelect } = this.props;

    handlerHoltelSelect && handlerHoltelSelect(record);
  };

  render() {
    let { pagination, list, loading } = this.props.hotelLists;

    return (
      <HotelSearchTable>
        <Table
          bordered
          loading={loading}
          size="small"
          rowKey="hotelId"
          dataSource={list}
          columns={this.columns}
          pagination={pagination}
          rowClassName="editable-row"
          onChange={this.handlePageChange}
          onShowSizeChange={this.handlePageChange}
        />
      </HotelSearchTable>
    );
  }
}
