import React, { PureComponent } from 'react';
import { Modal, Button, Input, message } from 'antd';
import { checkFloatNumber } from '@/utils/validate';
import styles from './RoomBox.less';

const Interval = 200;

export default class RoomBox extends PureComponent {
  constructor() {
    super();
    this.state = {
      modalVisible: false,
      inputCount: null,
    };
  }

  render() {
    const { index, inventory, roomType, listRate, rate, productIndex, number } = this.props;
    const { count, inputCount, modalVisible } = this.state;

    return (
      <li
        className={`${styles.roomBox} ${index === productIndex ? styles.active : ''}`}
        key={index}
        onClick={() => this.selectProduct()}
      >
        <p className={styles.hotelTypeLeft}>
          剩余
          <span>{inventory - number}间</span>
        </p>
        <p className={styles.hotelTypeTitle}>{roomType.saleRoomTypeName || '未知房型'}</p>
        <div className={styles.hotelTypePrice}>
          <Input value={rate} onChange={e => this.handlerPriceVal(e)} />
        </div>
        <div className={styles.control}>
          <div className={styles.controlBtn} onClick={e => this.handlerCount(e, 0)}>
            -
          </div>
          <div className={styles.controlShow}>{number}间</div>
          <div className={styles.controlBtn} onClick={e => this.handlerCount(e, 1)}>
            +
          </div>
        </div>
        <Modal
          title="预定间数"
          visible={modalVisible}
          onOk={this.handleOk}
          onCancel={this.handleCancel}
        >
          <Input type="number" value={inputCount} onChange={e => this.handleInputCount(e)} />
        </Modal>
      </li>
    );
  }

  handlerPriceVal(e) {
    const { index, roomType, onChange, number } = this.props;
    let price = e.target.value;

    if (!checkFloatNumber(price)) return false;

    if (Number(price) > 9999) price = '9999';

    price = price.replace(/^0/, '');

    onChange &&
      onChange({
        index,
        number,
        roomType: roomType.id,
        roomTypeDesc: roomType.saleRoomTypeName || '未知房型',
        price,
      });
  }

  selectProduct() {
    const { index, roomType, rate, onChange, number } = this.props;

    onChange &&
      onChange({
        index,
        number,
        roomType: roomType.id,
        roomTypeDesc: roomType.saleRoomTypeName || '未知房型',
        price: rate,
      });
  }

  showModal(e) {
    const count = this.state.count;

    e.stopPropagation();

    this.setState({
      modalVisible: true,
      inputCount: count || null,
    });
  }

  handleOk = () => {
    const { inventory, onChange, roomType, rate, index } = this.props;
    const { inputCount } = this.state;

    if (inputCount > inventory) return message.error(`不得超过最大库存${inventory}`);

    onChange &&
      onChange({
        index,
        number: inputCount,
        roomType: roomType.id,
        roomTypeDesc: roomType.saleRoomTypeName || '未知房型',
        price: rate,
      });

    this.setState({
      modalVisible: false,
      inputCount: null,
      count: inputCount,
    });
  };

  handleCancel = e => {
    this.setState({
      modalVisible: false,
      inputCount: null,
    });
  };

  // type = 0 减少一间 type = 1 则增加一间 触发onChange事件
  handlerCount(e, type, isInterval) {
    let { inventory, onChange, index, roomType, rate, number } = this.props;
    e.stopPropagation();

    number = type === 0 ? Math.max(--number, 0) : Math.min(++number, inventory);

    onChange &&
      onChange({
        index,
        rate,
        number,
        roomType: roomType.id,
        roomTypeDesc: roomType.saleRoomTypeName || '未知房型',
        price: rate,
      });
  }

  handleInputCount(e) {
    const { inventory, onChange, index, roomType, rate } = this.props;

    this.setState({
      inputCount: e.target.value,
    });
  }
}
