import React, { PureComponent } from 'react';
import { connect } from 'dva';
import { Table, Icon, Card, Input, Modal, Button, InputNumber, message } from 'antd';
import styled from 'styled-components';
import moment from 'moment';
import { spawn } from 'child_process';
import { number } from 'prop-types';
import defaultSettings from '@/defaultSettings';

const weekName = ['星期日', '星期一', '星期二', '星期三', '星期四', '星期五', '星期六'];
const reg = new RegExp('^\\d+\\.?\\d{0,2}$');

export default class RoomDayPrice extends PureComponent {
  constructor(props) {
    super(props);

    this.state = {
      priceList: [],
    };
  }

  componentWillReceiveProps(nextProps) {
    let { dataList, visible } = nextProps;
    if (dataList === this.props.dataList) {
      return;
    }
    let arr = dataList.map((v, i) => {
      let dateM = moment(v.date);
      let day = weekName[dateM.day()];

      return {
        ...v,
        date: dateM.format('YYYY-MM-DD'),
        day,
        price: v.price,
        originalPrice: v.originalPrice,
      };
    });
    this.setState({
      priceList: arr,
    });
  }

  handleOk = () => {
    let { isEidt } = this.props;
    let { priceList } = this.state;
    let ischeck = priceList.some(v => reg.test(v.price));
    if (!ischeck) {
      message.warn('请填写正确的价格！');
      return;
    }
    this.props.operateF(isEidt, false, priceList);
  };

  handleCancel = () => {
    let { isEidt } = this.props;
    this.props.operateF(isEidt, false);
  };

  dateChange = (e, i) => {
    let { priceList } = this.state;
    let num = e.target.value;
    if (i === 0) {
      priceList = priceList.map((v, index) => {
        v.price = num !== '' ? Number(num) : '';
        return v;
      });
    } else {
      priceList[i].price = num !== '' ? Number(num) : '';
    }
    if (!reg.test(priceList[i].price)) {
      message.warn('房价不可小于0,且最多支持两位小数！');
    }
    this.setState({
      priceList: priceList.concat([]),
    });
  };

  render() {
    let { isEidt, visible, isOrigin } = this.props;
    let { priceList } = this.state;

    return (
      <Modal
        title={`${!isEidt ? '查看' : '修改'}每日房价`}
        width="616px"
        visible={visible}
        onOk={this.handleOk}
        onCancel={this.handleCancel}
        footer={
          isEidt
            ? [
                <Button key="sure" type="primary" onClick={this.handleOk}>
                  确认
                </Button>,
                <Button key="submit" type="primary" onClick={this.handleCancel}>
                  取消
                </Button>,
              ]
            : []
        }
      >
        <Card>
          {priceList.map((v, i) => (
            <span key={i} style={{ width: 247, margin: 6, display: 'inline-block' }}>
              <Input
                addonBefore={`${v.date} ${v.day} `}
                value={v.price}
                type="number"
                disabled={!isEidt}
                min={0}
                onChange={e => this.dateChange(e, i)}
              />
            </span>
          ))}
        </Card>
      </Modal>
    );
  }
}
