import React, { PureComponent } from 'react';
import { connect } from 'dva';
import { Card, Form, Row, Col, Input, InputNumber, Button, message, Divider, Select } from 'antd';
import moment from 'moment';
import styles from '../Supplement.less';

/**
 * 补录房单form组件
 * url: /#/order/components/SupplementBox
 * 功能: 根据数量渲染对应房间数的list
 */

const FormItem = Form.Item;
const Option = Select.Option;
@Form.create()
@connect(({ supplementOrder }) => ({
  supplementOrder,
}))
export default class SupplementBoxForm extends PureComponent {
  componentWillReceiveProps(props) {
    // console.log(props);
  }

  resetVal() {
    this.props.form.resetFields();
  }

  handleFieldsValue = e => {
    e.preventDefault();

    const { onSubmit, form } = this.props;
    form.validateFields((err, fieldsValue) => {
      if (err) return;
      // console.log('------子组建fieldsValue------');
      // console.log(fieldsValue);
      typeof onSubmit === 'function' && onSubmit(fieldsValue);
    });
  };

  handleRoomNo = (e, i, option) => {
    console.log('---handleRoomNo---', e, i, option);
    const { form, bookingRoomList } = this.props;

    if (!Array.isArray(bookingRoomList)) return;
    if (bookingRoomList.length === 0) return;

    const roomTypeName = bookingRoomList[option].roomTypeName;
    const roomId = bookingRoomList[option].roomId;
    const roomNo = bookingRoomList[option].roomNo;

    console.log('handleRoomNo:', roomTypeName, roomId, roomNo);

    form.setFieldsValue({ [`roomInfos[${i}].roomId`]: roomId });
    form.setFieldsValue({ [`roomInfos[${i}].roomTypeName`]: roomTypeName });
  };

  // 补录房单信息
  renderRoom() {
    const {
      form: { getFieldDecorator },
      bookingRoomList,
      roomRate,
      roomLength,
      singlePrice,
    } = this.props;
    const formItemLayout = {
      labelCol: { span: 5 },
      wrapperCol: { span: 12 },
    };

    let items = [];
    for (let i = 0; i < roomLength; i++) {
      items.push(
        <div key={i}>
          <Row gutter={{ xs: 6, md: 6, lg: 12, xl: 12 }} type="flex">
            <Col md={6} sm={24}>
              <FormItem label="房间号码" {...formItemLayout}>
                {getFieldDecorator(`roomInfos[${i}].roomNo`, {
                  initialValue: null,
                  rules: [{ required: true, message: '请选择房间号码' }],
                })(
                  <Select
                    placeholder="请选择房间号码"
                    onSelect={(e, option) => this.handleRoomNo(e, i, option.key)}
                  >
                    {bookingRoomList.map((item, index) => (
                      <Option key={index} value={item.roomNo}>
                        {item.roomNo}
                      </Option>
                    ))}
                  </Select>
                )}
              </FormItem>
            </Col>
            <Col md={6} sm={24} style={{ display: 'none' }}>
              <FormItem label="房间类型id" {...formItemLayout}>
                {getFieldDecorator(`roomInfos[${i}].roomId`, {
                  initialValue: null,
                  getValueFromEvent: e => {
                    console.log('getValueFromEvent:', e);
                  },
                })(<Input style={{ width: '100%' }} disabled />)}
              </FormItem>
            </Col>
            <Col md={6} sm={24}>
              <FormItem label="房间类型" {...formItemLayout}>
                {getFieldDecorator(`roomInfos[${i}].roomTypeName`, {
                  initialValue: null,
                })(<Input style={{ width: '100%' }} disabled />)}
              </FormItem>
            </Col>
            <Col md={6} sm={24}>
              <FormItem label="房间价格" {...formItemLayout}>
                {getFieldDecorator('amount')(<span>{singlePrice}</span>)}
              </FormItem>
            </Col>
          </Row>
          <Row gutter={{ xs: 6, md: 6, lg: 12, xl: 12 }} type="flex">
            <Col md={6} sm={24}>
              <FormItem label="入住人" {...formItemLayout}>
                {getFieldDecorator(`roomInfos[${i}].roomReservationGuests[0].name`, {
                  initialValue: null,
                  rules: [{ required: true, message: '请输入入住人' }],
                })(<Input style={{ width: '100%' }} placeholder="请输入入住人" />)}
              </FormItem>
            </Col>
            <Col md={6} sm={24}>
              <FormItem label="联系电话" {...formItemLayout}>
                {getFieldDecorator(`roomInfos[${i}].roomReservationGuests[0].phone`, {
                  initialValue: null,
                  rules: [
                    {
                      message: '请输入正确的手机号码',
                      pattern: '^1(3|4|5|7|8)\\d{9}$',
                    },
                  ],
                })(<Input style={{ width: '100%' }} maxLength={11} placeholder="请输入电话号码" />)}
              </FormItem>
            </Col>
            <Col md={5} sm={24}>
              <FormItem label="证件类型" {...formItemLayout}>
                {getFieldDecorator(`roomInfos[${i}].roomReservationGuests[0].cardType`, {
                  initialValue: 1,
                })(
                  <Select>
                    <Option value={1}>身份证</Option>
                  </Select>
                )}
              </FormItem>
            </Col>
            <Col md={7} sm={24}>
              <FormItem label="证件号码" {...formItemLayout}>
                {getFieldDecorator(`roomInfos[${i}].roomReservationGuests[0].cardNo`, {
                  initialValue: null,
                  rules: [
                    {
                      message: '请输入正确的证件号码',
                      pattern: '(^\\d{15}$)|(^\\d{18}$)|(^\\d{17}(\\d|X|x)$)',
                    },
                  ],
                })(<Input style={{ width: '100%' }} maxLength={18} placeholder="请输入证件号码" />)}
              </FormItem>
            </Col>
          </Row>
          <Row gutter={{ xs: 6, md: 6, lg: 12, xl: 12 }} type="flex">
            <Col md={6} sm={24}>
              <FormItem label="入住人" {...formItemLayout}>
                {getFieldDecorator(`roomInfos[${i}].roomReservationGuests[1].name`, {
                  initialValue: null,
                })(<Input style={{ width: '100%' }} placeholder="请输入入住人" />)}
              </FormItem>
            </Col>
            <Col md={6} sm={24}>
              <FormItem label="联系电话" {...formItemLayout}>
                {getFieldDecorator(`roomInfos[${i}].roomReservationGuests[1].phone`, {
                  initialValue: null,
                  rules: [
                    {
                      message: '请输入正确的手机号码',
                      pattern: '^1(3|4|5|7|8)\\d{9}$',
                    },
                  ],
                })(<Input style={{ width: '100%' }} maxLength={11} placeholder="请输入电话号码" />)}
              </FormItem>
            </Col>
            <Col md={5} sm={24}>
              <FormItem label="证件类型" {...formItemLayout}>
                {getFieldDecorator(`roomInfos[${i}].roomReservationGuests[1].cardType`, {
                  initialValue: 1,
                })(
                  <Select>
                    <Option value={1}>身份证</Option>
                  </Select>
                )}
              </FormItem>
            </Col>
            <Col md={7} sm={24}>
              <FormItem label="证件号码" {...formItemLayout}>
                {getFieldDecorator(`roomInfos[${i}].roomReservationGuests[1].cardNo`, {
                  initialValue: null,
                  rules: [
                    {
                      message: '请输入正确的证件号码',
                      pattern: '(^\\d{15}$)|(^\\d{18}$)|(^\\d{17}(\\d|X|x)$)',
                    },
                  ],
                })(<Input style={{ width: '100%' }} maxLength={18} placeholder="请输入证件号码" />)}
              </FormItem>
            </Col>
          </Row>
          <Divider />
        </div>
      );
    }

    return (
      <Form onSubmit={this.handleFieldsValue} layout="inline">
        {items}
        <Row className={styles.submitBtn}>
          <Button type="primary" htmlType="submit">
            确认补录
          </Button>
        </Row>
      </Form>
    );
  }

  render() {
    return this.renderRoom();
  }
}
