import React from 'react';
import moment from 'moment';
import { Input, Select, Button, DatePicker } from 'antd';
import { HANDLE_TYPE_OPTION, getHandleTypeFromStatus } from '@/constant/orderHandleType';
import { SUBMIT_DEPT_TYPE_OPTION, getDeptTypeFromStatus } from '@/constant/submitDeptType';
import ButtonAuthorized from '@/components/ButtonAuthorized';
import { getOrderNameFromOrderStatus } from '@/constant/orderStatus';

const { Option } = Select;

const getFormConfig = (SOURCE_LIST_OPTION, hotelCpn, ALL_REASON_OPTION) => [
  {
    type: 'startDate',
    label: '开始日期',
    options: {
      initialValue: moment().subtract(7, 'days'),
      rules: [{ required: true, message: '请选择开始日期' }],
    },
    component: (
      <DatePicker format="YYYY-MM-DD" style={{ width: '100%' }} placeholder="请选择开始日期" />
    ),
  },
  {
    type: 'endDate',
    label: '结束日期',
    options: { initialValue: moment(), rules: [{ required: true, message: '请选择结束日期' }] },
    component: (
      <DatePicker format="YYYY-MM-DD" style={{ width: '100%' }} placeholder="请选择结束日期" />
    ),
  },
  {
    type: 'source',
    label: '订单渠道',
    options: { initialValue: null },
    component: (
      <Select>
        <Option value={null} key="CRSChannelList-all">
          全部
        </Option>
        {SOURCE_LIST_OPTION}
      </Select>
    ),
  },
  {
    type: 'bookingSn',
    label: '订单号',
    component: <Input placeholder="请输入订单号" />,
  },
  {
    type: 'committerName',
    label: '提交人',
    component: <Input placeholder="请输入提交人" />,
  },
  {
    type: 'committerRole',
    label: '提交部门',
    options: { initialValue: 'HOTEL' },
    component: <Select placeholder="请选择提交部门">{SUBMIT_DEPT_TYPE_OPTION}</Select>,
  },
  {
    type: 'hotelParams',
    label: '门店名称',
    options: { initialValue: undefined },
    component: hotelCpn,
  },
  {
    type: 'status',
    label: '处理状态',
    options: { initialValue: 'IN_PROCESS' },
    component: <Select placeholder="请选择处理状态">{HANDLE_TYPE_OPTION}</Select>,
  },
  {
    type: 'appealReasonCode',
    label: '门店申诉原因',
    options: { initialValue: null },
    component: (
      <Select placeholder="请选择门店申诉原因">
        <Option value={null} key="ReasonList-all">
          全部
        </Option>
        {ALL_REASON_OPTION}
      </Select>
    ),
  },
];

const getTableConfig = (handleEdit, showLogModal) => [
  {
    title: '发起时间',
    dataIndex: 'appealTime',
  },
  {
    title: '提交部门',
    dataIndex: 'committerRoleName',
  },
  {
    title: '门店名称',
    dataIndex: 'hotelName',
  },
  {
    title: '订单号',
    dataIndex: 'bookingSn',
  },
  {
    title: '订单渠道',
    dataIndex: 'sourceName',
  },
  {
    title: '城市',
    dataIndex: 'cityName',
  },
  {
    title: '申诉提交人',
    dataIndex: 'committerName',
  },
  {
    title: '提交内容',
    dataIndex: 'commitContent',
    render: commitContent =>
      Array.isArray(commitContent) &&
      commitContent.length > 0 &&
      commitContent.map((item, key) => (
        <div key={key}>
          {commitContent.length > 1 ? `${key + 1}、` : ''}
          {item}
        </div>
      )),
  },
  {
    title: '处理内容',
    dataIndex: 'dealContent',
    render: dealContent =>
      Array.isArray(dealContent) &&
      dealContent.length > 0 &&
      dealContent.map((item, key) => (
        <div key={key}>
          {dealContent.length > 1 ? `${key + 1}、` : ''}
          {item}
        </div>
      )),
  },
  {
    title: '处理状态',
    dataIndex: 'dealStatusName',
    render: (dealStatusName, record) => (
      <span>
        {dealStatusName}
        {record.payStatusDesc ? ` | ${record.payStatusDesc}` : null}
      </span>
    ),
  },
  {
    title: '操作',
    dataIndex: 'appealId',
    render: (appealId, record) => (
      <>
        {record.dealStatus === 'DONE' || record.dealStatus === 'REJECTED' ? null : (
          <ButtonAuthorized
            code="CRS3.8.3"
            size="small"
            style={{ marginRight: 10 }}
            onClick={() => handleEdit(2, record.bookingSn, record.appealId)}
          >
            操作
          </ButtonAuthorized>
        )}
        <ButtonAuthorized code="CRS3.8.4" size="small" onClick={() => showLogModal(appealId)}>
          日志
        </ButtonAuthorized>
      </>
    ),
  },
];

const LOG_CONFIG = [
  {
    title: '操作时间',
    dataIndex: 'operatorTime',
    key: 'operatorTime',
  },
  {
    title: '操作人',
    dataIndex: 'operatorName',
    key: 'operateName',
  },
  {
    title: '行为',
    dataIndex: 'operatorBehavior',
    key: 'operatorBehavior',
    render: (operatorBehavior, record) => `${operatorBehavior}-${record.appealContent}`,
  },
  {
    title: '房单号',
    dataIndex: 'orderSn',
    key: 'orderSn',
  },
  {
    title: '详情',
    dataIndex: 'appealDetail',
    key: 'appealDetail',
    render: appealDetail =>
      appealDetail
        ? Array.isArray(appealDetail) &&
          appealDetail.length > 0 &&
          appealDetail.map((item, key) => <div key={key}>{item}</div>)
        : '',
  },
  {
    title: 'IP',
    dataIndex: 'ip',
    key: 'ip',
  },
];

const getProcessingConfig = (showLogModal, operateClick) => [
  {
    title: '申诉时间',
    dataIndex: 'appealTime',
    width: 100,
  },
  {
    title: '申诉单号',
    dataIndex: 'appealId',
    width: 80,
  },
  {
    title: '提交部门',
    dataIndex: 'committerRole',
    width: 80,
    render: committerRole => <span>{getDeptTypeFromStatus(committerRole)}</span>,
  },
  {
    title: '提交内容',
    dataIndex: 'commitAppealDetail',
    width: 120,
    render: commitAppealDetail =>
      Array.isArray(commitAppealDetail) &&
      commitAppealDetail.length > 0 &&
      commitAppealDetail.map((item, key) => (
        <div key={key}>
          {commitAppealDetail.length > 1 ? `${key + 1}、` : ''}
          {item.appealCodeDesc}
          {item.bookingStatus !== null
            ? ` (${getOrderNameFromOrderStatus(item.bookingStatus)})`
            : ''}
        </div>
      )),
  },
  {
    title: '处理内容',
    dataIndex: 'dealContent',
    width: 120,
    render: dealContent =>
      Array.isArray(dealContent) &&
      dealContent.length > 0 &&
      dealContent.map((item, key) => (
        <div key={key}>
          {dealContent.length > 1 ? `${key + 1}、` : ''}
          {item}
        </div>
      )),
  },
  {
    title: '处理状态',
    dataIndex: 'dealStatus',
    width: 80,
    render: (dealStatus, record) => (
      <span>
        {getHandleTypeFromStatus(dealStatus)}
        {record.payStatusDesc ? ` | ${record.payStatusDesc}` : null}
      </span>
    ),
  },
  {
    title: '操作',
    width: 60,
    render: record => (
      <span>
        <ButtonAuthorized
          code="CRS3.8.5"
          size="small"
          style={{ marginLeft: 10 }}
          onClick={() => operateClick(record.appealId)}
        >
          操作
        </ButtonAuthorized>
        <ButtonAuthorized
          code="CRS3.8.6"
          size="small"
          style={{ marginLeft: 10 }}
          onClick={() => showLogModal(record.appealId)}
        >
          日志
        </ButtonAuthorized>
      </span>
    ),
  },
];

export { getFormConfig, getTableConfig, LOG_CONFIG, getProcessingConfig };
