import React from 'react';
import { Input, Select, Button, DatePicker, Tag } from 'antd';
import moment from 'moment';
import Link from 'umi/link';
import CitySelect from '@/components/CitySelect';
import { COOPERATION_TYPE } from '@/constant/allHotelType';
import { HOTEL_STATUS } from '@/constant/hotelStatus';
import style from '../PreventCID/index.less';
import ButtonAuthorized from '@/components/ButtonAuthorized';

const { Option } = Select;

const CCDataList = [
  {
    value: 0.6,
    label: '60%',
  },
  {
    value: 0.8,
    label: '80%',
  },
  {
    value: 1,
    label: '100%',
  },
];

const CidCallList = [
  {
    value: 0,
    label: '全部',
  },
  {
    value: 1,
    label: '已处理',
  },
  {
    value: 2,
    label: '待处理',
  },
];

const opResultList = [
  {
    value: 1,
    label: '无法联系OP',
  },
  {
    value: 2,
    label: '协调成功',
  },
  {
    value: 3,
    label: '协调失败',
  },
  {
    value: 4,
    label: '无需联系OP',
  },
];

const cidConfrimResultList = [
  {
    value: 0,
    label: '确认客人可入住',
  },
  {
    value: 1,
    label: '订单价格不对',
  },

  {
    value: 2,
    label: '酒店满房',
  },
  {
    value: 3,
    label: '客人已入住',
  },
  {
    value: 4,
    label: '客人已取消',
  },

  {
    value: 5,
    label: '酒店不配合/无法联系',
  },
  {
    value: 6,
    label: '酒店停止合作/停业',
  },
  {
    value: 7,
    label: '酒店不会查询',
  },
  {
    value: 8,
    label: '查询不到订单',
  },
  {
    value: 9,
    label: '其他结果',
  },
];

// CID来源
const CIDSourceList = [
  {
    value: 0,
    label: '前台升级',
  },
  {
    value: 1,
    label: '预防升级',
  },
];

// 赔付来源
const VOCSourceList = [
  {
    value: 0,
    label: 'CID',
  },
  {
    value: 1,
    label: 'VOC',
  },
];

// CID原因
const CIDReasonList = [
  {
    value: 0,
    label: '满房',
  },
  {
    value: 1,
    label: '价格不对',
  },
  {
    value: 2,
    label: '查无订单',
  },
  {
    value: 3,
    label: '酒店不会操作系统',
  },
  {
    value: 4,
    label: '酒店停止合作',
  },
  {
    value: 5,
    label: '酒店歇业',
  },
  {
    value: 6,
    label: '酒店拒绝接单',
  },
  {
    value: 7,
    label: '酒店不认可优惠券',
  },
  {
    value: 8,
    label: 'PMS系统问题',
  },
];

// 客人情况
const GuestSituationList = [
  {
    value: 0,
    label: '已到店',
  },
  {
    value: 1,
    label: '未到店',
  },
];

// 处理结果
const CIDProcessResultList = [
  {
    value: 0,
    label: '原酒店入住',
  },
  {
    value: 1,
    label: '转移到附近OYO酒店入住',
  },
  {
    value: 2,
    label: '转移到附近非OYO酒店入住',
  },
  {
    value: 3,
    label: '客人不接受协调',
  },
  {
    value: 4,
    label: '无需解决',
  },
];

// 赔付类型
const PayoutList = [
  {
    value: 0,
    label: '需要赔付',
  },
  {
    value: 1,
    label: '不需要赔付',
  },
];

// CID原因
const CIDComplaintList = [
  {
    value: 0,
    label: 'APP问题赔付',
  },
  {
    value: 1,
    label: '到店无房赔付',
  },
  {
    value: 2,
    label: '价格歧义赔付',
  },
  {
    value: 3,
    label: '确认后无房赔付',
  },
  {
    value: 4,
    label: '订单补偿退款',
  },
  {
    value: 5,
    label: '活动问题赔付',
  },
  {
    value: 6,
    label: '客户体验赔付',
  },
  {
    value: 7,
    label: '其他',
  },
];

// VOC处理结果
const VOCResultList = [
  {
    value: 0,
    label: '赔付差价',
  },
  {
    value: 1,
    label: '赔付首晚房费',
  },
  {
    value: 2,
    label: '首晚房费退一赔一',
  },
  {
    value: 3,
    label: '首晚房费退一赔二',
  },
  {
    value: 4,
    label: '首晚房费退一赔三',
  },
  {
    value: 5,
    label: '为用户补偿退款',
  },
  {
    value: 6,
    label: '协商赔付',
  },
];

// 责任方
const ResponsibleList = [
  {
    value: 0,
    label: '酒店',
  },
  {
    value: 1,
    label: 'OYO',
  },
  {
    value: 2,
    label: '客人',
  },
  {
    value: 3,
    label: '其他',
  },
];

function disabledDate(current) {
  return current && (current < moment().startOf('day') || current > moment().add(30, 'day'));
}

function formatArr(list) {
  let obj = {};
  list.forEach(element => {
    if (!obj[element.value]) {
      obj[element.value] = element;
    }
  });
  return obj;
}

const getCIDTypeFromStatus = function(value) {
  let obj = formatArr(CidCallList);
  return obj[value] ? obj[value].label : '未知类型';
};

const getSearchFormConfig = obj => {
  let { orderSourceData, defaultParams = {} } = obj;
  // 默认值
  let initData = {
    beginDate: moment(new Date()),
    occ: 0.6,
    channelId: null,
    area: [],
    cooperationType: 0,
    hotelStatus: null,
    hotelOyoId: null,
    cidStatus: 2,
  };

  // eslint-disable-next-line no-restricted-syntax
  for (let key of Object.keys(initData)) {
    if (defaultParams[key] !== undefined) {
      if (key === 'beginDate') {
        initData[key] = moment(defaultParams[key]);
      } else {
        initData[key] = defaultParams[key];
      }
    }
  }

  return [
    {
      type: 'beginDate',
      label: '入住日期',
      options: {
        initialValue: initData.beginDate,
        rules: [{ required: true }],
      },
      component: (
        <DatePicker
          disabledDate={disabledDate}
          allowClear={false}
          format="YYYY-MM-DD"
          style={{ width: '100%' }}
          placeholder="请选择入住日期"
        />
      ),
    },
    {
      type: 'occ',
      label: 'OCC高于',
      options: { initialValue: initData.occ },
      component: (
        <Select>
          {CCDataList.map(v => (
            <Option value={v.value} key={v.value}>
              {v.label}
            </Option>
          ))}
        </Select>
      ),
    },
    {
      type: 'channelId',
      label: '渠道',
      options: { initialValue: initData.channelId },
      component: (
        <Select>
          <Option value={null} key="CRSChannelList-all">
            全部
          </Option>
          {orderSourceData.map((channel, key) => (
            <Option key={`CRSChannelList-${channel.channelId}`} value={channel.channelId}>
              {channel.channelName}
            </Option>
          ))}
        </Select>
      ),
    },
    {
      type: 'area',
      label: '区域',
      options: { initialValue: initData.area },
      component: <CitySelect style={{ width: '100%' }} type="cityList" changeOnSelect />,
    },
    {
      type: 'cooperationType',
      label: '酒店协议类型',
      options: { initialValue: initData.cooperationType },
      component: (
        <Select placeholder="酒店协议类型">
          {COOPERATION_TYPE.map((v, i) => (
            <Option key={i} value={v.value}>
              {v.label}
            </Option>
          ))}
        </Select>
      ),
    },
    {
      type: 'hotelStatus',
      label: '酒店状态',
      options: { initialValue: initData.hotelStatus },
      component: (
        <Select placeholder="请选择酒店状态">
          <Option value={null} key="hotelstatus-all">
            全部
          </Option>
          {HOTEL_STATUS.map((v, i) => (
            <Option key={i} value={v.status}>
              {v.name}
            </Option>
          ))}
        </Select>
      ),
    },
    {
      type: 'hotelOyoId',
      label: '酒店OYOID',
      options: { initialValue: initData.hotelOyoId },
      component: <Input placeholder="请输入酒店OYOID" />,
    },
    {
      type: 'cidStatus',
      label: '状态',
      options: { initialValue: initData.cidStatus },
      component: (
        <Select placeholder="请选择状态">
          {CidCallList.map((v, i) => (
            <Option key={i} value={v.value}>
              {v.label}
            </Option>
          ))}
        </Select>
      ),
    },
  ];
};

const getTableConfig = that => {
  let { createCidCallRecord, seeCidCallRecord } = that;
  return [
    {
      title: '酒店',
      dataIndex: 'hotelName',
      render: (hotelName, record) => (
        <div>
          <div>
            <span>{record.hotelOyoId}</span>{' '}
            {record.cooperationType === 1 ? <Tag color="#EE2E24">china2.0</Tag> : ''}
          </div>
          <p className={style.textRed}>
            <Link to={`/hotel/hotelCreateEdit/index?hotelId=${record.hotelId}`}>{hotelName}</Link>
          </p>
        </div>
      ),
    },
    {
      title: '区域',
      dataIndex: 'area',
      render: (area, record) => {
        let textArr = [record.stateName, record.cityName, record.clusterName];
        textArr = textArr.filter(v => !!v);
        return <span>{textArr.join('/')} </span>;
      },
    },
    {
      title: 'OCC',
      dataIndex: 'occ',
      render: (occ, record) => <span>{`${((parseFloat(occ) || 0) * 100).toFixed(2)}%`} </span>,
    },
    {
      title: '当日CID量',
      dataIndex: 'currentDayCid',
    },
    {
      title: '酒店座机',
      dataIndex: 'landline',
    },
    {
      title: '订单',
      dataIndex: 'bookingSn',
      render: (bookingSn, record) => (
        <div>
          <div>{record.channelName}</div>
          <div className={style.textRed}>
            <Link to={`/order/detail/order?bookingId=${record.bookingId}`}>{bookingSn}</Link>
          </div>
        </div>
      ),
    },
    {
      title: '预定人',
      dataIndex: 'guestName',
    },
    {
      title: '状态',
      dataIndex: 'cidStatus',
      render: (cidStatus, record) => <span>{getCIDTypeFromStatus(cidStatus)}</span>,
    },
    {
      title: '操作',
      dataIndex: 'operation',
      render: (operation, record) => {
        if (record.cidStatus === 1) {
          return (
            <Button style={{ marginLeft: 10 }} onClick={() => seeCidCallRecord(record.bookingId)}>
              查看
            </Button>
          );
        }
        if (record.cidStatus === 2) {
          return (
            <ButtonAuthorized code="CRS3.9.1" onClick={() => createCidCallRecord(record.bookingId)}>
              记录外呼结果
            </ButtonAuthorized>
          );
        }
      },
    },
  ];
};

export {
  getSearchFormConfig,
  getTableConfig,
  opResultList,
  cidConfrimResultList,
  CIDSourceList,
  VOCSourceList,
  CIDReasonList,
  GuestSituationList,
  CIDProcessResultList,
  PayoutList,
  CIDComplaintList,
  VOCResultList,
  ResponsibleList,
};
