import { connect } from 'dva';
import moment from 'moment';
import React, { PureComponent } from 'react';
import ButtonAuthorized from '@/components/ButtonAuthorized';
import { queryResultsList } from '../../services/highBooking';
import { downloadFile } from '@/utils/downloadFile';
import OYOTable from '@/components/OyoTable/OyoTable.tsx';

@connect(({ associate, user, loading }) => ({
  associate,
  user,
  loading: loading.models.associate,
}))
export default class batchResults extends PureComponent<any, any> {
  public oyotable = null;

  constructor(props) {
    super(props);
    this.state = {
      tableParams: {},
      pageParams: ['page', 'limit'],
      logList: [],
    };
  }

  public componentDidMount() {
    // 默认请求：初始结果列表
    this.oyotable.getPageList();
  }

  componentWillReceiveProps() {
    let { active } = this.props;
    if (!active) {
      this.oyotable.getPageList();
    }
  }

  // 请求：获取结果列表数据
  public getResultsList = params =>
    queryResultsList(params)
      .then(res => {
        if (res && res.data) {
          const { result, totalCount } = res.data;

          return { data: result || [], total: totalCount };
        }
      })
      .catch(err => {
        console.log(err);
      });

  // 操作：下载失败条目
  public downloadErrorFile = (id, fileName) => {
    downloadFile('/api/crs/highBooking/download', { id, status: 2 }, fileName);
  };

  render() {
    const { tableParams, pageParams } = this.state;
    const { getResultsList } = this;
    const { loading } = this.props;

    const OYOTableColumns: object[] = [
      {
        title: '操作时间',
        dataIndex: 'createTime',
        key: 'createTime',
        render(createTime) {
          if (createTime) {
            return moment(createTime).format('YYYY-MM-DD HH:mm:ss');
          }
        },
      },
      {
        title: '操作人',
        dataIndex: 'operateName',
        key: 'operateName',
      },
      {
        title: '行为',
        dataIndex: 'behavior',
        key: 'behavior',
      },
      {
        title: '文件名',
        dataIndex: 'fileName',
        key: 'fileName',
      },
      {
        title: '上传条数',
        dataIndex: 'total',
        key: 'total',
      },
      {
        title: '处理结果',
        dataIndex: 'status',
        key: 'status',
        render: (status, item) => {
          if (status === 0) {
            return <p style={{ color: '#F9A73B' }}>处理中</p>;
          }
          let succStr = item.totalSuccess ? (
            <span style={{ color: ' #2BAB86' }}>{`成功${item.totalSuccess}条`}</span>
          ) : (
            ''
          );
          let failStr = item.totalFailed ? (
            <span style={{ color: ' #F5222D' }}>{`失败${item.totalFailed}条`}</span>
          ) : (
            ''
          );

          return (
            <span>
              {succStr}
              {succStr && failStr ? <span>，</span> : ''}
              {failStr}
            </span>
          );
        },
      },
      {
        title: '下载失败条目',
        dataIndex: 'fileName',
        key: 'downloadFifileNameleName',
        width: 120,
        render: (fileName, record) => {
          if (record.totalFailed) {
            return (
              <ButtonAuthorized
                code="CRS3.10.3"
                size="small"
                style={{ marginLeft: 26 }}
                onClick={() => this.downloadErrorFile(record.id, fileName)}
              >
                下载
              </ButtonAuthorized>
            );
          }
          return <span style={{ marginLeft: 46 }}>--</span>;
        },
      },
    ];

    return (
      <>
        <OYOTable
          ref={re => {
            this.oyotable = re;
          }}
          rowKey="id"
          bordered
          size="small"
          loading={loading}
          params={tableParams}
          pageParams={pageParams}
          columns={OYOTableColumns}
          getList={getResultsList}
          preventGetList
        />
      </>
    );
  }
}
