import moment from 'moment';
import {
  querySuggestHotel,
  queryComplaintList,
  queryJournalList,
  requestComplaint,
} from '../services/complaint';

export default {
  namespace: 'complaint',

  state: {
    complaintListData: {
      defaultParams: {
        page: 1,
        limit: 10,
        scheduleDate: '', // 预定日期
        checkInBeg: moment().format('YYYY-MM-DD'),
        checkInEnd: moment().format('YYYY-MM-DD'),
        bookingSn: '', // 订单号
        scheduleMemberName: '',
        scheduleMemberPhone: '',
        // hotelId: null,
        // hotelName: '',
        appealSubStatus: 'IN_APPEAL', // 房间子状态、申诉状态
      },
      pageNum: 1,
      pageSize: 10,
      totalCount: 10,
      complaintList: [],
    },
    suggestHotelList: [], // 酒店Id模糊搜索的推荐数组
    journalListData: {
      pageNum: 1,
      pageSize: 10,
      totalCount: 10,
      journalList: [], // 日志数组
    },
  },

  effects: {
    *fetchSuggestHotel({ payload }, { call, put }) {
      try {
        const response = yield call(querySuggestHotel, payload);
        let suggestHotelList = [];
        if (response.data.hotels !== undefined) {
          suggestHotelList = response.data.hotels;
        }
        yield put({
          type: 'setSuggestHotelList',
          payload: suggestHotelList,
        });
        return response;
      } catch (e) {
        yield put({
          type: 'setSuggestHotelList',
          payload: [],
        });
        return e.response;
      }
    },
    *fetchComplaintList({ payload }, { call, put }) {
      try {
        const response = yield call(queryComplaintList, payload);
        console.log('queryComplaintList', response);
        yield put({
          type: 'setComplaintList',
          payload: response,
        });
        return response;
      } catch (e) {
        return e.response;
      }
    },
    *fetchJournalList({ payload }, { call, put }) {
      try {
        const response = yield call(queryJournalList, payload);
        console.log('queryJournalList', response);
        yield put({
          type: 'setJournalList',
          payload: response,
        });
        return response;
      } catch (e) {
        yield put({
          type: 'setJournalList',
          payload: [],
        });
        return e.response;
      }
    },
    *fetchComplaint({ payload }, { call, put }) {
      try {
        const response = yield call(requestComplaint, payload);
        console.log('fetchComplaint:', response);
        return response;
      } catch (e) {
        return e.response;
      }
    },
  },

  reducers: {
    // 酒店列表
    setSuggestHotelList(state, { payload }) {
      const suggestHotelList = payload;
      return { ...state, suggestHotelList };
    },
    // 申诉列表
    setComplaintList(state, { payload }) {
      const defaultParams = state.complaintListData.defaultParams;
      const { data } = payload;
      const { pageNum, pageSize, totalCount, result } = data;
      let complaintList = [];
      if (result.length !== 0) {
        complaintList = result.map((item, key) => {
          const ele = item;
          ele.key = key;
          return ele;
        });
      }
      const complaintListData = { pageNum, pageSize, totalCount, complaintList, defaultParams };
      return { ...state, complaintListData };
    },
    // 日志列表
    setJournalList(state, { payload }) {
      const { data } = payload;
      const { pageNum, pageSize, totalCount, result } = data;
      let journalList = [];
      if (result.length !== 0) {
        journalList = result.map((item, key) => {
          const ele = item;
          ele.key = key;
          return ele;
        });
      }
      const journalListData = { pageNum, pageSize, totalCount, journalList };
      return { ...state, journalListData };
    },
  },
};
