import moment from 'moment';
import {
  createBooking,
  verifyNumber,
  listCrsChannel,
  listRateCode,
  getProductList,
  getSalesList,
  fetchQueryChannelList,
} from '../services/createOrder';

// 默认已经选择的房源产品
const DefaultRoom = {
  number: 0, // 房间数量
  price: 0, // 房型单价
  roomType: 0, // 房型ID
  roomTypeDesc: '', // 房型中文
  memberId: 0, // 填int类型 0
};

const DefaultBookingPayment = {
  amount: 0,
  method: 15,
  type: 1,
};

// 总的默认数据
const DefaultData = {
  extBookingSn: '', // 渠道订单号
  amount: 0,
  queryChannelListSwitch: false,
  queryChannelList: [],
  channelList: [],
  isCanRateCode: false,
  rateCodeList: [],
  bookingGuest: {
    member: false,
    name: '',
    phone: '',
    memberCode: '',
    memberId: 0,
  },
  bookingPayment: {
    ...DefaultBookingPayment,
  },
  bookingRoomTypeList: [
    {
      ...DefaultRoom,
    },
  ],
  accountType: undefined,
  paymentType: 1,
  bookingType: 1,
  channelId: null,
  checkin: null, // 入住时间
  checkout: null, // 离店时间
  createBookingType: 0,
  hotelId: null,
  operatorId: 0,
  rateCode: null,
  remark: '',
  retentionTime: null, // 保留时间
  productList: [],
  salesList: [],
  salesId: '',
};

export default {
  namespace: 'createOrder',

  state: {
    ...DefaultData,
  },

  effects: {
    *fetchQueryChannelList({ payload }, { call, put }) {
      try {
        const response = yield call(fetchQueryChannelList);

        yield put({
          type: 'saveKey',
          payload: {
            queryChannelList: response.data || [],
            queryChannelListSwitch: true,
          },
        });
      } catch (e) {
        console.log(e);
      }
    },
    // 获取房价类型(房价策略)
    *fetchRateCode({ payload }, { call, put, select }) {
      try {
        const createOrder = yield select(state => state.createOrder);
        const response = yield call(listRateCode, payload);
        const data = response.data;
        const payload2 = {
          rateCodeList: data,
        };
        let info = ''; // 最后返回的文案,用于message提示
        let statue; // 返回的状态 1 2 3 用于不同逻辑操作

        payload2.isCanRateCode = data.length !== 0; // 变化策略后是否需要重新请求房源类型

        // 请求下来的有匹配到的策略数据
        if (data.length) {
          const oldCodeId = createOrder.rateCode; // 缓存之前的策略id
          const historyId = data.find(item => item.rateCodeId === oldCodeId); // 查询新的可选策略列表中 有没有之前选择的策略
          const newId = historyId ? oldCodeId : data[0].rateCodeId; // 新的房价策略列表里存在之前选用的策略就用老的 没有则用列表默认第一条

          payload2.rateCode = newId; // 对选择的策略赋值

          // 当之前选择的策略与当前默认选择的策略不同时 提示用户房价类型被自动切换了
          if (oldCodeId !== newId) info = '房价类型已切换';

          statue = 1; // 最后返回的状态码 1 表示
        } else {
          payload2.rateCode = null;
          payload2.productList = [];
          payload2.amount = 0;
          payload2.bookingRoomTypeList = [{ ...DefaultRoom }];
          info = '无匹配的策略';
          statue = 2;
        }

        yield put({
          type: 'saveKey',
          payload: payload2,
        });

        return Promise.resolve({
          statue,
          info,
          ...payload2,
        });
      } catch (e) {
        return Promise.resolve({
          statue: 3,
        });
      }
    },

    // 获取订单来源
    *fetchChannelList({ payload }, { call, put }) {
      try {
        const response = yield call(listCrsChannel, payload);
        const data = response.data;

        yield put({
          type: 'saveKey',
          payload: {
            channelId: data[0].channelId,
            channelList: data,
          },
        });

        return Promise.resolve({
          statue: true,
        });
      } catch (e) {
        return Promise.resolve({
          statue: false,
        });
      }
    },

    // 获取商品信息
    *fetchProductList({ payload }, { call, put }) {
      try {
        const response = yield call(getProductList, payload);
        let productList = response.data;

        if (productList.length) {
          productList = productList.map(item => ({
            ...item,
            number: 0,
          }));
        }

        yield put({
          type: 'saveKey',
          payload: {
            productList,
            amount: 0,
            bookingRoomTypeList: [
              {
                ...DefaultRoom,
              },
            ],
            bookingPayment: {
              ...DefaultBookingPayment,
            },
          },
        });

        return Promise.resolve({
          statue: true,
        });
      } catch (e) {
        yield put({
          type: 'saveKey',
          payload: {
            productList: [],
            amount: 0,
            bookingRoomTypeList: [
              {
                ...DefaultRoom,
              },
            ],
            bookingPayment: {
              ...DefaultBookingPayment,
            },
          },
        });

        return Promise.resolve({
          statue: true,
        });
      }
    },

    *createBooking({ payload }, { call, put }) {
      try {
        const response = yield call(createBooking, payload);
        yield put({
          type: 'reset',
        });

        return Promise.resolve({
          statue: true,
          ...response,
        });
      } catch (err) {
        return Promise.resolve({
          statue: false,
          ...err.response,
        });
      }
    },

    *verifyNumber({ payload }, { call, put }) {
      try {
        const response = yield call(verifyNumber, payload.phone);

        if (response.code === '000' && response.data && response.data.status === 2) {
          const data = response.data;

          yield put({
            type: 'saveBookingGuest',
            payload: {
              name: data.memberName,
              memberCode: data.memberCode,
              member: true,
            },
          });

          return Promise.resolve();
        }
        yield put({
          type: 'saveBookingGuest',
          payload: {
            memberCode: '',
            member: false,
          },
        });
        return Promise.resolve();
      } catch (e) {
        return Promise.resolve();
      }
    },
    // 获取销售员信息
    *fetchSalesList({ payload }, { call, put }) {
      try {
        const response = yield call(getSalesList, payload);
        let salesList = response.data;

        if (salesList.length) {
          productList = salesList.map(item => ({
            ...item,
            number: 0,
          }));
        }

        return Promise.resolve({
          statue: true,
        });
      } catch (e) {
        return Promise.resolve({
          statue: true,
        });
      }
    },
  },

  reducers: {
    // 重置数据
    reset(state, action) {
      return {
        ...JSON.parse(JSON.stringify(DefaultData)),
      };
    },

    // 重置Ratecode
    resetRateCode(state, action) {
      return {
        ...state,
        rateCode: null,
        productList: [],
      };
    },

    // 重置已经选择的room
    resetRoom(state, action) {
      return {
        ...state,
        amount: 0,
        bookingRoomTypeList: [
          {
            ...DefaultRoom,
          },
        ],
        bookingPayment: {
          ...DefaultBookingPayment,
        },
      };
    },

    // 修改数据
    saveKey(state, action) {
      return {
        ...state,
        ...action.payload,
      };
    },

    // 暂存会员数据
    saveBookingGuest(state, action) {
      return {
        ...state,
        bookingGuest: {
          ...state.bookingGuest,
          ...action.payload,
        },
      };
    },
  },
};
