import React from 'react';
import { Select } from 'antd';
import {
  queryLogList,
  requestCreateAppeal,
  requestCheckOrder,
  queryProcessingList,
  queryOrderSnList,
  queryOrderDetail,
  queryRefundDetail,
  requestSingleAppeal,
  requestAppeal,
  queryAllAppealReason,
  queryAppealDetail,
  roomPriceDetail,
  appealAudit,
  rejectAppeal,
} from '../services/daily';

const { Option } = Select;

export default {
  namespace: 'daily',

  state: {
    logList: [],
    ALL_REASON_OPTION: [],
    refundDetail: {},
  },

  effects: {
    *fetchLogList({ payload }, { call, put }) {
      try {
        const response = yield call(queryLogList, payload);
        yield put({
          type: 'setLogList',
          payload: response,
        });
        return response;
      } catch (e) {
        return e.response;
      }
    },
    *fetchCreateAppeal({ payload }, { call, put }) {
      try {
        const response = yield call(requestCreateAppeal, payload);
        return response;
      } catch (e) {
        return e.response;
      }
    },
    *fetchCheckOrder({ payload }, { call, put }) {
      try {
        const response = yield call(requestCheckOrder, payload);
        return response;
      } catch (e) {
        return e.response;
      }
    },
    *fetchProcessingList({ payload }, { call, put }) {
      try {
        const response = yield call(queryProcessingList, payload);
        return response;
      } catch (e) {
        return e.response;
      }
    },
    *fetchOrderSnList({ payload }, { call, put }) {
      try {
        const response = yield call(queryOrderSnList, payload);
        return response;
      } catch (e) {
        return e.response;
      }
    },
    *fetchOrderDetail({ payload }, { call, put }) {
      try {
        const response = yield call(queryOrderDetail, payload);
        return response;
      } catch (e) {
        return e.response;
      }
    },
    *fetchRefundDetail({ payload }, { call, put }) {
      try {
        const response = yield call(queryRefundDetail, payload);
        yield put({
          type: 'setRefundDetail',
          payload: response,
        });
        return response;
      } catch (e) {
        return e.response;
      }
    },
    *fetchSingleAppeal({ payload }, { call, put }) {
      try {
        const response = yield call(requestSingleAppeal, payload);
        return response;
      } catch (e) {
        return e.response;
      }
    },
    *fetchAppeal({ payload }, { call, put }) {
      try {
        const response = yield call(requestAppeal, payload);
        return response;
      } catch (e) {
        return e.response;
      }
    },
    *fetchAllAppealReason({ payload }, { call, put }) {
      try {
        const response = yield call(queryAllAppealReason, payload);
        yield put({
          type: 'setAllReasonList',
          payload: response,
        });
        return response;
      } catch (e) {
        return e.response;
      }
    },
    *fetchQueryAppealDetail({ payload }, { call, put }) {
      try {
        const response = yield call(queryAppealDetail, payload);
        return response;
      } catch (e) {
        return e.response;
      }
    },
    *fetchRoomPriceDetail({ payload }, { call, put }) {
      try {
        const response = yield call(roomPriceDetail, payload);
        return response;
      } catch (e) {
        return e.response;
      }
    },
    *fetchAppealAudit({ payload }, { call, put }) {
      try {
        const response = yield call(appealAudit, payload);
        return response;
      } catch (e) {
        return e.response;
      }
    },
    *fetchRejectAppeal({ payload }, { call, put }) {
      try {
        const response = yield call(rejectAppeal, payload);
        return response;
      } catch (e) {
        return e.response;
      }
    },
  },

  reducers: {
    setLogList(state, { payload }) {
      let logList = payload.data || [];

      // 处理房单价调价记录文本格式
      if (logList.length !== 0) {
        logList = logList.map(v => {
          if (
            v.appealDetail &&
            v.appealDetail.length > 3 &&
            v.appealDetail[3] &&
            v.appealDetail[3].includes('现有价格')
          ) {
            let dayPriceLog = v.appealDetail[3];
            dayPriceLog = dayPriceLog.replace(/现有价格/g, '/r/n现有价格');
            dayPriceLog = dayPriceLog.split('/r/n');
            dayPriceLog = dayPriceLog.map((item, i) => {
              if (i !== 0) {
                return `[${item}]`;
              }
              return item;
            });
            v.appealDetail = [
              v.appealDetail[0],
              v.appealDetail[1],
              v.appealDetail[2],
              ...dayPriceLog,
              v.appealDetail[4],
            ];
            return v;
          }
          return v;
        });
      }

      return { ...state, logList };
    },
    setAllReasonList(state, { payload }) {
      const allReasonList = payload.data || [];
      const ALL_REASON_OPTION = allReasonList.map((item, key) => (
        <Option value={item.appealReasonCode} key={`HANDLE_TYPE-${key}`}>
          {item.appealReasonName}
        </Option>
      ));
      return { ...state, ALL_REASON_OPTION };
    },
    setRefundDetail(state, { payload }) {
      const refundDetail = payload.data || {};
      return { ...state, refundDetail };
    },
  },
};
