import _ from 'lodash';
import moment from 'moment';
import {
  queryOrderList,
  queryOrderDetail,
  updateOrderDetail,
  queryHotelPriceTypeList,
  queryRoomReservationList,
  queryJournalList,
  cancelOrder,
  deleteOrder,
  queryCRSChannelList,
  queryGuestType,
  queryProduct,
  querySuggestHotel,
  queryhotelBaseInfo,
  queryRangePrice,
  queryCancelReason,
  reasonCancelOrder,
  queryRoomDataList,
  generateOfflinePassword,
} from '../services/order';
import { getDiscountTypeFromStatus } from '@/constant/discountType';
import { getEncryptionStr } from '@/utils/utils';

export default {
  namespace: 'order',

  state: {
    bookingId: '',
    orderListData: {
      defaultParams: {},
      pageNum: 1,
      pageSize: 10,
      totalCount: 0,
      orderList: [],
    },
    houseDataList: [], // byhuang 维护新的房单列表
    suggestHotelList: [], // 酒店Id模糊搜索的推荐数组
    orderDetailData: {},
    orderDetailDefaultData: {},
    roomReservationData: [],
    roomTypeList: [], // 固定价格策略等条件下的房型和对应价格
    CRSChannelList: [], // 订单来源，渠道列表
    baseCheckoutTime: '', // 基础酒店信息的离店时间
    rangePrice: {}, // 范围价格
  },

  effects: {
    *fetchSuggestHotel({ payload }, { call, put }) {
      try {
        const response = yield call(querySuggestHotel, payload);
        let suggestHotelList = [];
        if (response.data.hotels !== undefined) {
          suggestHotelList = response.data.hotels;
        }
        yield put({
          type: 'setSuggestHotelList',
          payload: suggestHotelList,
        });
        return response;
      } catch (e) {
        yield put({
          type: 'setSuggestHotelList',
          payload: [],
        });
        return e.response;
      }
    },
    *fetchOrderList({ payload }, { call, put }) {
      try {
        const response = yield call(queryOrderList, payload);

        yield put({
          type: 'setOrderList',
          payload: response,
        });
        return response;
      } catch (e) {
        return e.response;
      }
    },
    *fetchGuestType({ payload }, { call, put }) {
      try {
        const response = yield call(queryGuestType, payload);
        yield put({ type: 'setGuestType', payload: response });
        return response;
      } catch (e) {
        return e.response;
      }
    },
    *fetchCRSChannelList(action, { call, put }) {
      try {
        const response = yield call(queryCRSChannelList);
        yield put({
          type: 'setCRSChannelList',
          payload: response,
        });
        return response;
      } catch (e) {
        return e.response;
      }
    },
    *fetchOrderDetail({ payload }, { call, put }) {
      try {
        const response = yield call(queryOrderDetail, payload);

        if (response.data === null || JSON.stringify(response.data) === '{}') {
          yield put({
            type: 'setOrderDetail',
            payload: response,
          });
        } else {
          // 酒店id
          const hotelId = response.data.hotelId;
          // 入住时间（ yyyy-MM-dd）
          const checkInDate = moment(response.data.arrivalTime).format('YYYY-MM-DD');
          // 离店时间（ yyyy-MM-dd）
          const checkOutDate = moment(response.data.departureTime).format('YYYY-MM-DD');
          // 渠道id
          const channelId = response.data.source;
          // 价格策略id
          const rateCodeId = response.data.bookingRoomList[0].rateCode;
          // 入住类型
          const checkinType = response.data.type;

          response.data.accountType = response.data.accountType || '';
          yield put({
            type: 'setOrderDetail',
            payload: response,
          });

          // yield put({
          //   type: 'updateRoomFee',
          //   payload: {},
          // });
          // 解释：不再调用
          // yield put({
          //   type: 'fetchProduct',
          //   payload: {
          //     hotelId,
          //     checkInDate,
          //     checkOutDate,
          //     channelId,
          //     rateCodeId,
          //     checkinType: typeof checkinType === 'undefined' ? 1 : checkinType,
          //   },
          // });
        }
        return response;
      } catch (e) {
        return e.response;
      }
    },

    *fetchProduct({ payload }, { call, put }) {
      try {
        const rateCodeId = payload.rateCodeId;
        const response = yield call(queryProduct, payload);

        if (Array.isArray(response.data) && response.data.length !== 0) {
          const rateCodeName = response.data[0].rateCodeName;

          yield put({
            type: 'setRoomTypeList',
            payload: response,
          });
          yield put({ type: 'setRateCodeName', payload: { rateCodeId, rateCodeName } });
        }
        return response;
      } catch (e) {
        return e.response;
      }
    },

    *fetchHotelPriceTypeList({ payload }, { call, put }) {
      try {
        const response = yield call(queryHotelPriceTypeList, payload);
        yield put({
          type: 'setHotelPriceTypeList',
          payload: response,
        });
        return response;
      } catch (e) {
        return e.response;
      }
    },
    *fetchRoomReservationList({ payload }, { call, put }) {
      try {
        const response = yield call(queryRoomReservationList, payload);

        yield put({
          type: 'setRoomReservationList',
          payload: response,
        });
        return response;
      } catch (e) {
        return e.response;
      }
    },
    // 新增获取房单列表
    *fetchRoomDataList({ payload }, { call, put }) {
      try {
        const response = yield call(queryRoomDataList, payload);
        yield put({
          type: 'setRoomDataList',
          payload: response,
        });
        return response;
      } catch (e) {
        return e.response;
      }
    },
    *fetchJournalList({ payload }, { call, put }) {
      try {
        const response = yield call(queryJournalList, payload);

        return response;
      } catch (error) {
        return Promise.reject(error.response);
      }
    },
    *updateOrderDetail({ payload }, { call, put }) {
      try {
        const bookingId = payload.id;
        const response = yield call(updateOrderDetail, payload);
        if (response && response.code === '000') {
          yield put({
            type: 'fetchOrderDetail',
            payload: { bookingId, source: 1 },
          });
        }
        return response;
      } catch (e) {
        return e.response;
      }
    },
    *cancel({ payload }, { call, put }) {
      try {
        const response = yield call(cancelOrder, payload);
        if (response && response.code === 200) {
          yield put({
            type: 'fetchOrderDetail',
            payload,
          });
        }
        return response;
      } catch (e) {
        return e.response;
      }
    },
    *delete({ payload }, { call, put }) {
      try {
        const response = yield call(deleteOrder, payload);
        return Promise.resolve(response);
      } catch (e) {
        return Promise.reject(e);
      }
    },
    *fetchHotelBaseInfo({ payload }, { call, put }) {
      try {
        const response = yield call(queryhotelBaseInfo, payload);

        yield put({
          type: 'setHotelDepartureTime',
          payload: response,
        });
        return response;
      } catch (e) {
        return e.response;
      }
    },
    *generateOfflinePassword({ payload }, { call, put }) {
      try {
        const response = yield call(generateOfflinePassword, payload);

        if (response && response.code === '000') {
          yield put({
            type: 'fetchRoomReservationList',
            payload: {
              bookingId: payload.bookingId,
            },
          });
        }

        return response.data;
      } catch (e) {
        return false;
      }
    },
    *fetchRangePrice({ payload }, { call, put }) {
      try {
        const response = yield call(queryRangePrice, payload);

        yield put({
          type: 'setRangePrice',
          payload: response,
        });
        return response;
      } catch (e) {
        return e.response;
      }
    },
    *fetchCancelReason({ payload }, { call, put }) {
      try {
        const response = yield call(queryCancelReason);
        yield put({
          type: 'queryCancelReason',
          payload: response,
        });
        return Promise.resolve(response);
      } catch (e) {
        return Promise.reject(e);
      }
    },
  },

  reducers: {
    setSuggestHotelList(state, { payload }) {
      const suggestHotelList = payload;
      return { ...state, suggestHotelList };
    },
    updateBookingId(state, { payload }) {
      const { bookingId } = payload;
      return { ...state, bookingId };
    },
    setGuestType(state, { payload }) {
      const { orderDetailData } = state;
      if (_.isObject(payload.data)) {
        orderDetailData.bookingGuest.guestType = payload.data.status;
        orderDetailData.bookingGuest.name = payload.data.memberName;
        orderDetailData.bookingGuest.memberCode = payload.data.memberCode;
      }
      return { ...state, orderDetailData };
    },
    updateRoomTypeId(state, { payload }) {
      // console.log('updateRoomTypeId:', payload);

      const { orderDetailData, roomTypeList } = state;
      const bookingRoomList = orderDetailData.bookingRoomList;
      const { roomType, roomTypeListIndex } = payload;
      const room = roomTypeList.find(item => item.id === roomType);
      bookingRoomList[roomTypeListIndex].roomType = roomType;
      bookingRoomList[roomTypeListIndex].roomTypeDesc = room.name;
      bookingRoomList[roomTypeListIndex].price = +room.rate; // 价格
      bookingRoomList[roomTypeListIndex].listRate = room.listRate; // 门市价格
      bookingRoomList[roomTypeListIndex].inventory = room.inventory; // 门市价格

      // console.log('updateRoomTypeId:', bookingRoomList[roomTypeListIndex]);

      return {
        ...state,
      };
    },
    updateRoomTypePrice(state, { payload }) {
      const { orderDetailData } = state;

      const { price, roomTypeListIndex } = payload;
      orderDetailData.bookingRoomList[roomTypeListIndex].price = price; // 价格

      // console.log(orderDetailData.bookingRoomList[roomTypeListIndex]);

      return {
        ...state,
      };
    },
    updateRoomNumber(state, { payload }) {
      const { orderDetailData } = state;

      const { number, roomTypeListIndex } = payload;
      orderDetailData.bookingRoomList[roomTypeListIndex].number = number;

      return {
        ...state,
      };
    },
    // updateAmount(state, { payload }) {
    //   const { orderDetailData, bookingRoomList } = state;
    //   bookingRoomList.map((room, key) => room.price * room.number);
    //   return { ...state };
    // },
    setRoomTypeList(state, { payload }) {
      const productList = Array.isArray(payload.data) ? payload.data : [];
      const roomTypeList = productList.map(product => {
        const { inventory, listRate, rate, roomType } = product;
        const { id, name } = roomType;
        const room = { inventory, listRate, rate, id, name };

        return room;
      });
      return { ...state, roomTypeList };
    },
    // 设置价格策略中文
    setRateCodeName(state, { payload }) {
      const { orderDetailData } = state;
      const { rateCodeId, rateCodeName } = payload;

      orderDetailData.bookingRoomList.forEach(room => {
        let roomParam = room;
        roomParam.rateCodeName = roomParam.rateCode === rateCodeId ? rateCodeName : '';
      });
      return { ...state, orderDetailData };
    },
    // 设置CRS渠道列表
    setCRSChannelList(state, { payload }) {
      const CRSChannelList =
        Array.isArray(payload.data) && payload.data.length !== 0 ? payload.data : [];
      return { ...state, CRSChannelList };
    },
    // 设置订单列表
    setOrderList(state, { payload }) {
      const defaultParams = state.orderListData.defaultParams;
      const { data } = payload;
      const { pageNum, pageSize, totalCount, result } = data;
      let orderList = [];
      if (result.length !== 0) {
        orderList = result.map((item, key) => {
          const ele = item;
          ele.key = key;
          ele.No = key + 1;
          return ele;
        });
      }
      const orderListData = { pageNum, pageSize, totalCount, orderList, defaultParams };
      return { ...state, orderListData };
    },
    setOrderDetail(state, { payload }) {
      const { data } = payload;
      // 根据memberCode是否为空设置一个guestType，空：非会员（2）
      if (data.bookingGuest) {
        data.bookingGuest.guestType =
          data.bookingGuest !== undefined && data.bookingGuest.memberCode !== '' ? 2 : 1;
      }
      data.bookingDiscount = data.bookingDiscount || []; // bookingDiscount：优惠信息不存在为null

      data.bookingDiscount.forEach(item => {
        item.info = item.couponType === 3 ? '首间夜使用' : '均分到间夜';
        item.discountName = getDiscountTypeFromStatus(item.discountType);
      });

      // discountType {String} 优惠类型: 会员优惠: MEMBER, 优惠券优惠: COUPON, 酒店优惠: HOTEL, OYO优惠: OYO
      data.discountInfo = _.keyBy(data.bookingDiscount, 'discountType');
      console.log(data.discountInfo);
      let roomReservationRoomData = {};
      data.roomReservationRoomList = [];
      data.orderDetailList = data.orderDetailList || [];

      data.orderDetailList.forEach(item => {
        if (Array.isArray(item.roomReservationRoomPriceVOList)) {
          item.roomReservationRoomPriceVOList.forEach(room => {
            let day = (room.date || '').split(' ');

            room.date = day ? day[0] : '未知';

            if (/^\d{4}-\d{2}-\d{2}$/.test(room.date)) {
              if (!roomReservationRoomData[room.date]) roomReservationRoomData[room.date] = [];

              roomReservationRoomData[room.date].push(room);
            }
          });
        }
      });

      Object.entries(roomReservationRoomData).forEach(([key, val]) => {
        let roomData = {
          time: key,
          timeNum: Number(key.replace(/-/g, '')),
          child: [],
        };

        val.forEach(room => {
          let esistData = roomData.child.find(r => r.price === room.price);

          if (esistData) {
            esistData.count++;
          } else {
            roomData.child.push({
              price: room.price,
              count: 1,
            });
          }
        });

        data.roomReservationRoomList.push(roomData);
      });

      data.roomReservationRoomList = data.roomReservationRoomList.sort(
        (a, b) => a.timeNum - b.timeNum
      );

      const orderDetailData = data;
      const orderDetailDefaultData = { ...data };
      return {
        ...state,
        orderDetailData,
        orderDetailDefaultData,
      };
    },
    setHotelPriceTypeList(state, { payload }) {
      const { data } = payload;
      const { orderDetailData } = state;

      orderDetailData.hotelRoomAndPriceTypeList =
        data &&
        data.map(item => {
          const roomInfo = {};
          roomInfo.label = item.roomTypeName;
          roomInfo.value = item.roomTypeId;
          roomInfo.children =
            item.rateCodeList &&
            item.rateCodeList.map(price => {
              const priceInfo = {};
              priceInfo.label = price.rateCodeName;
              priceInfo.value = price.rateCodeId;
              return priceInfo;
            });
          return roomInfo;
        });

      return {
        ...state,
        orderDetailData,
      };
    },
    // 设置房单列表
    setRoomDataList(state, { payload }) {
      let { result } = payload.data;

      result = result || [];

      result.forEach(item => {
        item.showRemark = (item.remark || '') + (item.sysRemark || '');
      });

      return { ...state, houseDataList: result };
    },
    setRoomReservationList(state, { payload }) {
      const { data } = payload;

      let roomReservationData = [];
      // 无房单和账单信息返回空数组
      const roomReservationResp = data === null || data === undefined ? [] : data;

      if (Array.isArray(roomReservationResp) && roomReservationResp.length === 0) {
        roomReservationData = roomReservationResp;
        return { ...state, roomReservationData };
      }
      roomReservationData = roomReservationResp.map(room => {
        const roomParam = room;

        const guestList = roomParam.guestList || [];
        roomParam.guestList = guestList.map(guest => ({
          ...guest,
          cardNo: getEncryptionStr(guest.cardNo),
          offLineInfo: guest.haveOfflinePassword
            ? `密码已生成,有效期${guest.offlinePasswordStartTime}-${guest.offlinePasswordEndTime}`
            : '',
        }));
        if (
          !Array.isArray(roomParam.postingList) ||
          (Array.isArray(roomParam.postingList) && roomParam.postingList.length === 0)
        ) {
          roomParam.postingList = [];
          return roomParam;
        }
        roomParam.postingList.forEach(postingItem => {
          const item = postingItem;
          item.key = item.id;
          // 0:代表应收、消费;1:代表实收、结算
          if (item.type === 1) {
            item.settlementFee = item.amount; // 结算
            item.consumptionFee = '-'; // 消费
          } else {
            item.settlementFee = '-';
            item.consumptionFee = item.amount;
          }
        });

        return roomParam;
      });

      return { ...state, roomReservationData };
    },
    cancelOrder(state, { payload }) {
      const { data } = payload;
      const orderDetailData = data;
      return {
        ...state,
        orderDetailData,
      };
    },
    deleteOrder(state, { payload }) {
      const { data } = payload;
      const orderDetailData = data;
      return {
        ...state,
        orderDetailData,
      };
    },
    setHotelDepartureTime(state, { payload }) {
      const {
        data: { checkoutTime },
      } = payload;
      return {
        ...state,
        baseCheckoutTime: checkoutTime,
      };
    },
    setRangePrice(state, { payload }) {
      const { data } = payload;
      const rangePrice = data;

      return {
        ...state,
        rangePrice,
      };
    },
    queryCancelReason(state, { payload }) {
      const { data } = payload;
      const cancelReasonList = data;
      return {
        ...state,
        cancelReasonList,
      };
    },
    // 设置数据
    setCustomerComment(state, { payload }) {
      const orderListData = { ...state.orderListData, defaultParams: payload };
      return {
        ...state,
        orderListData,
      };
    },
    // 清空订单列表table数据
    resetOrderList(state, { payload }) {
      const { pageNum, pageSize, totalCount, orderList } = payload;
      const orderListData = { ...state, pageNum, pageSize, totalCount, orderList };
      return {
        ...state,
        orderListData,
      };
    },
  },
};
