import moment from 'moment';
import {
  verifyNumber,
  listCrsChannel,
  listRateCode,
  listHotelRoomType,
  requestCreateBooking,
  requestSupplementOrder,
  fetchQueryChannelList,
  // getProductList,
  // getSalesList,
} from '../services/supplementOrder';

// 默认已经选择的房源产品
const DefaultRoom = {
  number: 0, // 房间数量
  price: 0, // 房型单价
  roomType: 0, // 房型ID
  roomTypeDesc: '', // 房型中文
  memberId: 0, // 填int类型 0
};

const DefaultBookingPayment = {
  amount: 0,
  method: 0,
  type: 1,
};

// 总的默认数据
const DefaultData = {
  bookingGuest: {
    memberId: '',
    name: '',
    phone: '',
  },
  bookingRoomTypes: [
    {
      count: 0,
      roomTypeId: 0,
      rateCode: null,
    },
  ],
  roomReservationGuests: [
    {
      roomId: 2,
      roomNo: '20',
      name: 'dengchao',
      cardType: 1,
      cardNo: 1111,
      phone: 1122,
    },
    {
      roomId: 3,
      roomNo: '20',
      name: 'dengchao2',
      cardType: 1,
      cardNo: 1111,
      phone: 1122,
    },
  ],
  hotelId: null,
  channelId: null,
  extBookingSn: '',
  checkin: null,
  checkout: null,
  reserve: null,
  payType: 1,
  salesmanId: '',
  status: 1,
  createTime: null,
  amount: 0,
  remark: '',
};

export default {
  namespace: 'supplementOrder',

  state: {
    queryChannelList: [],
    queryChannelListSwitch: false,
    rateCodeList: [],
    channelList: [],
    productList: [],
    roomTypeList: [],
    bookingRoomList: [],
    ...DefaultData,
  },

  effects: {
    *fetchQueryChannelList({ payload }, { call, put, select }) {
      try {
        const response = yield call(fetchQueryChannelList);

        yield put({
          type: 'saveKey',
          payload: {
            queryChannelList: response.data || [],
            queryChannelListSwitch: true,
          },
        });
      } catch (e) {
        console.log(e);
      }
    },
    // 获取房价类型(房价策略)
    *fetchRateCode({ payload }, { call, put, select }) {
      try {
        const supplementOrder = yield select(state => state.supplementOrder);
        const response = yield call(listRateCode, payload);
        const data = response.data;
        const payload2 = {
          rateCodeList: data,
        };
        let info = ''; // 最后返回的文案,用于message提示
        let statue; // 返回的状态 1 2 3 用于不同逻辑操作

        payload2.isCanRateCode = data.length !== 0; // 变化策略后是否需要重新请求房源类型

        // 请求下来的有匹配到的策略数据
        if (data.length) {
          const oldCodeId = supplementOrder.rateCode; // 缓存之前的策略id
          const historyId = data.find(item => item.rateCodeId === oldCodeId); // 查询新的可选策略列表中 有没有之前选择的策略
          const newId = historyId ? oldCodeId : data[0].rateCodeId; // 新的房价策略列表里存在之前选用的策略就用老的 没有则用列表默认第一条

          payload2.rateCode = newId; // 对选择的策略赋值

          // 当之前选择的策略与当前默认选择的策略不同时 提示用户房价类型被自动切换了
          if (oldCodeId !== newId) info = '房价类型已切换';

          statue = 1; // 最后返回的状态码 1 表示
        } else {
          payload2.rateCode = null;
          payload2.productList = [];
          payload2.roomTypeList = [];
          payload2.rateCodeList = [];
          payload2.amount = 0;
          payload2.bookingRoomTypeList = [{ ...DefaultRoom }];
          info = '无匹配的策略';
          statue = 2;
        }

        yield put({
          type: 'saveKey',
          payload: payload2,
        });

        return Promise.resolve({
          statue,
          info,
          ...payload2,
        });
      } catch (e) {
        return Promise.resolve({
          statue: 3,
        });
      }
    },

    // 获取订单来源
    *fetchChannelList({ payload }, { call, put }) {
      try {
        const response = yield call(listCrsChannel, payload);
        const data = response.data;
        yield put({
          type: 'saveKey',
          payload: {
            channelId: data[0].channelId,
            channelList: data,
          },
        });

        return Promise.resolve({
          statue: true,
        });
      } catch (e) {
        return Promise.resolve({
          statue: false,
        });
      }
    },

    // 获取房型列表
    *fetchRoomTypeList({ payload }, { call, put }) {
      try {
        const response = yield call(listHotelRoomType, payload.hotel_id);
        const data = response.data;

        let roomTypeList = response.data;

        if (roomTypeList.length) {
          roomTypeList = roomTypeList.map(item => ({
            ...item,
            number: 0,
          }));
        }

        yield put({
          type: 'saveKey',
          payload: {
            roomTypeList,
            // amount: 0,
            // bookingRoomTypeList: [
            //   {
            //     ...DefaultRoom,
            //   },
            // ],
            // bookingPayment: {
            //   ...DefaultBookingPayment,
            // },
          },
        });
        yield put({
          type: 'saveKey',
          payload: {
            roomTypeList: data,
          },
        });

        return Promise.resolve({
          statue: true,
        });
      } catch (e) {
        yield put({
          type: 'saveKey',
          payload: {
            roomTypeList: [],
            // amount: 0,
            // bookingRoomTypeList: [
            //   {
            //     ...DefaultRoom,
            //   },
            // ],
            // bookingPayment: {
            //   ...DefaultBookingPayment,
            // },
          },
        });

        return Promise.resolve({
          statue: false,
        });
      }
    },

    // // 获取商品信息
    // *fetchProductList({ payload }, { call, put }) {
    //   try {
    //     // const response = yield call(getProductList, payload);
    //     const response = {
    //       code: '000',
    //       msg: '成功',
    //       data: [
    //         {
    //           hotelId: 17782,
    //           channelId: 1,
    //           rateCodeId: 5,
    //           roomType: {
    //             id: 29,
    //             name: '标准双床房',
    //             code: 'SD',
    //             englishName: '',
    //             size: '',
    //             personAllowed: 0,
    //             extraBedAllowed: 0,
    //             bedType: 0,
    //             bedTypeDesc: '',
    //             bedWideth: '',
    //             windowType: 1,
    //             windowTypeDesc: '',
    //           },
    //           listRate: '537',
    //           rate: '537',
    //           rateCodeName: '门市价',
    //           inventory: 3,
    //           cancelType: 1,
    //         },
    //         {
    //           hotelId: 17782,
    //           channelId: 1,
    //           rateCodeId: 5,
    //           roomType: {
    //             id: 34,
    //             name: '主题房',
    //             code: 'THR',
    //             englishName: '',
    //             size: '',
    //             personAllowed: 0,
    //             extraBedAllowed: 0,
    //             bedType: 0,
    //             bedTypeDesc: '',
    //             bedWideth: '',
    //             windowType: 1,
    //             windowTypeDesc: '',
    //           },
    //           listRate: '1220',
    //           rate: '1220',
    //           rateCodeName: '门市价',
    //           inventory: 528,
    //           cancelType: 1,
    //         },
    //       ],
    //     };

    //     let productList = response.data;

    //     console.log(productList);
    //     if (productList.length) {
    //       productList = productList.map(item => ({
    //         ...item,
    //         number: 0,
    //       }));
    //     }

    //     yield put({
    //       type: 'saveKey',
    //       payload: {
    //         productList,
    //         amount: 0,
    //         bookingRoomTypeList: [
    //           {
    //             ...DefaultRoom,
    //           },
    //         ],
    //         bookingPayment: {
    //           ...DefaultBookingPayment,
    //         },
    //       },
    //     });

    //     return Promise.resolve({
    //       statue: true,
    //     });
    //   } catch (e) {
    //     yield put({
    //       type: 'saveKey',
    //       payload: {
    //         productList: [],
    //         amount: 0,
    //         bookingRoomTypeList: [
    //           {
    //             ...DefaultRoom,
    //           },
    //         ],
    //         bookingPayment: {
    //           ...DefaultBookingPayment,
    //         },
    //       },
    //     });

    //     return Promise.resolve({
    //       statue: true,
    //     });
    //   }
    // },

    // 获取房单信息-保存生成房单
    *requestCreateBooking({ payload }, { call, put }) {
      try {
        console.log('requestCreateBooking:', payload);

        const response = yield call(requestCreateBooking, payload);

        yield put({
          type: 'saveSupplement',
          payload: response.data,
        });
        return response;
      } catch (err) {
        console.log(err);

        return err;
        // return Promise.resolve({
        //   statue: false,
        //   ...err.response,
        // });
      }
    },

    // 发起补录订单
    *requestSupplementOrder({ payload }, { call, put }) {
      try {
        let response = yield call(requestSupplementOrder, payload);

        console.log('response');

        return response;
      } catch (e) {
        return e.response;
      }
    },

    *verifyNumber({ payload }, { call, put }) {
      try {
        const response = yield call(verifyNumber, payload.phone);

        if (response.code === '000' && response.data && response.data.status === 2) {
          const data = response.data;

          yield put({
            type: 'saveBookingGuest',
            payload: {
              name: data.memberName,
              memberCode: data.memberCode,
              member: true,
            },
          });

          return response;
        }
        yield put({
          type: 'saveBookingGuest',
          payload: {
            name: '',
            memberCode: '',
            member: false,
          },
        });
        return response;
      } catch (e) {
        return e;
      }
    },
  },

  reducers: {
    // 重置数据
    saveSupplement(state, { payload }) {
      const bookingRoomList = payload;

      return {
        ...state,
        bookingRoomList,
      };
    },

    // 修改数据
    saveKey(state, action) {
      return {
        ...state,
        ...action.payload,
      };
    },

    // 暂存会员数据
    saveBookingGuest(state, action) {
      return {
        ...state,
        bookingGuest: {
          ...state.bookingGuest,
          ...action.payload,
        },
      };
    },
  },
};
