import { authFetch as request, transAuthFetch } from '@/utils/fetch';

export function updateOrderDetail(params) {
  return request(`/api/crs/v1/booking/updateBooking`, {
    method: 'POST',
    params: { ...params },
  });
}

export function cancelOrder(params) {
  return request(`/api/crs/v1/booking/cancelBooking`, {
    method: 'POST',
    params,
  });
}

// 删除订单
export function deleteOrder(params) {
  const { bookingId, operatorId, sysRemark } = params;
  return transAuthFetch(`/crs/booking/deleteByBookingId/${bookingId}`, {
    type: 3,
    method: 'POST',
    params: {
      bookingId,
      sysRemark,
      operatorId,
    },
  });
}

export function queryOrderList(params) {
  return request(`/api/crs/v2/booking/listBooking`, {
    params,
  });
}

export function queryOrderDetail(params) {
  return request(`/api/crs/v1/booking/getDetail`, {
    params,
  });
}

export function queryHotelPriceTypeList(params) {
  return request(`/api/crs/v1/roomType/roomTypeListWithRateCode`, {
    params,
  });
}

export function queryRoomReservationList(params) {
  return request(`/api/crs/v1/posting/listRoomReservation`, {
    params,
  });
}

// 新订单详情房单列表详情接口
export function queryRoomDataList(params) {
  return transAuthFetch(`/posting/pagin`, {
    type: 3,
    method: 'POST',
    params,
  });
}
// 操作日志列表
export function queryJournalList(params) {
  return transAuthFetch(`/log/query`, {
    type: 3,
    params,
  });
}

// 获取CRS的渠道列表（目前返回的是全渠道，非CRS下可用渠道）
// export function queryCRSChannelList(params) {
//   return request(`/api/crs/v1/channel/listCrsChannel`, {
//     params,
//   });
// }

// 获取CRS的渠道列表（目前返回的是全渠道，非CRS下可用渠道）
export function queryCRSChannelList() {
  return transAuthFetch(`/channel/allChannel`, {
    type: 1,
    params: {},
  });
}

// 获取是否是会员
export function queryGuestType(params) {
  return request(`/api/crs/v1/member/verify`, {
    params,
  });
}
// 获取商品信息（酒店房型和价格）
export function queryProduct(params) {
  return request(`/api/crs/v1/product/getProduct`, {
    params,
  });
}

// 获取酒店Id（模糊搜索）
export function querySuggestHotel(params) {
  return request(`/api/crs/v1/common/suggestHotel`, {
    method: 'POST',
    params,
  });
}

// 获取酒店基础信息
export function queryhotelBaseInfo(params) {
  return transAuthFetch(`/hotel/hotelBaseInfo`, {
    type: 1,
    params,
  });
}

// 获取范围房价
export function queryRangePrice(params) {
  return transAuthFetch(`/rateCode/getRateCodeLite`, {
    type: 2,
    params,
  });
}

// 获取取消订单理由
export function queryCancelReason() {
  return transAuthFetch(`/app/booking/getCancelReason`, {
    type: 3,
  });
}

// 取消订单
export function reasonCancelOrder() {
  return transAuthFetch(`/crs/booking/cancel`, {
    type: 3,
    method: 'POST',
  });
}

export function generateOfflinePassword(params) {
  return request(`/api/crs/smartLock/generateOfflinePassword`, {
    method: 'POST',
    params,
  });
}
