import PageHeaderWrapper from '@/components/PageHeaderWrapper';
import { xlsx } from '@/constant/mimeType';
import {
  Badge,
  Button,
  Card,
  Col,
  Icon,
  Input,
  message,
  Row,
  Spin,
  Table,
  Timeline,
  Upload,
} from 'antd';
import { connect } from 'dva';
import React, { PureComponent } from 'react';
import router from 'umi/router';
import { getExcelFile, IgetExcelFile, uploadFile } from './services/batchAdd';
const styles = require('./style.less');
// const mock = {
//   successCount: 0,
//   errorCount: 3,
//   batchImportDataList: [
//     {
//       desc: '姓名不可为空！',
//       row: 2,
//     },
//     {
//       desc: '邮件不可为空！',
//       row: 3,
//     },
//     {
//       desc: '员工所属公司或酒店不存在!',
//       row: 4,
//     },
//   ],
// };
@connect(({ global, user }) => ({
  global,
  user,
}))
export default class BatchAdd extends PureComponent<any, any> {
  constructor(props) {
    super(props);
    this.state = {
      res: null,
      loading: false,
    };
  }

  public componentDidMount() {}

  public customRequest = file => {
    const { user } = this.props;
    const { accountId } = user;
    const formData: FormData = new FormData();
    formData.append('files', file.file);
    formData.append('accountId', accountId);
    this.setState({
      loading: true,
      res: null,
    });
    uploadFile({ formData, params: { accountId } })
      .then(res => {
        if (res.code === '000') {
          this.setState({
            res: res.data,
          });
        } else {
          message.error(res.message || '上传出错');
        }
        this.setState({
          loading: false,
        });
      })
      .catch(er => {
        console.log(er);
        this.setState({
          loading: false,
        });
      });
  };
  public down = (): void => {
    getExcelFile({})
      .then(data => {
        data.data && window.open('./AddUsers.xlsx');
        // data.data && (window.location=data.data);
      })
      .catch(er => {
        console.log(er);
      });
  };
  public renderRes = ({ successCount, errorCount, batchImportDataList, totalCount }) => {
    const list = batchImportDataList.map(item => {
      return (
        <li key={item.row}>
          第{item.row}
          行：
          {item.desc}
        </li>
      );
    });

    return (
      <div>
        {successCount === 0 ? (
          <div>
            <Row type="flex">
              <Col>
                <Icon type="close-circle" style={{ fontSize: 60, color: '#F5222D' }} />
              </Col>
              <Col style={{ marginLeft: 20 }}>
                <p>上传失败</p>
                <p>
                  共{totalCount}
                  条数据，其中有
                  {errorCount}
                  条数据有错误，未成功新增用户，请参照错误提示修改后重新上传
                </p>
              </Col>
            </Row>
            <ul style={{ marginTop: 20 }}>
              <li>错误提示：</li>
              {list}
            </ul>
          </div>
        ) : (
          <div>
            <Row type="flex">
              <Col>
                <Icon type="check-circle" style={{ fontSize: 60, color: 'green' }} />
              </Col>
              <Col style={{ marginLeft: 20 }}>
                <p>上传完成</p>
                <p>
                  成功上传
                  {successCount}
                  条数据
                </p>
              </Col>
            </Row>
            <ul style={{ marginTop: 20 }}>
              <li>
                有{errorCount}
                条数据未上传：
              </li>
              {list}
            </ul>
          </div>
        )}
      </div>
    );
  };

  public render() {
    const { down } = this;
    const { res, loading } = this.state;
    return (
      <PageHeaderWrapper title="">
        <Card className={styles.box}>
          <Timeline>
            <Timeline.Item dot={<Badge count={1} />}>
              <Button type="primary" style={{ marginLeft: 10 }} onClick={down}>
                下载模板
              </Button>{' '}
              （每次新增时需重新下载表格）
            </Timeline.Item>
            <Timeline.Item dot={<Badge count={2} />}>
              <p style={{ marginLeft: 15 }}>
                填写信息：参照表格中的范例在excel中填写信息，填写完成后保存表格。
                （新增上限：100条/次）
              </p>
            </Timeline.Item>
            <Timeline.Item dot={<Badge count={3} />}>
              <Upload showUploadList={false} customRequest={this.customRequest} accept={xlsx}>
                <Button type="primary" style={{ marginLeft: 10 }}>
                  上传表格
                </Button>{' '}
              </Upload>
              （上传成功后10分钟内新增完成所有用户）
            </Timeline.Item>
          </Timeline>
          {res ? this.renderRes(res) : null}
          {loading ? <Spin /> : null}
        </Card>
        {/* <a href="http://backend-account-oauth-service.dev.ahotels.tech/data/importDb.xlsx" download="filename">点击</a> */}
      </PageHeaderWrapper>
    );
  }
}
