import React, { PureComponent } from 'react';
import { connect } from 'dva';
import router from 'umi/router';
import { Row, Col, Card, Input, Button, Table, Badge } from 'antd';
import PageHeaderWrapper from '@/components/PageHeaderWrapper';
import { getRoleList } from './services';
import ButtonAuthorized from '@/components/ButtonAuthorized';
import styles from './style.less';

const data = [];

@connect(({ global }) => ({
  global,
}))
export default class Role extends PureComponent {
  constructor(props) {
    super(props);
    this.state = {
      data,
      loading: false,
      name: null,
      id: null,
      pagination: {
        showSizeChanger: true,
        current: 1,
        pageSize: 10,
        total: '',
      },
    };
  }

  componentDidMount() {
    const { name, id } = this.state;
    this.getList({ name, id });
  }

  toEdit = id => {
    const { dispatch } = this.props;
    // debugger
    router.push({
      pathname: '/permission/roleEdit',
      query: { id },
    });
  };

  toQuery = id => {
    const { dispatch } = this.props;
    router.push({
      pathname: '/permission/query',
      query: { id },
    });
  };

  toAdd = () => {
    router.push({
      pathname: '/permission/roleAdd',
      query: {},
    });
  };

  handlePageChange = ({ current, pageSize }) => {
    // debugger
    this.getList({
      id: this.state.id,
      name: this.state.name,
      pageNum: current,
      pageSize,
    });
  };

  getList = async ({ name, pageNum = 1, pageSize = 10, id }) => {
    // debugger
    let pagination = this.state.pagination;
    this.setState({
      loading: true,
    });
    getRoleList({ roleName: name, pageNum, pageSize, roleId: id })
      .then(res => {
        // debugger
        this.setState({
          data: res.data.list,
          pagination: {
            ...pagination,
            current: pageNum,
            pageSize,
            total: res.data.total,
          },
        });
      })
      .catch(() => {})
      .finally(() => {
        this.setState({
          loading: false,
        });
      });
  };

  handleChange = (ev, key) => {
    this.setState({
      [key]: ev.target.value ? ev.target.value : null,
    });
  };

  query = () => {
    // debugger
    this.getList({
      name: this.state.name,
      id: this.state.id,
      pageSize: this.state.pagination.pageSize,
    });
  };

  reset = () => {
    this.setState(
      {
        name: null,
        id: null,
      },
      () => {
        this.getList({ name: null, id: null, pageNum: 1, pageSize: 10 });
      }
    );
  };

  render() {
    let { global } = this.props;
    const columns = [
      {
        title: '角色ID',
        dataIndex: 'id',
        key: 'id',
      },
      {
        title: '角色名称',
        dataIndex: 'name',
        key: 'name',
      },
      {
        title: '角色描述',
        dataIndex: 'description',
        key: 'description',
        width: 350,
      },
      {
        title: '创建时间',
        dataIndex: 'createTime',
        key: 'createTime',
      },
      {
        title: '角色状态',
        dataIndex: 'status',
        key: 'status',
        render: status => <Badge status={global.STATUS_MAP[status]} text={global.STATUS[status]} />,
      },
      {
        title: '操作',
        dataIndex: 'id',
        key: 'xx',
        render: id => (
          <>
            <Button size="small" onClick={() => this.toQuery(id)} style={{ marginRight: 5 }}>
              查看
            </Button>
            <Button size="small" onClick={() => this.toEdit(id)}>
              编辑
            </Button>
          </>
        ),
      },
    ];

    return (
      <PageHeaderWrapper title="">
        <Card className={styles.permissionList}>
          <Row>
            <Col span={12}>
              <Row>
                <Col span={11}>
                  <Input
                    placeholder="请输入角色名称(精确查询)"
                    value={this.state.name}
                    onChange={v => this.handleChange(v, 'name')}
                  />
                </Col>
                <Col span={11}>
                  <Input
                    type="number"
                    placeholder="请输入角色ID(精确查询)"
                    value={this.state.id}
                    onChange={v => this.handleChange(v, 'id')}
                    style={{ marginLeft: 10 }}
                  />
                </Col>
              </Row>
            </Col>
            <Col span={12}>
              <Button type="primary" onClick={this.query}>
                查询
              </Button>

              <Button onClick={this.reset} style={{ marginLeft: 20 }}>
                重置
              </Button>
            </Col>
          </Row>

          <Row style={{ marginTop: 30 }}>
            <Col span={20} />

            <Col span={24}>
              <Button icon="plus" type="primary" onClick={this.toAdd}>
                新增角色
              </Button>

              {/* <ButtonAuthorized code='CRS6.1.2.2' type="primary" onClick={this.toAdd}>
                <Button />
              </ButtonAuthorized> */}
            </Col>
          </Row>

          <Table
            rowKey="id"
            bordered
            size="small"
            style={{ marginTop: 20 }}
            loading={this.state.loading}
            dataSource={this.state.data}
            columns={columns}
            pagination={this.state.pagination}
            onChange={this.handlePageChange}
            // onShowSizeChange={this.handlePageChange}
          />
        </Card>
      </PageHeaderWrapper>
    );
  }
}
