import React, { PureComponent } from 'react';
import { connect } from 'dva';
import router from 'umi/router';
import {
  Row,
  Col,
  Card,
  Form,
  Input,
  Select,
  Button,
  Modal,
  message,
  Badge,
  Table,
  TreeSelect,
  Switch,
  Icon,
  InputNumber,
  Radio,
} from 'antd';
import PageHeaderWrapper from '@/components/PageHeaderWrapper';
import {
  addRole,
  getPermissionList,
  getRoleDetail,
  editRole,
  getLowerRule,
  getAllRoleList,
} from './services';
import styles from './style.less';
import PermissionSelect from './components/PermissionSelect';
import judgePermission from '@/utils/judgePermission';
import { formartTypeToUp, formartTypeToFe } from '@/utils/formartType';
import { ProjectListMap } from './constants';

const FormItem = Form.Item;
const formItemLayout = {
  labelCol: { span: 5 },
  wrapperCol: { span: 12 },
};
const Option = Select.Option;
const { TextArea } = Input;
const SHOW_PARENT = TreeSelect.SHOW_PARENT;
const titleMap = {
  roleAdd: '新增角色',
  roleEdit: '设置角色',
  roleQuery: '角色查看',
};
function formartAllPre(...rest) {
  let arr = [];
  rest.forEach(item => {
    item &&
      item.forEach(ele => {
        arr.push(ele.code);
      });
  });
  return arr;
}

@connect(({ global, permission, user }) => ({
  global,
  permission,
  user,
}))
@Form.create()
export default class RoleAddEdit extends PureComponent {
  constructor(props) {
    super(props);
    this.state = {
      type: '', // roleAdd  roleEdit roleQuery
      isLoad: false,
      roleId: '', // 角色id  供编辑上行使用
      roleList: [], // {} "roleId": "admin","roleName": "管理员"
      data: {
        lowerRoles: [], // 下级角色
        name: '',
        description: '',
        switcher: 0, // 人数限制开关（）
        limitedNum: '', // 数量限制
        pmsStatus: 0,
        crsStatus: 0,
        otaStatus: 0,
        hooStatus: 0,
        status: 1, // 角色状态（0 开 1关）
        permissionList: [],
        crs: [],
        pms: [],
        hotelType: [],
        appList: [], // 其他项目
      },
    };
  }

  componentDidMount() {
    // roleQuery roleEdit  roleAdd  三种状态
    let roleId = this.props.location.query.id;
    let { permission, dispatch } = this.props;
    this.setState({
      type: this.props.route.name,
    });
    // 获取所有权限树
    // this.getPermissionList();

    // 获取下级角色列表
    this.getLowerRule();
    if (this.props.route.name === 'roleEdit' || this.props.route.name === 'roleQuery') {
      // 获取角色信息
      this.getRoleDetail({ id: roleId });
      this.setState({
        roleId,
      });
    }
    // 置顶
    setTimeout(() => {
      document.documentElement.scrollTop = 0;
    }, 200);
  }

  // 获取下级角色列表  就是获取所有角色
  getLowerRule = () => {
    let { accountId } = this.props.user;
    getAllRoleList()
      .then(res => {
        this.setState({
          roleList: res.data,
        });
      })
      .catch(er => {
        console.log(er);
      });
  };

  // 获取角色详情
  getRoleDetail = param => {
    getRoleDetail(param)
      .then(res => {
        this.setState({
          data: {
            ...res.data,
            lowerRoles: res.data.lowerRoles.map(item => `${item.lowerId}`),
            hotelType: res.data.hotelType ? formartTypeToFe(res.data.hotelType) : [],
          },
          isLoad: true,
        });
      })
      .catch(error => {
        console.log(error);
      });
  };

  // 渲染所有角色列表
  renderRoleList = () => {
    let arr = [];
    let { roleList } = this.state;
    return roleList.map(item => <Option key={item.id}>{item.name}</Option>);
  };

  handleOk = () => {
    let { data, type } = this.state;
    let { accountId } = this.props.user;
    let obj = this.permissionCom.getAllCheckedPre();
    let { name, description, lowerRoles, switcher, limitedNum, hotelType } = data;
    hotelType = formartTypeToUp(hotelType);
    if (!name.trim()) {
      message.error('请输入角色名称');
      return;
    }
    if (!description.trim()) {
      message.error('请输入角色描述');
      return;
    }

    if (switcher === 1 && !limitedNum) {
      message.error('人数限制开关已经打开，请输入人数');
      return;
    }
    if (type === 'roleEdit') {
      editRole({
        ...data,
        ...obj,
        hotelType,
        lowerRoles: lowerRoles.map(id => ({ lowerId: id, name: '' })),
        accountId,
      })
        .then(res => {
          message.success('保存成功');
          router.go(-1);
        })
        .catch(e => {
          console.log(e);
        });
    }
    if (type === 'roleAdd') {
      addRole({
        ...data,
        ...obj,
        hotelType,
        lowerRoles: lowerRoles.map(id => ({ lowerId: id, name: '' })),
        accountId,
      })
        .then(res => {
          message.success('保存成功');
          router.go(-1);
        })
        .catch(e => {
          console.log(e);
        });
    }
  };

  onChange = value => {
    // console.log('onChange ', value);
    // this.setState({ value });
  };

  back = () => {
    router.go(-1);
  };

  handleSwitchChange = (ev, key) => {
    let { data } = this.state;
    this.setState({
      data: {
        ...data,
        [key]: ev ? 1 : 0,
      },
    });
  };

  handleRadioChange = (ev, key) => {
    let { data } = this.state;
    this.setState({
      data: {
        ...data,
        [key]: ev.target.value,
      },
    });
  };

  handleChange = (ev, key) => {
    let { data } = this.state;
    this.setState({
      data: {
        ...data,
        [key]: ev.target ? ev.target.value : ev,
      },
    });
  };

  renderLable = text => (
    <span>
      <span style={{ color: 'red' }}>*</span>
      {text}
    </span>
  );

  render() {
    let disabled = this.state.type === 'roleQuery';
    let { renderRoleList, handleChange, handleSwitchChange, renderLable, handleRadioChange } = this;
    let { type, isLoad, roleList, roleId } = this.state;
    let {
      lowerRoles,
      name,
      description,
      switcher,
      limitedNum,
      status,
      permissionList,
      hotelType,
      appList,
    } = this.state.data;

    const statusList = {};
    const projectlist = {};
    // Object.values(ProjectListMap).forEach(item => {
    //   statusList[item] = this.state.data[item];
    // });
    Object.keys(ProjectListMap).forEach(itemKey => {
      statusList[ProjectListMap[itemKey]] = this.state.data[ProjectListMap[itemKey]];
    });
    Object.keys(ProjectListMap).forEach(item => {
      projectlist[item] = this.state.data[item];
    });
    return (
      <PageHeaderWrapper title={titleMap[type]}>
        <Row />

        <Card
          className={styles.permissionList}
          title={
            <>
              {' '}
              <span>角色信息</span>
              {roleId ? (
                <span style={{ color: '#aaa', marginLeft: 20 }}>{`id:${roleId}`}</span>
              ) : null}{' '}
            </>
          }
          extra={
            <Radio.Group
              onChange={ev => handleRadioChange(ev, 'status')}
              disabled={disabled || !judgePermission('CRS5.2.1.1')}
              style={{ width: 120 }}
              value={status}
            >
              <Radio.Button value={1}>有效</Radio.Button>
              <Radio.Button value={0}>无效</Radio.Button>
            </Radio.Group>
          }
        >
          <Form layout="horizontal">
            <FormItem label={renderLable('角色名称')} {...formItemLayout}>
              <Input
                disabled={disabled}
                placeholder="请输入角色名称"
                value={name}
                onChange={ev => handleChange(ev, 'name')}
              />
            </FormItem>
            <FormItem label={renderLable('角色描述')} {...formItemLayout}>
              <TextArea
                disabled={disabled}
                placeholder="请输入角色描述"
                value={description}
                onChange={ev => handleChange(ev, 'description')}
              />
            </FormItem>

            <FormItem label="下级角色" {...formItemLayout}>
              {/* {console.log(roleList,lowerRoles)} */}
              {roleList.length ? (
                <Select
                  disabled={disabled}
                  // mode="tags"
                  mode="multiple"
                  style={{ width: '100%' }}
                  value={lowerRoles}
                  onChange={ev => handleChange(ev, 'lowerRoles')}
                  placeholder="请选择下级角色"
                >
                  {renderRoleList()}
                </Select>
              ) : null}

              <p style={{ fontSize: 12 }}>
                在新增用户时，角色只可选择下级角色。对下级角色拥有查看、编辑、新增和删除的权限
              </p>
            </FormItem>
            <FormItem label="人数限制" {...formItemLayout}>
              <Switch
                disabled={disabled}
                onChange={ev => handleSwitchChange(ev, 'switcher')}
                checked={switcher === 1}
              />{' '}
              <InputNumber
                disabled={switcher === 0 || disabled}
                value={limitedNum}
                min={0}
                max={9999}
                onChange={ev => handleChange(ev, 'limitedNum')}
              />
              <p style={{ fontSize: 12 }}>角色在一家酒店中的人数限制</p>
            </FormItem>

            <FormItem label="关联酒店" {...formItemLayout}>
              <Select
                mode="multiple"
                // style={{ width: '100%' }}
                placeholder="请选择"
                value={hotelType}
                onChange={ev => handleChange(ev, 'hotelType')}
              >
                <Option value={2}>加盟酒店</Option>
                <Option value={1}>直营酒店</Option>
              </Select>
            </FormItem>
          </Form>
        </Card>

        <Card title="权限管理" style={{ marginTop: 40 }}>
          {isLoad || type === 'roleAdd' ? (
            <PermissionSelect
              data={{
                type,
                appList,
                // permissionList: formartAllPre(...Object.values(projectlist)),
                permissionList: formartAllPre(...Object.keys(projectlist).map(k => projectlist[k])),
                ...statusList,
              }}
              ref={permissionCom => {
                this.permissionCom = permissionCom;
              }}
            />
          ) : null}
        </Card>

        {disabled ? null : (
          <FormItem style={{ textAlign: 'center', marginTop: 40 }}>
            <Button size="large" type="primary" htmlType="submit" onClick={this.handleOk}>
              保存
            </Button>
            <Button size="large" onClick={this.back} style={{ marginLeft: 40 }}>
              取消
            </Button>
          </FormItem>
        )}
      </PageHeaderWrapper>
    );
  }
}
