import React, { PureComponent } from 'react';
import { connect } from 'dva';
import _ from 'lodash';
import router from 'umi/router';
import Link from 'umi/link';
import moment from 'moment';
import { Row, Col, Card, Input, Button, Table, Radio, Badge, message } from 'antd';
import PageHeaderWrapper from '@/components/PageHeaderWrapper';
import ButtonAuthorized from '@/components/ButtonAuthorized';
import HotelSearch from './components/HotelSearch';
import { getUserListAccountInfo, canEditUser } from './services';
import styles from './style.less';

const RadioButton = Radio.Button;
const RadioGroup = Radio.Group;

@connect(({ global, user }) => ({
  global,
  user,
}))
export default class User extends PureComponent {
  constructor(props) {
    super(props);
    this.state = {
      isSearch: false, // 标记是否已经点击查询过
      data: [],
      loading: false,
      searchType: 'id',
      searchTypePlaceholder: '请输入用户id',
      accountId: '', // 登陆人账号
      searchFiled: {
        id: '用户id',
        name: '用户姓名',
        hotelName: '酒店名称',
        phone: '手机号',
        email: '邮箱',
      },
      searchFiledValue: {
        id: '',
        name: '',
        hotelName: '',
        phone: '',
        email: '',
      },
      pagination: {
        showSizeChanger: true,
        current: 1,
        pageSize: 10,
        total: '',
      },
    };
  }

  toInfo = id => {
    router.push({
      pathname: `/permission/user/userInfo`,
      query: {
        id,
      },
    });
  };

  toAdd = () => {
    router.push({
      pathname: '/permission/user/userAdd',
      query: {},
    });
  };

  toBatchAdd = () => {
    router.push({
      pathname: '/permission/user/batchAdd',
      query: {},
    });
  };

  toEdit = id => {
    let { accountId } = this.props.user;
    canEditUser({
      employeeId: id,
      accountId,
    })
      .then(res => {
        if (res.data) {
          router.push({
            pathname: `/permission/user/userEdit`,
            query: { id },
          });
        } else {
          message.error('没有权限编辑哦');
        }
      })
      .catch(er => {
        console.log(er);
      });
  };

  componentDidMount() {
    const { dispatch } = this.props;
    const { searchFiledValue } = this.state;

    dispatch({
      type: 'user/getInfo',
      payload: {},
    })
      .then(res => {
        let { accountId } = res;
        this.setState(
          {
            accountId,
          },
          () => {
            this.getList({ ...searchFiledValue });
          }
        );
      })
      .catch(er => console.log(er));
  }

  handlePageChange = ({ current, pageSize }) => {
    // debugger
    const { searchFiledValue } = this.state;

    this.getList({
      ...searchFiledValue,
      pageNum: current,
      pageSize,
    });
  };

  getList = async ({ pageNum = 1, pageSize = 10 }) => {
    // debugger
    const _this = this;
    const { searchFiledValue, accountId, isSearch } = this.state;
    let pagination = this.state.pagination;
    this.setState({
      loading: true,
    });

    getUserListAccountInfo({ ...searchFiledValue, pageNum, pageSize, accountId, isSearch })
      .then(res => {
        const _data = res.data.list;
        _this.setState({
          data: _data,
          pagination: {
            ...pagination,
            current: pageNum,
            pageSize,
            total: res.data.total,
          },
        });
        if (_data.length === 0) {
          message.error('无搜索结果');
        }
      })
      .catch(err => {
        // message.error('用户数据异常');
      })
      .finally(() => {
        this.setState({
          loading: false,
        });
      });
  };

  changeKey = ev => {
    const { searchType, searchFiled } = this.state;
    let searchFiledValue = {
      id: '',
      name: '',
      hotelName: '',
      phone: '',
      email: '',
    };
    searchFiledValue[searchType] = ev.target.value;
    this.setState({
      searchFiledValue: {
        ...searchFiledValue,
      },
    });
  };

  getInputValue = () => {
    const { searchType, searchFiled, searchFiledValue } = this.state;
    return searchFiledValue[searchType];
  };

  query = () => {
    const { searchFiledValue, searchType, pagination, isSearch } = this.state;
    let inputBl = Object.keys(searchFiledValue).some(item => searchFiledValue[item]);
    if (!inputBl) {
      message.error('请输入查询条件，进行搜索');
      return;
    }
    if (isSearch) {
      this.getList({
        ...searchFiledValue,
        pageSize: pagination.pageSize,
      });
    } else {
      this.setState(
        {
          isSearch: true,
        },
        () => {
          this.getList({
            ...searchFiledValue,
            pageSize: pagination.pageSize,
          });
        }
      );
    }
  };

  reset = () => {
    this.setState(
      {
        searchType: 'id',
        searchTypePlaceholder: '请输入用户ID',
        isSearch: false,
        searchFiledValue: {
          id: '',
          name: '',
          hotelName: '',
          phone: '',
          email: '',
        },
      },
      () => {
        this.getList({
          searchFiledValue: {
            id: '',
            name: '',
            hotelName: '',
            phone: '',
            email: '',
          },
        });
      }
    );
  };

  changeSearchType = ev => {
    const { searchFiled, searchFiledValue } = this.state;
    let searchTypePlaceholder = `请输入${searchFiled[ev.target.value]}`;
    this.setState({
      searchTypePlaceholder,
      searchType: ev.target.value,
      searchFiledValue: {
        ...searchFiledValue,
        id: '',
        name: '',
        // hotelName: '',
        phone: '',
        email: '',
      },
    });
  };

  changeHotelName = obj => {
    this.setState(
      {
        searchFiledValue: {
          ...this.state.searchFiledValue,
          hotelName: obj.hotelName,
        },
        isSearch: true,
      },
      () => {
        this.query();
      }
    );
  };

  render() {
    const { global } = this.props;
    const { searchTypePlaceholder, searchType, searchFiledValue } = this.state;
    const columns = [
      {
        title: '用户ID',
        dataIndex: 'id',
        key: 'id',
        width: '8%',
        render: (employeeId, item) => item.id,
      },
      {
        title: '用户姓名',
        dataIndex: 'name',
        key: 'name',
        width: '10%',
        render: (name, item) => item.name,
      },
      {
        title: '手机号',
        dataIndex: 'phone',
        key: 'phone',
        width: '14%',
      },
      {
        title: '邮箱',
        dataIndex: 'email',
        key: 'email',
        width: '18%',
      },
      {
        title: '创建时间',
        dataIndex: 'createTime',
        key: 'createTime',
        width: '12%',
        render: (createTime, item) => {
          if (!createTime) {
            return '';
          }
          return moment(createTime).format('YYYY-MM-DD HH:mm:ss');
        },
      },
      {
        title: '岗位',
        dataIndex: 'position',
        key: 'position',
        width: '12%',
      },
      {
        title: '用户状态',
        dataIndex: 'status',
        key: 'status',
        width: '10%',
        render: status => {
          const _status = status === null ? 2 : status;
          return <Badge status={global.STATUS_MAP[_status]} text={global.STATUS[_status]} />;
        },
      },
      {
        title: '操作',
        dataIndex: 'actionId',
        key: 'actionId',
        render: (actionId, item) => (
          <span>
            <ButtonAuthorized
              style={{ marginRight: 10 }}
              code="CRS5.2.4"
              size="small"
              onClick={() => {
                this.toInfo(item.id);
              }}
            >
              详情
            </ButtonAuthorized>
            <ButtonAuthorized
              style={{ marginRight: 10 }}
              code="CRS5.2.6"
              size="small"
              onClick={() => {
                this.toEdit(item.id);
              }}
            >
              编辑
            </ButtonAuthorized>
          </span>
        ),
      },
    ];

    return (
      <PageHeaderWrapper title="">
        <Card className={styles.permissionUser}>
          <Row>
            <Col span={24}>
              <RadioGroup
                onChange={this.changeSearchType}
                value={searchType}
                style={{ marginRight: 10 }}
              >
                <RadioButton value="id">用户id</RadioButton>
                <RadioButton value="name">用户姓名</RadioButton>
                <RadioButton value="phone">手机号</RadioButton>
                <RadioButton value="email">邮箱</RadioButton>
                {/* <RadioButton value="hotelName">酒店名称</RadioButton> */}
              </RadioGroup>
              <Input
                style={{ width: 200, marginRight: 20 }}
                placeholder={searchTypePlaceholder}
                value={this.getInputValue()}
                type={searchType === 'id' || searchType === 'phone' ? 'number' : ''}
                onChange={this.changeKey}
              />
              <Button type="primary" onClick={this.query}>
                查询
              </Button>
              <HotelSearch
                style={{ width: 220, marginLeft: 10 }}
                callback={this.changeHotelName}
                defaultValue={searchFiledValue.hotelName}
                url="/api/v1/group/getHotelName"
              />
              <Button onClick={this.reset} style={{ marginLeft: 20 }}>
                重置
              </Button>
            </Col>
          </Row>

          {/* <Row style={{ marginTop: 30 }}>
            <Col span={20} />

            <Col span={24}>
              <ButtonAuthorized
                type="primary"
                style={{ marginRight: 10 }}
                code="CRS5.2.5"
                onClick={this.toAdd}
              >
                新增账号
              </ButtonAuthorized>
              <ButtonAuthorized onClick={this.toBatchAdd} code="CRS5.2.7">
                批量新增
              </ButtonAuthorized>
            </Col>
          </Row> */}

          <Table
            rowKey="id"
            bordered
            size="small"
            style={{ marginTop: 20 }}
            loading={this.state.loading}
            dataSource={this.state.data}
            columns={columns}
            pagination={this.state.pagination}
            onChange={this.handlePageChange}
          />
        </Card>
      </PageHeaderWrapper>
    );
  }
}
