import React, { PureComponent } from 'react';
import router from 'umi/router';
import Link from 'umi/link';
import { connect } from 'dva';
import {
  Col,
  Row,
  Card,
  Form,
  Input,
  Select,
  Button,
  message,
  TreeSelect,
  Table,
  Popconfirm,
  Icon,
  Radio,
  Cascader,
  Modal,
  Badge,
  Upload,
} from 'antd';
import PageHeaderWrapper from '@/components/PageHeaderWrapper';
import ButtonAuthorized from '@/components/ButtonAuthorized';
import styles from './style.less';
import HotelSearch from './components/HotelSearch2';
import { PHONE } from '@/constant/reg';
import { RULES } from '@/utils/validateRule';
import NewHotelRoleModal from './components/NewHotelRoleModal';
import judgePermission from '@/utils/judgePermission';
import getUUID from '@/utils/uuid';
import setKeyByImmutable from '@/utils/setKeyByImmutable';
import {
  addUser,
  editUser,
  getUserDetail,
  userUpdateRole,
  userDeleteRole,
  getHotelRolePageList,
  getLowerRule,
  editUserRole,
  getSalesArea,
  getPostList,
  userAddRole,
  userSendMessage,
  deleteUser,
  deleteEmployeeHotel,
  uploadAvatar,
  deleteAvatar,
} from './services';

const { Option } = Select;
const { InputGroup, TextArea } = Input;
const defaultPagination = {
  showSizeChanger: true,
  current: 1,
  pageSize: 10,
  total: 0,
};

let isLt3M = true;

function handleBeforeUpload(file) {
  isLt3M = file.size / 1024 / 1024 < 3;
  if (!isLt3M) {
    message.error('请上传小于等于3M的头像');
  }
  const avatar = {};
  return isLt3M;
}

// const SHOW_PARENT = TreeSelect.SHOW_PARENT;
@connect(user => user)
@Form.create()
export default class UserAddEdit extends PureComponent {
  constructor(props) {
    super(props);
    this.state = {
      userInfoDisable: true,
      componyInfoDisable: true,
      modalVisible: false,
      loading: false,
      saveText: '保存并下一步',
      type: '', // userAdd  userEdit userInfo
      defaultValue: {},
      roleType: { userAdd: '新增员工', userEdit: '修改员工', userInfo: '查看员工' },
      companyType: [{ key: '0', name: '公司' }, { key: '1', name: '酒店' }],
      companyTypeValue: '1',
      userInfoData: {
        status: '1',
      },
      addHotelInfo: {
        hotelName1: '',
        hotelId1: '',
        hotelName2: '',
        hotelId2: '',
      },
      roleData: {
        company: 0,
        hotel: 1,
      },
      userRoleAddData: {
        hotelId: '',
        hotelName: '',
        roleId: '',
        roleName: '',
        id: '',
      },
      pagination: defaultPagination,
      userRoleList: [],
      postRoleList: [],
      accountId: '',
      employeeId: '',
      editVisible: true,
      fromAdd: false,
      defaultEmailType: '@oyohotels.cn',
      hotelRoleVisible: styles.hide,
      avatar: {
        previewVisible: false,
        previewImage: '',
        fileList: [],
      },
      imgPath: '',
    };
  }

  changeState(key, value) {
    this.setState(setKeyByImmutable(this.state, key, value));
  }

  componentDidMount() {
    const { dispatch, route, location, user, roleData } = this.props;
    const { name } = route;
    const { query } = location;
    // const { accountId } = user;
    const type = name;
    const employeeId = query.id;
    const from = query.from;
    const editVisible = name === 'userInfo';
    const fromAdd = from === 'add';
    this.setState({
      fromAdd, // 标记是否从新增过来
      type,
      employeeId,
      editVisible,
      userRoleList: [],
    });
    dispatch({
      type: 'user/getInfo',
      payload: {},
    })
      .then(res => {
        this.setState({ accountId: res.accountId, userRoleAddData: { id: employeeId } });
        // this.getLowerRule({ accountId: res.accountId });
        if (employeeId) {
          this.getHotelRolePageList({ id: employeeId });
        }
      })
      .catch(err => {});

    this.getSalesArea();
    this.getPostRoleList();
    if (name === 'userEdit' || name === 'userInfo') {
      // 获取角色信息
      this.getUserDetail({ id: employeeId });
      this.setState({ hotelRoleVisible: styles.show, saveText: '保存' });
    }
  }

  getSalesArea = () => {
    getSalesArea()
      .then(res => {
        if (res.data && res.data.length > 0) {
          const cascaderOptions = this.convertTree(res.data);

          this.setState({ cascaderOptions });
        }
      })
      .catch(err => {});
  };

  getPostRoleList = () => {
    let { companyTypeValue } = this.state;
    let roleData = {};
    if (companyTypeValue === '1') {
      roleData = {
        company: 0,
        hotel: 1,
      };
    } else {
      roleData = {
        company: 1,
        hotel: 0,
      };
    }

    getPostList(roleData)
      .then(res => {
        this.setState({ postRoleList: res.data });
      })
      .catch(err => {});
  };

  convertTree = tree => {
    const result = [];
    // 遍历 tree
    tree.forEach(item => {
      let children = [];
      if (item.hubBOList && item.hubBOList.length > 0) {
        children = item.hubBOList;
      } else if (item.cityBOList && item.cityBOList.length > 0) {
        children = item.cityBOList;
      }
      if (children) {
        children = this.convertTree(children);
      }

      result.push({
        value: item.name,
        label: item.name,
        children,
      });
    });
    return result;
  };

  getUserDetail = params => {
    getUserDetail(params)
      .then(res => {
        if (res.code === '000') {
          console.log('getUserDetail', res.data);
          let data = res.data;
          let defaultEmailType = '';
          if (!data.email) {
            data.email = '';
            defaultEmailType = '@oyohotels.cn';
          } else if (data.email.indexOf('@oyohotels.cn') >= 0) {
            data.email = data.email.replace('@oyohotels.cn', '');
            defaultEmailType = '@oyohotels.cn';
          } else if (data.email.indexOf('@oyorooms.com') >= 0) {
            data.email = data.email.replace('@oyorooms.com', '');
            defaultEmailType = '@oyorooms.com';
          }

          const avatar = {
            previewVisible: false,
            previewImage: data.imgPath,
            fileList: data.imgPath
              ? [
                  {
                    uid: -1,
                    name: 'xxx.png',
                    status: 'done',
                    url: data.imgPath,
                    thumbUrl: data.imgPath,
                  },
                ]
              : [],
          };
          this.setState({
            userInfoData: data,
            defaultEmailType,
            addHotelInfo: {
              hotelName1: data.hotelName,
              hotelId1: data.hotelId,
              hotelName2: data.hotelName,
              hotelId2: data.hotelId,
            },
            avatar,
            imgPath: data.imgPath ? data.imgPath : '',
          });
        }
      })
      .catch(err => {});
  };

  handleUserEdit = item => {
    const { userRoleAddData, employeeId, userRoleList, accountId } = this.state;
    let index = userRoleList.findIndex(el => el.uuid === item.uuid);
    let value = userRoleList[index].value2;
    let { hotelId, hotelName, roleId, roleName, id, pkId } = value;
    if (!hotelName) {
      message.error('请选择酒店');
      return;
    }
    if (!roleName) {
      message.error('请选择角色');
      return;
    }
    let params = {
      hotelId,
      hotelName,
      roleId,
      roleName,
      id: employeeId,
      pkId,
      accountId,
    };
    userUpdateRole(params)
      .then(res => {
        if (res.code === '000') {
          message.success('角色修改成功');
          userRoleList[index].value1 = JSON.parse(JSON.stringify(value));
          userRoleList[index].value1.status = res.data.status;
          userRoleList[index].type = 'query';
          this.setState({
            userRoleList: [...userRoleList],
          });
        }
      })
      .catch(err => {
        // message.error('角色修改失败');
      });
  };

  handleUserSave = params => {
    const { userRoleAddData, employeeId, accountId } = this.state;
    const payload = { ...params, ...userRoleAddData };
    delete payload.pkId;
    delete payload.status;
    delete payload.list;

    userAddRole(payload)
      .then(res => {
        if (res.code === '000') {
          message.success('角色保存成功');
          this.getHotelRolePageList({ id: employeeId });
          this.setState({
            userRoleAddData: { hotelId: '', roleId: '', hotelName: '', roleName: '' },
          });
        }
      })
      .catch(err => {
        message.error('角色保存失败');
      });
  };

  userLowerRoleChange = (val, params, item) => {
    let { userRoleList } = this.state;
    let index = userRoleList.findIndex(el => el.uuid === item.uuid);
    userRoleList[index].value2.roleId = params.props.id;
    userRoleList[index].value2.roleName = val;
    this.setState({ userRoleList: [...userRoleList] });
  };

  hotelRoleChange = (params, item) => {
    let { userRoleAddData, accountId, userRoleList } = this.state;
    let index = userRoleList.findIndex(el => el.uuid === item.uuid);
    const { hotelId, hotelName, pkId } = params;
    userRoleAddData.hotelId = hotelId;
    // userRoleAddData.status = status;delete
    userRoleAddData.hotelName = hotelName;
    userRoleAddData.pkId = pkId;
    userRoleList[index] = {
      ...userRoleList[index],
      value2: {
        ...userRoleList[index].value2,
        ...userRoleAddData,
      },
    };
    this.setState({ userRoleAddData, userRoleList: [...userRoleList] });
    this.getLowerRule({ accountId, hotelId, pkId, index });
  };

  getHotelRolePageList = params => {
    let { employeeId } = this.state;
    let { current, pageSize } = this.state.pagination;
    params.id = params.id || employeeId;
    params.pageNum = params.pageNum || current;
    params.pageSize = params.pageSize || pageSize;
    getHotelRolePageList(params)
      .then(res => {
        if (res.code === '000') {
          const userRoleList = res.data.list.map((item, index) => ({
            value1: { ...item, list: [] }, // 原值
            value2: { ...item, list: [] }, // 正在编辑的值
            index,
            type: 'query',
            uuid: getUUID(),
          })); // or edit
          this.setState({
            userRoleList,
            pagination: {
              ...this.state.pagination,
              current: params.pageNum,
              pageSize: params.pageSize,
              total: res.data.total,
            },
          });
        }
      })
      .catch(err => {
        // message.error('用户角色获取失败');
        console.log('====================================');
        console.log(err);
        console.log('====================================');
      });
  };

  handleOk = () => {
    const {
      user,
      dispatch,
      form: { validateFields },
    } = this.props;
    const {
      type,
      defaultEmailType,
      userInfoData,
      employeeId,
      userRoleList,
      addHotelInfo,
      companyTypeValue,
      fromAdd,
      imgPath,
    } = this.state;
    validateFields((err, values) => {
      console.log('values', values);
      if (!err) {
        if (!values.name) {
          // 两个都不存在
          message.error('姓名必填');
          return;
        }

        if (!values.phone) {
          // 两个都不存在
          message.error('手机号必须填写');
          return;
        }

        if (values.phone && !values.phone.match(PHONE)) {
          message.error('请输入正确格式手机号');
          return;
        }
        if (values.email !== null && values.email !== '') {
          if (
            defaultEmailType !== '' &&
            typeof values.email !== 'undefined' &&
            values.email.indexOf('@') >= 0
          ) {
            message.error('非自定义邮箱不需要@以及后缀');
            return;
          }

          if (defaultEmailType !== '' && values.email) {
            values.email = values.email.replace('@oyohotels.cn', '');
            values.email = values.email.replace('@oyorooms.com', '');
            values.email += defaultEmailType;
          } else {
            values.email = '';
          }
        }
        values.hotelId = userInfoData.hotelId;
        values.state =
          values.state_cityGroup_city && values.state_cityGroup_city[0]
            ? values.state_cityGroup_city[0]
            : '';
        values.cityGroup =
          values.state_cityGroup_city && values.state_cityGroup_city[1]
            ? values.state_cityGroup_city[1]
            : '';
        values.city =
          values.state_cityGroup_city && values.state_cityGroup_city[2]
            ? values.state_cityGroup_city[2]
            : '';
        values.cardId = values.cardId ? values.cardId : '';
        values.bankId = values.bankId ? values.bankId : '';
        values.accountId = user.accountId;
        delete values.state_cityGroup_city;

        console.log('---imgPath---', imgPath);
        values.imgPath = imgPath;

        if (companyTypeValue === '1') {
          if (!addHotelInfo.hotelId1) {
            message.error('请选择酒店');
            return;
          }
          values.hotelId = addHotelInfo.hotelId1;
          values.hotelName = addHotelInfo.hotelName1;
        }
        if (companyTypeValue === '0') {
          if (!addHotelInfo.hotelId2) {
            message.error('请选择公司');
            return;
          }
          values.hotelId = addHotelInfo.hotelId2;
          values.hotelName = addHotelInfo.hotelName2;
        }

        if (type === 'userAdd') {
          // 用户新增逻辑
          addUser(values)
            .then(res => {
              if (res.code === '000') {
                message.success('请配置酒店角色信息');
                // 去下一步
                this.toEdit(res.data.employeeId);
              }
            })
            .catch(error => {
              message.error('用户添加失败');
            });
        } else if (type === 'userEdit') {
          if (userRoleList.length === 0 && fromAdd) {
            message.error('请配置酒店与角色');
            return;
          }
          values.id = this.state.employeeId;
          if (!userInfoData.encryptedPwd) {
            //  values.status = 1;
          }

          // 处理：查询参数未输入时候undefined转成空字符串。
          Object.keys(values).forEach(key => {
            if (values[key] === undefined) values[key] = '';
          });
          // values = this.removeNull(values);

          editUser(values)
            .then(res => {
              if (res.code === '000') {
                message.success('保存成功');
                if (!userInfoData.encryptedPwd && userRoleList.length > 0) {
                  userSendMessage({ password: '', employeeId })
                    .then(result => {
                      this.toList();
                    })
                    .catch(error => {
                      message.error('发送短信失败');
                    });
                } else {
                  this.toList();
                }
              }
            })
            .catch(error => {
              message.error('用户修改失败');
            });
        }
      }
    });
  };

  removeNull = obj => {
    Object.keys(obj).forEach(
      key =>
        (obj[key] && typeof obj[key] === 'object' && this.removeNull(obj[key])) ||
        ((obj[key] === undefined || obj[key] === null || obj[key] === '') && delete obj[key])
    );
    return obj;
  };

  deleteUserRole = params => {
    let { accountId } = this.props.user;
    const { employeeId, userRoleList, pagination } = this.state;
    const index = userRoleList.findIndex(item => item.uuid === params.uuid);
    const _params = { pkId: params.value1.pkId, accountId };
    let { current } = pagination;
    // if (userRoleList.length === 1 && current === 1) {
    //   message.error('该酒店与角色配置是最后一条，禁止删除。');
    //   return;
    // }

    userDeleteRole(_params)
      .then(res => {
        if (res.code === '000') {
          message.success('删除成功');
          // this.getLowerRule({ id: employeeId });
          userRoleList.splice(index, 1);
          this.setState({
            userRoleList: [...userRoleList],
          });
        }
      })
      .catch(err => {
        message.error('用户删除失败');
      });
  };

  deleteUser = () => {
    let { employeeId } = this.state;
    let { accountId } = this.props.user;

    deleteUser({ employeeId, accountId })
      .then(() => {
        message.success('用户删除成功');
        this.back();
      })
      .catch(er => {
        console.log(er);
      });
  };

  getLowerRule = param => {
    let { userRoleList } = this.state;
    let update = param;
    getLowerRule(update)
      .then(res => {
        // TODO 未完待续

        if (res.data && res.data.length > 0) {
          let list = res.data;
          userRoleList[param.index].value2.list = list;
          this.setState({ userRoleList: [...userRoleList] });
        }
      })
      .catch(error => {});
  };

  emailTypeChange = ev => {
    this.setState({ defaultEmailType: ev });
  };

  handlePageChange = ({ current, pageSize }) => {
    let { employeeId } = this.state;
    this.getHotelRolePageList({
      pageNum: current,
      pageSize,
      id: employeeId,
    });
  };

  back = () => {
    router.go(-1);
  };

  toList = () => {
    router.push({
      pathname: `/permission/user`,
      query: {},
    });
  };

  toEdit = id => {
    router.replace({
      pathname: `/permission/user/userEdit`,
      query: { id, from: 'add' },
    });
  };

  toHotel = hotelId => {
    router.push({
      pathname: `/hotel/hotelCreateEdit/index`,
      query: { hotelId },
    });
  };

  hotelChange = (data, key) => {
    let { addHotelInfo } = this.state;
    const hotel_name = data.hotelName;
    const hotel_id = data.id;

    addHotelInfo[`hotelName${key}`] = hotel_name;
    addHotelInfo[`hotelId${key}`] = hotel_id;

    this.setState({ addHotelInfo: { ...addHotelInfo } }, () => {
      this.getPostRoleList();
    });
  };

  // motal显示
  showAddHotelsRoleModal = () => {
    this.setState({
      modalVisible: true,
    });
  };

  addHotelRole = ({ hotelName, status, roleName, roleId, hotelId, list, pkId }) => {
    let { userRoleList } = this.state;
    userRoleList.push({
      value1: { hotelName, roleName, status, roleId, hotelId, pkId, list },
      value2: { hotelName, roleName, status, roleId, hotelId, pkId, list },
      index: userRoleList.length,
      uuid: getUUID(),
      type: 'query',
    });
    this.setState({
      modalVisible: false,
      userRoleList: [...userRoleList],
    });
  };

  userStatusExtraChange = ev => {
    let { userInfoData } = this.state;
    userInfoData.status = ev.target.value;
    this.setState({ userInfoData });
  };

  userCompanyTypeChange = ev => {
    let roleData = {};
    let { userInfoData } = this.state;
    const companyTypeValue = ev.target.value.toString();
    this.setState({ roleData, companyTypeValue }, () => {
      this.getPostRoleList();
    });
  };

  // 去编辑状态 有酒店则请求
  toEditStatus = item => {
    let { userRoleList, accountId } = this.state;
    let index = userRoleList.findIndex(el => el.uuid === item.uuid);
    let { hotelId, pkId } = userRoleList[index].value2;
    userRoleList[index].type = 'edit';
    this.setState({
      userRoleList: [...userRoleList],
    });
    // 请求角色
    if (userRoleList[index].value2.hotelId && userRoleList[index].value2.list.length === 0) {
      this.getLowerRule({ accountId, hotelId, pkId, index });
    }
  };

  handleModalCancel = () => {
    this.setState({
      modalVisible: false,
    });
  };

  // 去查看状态
  toQueryStatus = item => {
    let { userRoleList } = this.state;
    let index = userRoleList.findIndex(el => el.uuid === item.uuid);
    userRoleList[index].type = 'query';
    this.setState({
      userRoleList: [...userRoleList],
    });
  };
  // 删除所有关联角色

  deleteEmployeeHotel = () => {
    let { accountId } = this.props.user;
    let { employeeId } = this.state;
    deleteEmployeeHotel({ accountId, employeeId })
      .then(() => {
        message.success('删除成功！');
        this.setState({
          userRoleList: [],
          pagination: defaultPagination,
        });
      })
      .catch(er => {});
  };

  // 头像相关操作
  handleCancel = () => {
    let { avatar } = this.state;
    avatar = {
      ...avatar,
      previewVisible: false,
    };

    this.setState({
      avatar,
    });
  };

  handlePreview = file => {
    console.log(file);
    let { avatar } = this.state;
    avatar = {
      ...avatar,
      previewImage: file.url || file.thumbUrl,
      previewVisible: true,
    };

    this.setState({
      avatar,
    });
  };

  handleRemove = () => {
    let { avatar, employeeId, imgPath, editVisible } = this.state;
    console.log('judgePermission', judgePermission('CRS5.2.9'));
    const isPermission = judgePermission('CRS5.2.9');

    if (editVisible) return false;

    if (!isPermission) {
      message.error('您没有删除头像的权限');
      return false;
    }

    const payload = {
      employeeId,
      imgPath,
    };
    deleteAvatar(payload)
      .then(res => {
        if (res.code === '000') {
          console.log(res);
          message.success('头像删除成功');
          this.setState({ imgPath: '' });
          avatar = {
            ...avatar,
            fileList: [],
          };

          this.setState({
            avatar,
          });
        }
      })
      .catch(err => {
        console.log(err);
        message.error('头像删除失败');
      });
  };

  handleChange = file => {
    console.log(111, file, isLt3M);
    let { avatar } = this.state;
    let { accountId } = this.props.user;

    const formData = new FormData();
    formData.append('files', file.file);
    formData.append('accountId', accountId);

    uploadAvatar({ formData })
      .then(res => {
        if (res.code === '000') {
          console.log(res);
          message.success('头像上传成功');
          this.setState({ imgPath: res.data });
          avatar = {
            ...avatar,
            fileList: [
              {
                uid: -1,
                name: 'xxx.png',
                status: 'done',
                url: res.data,
                thumbUrl: res.data,
              },
            ],
          };
          this.setState({
            avatar,
          });
        }
      })
      .catch(err => {
        console.log(err);
        message.error('头像上传失败');
      });
  };

  render() {
    const {
      form: { getFieldDecorator },
    } = this.props;
    const {
      saveText,
      roleType,
      type,
      userInfoData,
      loading,
      userRoleList,
      pagination,
      defaultEmailType,
      hotelRoleVisible,
      cascaderOptions,
      postRoleList,
      accountId,
      editVisible,
      companyTypeValue,
      companyType,
      addHotelInfo,
      modalVisible,
      employeeId,
      fromAdd,
      avatar: { previewVisible, previewImage, fileList },
    } = this.state;
    const { userInfo } = userInfoData;
    const FormItem = Form.Item;

    const formItemLayout = {
      labelCol: { span: 6 },
      wrapperCol: { span: 16 },
    };
    const formItemLayout2 = {
      labelCol: { span: 6 },
      wrapperCol: { span: 18 },
    };
    const formItemTextArea = {
      labelCol: { span: 4 },
      wrapperCol: { span: 18 },
    };
    const uploadButton = (
      <div>
        <Icon type="plus" />
      </div>
    );
    // pagination.total = userRoleList.length;
    const columns = [
      {
        title: '酒店名称',
        dataIndex: 'hotelId',
        key: 'hotelId',
        width: '50%',
        render: (hotelId, item) => {
          if (type === 'userInfo') {
            return (
              <>
                <Badge
                  onClick={() => {
                    this.toHotel(item.value1.hotelId);
                  }}
                  style={{ cursor: 'pointer' }}
                  status={item.value1.status === 0 ? 'success' : 'default'}
                  text={item.value1.hotelName}
                />
              </>
            );
          }
          return (
            <Row>
              <Col span={1}>
                <Badge status={item.value1.status === 0 ? 'success' : 'default'} />
              </Col>
              <Col span={20}>
                <HotelSearch
                  callback={value => this.hotelRoleChange(value, item)}
                  defaultValue={
                    item.type === 'query' ? item.value1.hotelName : item.value2.hotelName
                  }
                  params={{
                    accountId,
                    pkId: item.type === 'query' ? item.value1.pkId : item.value2.pkId,
                  }}
                  disabled={editVisible || item.type === 'query'}
                />
              </Col>
            </Row>
          );
        },
      },
      {
        title: '角色',
        dataIndex: 'roleId',
        key: 'roleId',
        width: '30%',
        render: (roleId, item) => (
          <Select
            value={item.type === 'query' ? item.value1.roleName : item.value2.roleName}
            onChange={(value, param) => this.userLowerRoleChange(value, param, item)}
            disabled={editVisible || item.type === 'query'}
          >
            {(item.type === 'query' ? item.value1 : item.value2).list.map((roleItem, key) => (
              <Option
                value={roleItem.roleName}
                id={roleItem.roleId}
                pkid={roleItem.pkId}
                key={`roleId-${key}`}
              >
                {roleItem.roleName}
              </Option>
            ))}
          </Select>
        ),
      },
      {
        title: '操作',
        dataIndex: 'pkId',
        key: 'pkId',
        width: '20%',
        render: (pkId, item) => {
          return (
            <span>
              {item.type === 'query' ? (
                <>
                  {this.state.type === 'userInfo' ? null : (
                    <>
                      {item.value1.editStatus === false ? (
                        <Button size="small" disabled style={{ marginRight: 20 }}>
                          编辑
                        </Button>
                      ) : (
                        <ButtonAuthorized
                          code="CRS5.2.1.6"
                          size="small"
                          style={{ marginRight: 20 }}
                          onClick={() => this.toEditStatus(item)}
                        >
                          编辑
                        </ButtonAuthorized>
                      )}

                      {item.value1.editStatus === false ? (
                        <Button size="small" disabled>
                          删除
                        </Button>
                      ) : (
                        <Popconfirm
                          title="确定删除？"
                          disabled={editVisible || !judgePermission('CRS5.2.1.7')}
                          onConfirm={() => {
                            this.deleteUserRole(item);
                          }}
                          icon={<Icon type="question-circle-o" style={{ color: 'red' }} />}
                        >
                          <ButtonAuthorized code="CRS5.2.1.7" size="small">
                            删除
                          </ButtonAuthorized>
                        </Popconfirm>
                      )}
                    </>
                  )}
                </>
              ) : (
                <>
                  <Button
                    size="small"
                    style={{ marginRight: 20 }}
                    onClick={() => this.handleUserEdit(item)}
                  >
                    保存
                  </Button>
                  <Button
                    size="small"
                    disabled={editVisible}
                    onClick={() => this.toQueryStatus(item)}
                  >
                    取消
                  </Button>
                </>
              )}
            </span>
          );
        },
      },
    ];

    const selectAfter = (
      <Select
        value={defaultEmailType}
        style={{ width: 150 }}
        onChange={this.emailTypeChange}
        disabled={editVisible}
      >
        <Option value="@oyohotels.cn">@oyohotels.cn</Option>
        <Option value="@oyorooms.com">@oyorooms.com</Option>
      </Select>
    );

    const userStatusExtra = (
      <FormItem label="" labelCol={{ span: 10 }} wrapperCol={{ span: 14 }}>
        {getFieldDecorator('status', {
          initialValue: userInfoData.status === null ? '' : userInfoData.status.toString(),
        })(
          <Radio.Group
            onChange={this.userStatusExtraChange}
            disabled={editVisible || !judgePermission('CRS5.2.1.1')}
            style={{ width: 120 }}
          >
            <Radio.Button value="1">有效</Radio.Button>
            <Radio.Button value="0">无效</Radio.Button>
          </Radio.Group>
        )}
      </FormItem>
    );
    let companyTypeText = companyTypeValue === '1' ? '所属酒店' : '所属公司';
    const companyTypeTtitle = '公司信息';
    const userCompanyTypeExtra = (
      <div>
        <span style={{ marginRight: 20 }}>{companyTypeTtitle}</span>
        <Radio.Group
          value={companyTypeValue}
          onChange={this.userCompanyTypeChange}
          style={{ width: '225px' }}
          disabled={editVisible}
        >
          {companyType.map((item, index) => (
            <Radio.Button value={item.key} key={index}>
              {item.name}
            </Radio.Button>
          ))}
        </Radio.Group>
        {this.state.type === 'userInfo' ? null : (
          <ButtonAuthorized
            code="CRS5.2.1.8"
            onClick={() => this.changeState('componyInfoDisable', false)}
          >
            编辑
          </ButtonAuthorized>
        )}
      </div>
    );
    const positionChild = postRoleList.map((item, key) => (
      <Option value={item} key={`userRole-${key}`}>
        {item}
      </Option>
    ));

    console.log('fileList', fileList);

    return (
      <PageHeaderWrapper title="">
        <Form layout="horizontal">
          <Card
            // title="用户个人信息"
            title={
              <>
                {' '}
                <span>用户个人信息</span>
                {employeeId ? (
                  <span style={{ color: '#aaa', marginLeft: 20 }}>{`id:${employeeId}`}</span>
                ) : null}{' '}
                {this.state.type === 'userInfo' ? null : (
                  <ButtonAuthorized
                    code="CRS5.2.1.9"
                    onClick={() => this.changeState('userInfoDisable', false)}
                  >
                    编辑
                  </ButtonAuthorized>
                )}
              </>
            }
            className={styles.permissionUser}
            style={{ marginBottom: '24px' }}
            bordered={false}
            extra={userStatusExtra}
          >
            <Row gutter={16} type="flex">
              <Col lg={8} md={12} sm={24}>
                <FormItem label="姓名" {...formItemLayout}>
                  {getFieldDecorator('name', {
                    rules: RULES.chinaName,
                    initialValue: userInfoData.name,
                  })(<Input placeholder="请输入姓名" disabled={this.state.userInfoDisable} />)}
                </FormItem>
              </Col>
              <Col lg={8} md={12} sm={24}>
                <FormItem label="手机号" {...formItemLayout}>
                  {getFieldDecorator('phone', {
                    rules: RULES.phone,
                    initialValue: userInfoData.phone,
                  })(<Input placeholder="请输入手机号" disabled={this.state.userInfoDisable} />)}
                </FormItem>
              </Col>
              <Col lg={8} md={12} sm={24}>
                <FormItem label="邮箱" {...formItemLayout}>
                  {getFieldDecorator('email', {
                    initialValue: userInfoData.email,
                  })(
                    <Input
                      placeholder="请输入邮箱"
                      addonAfter={selectAfter}
                      style={{ width: 275 }}
                      disabled={editVisible || fromAdd}
                    />
                  )}
                </FormItem>
              </Col>
            </Row>
            <Row gutter={16}>
              <Col lg={8} md={12} sm={24}>
                <FormItem label="身份证号" {...formItemLayout}>
                  {getFieldDecorator('cardId', {
                    initialValue: userInfoData.cardId ? userInfoData.cardId : '',
                  })(<Input placeholder="请输入身份证号" disabled={this.state.userInfoDisable} />)}
                </FormItem>
              </Col>
              <Col lg={8} md={12} sm={24}>
                <FormItem label="开户行" {...formItemLayout}>
                  {getFieldDecorator('bankName', {
                    initialValue: userInfoData.bankName,
                  })(<Input placeholder="请输入开户行" disabled={this.state.userInfoDisable} />)}
                </FormItem>
              </Col>
              <Col lg={8} md={12} sm={24}>
                <FormItem label="银行卡号" {...formItemLayout}>
                  {getFieldDecorator('bankId', {
                    initialValue: userInfoData.bankId ? userInfoData.bankId : '',
                  })(<Input placeholder="请输入银行卡号" disabled={this.state.userInfoDisable} />)}
                </FormItem>
              </Col>
              <Col lg={8} md={12} sm={24}>
                <FormItem label="头像" {...formItemLayout}>
                  <div>
                    {/* <ButtonAuthorized code="CRS5.2.9"> */}
                    <Upload
                      accept="image/png,image/jpeg"
                      listType="picture-card"
                      fileList={fileList}
                      beforeUpload={handleBeforeUpload}
                      onPreview={this.handlePreview}
                      onRemove={this.handleRemove}
                      customRequest={this.handleChange}
                      disabled={editVisible || !judgePermission('CRS5.2.9')}
                    >
                      {fileList.length >= 1 ? null : uploadButton}
                    </Upload>
                    <Modal visible={previewVisible} footer={null} onCancel={this.handleCancel}>
                      <img
                        alt="avatar"
                        style={{ width: '100%', marginTop: 30 }}
                        src={previewImage}
                      />
                    </Modal>
                    {/* </ButtonAuthorized> */}
                  </div>
                </FormItem>
              </Col>
              <Col lg={12} md={12} sm={24}>
                <FormItem label="简介" {...formItemTextArea}>
                  {getFieldDecorator('summary', {
                    initialValue: userInfoData.summary ? userInfoData.summary : '',
                  })(
                    <TextArea
                      placeholder="请输入简介"
                      rows={5}
                      maxLength={100}
                      disabled={this.state.userInfoDisable}
                    />
                  )}
                </FormItem>
              </Col>
            </Row>
          </Card>

          <Card
            title={userCompanyTypeExtra}
            className={styles.permissionUser}
            style={{ marginBottom: '24px' }}
            bordered={false}
          >
            <Row gutter={16}>
              {companyTypeValue === '1' ? ( // 酒店
                <Col md={12} sm={5} key="addHotelInfo1">
                  <FormItem label={companyTypeText} {...formItemLayout2}>
                    <HotelSearch
                      defaultValue={addHotelInfo.hotelName1}
                      callback={data => this.hotelChange(data, '1')}
                      disabled={this.state.componyInfoDisable}
                    />
                  </FormItem>
                </Col>
              ) : (
                <Col md={12} sm={5} key="addHotelInfo2">
                  <FormItem label={companyTypeText} {...formItemLayout2}>
                    <HotelSearch
                      defaultValue={addHotelInfo.hotelName2}
                      callback={data => this.hotelChange(data, '2')}
                      filters="遨游酒店信息技术"
                      disabled={this.state.componyInfoDisable}
                    />
                  </FormItem>
                </Col>
              )}

              {
                // filters="遨游" 公司与酒店共用的接口，过滤掉酒店只留公司
              }

              <Col md={12} sm={5}>
                <FormItem
                  label={`${companyTypeValue === '1' ? '酒店' : '公司'}岗位`}
                  {...formItemLayout2}
                >
                  {getFieldDecorator('position', {
                    initialValue: userInfoData.position,
                  })(
                    <Select
                      style={{ width: 200 }}
                      placeholder="选择一个职位"
                      disabled={this.state.componyInfoDisable}
                    >
                      {positionChild}
                    </Select>
                  )}
                </FormItem>
              </Col>
            </Row>

            <Row gutter={{ xs: 6, md: 8, xl: 48 }} style={{ display: 'none' }}>
              <Col md={12} sm={6}>
                <FormItem label="区域/城市群/城市" {...formItemLayout2}>
                  {getFieldDecorator('state_cityGroup_city', {
                    initialValue: [userInfoData.state, userInfoData.cityGroup, userInfoData.city],
                  })(
                    <Cascader
                      options={cascaderOptions}
                      placeholder="请选择区域城市群和城市"
                      disabled={editVisible || fromAdd}
                    />
                  )}
                </FormItem>
              </Col>
            </Row>
          </Card>

          <Card
            title="酒店和角色配置"
            className={[styles.permissionUser, hotelRoleVisible]}
            style={{ marginBottom: '24px', width: '100%' }}
            bordered={false}
          >
            <Row gutter={{ xs: 6, md: 8, lg: 24, xl: 48 }}>
              <Col>
                {this.state.type === 'userInfo' ? null : (
                  <>
                    <ButtonAuthorized
                      code="CRS5.2.1.4"
                      type="primary"
                      onClick={this.showAddHotelsRoleModal}
                    >
                      新增
                    </ButtonAuthorized>

                    <Popconfirm
                      title="确定全部删除？"
                      disabled={editVisible}
                      onConfirm={() => {
                        this.deleteEmployeeHotel();
                      }}
                      icon={<Icon type="question-circle-o" style={{ color: 'red' }} />}
                    >
                      {/* <ButtonAuthorized style={{ marginLeft: 10 }} myDisabled={editVisible} code='CRS5.2.1.3'> */}
                      <ButtonAuthorized
                        style={{ marginLeft: 10 }}
                        myDisabled={editVisible}
                        code="CRS5.2.1.3"
                      >
                        全部删除
                      </ButtonAuthorized>
                    </Popconfirm>
                  </>
                )}

                <Table
                  rowKey="uuid"
                  style={{ marginTop: 20, width: '100%' }}
                  loading={loading}
                  dataSource={userRoleList}
                  columns={columns}
                  pagination={pagination}
                  onChange={this.handlePageChange}
                />
              </Col>
            </Row>
          </Card>
          <div className={styles.middle}>
            <Button type="primary" htmlType="submit" onClick={this.handleOk} disabled={editVisible}>
              {saveText}
            </Button>
            <Button onClick={this.back} style={{ marginLeft: 20 }} disabled={editVisible}>
              取消
            </Button>
            {type === 'userEdit' ? (
              <Popconfirm
                title="确认删除该用户吗?"
                onConfirm={this.deleteUser}
                okText="删除"
                cancelText="取消"
              >
                <ButtonAuthorized type="primary" style={{ marginLeft: 20 }} code="CRS5.2.1.2">
                  删除
                </ButtonAuthorized>
              </Popconfirm>
            ) : null}
          </div>
        </Form>

        {/* 新增角色 */}
        {modalVisible ? (
          <NewHotelRoleModal
            handleModalCancel={this.handleModalCancel}
            modalVisible={modalVisible}
            callbackOk={this.addHotelRole}
            id={employeeId}
          />
        ) : null}
      </PageHeaderWrapper>
    );
  }
}
