import React, { PureComponent } from 'react';
import { connect } from 'dva';
import router from 'umi/router';
import { Row, Col, Card, Input, Button, Table, Form, Radio, Select, Cascader } from 'antd';
import PageHeaderWrapper from '@/components/PageHeaderWrapper';
import HotelSearch from '../components/HotelSearch2';
import styles from '../style.less';
import { PHONE } from '@/constant/reg';
import { RULES } from '@/utils/validateRule';
import {
  addUser,
  editUser,
  getUserDetail,
  userUpdateRole,
  userDeleteRole,
  getHotelRolePageList,
  getLowerRule,
  editUserRole,
  getSalesArea,
  getPostList,
  userAddRole,
  userSendMessage,
} from '../services';

const { Option } = Select;
const { InputGroup } = Input;
const FormItem = Form.Item;
const formItemLayout = {
  labelCol: { span: 6 },
  wrapperCol: { span: 16 },
};
const formItemLayout2 = {
  labelCol: { span: 6 },
  wrapperCol: { span: 18 },
};
@Form.create()
@connect()
export default class User extends PureComponent {
  constructor(props) {
    super(props);
    this.state = {
      companyType: [{ key: '0', name: '公司' }, { key: '1', name: '酒店' }],
      companyTypeValue: '1',
    };
  }

  componentWillMount() {
    let { addHotelInfo, editVisible, userInfoData, postRoleList, cascaderOptions } = this.props;
    this.setState({
      addHotelInfo,
      editVisible,
      userInfoData,
      postRoleList,
      cascaderOptions,
    });
  }

  getPostRoleList = () => {
    const { roleData } = this.state;
    getPostList(roleData)
      .then(res => {
        this.setState({ postRoleList: res.data, roleListFlag: true });
      })
      .catch(err => {});
  };

  hotelChange = (data, key) => {
    let { addHotelInfo } = this.state;
    const hotel_name = data.hotelName;
    const hotel_id = data.id;

    addHotelInfo[`hotelName${key}`] = hotel_name;
    addHotelInfo[`hotelId${key}`] = hotel_id;
    this.setState({ addHotelInfo: { ...addHotelInfo } }, () => {
      this.getPostRoleList();
    });
  };

  userCompanyTypeChange = ev => {
    let roleData = {};
    let { userInfoData } = this.state;
    const companyTypeValue = ev.target.value.toString();
    if (companyTypeValue === '1') {
      roleData = {
        company: 0,
        hotel: 1,
      };
    } else {
      roleData = {
        company: 1,
        hotel: 0,
      };
    }

    this.setState({ roleData, companyTypeValue });
    this.getPostRoleList({ roleData });
  };

  render() {
    const {
      form: { getFieldDecorator },
    } = this.props;
    let {
      companyType,
      companyTypeValue,
      editVisible,
      addHotelInfo,
      userInfoData,
      postRoleList,
      cascaderOptions,
    } = this.state;
    let companyTypeText = companyTypeValue === '1' ? '所属酒店' : '所属公司';

    const companyTypeTtitle = '公司信息';
    const userCompanyTypeExtra = (
      <div>
        <span style={{ marginRight: 20 }}>{companyTypeTtitle}</span>
        <Radio.Group
          defaultValue={companyTypeValue}
          onChange={this.userCompanyTypeChange}
          style={{ width: '225px' }}
          disabled={editVisible}
        >
          {companyType.map((item, index) => (
            <Radio.Button value={item.key}>{item.name}</Radio.Button>
          ))}
        </Radio.Group>
      </div>
    );
    const positionChild = postRoleList.map((item, key) => (
      <Option value={item} key={`userRole-${key}`}>
        {item}
      </Option>
    ));
    return (
      <Card
        title={userCompanyTypeExtra}
        className={styles.permissionUser}
        style={{ marginBottom: '24px' }}
        bordered={false}
      >
        <Row gutter={16}>
          {companyTypeValue === '1' ? ( // 酒店
            <Col md={12} sm={5} key="addHotelInfo1">
              <FormItem label={companyTypeText} {...formItemLayout2}>
                <HotelSearch
                  defaultValue={addHotelInfo.hotelName1}
                  callback={data => this.hotelChange(data, '1')}
                  disabled={editVisible}
                />
              </FormItem>
            </Col>
          ) : (
            <Col md={12} sm={5} key="addHotelInfo2">
              <FormItem label={companyTypeText} {...formItemLayout2}>
                <HotelSearch
                  defaultValue={addHotelInfo.hotelName2}
                  callback={data => this.hotelChange(data, '2')}
                  filters="遨游酒店信息技术"
                  disabled={editVisible}
                />
              </FormItem>
            </Col>
          )}

          {
            // filters="遨游" 公司与酒店共用的接口，过滤掉酒店只留公司
          }

          <Col md={12} sm={5}>
            <FormItem label="岗位" {...formItemLayout2}>
              {getFieldDecorator('position', {
                initialValue: userInfoData.position,
              })(
                <Select style={{ width: 200 }} placeholder="选择一个职位" disabled={editVisible}>
                  {positionChild}
                </Select>
              )}
            </FormItem>
          </Col>
        </Row>

        <Row gutter={{ xs: 6, md: 8, xl: 48 }} style={{ display: 'none' }}>
          <Col md={12} sm={6}>
            <FormItem label="区域/城市群/城市" {...formItemLayout2}>
              {getFieldDecorator('state_cityGroup_city', {
                initialValue: [userInfoData.state, userInfoData.cityGroup, userInfoData.city],
              })(
                <Cascader
                  options={cascaderOptions}
                  placeholder="请选择区域城市群和城市"
                  disabled={editVisible}
                />
              )}
            </FormItem>
          </Col>
        </Row>
      </Card>
    );
  }
}
