import React, { PureComponent } from 'react';
import { connect } from 'dva';
import router from 'umi/router';
import { Row, Col, Card, Input, Button, Table } from 'antd';
import PageHeaderWrapper from '@/components/PageHeaderWrapper';
import UserInfo from './UserInfo';
import CompanyInfo from './CompanyInfo';

import styles from '../style.less';

import {
  addUser,
  editUser,
  getUserDetail,
  userUpdateRole,
  userDeleteRole,
  getHotelRolePageList,
  getLowerRule,
  editUserRole,
  getSalesArea,
  getPostList,
  userAddRole,
  userSendMessage,
} from '../services';

@connect(user => user)
export default class User extends PureComponent {
  constructor(props) {
    super(props);
    this.state = {
      infoFlag: false,
      salesAreaFlag: false,
      roleListFlag: false,
    };
  }

  componentDidMount() {
    const { dispatch, route, location, user, roleData } = this.props;
    const { name } = route;
    const { query } = location;
    // const { accountId } = user;
    const type = name;
    const employeeId = query.id;
    const editVisible = name === 'userInfo';
    this.setState({
      type,
      employeeId,
      editVisible,
      userRoleList: [],
    });
    dispatch({
      type: 'user/getInfo',
      payload: {},
    })
      .then(res => {
        this.setState({ accountId: res.accountId, userRoleAddData: { id: employeeId } });
        // this.getLowerRule({ accountId: res.accountId });
        if (employeeId) {
          this.getHotelRolePageList({ id: employeeId });
        }
      })
      .catch(err => {});

    this.getSalesArea();
    // this.getPostRoleList({ roleData });
    if (name === 'userEdit' || name === 'userInfo') {
      // 获取角色信息
      this.getUserDetail({ id: employeeId });
      this.setState({ hotelRoleVisible: styles.show, saveText: '保存' });
    }
  }

  getSalesArea = () => {
    getSalesArea()
      .then(res => {
        if (res.data && res.data.length > 0) {
          const cascaderOptions = this.convertTree(res.data);

          this.setState({ cascaderOptions });
        }
        this.setState({
          salesAreaFlag: true,
        });
      })
      .catch(err => {});
  };

  getPostRoleList = () => {
    const { roleData } = this.state;
    getPostList(roleData)
      .then(res => {
        this.setState({ postRoleList: res.data, roleListFlag: true });
      })
      .catch(err => {});
  };

  getUserDetail = params => {
    getUserDetail(params)
      .then(res => {
        let data = res.data;
        let defaultEmailType = '';
        if (!data.email) {
          data.email = '';
          defaultEmailType = '@oyohotels.cn';
        } else if (data.email.indexOf('@oyohotels.cn') >= 0) {
          data.email = data.email.replace('@oyohotels.cn', '');
          defaultEmailType = '@oyohotels.cn';
        } else if (data.email.indexOf('@oyorooms.com') >= 0) {
          data.email = data.email.replace('@oyorooms.com', '');
          defaultEmailType = '@oyorooms.com';
        }

        this.setState(
          {
            userInfoData: data,
            defaultEmailType,
            addHotelInfo: {
              hotelName1: data.hotelName,
              hotelId1: data.hotelId,
              hotelName2: data.hotelName,
              hotelId2: data.hotelId,
            },
          },
          () => {
            this.setState({
              infoFlag: true,
            });
          }
        );
      })
      .catch(err => {
        console.log(err);
      });
  };

  convertTree = tree => {
    const result = [];
    // 遍历 tree
    tree.forEach(item => {
      let children = [];
      if (item.hubBOList && item.hubBOList.length > 0) {
        children = item.hubBOList;
      } else if (item.cityBOList && item.cityBOList.length > 0) {
        children = item.cityBOList;
      }
      if (children) {
        children = this.convertTree(children);
      }

      result.push({
        value: item.name,
        label: item.name,
        children,
      });
    });
    return result;
  };

  render() {
    let {
      userInfoData,
      infoFlag,
      addHotelInfo,
      editVisible,
      postRoleList,
      cascaderOptions,
      roleListFlag,
      salesAreaFlag,
    } = this.state;
    return (
      <>
        {infoFlag ? <UserInfo userInfoData={userInfoData} editVisible={editVisible} /> : null}
        {infoFlag && roleListFlag && salesAreaFlag ? (
          <CompanyInfo
            addHotelInfo={addHotelInfo}
            userInfoData={userInfoData}
            editVisible={editVisible}
            postRoleList={postRoleList}
            cascaderOptions={cascaderOptions}
          />
        ) : null}
      </>
    );
  }
}
