import React, { PureComponent } from 'react';
import { connect } from 'dva';
import router from 'umi/router';
import { Row, Col, Card, Input, Button, Table, Form, Radio, Select } from 'antd';
import PageHeaderWrapper from '@/components/PageHeaderWrapper';
import styles from '../style.less';
import { PHONE } from '@/constant/reg';
import { RULES } from '@/utils/validateRule';

let defaultEmailType = '@oyohotels.cn';
const { Option } = Select;
const { InputGroup } = Input;
const FormItem = Form.Item;
const formItemLayout = {
  labelCol: { span: 6 },
  wrapperCol: { span: 16 },
};
const formItemLayout2 = {
  labelCol: { span: 6 },
  wrapperCol: { span: 18 },
};

@Form.create()
@connect()
export default class User extends PureComponent {
  constructor(props) {
    super(props);
    this.state = {};
  }

  componentWillMount() {
    let { userInfoData, editVisible } = this.props;
    this.setState({
      userInfoData,
      editVisible,
    });
  }

  userStatusExtraChange = ev => {
    let { userInfoData } = this.state;
    userInfoData.status = ev.target.value;
    this.setState({ userInfoData });
  };

  getAllValue = () => {
    let { status, name, phone, email, cardId, bankName, bankId } = this.state;
    return { status, name, phone, email, cardId, bankName, bankId };
  };

  emailTypeChange = ev => {
    defaultEmailType = ev;
  };

  render() {
    let { userInfoData, editVisible } = this.state;
    const {
      form: { getFieldDecorator },
    } = this.props;
    const userStatusExtra = (
      <FormItem label="" {...formItemLayout}>
        {getFieldDecorator('status', {
          initialValue: userInfoData.status === null ? '' : userInfoData.status.toString(),
        })(
          <Radio.Group
            onChange={this.userStatusExtraChange}
            disabled={editVisible}
            style={{ width: 120 }}
          >
            <Radio.Button value="1">有效</Radio.Button>
            <Radio.Button value="0">无效</Radio.Button>
          </Radio.Group>
        )}
      </FormItem>
    );
    const selectAfter = (
      <Select
        defaultValue={defaultEmailType}
        style={{ width: 150 }}
        onChange={this.emailTypeChange}
        disabled={editVisible}
      >
        <Option value="@oyohotels.cn">@oyohotels.cn</Option>
        <Option value="@oyorooms.com">@oyorooms.com</Option>
      </Select>
    );
    return (
      <Card
        title="用户个人信息"
        className={styles.permissionUser}
        style={{ marginBottom: '24px' }}
        bordered={false}
        extra={userStatusExtra}
      >
        <Row gutter={16} type="flex">
          <Col lg={8} md={12} sm={24}>
            <FormItem label="姓名" {...formItemLayout}>
              {getFieldDecorator('name', {
                rules: RULES.chinaName,
                initialValue: userInfoData.name,
              })(<Input placeholder="请输入姓名" disabled={editVisible} />)}
            </FormItem>
          </Col>
          <Col lg={8} md={12} sm={24}>
            <FormItem label="手机号" {...formItemLayout}>
              {getFieldDecorator('phone', {
                rules: RULES.phone,
                initialValue: userInfoData.phone,
              })(<Input placeholder="请输入手机号" disabled={editVisible} />)}
            </FormItem>
          </Col>
          <Col lg={8} md={12} sm={24}>
            <FormItem label="邮箱" {...formItemLayout}>
              {getFieldDecorator('email', {
                initialValue: userInfoData.email,
              })(
                <Input
                  placeholder="请输入邮箱"
                  addonAfter={selectAfter}
                  style={{ width: 275 }}
                  disabled={editVisible}
                />
              )}
            </FormItem>
          </Col>
        </Row>
        <Row gutter={16}>
          <Col lg={8} md={12} sm={24}>
            <FormItem label="身份证号" {...formItemLayout}>
              {getFieldDecorator('cardId', {
                initialValue: userInfoData.cardId ? userInfoData.cardId : '',
              })(<Input placeholder="请输入身份证号" disabled={editVisible} />)}
            </FormItem>
          </Col>
          <Col lg={8} md={12} sm={24}>
            <FormItem label="开户行" {...formItemLayout}>
              {getFieldDecorator('bankName', {
                initialValue: userInfoData.bankName,
              })(<Input placeholder="请输入开户行" disabled={editVisible} />)}
            </FormItem>
          </Col>
          <Col lg={8} md={12} sm={24}>
            <FormItem label="银行卡号" {...formItemLayout}>
              {getFieldDecorator('bankId', {
                initialValue: userInfoData.bankId ? userInfoData.bankId : '',
              })(<Input placeholder="请输入银行卡号" disabled={editVisible} />)}
            </FormItem>
          </Col>
        </Row>
      </Card>
    );
  }
}
