import React, { PureComponent } from 'react';
import { Select } from 'antd';
import _ from 'lodash';
import { authFetch, transAuthFetch } from '@/utils/fetch';
// import PropTypes from 'prop-types';

const Option = Select.Option;
const defaultUrl = `/api/crs/v1/hotel/group/getHotelName`;
export default class HotelSearch extends PureComponent {
  constructor(props) {
    super(props); // defaultValue //callback
    this.state = {
      value: '',
      data: [],
    };
  }

  componentWillMount() {
    this.setState({
      // value: this.props.defaultValue
      value: this.props.defaultValue ? this.props.defaultValue : '',
    });
  }

  componentWillReceiveProps(nextProps) {
    this.setState({
      // value: this.props.defaultValue
      value: nextProps.defaultValue ? nextProps.defaultValue : '',
    });
  }

  handleChange = data => {
    let _data = JSON.parse(data);
    this.setState({
      value: _data.hotelName,
    });
    this.props.callback && this.props.callback(_data);
  };

  handleSearch = data => {
    this.setState({
      value: data,
    });
    // this.props.callback&&this.props.callback(data);
    this.requestSearch();
  };

  // 酒店名字搜索(绑定debounce避免过多请求)
  requestSearch = _.debounce(async function(val = this.state.value) {
    try {
      const res = await this.suggestHotel({ hotelName: val });
      if (res.data) {
        this.setState({
          data: res.data,
        });
      }
    } catch (error) {
      // console.log(error);
    }
  }, 200);

  suggestHotel = params => {
    let { url = defaultUrl } = this.props;
    return transAuthFetch(url, {
      params,
      type: 5,
      method: 'GET',
    });
  };

  render() {
    const { data } = this.state;
    const { style } = this.props;
    return (
      <Select
        style={style}
        // mode="multiple"
        disabled={!!this.props.disabled}
        showSearch
        value={this.state.value ? this.state.value : undefined}
        placeholder="请输入酒店名称（模糊查询）"
        defaultActiveFirstOption={false}
        showArrow={false}
        filterOption={false}
        onSearch={this.handleSearch}
        onChange={this.handleChange}
        notFoundContent="无匹配结果"
      >
        {data.map(d => (
          <Option key={JSON.stringify(d)}>{d.hotelName}</Option>
        ))}
      </Select>
    );
  }
}
