import React, { PureComponent } from 'react';
import { Select, message } from 'antd';
import _ from 'lodash';
import { authFetch } from '@/utils/fetch';
import { getHotelNameByEmplyeeId, getHotelName } from '../services';
// import PropTypes from 'prop-types';

const Option = Select.Option;

export default class HotelSearch extends PureComponent {
  constructor(props) {
    super(props); // defaultValue //callback
    this.state = {
      value: null,
      accountId: '',
      pkId: '',
      data: [],
    };
  }

  componentWillMount() {
    const { value } = this.state;

    this.setState({
      value: this.props.defaultValue ? this.props.defaultValue : value,
      accountId: this.props.params ? this.props.params.accountId : '',
      pkId: this.props.params ? this.props.params.pkId : '',
    });
  }

  componentWillReceiveProps(nextProps) {
    const { value } = this.state;
    let params = nextProps.params || {};
    if (nextProps.defaultValue || params.accountId || params.pkId) {
      this.setState({
        value: nextProps.defaultValue,
        accountId: params.accountId,
        pkId: params.pkId,
      });
    }
  }

  handleChange = data => {
    let _data = JSON.parse(data);
    const { pkId } = this.state;
    if (pkId) {
      _data.pkId = pkId;
    }
    this.setState({
      value: _data.hotelName,
    });
    this.props.callback && this.props.callback(_data);
  };

  handleSearch = data => {
    this.setState({
      value: data || null,
    });
    // this.props.callback&&this.props.callback(data);
    if (!data) {
      return;
    }
    this.requestSearch();
  };

  // 酒店名字搜索(绑定debounce避免过多请求)
  requestSearch = _.debounce(async function(val = this.state.value) {
    const { filters } = this.props;
    const { accountId } = this.state;
    try {
      let postData = { hotelName: val };
      if (accountId !== '') {
        postData.accountId = accountId;
      }
      const result = await this.suggestHotel(postData);
      if (result && result.data) {
        this.setState({
          data: filters
            ? result.data.filter(item => item.hotelName.indexOf(filters) !== -1)
            : result.data,
        });
      }
    } catch (error) {
      console.log(error);
      // message.success('酒店数据异常');
    }
  }, 200);

  suggestHotel(params) {
    if (params.accountId) {
      return getHotelNameByEmplyeeId(params);
    }

    return getHotelName(params);
  }

  render() {
    const { data, value } = this.state;
    let { style } = this.props;
    return (
      <Select
        // mode="multiple"
        disabled={!!this.props.disabled}
        style={style}
        showSearch
        value={value || undefined}
        placeholder="请输入酒店名称（模糊查询）"
        onSearch={this.handleSearch}
        onChange={this.handleChange}
        notFoundContent="暂无数据"
      >
        {data.map(d => (
          <Option key={JSON.stringify(d)}>{d.hotelName}</Option>
        ))}
      </Select>
    );
  }
}
