import React, { PureComponent } from 'react';
import { Select, Switch, Checkbox, Row, Col, Card, Button, message, Form } from 'antd';
import _ from 'lodash';
import { authFetch, transAuthFetch } from '@/utils/fetch';
// import PropTypes from 'prop-types';
import { getPermissionList } from '../services';
import styles from './styles.less';
import { WORD } from '@/constant/reg';
import { formartTypeToUp, formartTypeToFe } from '@/utils/formartType';
import { keyList, keyAppList, mapNameToStatus, mapStatusToName } from '../constants';

const FormItem = Form.Item;
const APPLIST = [
  // { name: 'FLASH', status: [1] }, { name: 'OWNER', status: [1] }
];
const formItemLayout = {
  labelCol: { span: 2 },
  wrapperCol: { span: 12 },
};
// 交互逻辑： 注意点   点选后，有父级所有父级选上，  取消选择后所有子集都不选
function format(list) {
  let obj = {};
  let { permissionList } = this.state;
  function loop(_list) {
    _list.forEach(item => {
      if (!obj[item.code]) {
        item.isCheck = permissionList.some(ele => ele === item.code);
        let bl = WORD.test(item.code);
        item.level = item.code.length - 3;
        if (!bl && item.code.indexOf('.') === -1) {
          item.isActive = false;
        }
        obj[item.code] = item;
      }
      if (item.childPermission) {
        loop(item.childPermission);
      }
    });
  }
  loop(list);
  return obj;
}
const Option = Select.Option;

// 数据源
export default class HotelSearch extends PureComponent {
  constructor(props) {
    super(props); // defaultValue //callback
    this.state = {
      appList: APPLIST,
      crsStatus: '',
      otaStatus: '',
      pmsStatus: '',
      permissionList: [],
      type: '',
      activeCode: {
        fatherIndex: '',
        code: '',
        isAllCheck: false,
      },
      viewSource: [
        {
          name: 'CRS',
          tree: {},
          isActive: true,
        },
        {
          name: 'PMS',
          tree: {},
          isActive: true,
        },
      ],
      source: [
        {
          name: 'CRS',
          tree: [],
        },
        {
          name: 'PMS',
          tree: [],
        },
      ],
    };
  }
  /* eslint-disable*/
  componentDidMount() {
    const statusMap = {};
    Object.values(mapNameToStatus).forEach(item => {
      statusMap[item] = this.props.data[item];
    });
    this.getPermissionList();
    let { permissionList, type } = this.props.data;
    this.setState({ permissionList, type, ...statusMap });
  }
  /* eslint-disable*/
  handleChange = data => {};

  handleSearch = data => {};

  // 获取当前所有已经选code
  getAllCheckedPre = () => {
    let { viewSource, crsStatus, pmsStatus, appList, otaStatus } = this.state;
    const statusMap = {};
    let keysArray = Object.keys(mapNameToStatus);
    let permissionList = [];
    appList = appList.map(({ name, status }) => ({
      name,
      type: formartTypeToUp(status),
    }));
    viewSource.forEach(item => {
      [...Object.keys(item.tree)].forEach(ele => {
        if (item.tree[ele].isCheck) {
          permissionList.push(item.tree[ele].id);
        }
      });
    });
    Object.values(mapNameToStatus).forEach(item => {
      let value = viewSource.find(ITEM => ITEM.name === mapStatusToName[item]);
      statusMap[item] = value ? value.isActive : null;
    });
    return {
      permissionList,
      ...statusMap,
      appList,
    };
  };

  // 获取所有权限
  getPermissionList = () => {
    let { crsStatus, permissionList, pmsStatus, type, otaStatus } = this.state;

    getPermissionList()
      .then(res => {
        let { viewSource, source, appList } = this.state;
        let sourceArr = [];
        let viewArr = [];
        let { data } = res;
        [...Object.keys(data)].forEach(key => {
          if (keyList.indexOf(key) > -1) {
            let sourceObj = {};
            let viewObj = {};
            sourceObj.name = key;
            sourceObj.isActive = this.state[mapNameToStatus[key]];
            viewObj.name = key;
            viewObj.isActive = this.state[mapNameToStatus[key]];
            sourceObj.tree = data[key];
            viewObj.tree = format.call(this, data[key]);
            sourceArr.push(sourceObj);
            viewArr.push(viewObj);
          }
          if (keyAppList.indexOf(key) > -1) {
            // 值 由list 以及初始值确定
            let { appList: AppList } = this.props.data; // 初始值

            appList = data[key].map(({ name, status }) => {
              let index = AppList.findIndex(item => item.name === name);
              return {
                name,
                status: index > -1 ? formartTypeToFe(AppList[index].type, name === 'FLASH') : [],
              };
            });
          }
        });
        // 默认当前激活的一级菜单 默认第一个系统的 index 第一个一级菜单
        let activeCode = [...Object.keys(viewArr[0].tree)][1];
        viewArr[0].tree[activeCode].isActive = true;

        this.setState({
          appList,
          viewSource: viewArr,
          source: sourceArr,
          activeCode: {
            fatherIndex: 0,
            code: activeCode,
          },
        });
      })
      .catch(error => {
        //
      });
  };

  // 可登陆态切换
  onSystemChange = (value, index) => {
    let { viewSource } = this.state;
    // viewSource = JSON.parse(JSON.stringify(viewSource))
    viewSource[index].isActive = value ? 1 : 0;
    this.setState({
      viewSource: [...viewSource],
    });
    if (!value) {
      message.info(`请注意：该角色将无权限登陆${viewSource[index].name}系统`);
    } else {
      message.info(`请注意：该角色可登陆${viewSource[index].name}系统`);
    }
  };

  // 选中父
  checkParent = code => {
    let { checkParent } = this;
    let { viewSource } = this.state;
    let { activeCode } = this.state;
    let { fatherIndex } = activeCode;
    let obj = viewSource[fatherIndex].tree[code];
    if (obj.parentCode && obj.parentCode !== '0') {
      // 有父级
      let parentCode = obj.parentCode;
      viewSource[fatherIndex].tree[parentCode].isCheck = true;
      this.setState({
        viewSource: [...viewSource],
      });
      checkParent(parentCode);
    }
  };

  // 取消子的选中
  nocheckChildren = code => {
    // 取消子的选择
    let { nocheckChildren } = this;
    let { viewSource } = this.state;
    let { activeCode } = this.state;
    let { fatherIndex } = activeCode;
    let obj = viewSource[fatherIndex].tree[code];

    let loop = function(_code) {
      let _obj = viewSource[fatherIndex].tree[_code];
      _obj.childPermission.forEach(item => {
        viewSource[fatherIndex].tree[item.code].isCheck = false;
        // debugger
        this.setState({
          viewSource: [...viewSource],
        });
        if (item.childPermission) {
          loop(item.code);
        }
      });
    }.bind(this);
    if (obj.childPermission) {
      loop(code);
    }
  };

  // check的回调
  onCheckChange = (ev, fatherIndex, key) => {
    // debugger;
    let { checkParent, nocheckChildren } = this;
    let value = ev.target.checked;
    let { viewSource } = this.state;
    // viewSource = JSON.parse(JSON.stringify(viewSource));
    viewSource[fatherIndex].tree[key].isCheck = value;
    this.setState({
      viewSource: [...viewSource],
    });
    // 依赖activecode的变化
    setTimeout(() => {
      if (value) {
        // 选中  所有的父也要选中
        checkParent(key);
      } else {
        // 未选中 所有的子也要不选
        nocheckChildren(key);
      }
    }, 0);
  };

  // 下方系统切换
  activeCodeChange = (fatherIndex, code) => {
    let activeCode = this.state;
    if (activeCode.fatherIndex !== fatherIndex || activeCode.code !== code) {
      this.setState({
        activeCode: {
          fatherIndex,
          code,
        },
      });
    }
  };

  // 渲染左侧
  renderLeftSide = disabled => {
    let arr = [];
    let { viewSource, activeCode } = this.state;
    let { onSystemChange, onCheckChange, activeCodeChange } = this;

    let loop = (obj, fatherIndex) => {
      let list = [...Object.keys(obj)].filter(
        item => !WORD.test(obj[item].code) && obj[item].code.indexOf('.') === -1
      );
      let _arr = [];
      list.forEach((key, index) => {
        _arr.push(
          <li
            style={{
              height: '40px',
              lineHeight: '40px',
              paddingLeft: 20,
              overflow: 'hiden',
              paddingRight: 20,
            }}
            key={obj[key].code}
            className={key === activeCode.code ? styles.active : 'xx'}
            onClick={() => activeCodeChange(fatherIndex, key)}
          >
            <span style={{ float: 'left' }}>{obj[key].name}</span>
            <Checkbox
              disabled={disabled}
              style={{ float: 'right' }}
              checked={obj[key].isCheck}
              onChange={ev => {
                ev.stopPropagation;
                onCheckChange(ev, fatherIndex, key);
              }}
            />
          </li>
        );
      });
      return _arr;
    };

    viewSource.forEach((item, index) => {
      arr.push(
        <div key={item.name}>
          <Row style={{ fontSize: 20, fontWeight: 600, marginBottom: 10 }}>
            <Col span={12}>{item.name}</Col>
            <Col span={12}>
              <Switch
                disabled={disabled}
                onChange={ev => onSystemChange(ev, index)}
                checked={item.isActive === 1}
              />
            </Col>
          </Row>
          <ul>{loop(item.tree, index)}</ul>
        </div>
      );
    });
    return arr;
  };

  // 渲染按钮
  renderButtonList = (fatherIndex, code, disabled) => {
    let { onCheckChange } = this;
    let { activeCode, viewSource } = this.state;
    let list = viewSource[fatherIndex].tree[code].childPermission;
    if (list) {
      return list.map(item => {
        let obj = viewSource[fatherIndex].tree[item.code];
        if (obj.type === 'BUTTON') {
          return (
            <span style={{ marginRight: 15 }} key={obj.code}>
              <span style={{ marginRight: 5 }}>{obj.name}</span>
              <Checkbox
                disabled={disabled}
                checked={obj.isCheck}
                onChange={ev => {
                  onCheckChange(ev, fatherIndex, obj.code);
                }}
              />
            </span>
          );
        }
        return null;
      });
    }
    return null;
  };

  renderTree = disabled => {
    let { activeCode, viewSource } = this.state;
    let { fatherIndex, code } = activeCode;
    let { onCheckChange, renderButtonList } = this;
    let dom = null;
    if (!fatherIndex && !code) {
      return null;
    }
    let obj = viewSource[fatherIndex].tree[code];
    let list = obj && obj.childPermission ? obj.childPermission : [];
    function loop(_obj) {
      let _list = _obj && _obj.childPermission ? _obj.childPermission : [];
      return (
        <ul style={{ maxHeight: 600, overflow: 'hidden', overflowY: 'scroll' }}>
          {/* <li>{_obj.name}</li> */}
          {_list.length !== 0
            ? _list.map(item => (
                <li style={{ lineHeight: '50px' }} key={item.code}>
                  <Row
                    style={{
                      borderBottom: '1px solid #eee',
                      display: item.type === 'BUTTON' ? 'none' : 'block',
                    }}
                  >
                    <Col span={8} style={{ paddingLeft: item.code.split('.').length * 16 }}>
                      {item.name}
                    </Col>
                    <Col span={4}>
                      <Checkbox
                        disabled={disabled}
                        checked={viewSource[fatherIndex].tree[item.code].isCheck}
                        onChange={ev => {
                          onCheckChange(ev, fatherIndex, item.code);
                        }}
                      />
                    </Col>
                    <Col span={12}>{renderButtonList(fatherIndex, item.code, disabled)}</Col>
                  </Row>
                  {loop(item)}{' '}
                </li>
              ))
            : null}
        </ul>
      );
    }
    if (list.length === 0) {
      return <ul style={{ color: '#aaa' }}>无子菜单</ul>;
    }
    dom = loop(obj);

    return dom;
  };

  // 全选回调
  checkAll = () => {
    let { activeCode, viewSource } = this.state;
    let { fatherIndex, code } = activeCode;
    function loop(_code) {
      let obj = viewSource[fatherIndex].tree[_code];
      obj.isCheck = true;
      if (obj.childPermission) {
        obj.childPermission.forEach(item => {
          loop(item.code);
        });
      }
    }
    loop(code);
    this.setState({
      viewSource: [...viewSource],
    });
  };

  renderAppList = () => {
    let { appList } = this.state;
    return appList.map((item, index) => {
      console.log('item', item);
      return (
        <FormItem label={item.name} {...formItemLayout} key={index}>
          <Select
            mode="multiple"
            placeholder="请选择"
            value={item.status}
            onChange={ev => this.changeAppList(ev, index)}
            style={{ minWidth: 200 }}
          >
            {item.name === 'FLASH' ? null : <Option value={1}>前端</Option>}
            <Option value={2}>后端</Option>
          </Select>
        </FormItem>
      );
    });
  };

  changeAppList = (value, index) => {
    let { appList } = this.state;
    appList[index].status = value;
    this.setState({
      appList: [...appList],
    });
  };

  render() {
    const { data, viewSource, activeCode } = this.state;
    let { renderLeftSide, renderTree, checkAll, renderAppList } = this;
    let { fatherIndex, code } = activeCode;
    let disabled = this.state.type === 'roleQuery';

    return (
      <>
        <Row>
          <Col span={4} style={{ marginTop: 18 }}>
            {' '}
            {renderLeftSide(disabled)}
          </Col>
          <Col span={20}>
            <Card
              bordered={false}
              title={code ? viewSource[activeCode.fatherIndex].tree[activeCode.code].name : ''}
            >
              <Row
                style={{
                  background: 'rgba(250, 250, 250, 1)',
                  marginBottom: 10,
                  fontSize: 14,
                  borderBottom: '1px solid  #eee',
                }}
              >
                <Col span={8} style={{ height: '50px', lineHeight: '50px' }}>
                  <span style={{ paddingLeft: '20px' }}>页面树</span>
                </Col>
                <Col span={4} style={{ height: '50px', lineHeight: '50px' }}>
                  页面权限
                </Col>
                <Col span={12} style={{ height: '50px', lineHeight: '50px' }}>
                  <Row>
                    <Col span={18}>按钮权限</Col>
                    <Col span={6}>
                      <Button size="small" onClick={checkAll} disabled={disabled} type="primary">
                        全选
                      </Button>
                    </Col>
                  </Row>
                </Col>
              </Row>
              {renderTree(disabled)}
            </Card>
          </Col>
        </Row>
        <Row>
          <Card bordered={false} title="系统登陆权限:">
            {renderAppList()}
          </Card>
        </Row>
      </>
    );
  }
}
