import React, { PureComponent } from 'react';
import { connect } from 'dva';
import moment from 'moment';
import { Row, Col, Form, Input, Radio, Button, Checkbox, Select, Switch, message } from 'antd';
import PageHeaderWrapper from '@/components/PageHeaderWrapper';
import AllDayRoom from './AllDayRoom';
import HourRoom from './HourRoom';
import styles from './AddStrategy.less';

const RadioGroup = Radio.Group;
const CheckboxGroup = Checkbox.Group;
const Option = Select.Option;

/**
 * 价格策略类
 * url: /#/price/create (新增) || /#/price/create?rateCodeId=xxx (更新)
 * 功能: 进行价格策略的[新增] [暂存] [更新] 功能 , 提交表单时会对所有字段进行校验
 */

@connect(({ user, strategy, loading }) => ({
  user,
  strategy,
  loading: loading.models.price,
}))
class AddStrategy extends PureComponent {
  constructor() {
    super();

    this.state = {
      isSaveLoading: false, // 用于控制发送保存或者更新时按钮的loading动画 以及避免快速点击后多次请求
      pageType: null, // 页面类型 0: 新增 1: 更新
    };
  }

  render() {
    const { isSaveLoading, pageType } = this.state;
    const { strategy } = this.props;
    const { rateCodeName, description, status, checkinType } = strategy;

    return (
      <PageHeaderWrapper>
        <div className={styles.addStrategyPage}>
          <div className={styles.addStrategyHd}>
            <Row className="hdRow">
              <Col md={7} sm={7} className="hdRowInput">
                <p htmlFor="ref-rateCodeName">价格策略名称: </p>
                <Input
                  placeholder="请输入价格策略名称"
                  value={rateCodeName}
                  onChange={e => this.handlerInput(e, 'rateCodeName')}
                  id="ref-rateCodeName"
                />
              </Col>
              <Col md={7} sm={7} className="hdRowInput">
                <p htmlFor="ref-description">价格策略概述: </p>
                <Input
                  placeholder="请输入价格策略概述"
                  value={description}
                  onChange={e => this.handlerInput(e, 'description')}
                  id="ref-description"
                />
              </Col>
              <Col md={7} sm={7}>
                <div className={styles.hdRadio}>
                  <p>价格策略状态: </p>
                  <RadioGroup onChange={e => this.handlerInput(e, 'status')} value={status}>
                    <Radio value={1}>有效</Radio>
                    <Radio value={0}>无效</Radio>
                  </RadioGroup>
                </div>
              </Col>
            </Row>
          </div>
          <div className={`${styles.addStrategyStayType} strategyStayTypeWrapper`}>
            <p>选择入住类型: </p>
            <RadioGroup onChange={e => this.handlerCheckoutType(e)} value={checkinType}>
              {(() => {
                if (pageType === 0) {
                  return (
                    <>
                      <Radio value={1}>全天房</Radio>
                      <Radio value={2}>时租房</Radio>
                    </>
                  );
                }

                return checkinType === 1 ? (
                  <Radio value={1}>全天房</Radio>
                ) : (
                  <Radio value={2}>时租房</Radio>
                );
              })()}
            </RadioGroup>
          </div>

          {checkinType === 2 ? (
            <HourRoom
              ref={ref => {
                this.HourRoomComponent = ref;
              }}
            />
          ) : (
            <AllDayRoom
              ref={ref => {
                this.AllDayRoomComponent = ref;
              }}
            />
          )}

          <div className={styles.saves}>
            <div className={styles.savesWrapper}>
              <Button
                type="primary"
                onClick={() => {
                  this.save();
                }}
                loading={isSaveLoading}
              >
                保存
              </Button>
              {this.state.pageType === 0 ? (
                <Button onClick={() => this.store()}>暂存</Button>
              ) : null}
              <Button onClick={() => this.back()}>返回</Button>
            </div>
          </div>
        </div>
      </PageHeaderWrapper>
    );
  }

  componentDidMount() {
    this.initialPage();
  }

  // 初次加载时 对页面类型进行判断
  initialPage() {
    const { history, dispatch } = this.props;
    const params = history.location.query;

    // url参数中带rateCodeId为更新策略,不带的为新增策略
    if (params.rateCodeId) {
      // 请求获取需要更新的策略数据
      dispatch({
        type: 'strategy/fetch',
        payload: {
          rateCodeId: params.rateCodeId,
          errCb: () => {
            this.props.history.go(-1);
          },
        },
      });

      this.setState({
        id: params.rateCodeId,
        pageType: 1, // 1: 更新
      });
    } else {
      let oyoStrategy = sessionStorage.getItem('oyoStrategy'); // 新增策略时优先调用之前暂存的数据

      if (oyoStrategy) {
        oyoStrategy = JSON.parse(oyoStrategy);

        // 存在暂存数据时渲染该数据
        dispatch({
          type: 'strategy/store',
          payload: oyoStrategy,
        });
      }

      this.setState({
        pageType: 0, // 0: 新增
      });
    }
  }

  // 组件摧毁时清空数据 避免再次进入时留有上次的数据
  componentWillUnmount() {
    const { dispatch } = this.props;
    // 初始化数据
    dispatch({
      type: 'strategy/init',
    });
  }

  // 切换房型
  handlerCheckoutType(e) {
    let val = e.target.value;

    this.props.dispatch({
      type: 'strategy/checkinTypeInit',
      payload: {
        checkinType: val,
      },
    });
  }

  // 暂存
  store() {
    sessionStorage.setItem('oyoStrategy', JSON.stringify(this.props.strategy));
    message.success('暂存成功');
  }

  /**
   * 发送改变model层的值
   * @param  {Object} payload 需要改动model层的对应值{key: value}
   */
  dispatchChangeVal(payload) {
    this.props.dispatch({
      type: 'strategy/changeMainVal',
      payload,
    });
  }

  /**
   * 处理input的value值
   * @param  {[Objact, String]} val input传输的值
   * @param  {String} key 需要修改的key值
   * @param  {Boolean} 是否有右边的开关控制
   */
  handlerInput(val, key, relyOn) {
    // input类型为text时传的是event对象(event.target.value) 为select时传来直接的value值
    const valParam = val instanceof Object ? val.target.value : val;

    // 传值relyOn表示右边有switch 需打开的时候才能调整input值
    if (relyOn && !this.props.strategy[relyOn]) return message.error('请先开启该功能');

    this.dispatchChangeVal({
      [key]: valParam,
    });
  }

  /**
   * 格式化日期
   * @param  {String} time 时间为8位是为准确的年月日 大于8位为时间戳
   * @return {Number}      返回8位格式的年月日 数字类型
   */
  formatDate(time) {
    return `${time}`.length === 8 ? Number(time) : Number(moment(time).format('YYYYMMDD'));
  }

  /**
   * 保存功能
   * 会优先进行校验 然后按照页面是新增或者更新策略做不同的逻辑操作
   */
  save() {
    const { checkinType } = this.props.strategy;

    if (this.state.isSaveLoading) return; // 请求中直接弹走

    const strategy = this.props.strategy;
    // 进行字段校验
    const isCanUpdate = this.validate(strategy);

    if (!isCanUpdate.state) {
      // 进行input焦点报红处理
      if (isCanUpdate.input) {
        const errorInput = document.getElementById(`ref-${isCanUpdate.input}`);

        errorInput && errorInput.focus();
      }

      if (isCanUpdate.dom) {
        this.scroll(isCanUpdate.dom);
      }

      return message.error(isCanUpdate.msg);
    }

    const payload =
      checkinType === 1
        ? AllDayRoom.getSaveDate(strategy, this.formatDate)
        : HourRoom.getSaveDate(strategy, this.formatDate);

    payload.operatorId = this.props.user.accountId;

    this.requestSave(payload);
  }

  /**
   * 发送请求
   * @param  {Object}  payload 保存的参数 https://www.showdoc.cc./148767637991522?page_id=847868396421526
   */
  async requestSave(payload) {
    this.setState({
      isSaveLoading: true,
    });

    // 新增策略的页面
    if (this.state.pageType === 0) {
      payload.isCreate = true;

      const res = await this.props.dispatch({
        type: 'strategy/createRateCode',
        payload,
      });

      if (res.statue) {
        message.success('保存成功');
        this.props.history.push('/price/list');
        sessionStorage.removeItem('oyoStrategy');
      } else {
        message.error('保存失败');
        this.setState({
          isSaveLoading: false,
        });
      }
    } else {
      // 更新策略的页面
      payload.id = this.state.id;

      const res = await this.props.dispatch({
        type: 'strategy/update',
        payload,
      });

      if (res.statue) {
        message.success('更新成功');
        this.props.history.push('/price/list');
      } else {
        this.setState({
          isSaveLoading: false,
        });
        message.error('更新失败');
      }
    }
  }

  /**
   * 上传前所有字段的校验
   * @param  {Object} strategy model层的strategy内所有数据
   * @return {Boolean} state   最终校验的成果
   * @return {String}  msg     报错的内容
   * @return {String}  input   需要聚焦的input
   */
  validate(strategy) {
    if (!strategy.rateCodeName.length) {
      return {
        state: false,
        msg: '价格策略名称不能为空',
        input: 'rateCodeName',
      };
    }

    if (!strategy.description.length) {
      return {
        state: false,
        msg: '价格策略概述不能为空',
        input: 'description',
      };
    }

    // 按固定日期
    if (strategy.reservationDateRule.type === 1) {
      const { startDate, endDate } = strategy.reservationDateRule.regularDate;

      if (this.formatDate(startDate) > this.formatDate(endDate)) {
        this.scroll('reservationDateRuleWrapper');

        return {
          state: false,
          msg: '起始日期需比结束日期早',
        };
      }
    }

    // 全天房
    if (strategy.applyDateRule.type === 1) {
      const { startDate, endDate } = strategy.applyDateRule.regularDate;
      if (this.formatDate(startDate) > this.formatDate(endDate)) {
        this.scroll('applyDateRuleWrapper');

        return {
          state: false,
          msg: '起始日期需比结束日期早',
        };
      }
    }

    let PriceChangeValidate =
      strategy.checkinType === 1 ? AllDayRoom.validate(strategy) : HourRoom.validate(strategy);

    if (!PriceChangeValidate.state) return PriceChangeValidate;

    if (!strategy.guestSourceRule.guestSource.length) {
      return {
        state: false,
        msg: '可使用客源类型至少选择一个',
      };
    }

    if (strategy.isUseLeastReservation) {
      const leastReservationRule = strategy.leastReservationRule;
      const { continuousRoom, inAdvanceDay, continuousDay } = leastReservationRule;

      if (continuousRoom + inAdvanceDay + continuousDay === 0) {
        return {
          state: false,
          msg: '可使用起订规则有误',
          input: `leastReservation_${leastReservationRule.type}`,
        };
      }
    }

    if (strategy.inventoryRule.shareInventoryRate === null) {
      return {
        state: false,
        msg: '请填写共享正常库存',
        input: 'shareInventoryRate',
      };
    }

    return {
      state: true,
    };
  }

  // 返回上个页面
  back() {
    this.props.history.goBack();
  }

  /**
   * 滚动至参数节点的高度,用于做上传时大模块的焦点报错
   * @param  {String} className 需要焦点的模块吗
   */
  scroll(className) {
    const strategyStayTypeWrapper = document.querySelector(`.${className}`);
    const top = strategyStayTypeWrapper.offsetTop;

    document.documentElement.scrollTop = top;
    document.body.scrollTop = top;
  }
}

export default Form.create()(AddStrategy);
