import React, { PureComponent, Fragment } from 'react';
import { connect } from 'dva';
import { Row, Col, Card, Form, Input, Select, Button, Modal, message, Badge, Table } from 'antd';
import PageHeaderWrapper from '@/components/PageHeaderWrapper';
import ButtonAuthorized from '@/components/ButtonAuthorized';

import styles from './List.less';

const FormItem = Form.Item;
const { Option } = Select;
const getValue = obj =>
  Object.keys(obj)
    .map(key => obj[key])
    .join(',');

/* eslint react/no-multi-comp:0 */
@connect(({ global, price, loading }) => ({
  global,
  price,
  loading: loading.models.price,
}))
@Form.create()
export default class PriceStrategyList extends PureComponent {
  state = {
    formValues: { status: '', name: '' },
  };

  componentWillMount() {
    const { global } = this.props;

    const columns = [
      { title: '价格策略名称', dataIndex: 'rateCodeName', width: 150 },
      { title: '价格策略代码', dataIndex: 'rateCodeId', width: 150 },
      { title: '价格策略概述', dataIndex: 'rateCodeDescription', width: 150 },
      {
        title: '可用渠道',
        dataIndex: 'channel',
        // width: 300,
        render(channel) {
          const channleNameList = [];
          channel.forEach(item => {
            channleNameList.push(item.channelName);
          });
          return channleNameList && channleNameList.join(',');
        },
      },
      {
        title: '可用客源类型',
        dataIndex: 'guestSourceType',
        width: 130,
        render(val) {
          return global.GUEST_SOURCE_TYPE[val];
        },
      },
      {
        title: '价格策略状态',
        dataIndex: 'status',
        width: 135,
        // filters: [{ text: global.STATUS[0], value: 0 }, { text: global.STATUS[1], value: 1 }],
        render(val) {
          return <Badge status={global.STATUS_MAP[val]} text={global.STATUS[val]} />;
        },
      },
      {
        title: '操作',
        dataIndex: 'rateCodeId',
        width: 65,
        render: rateCodeId => (
          <ButtonAuthorized
            code="CRS4.1.2"
            size="small"
            onClick={() => this.props.history.push(`/price/create?rateCodeId=${rateCodeId}`)}
          >
            编辑
          </ButtonAuthorized>
        ),
      },
    ];
    this.setState({ columns });
  }

  componentDidMount() {
    const { price } = this.props;
    this.fetchPriceStrategyList(price.queryData.defaultParams);
  }

  // 请求：渠道列表
  fetchPriceStrategyList = params => {
    const { dispatch } = this.props;
    if (!params) return;
    dispatch({
      type: 'price/fetch',
      payload: params,
    }).then(response => {
      this.handleFetchMessage(response);
    });
  };

  // 处理数据请求的消息提示
  handleFetchMessage = response => {
    // if (response.code !== '000') return;
    // Message.success('数据加载成功' || response.msg);
  };

  // 表格分页pageSize和PageNum回调
  handlePageChange = (pagination, filtersArg) => {
    const { formValues } = this.state;

    // const filters = Object.keys(filtersArg).reduce((obj, key) => {
    //   const newObj = { ...obj };
    //   newObj[key] = getValue(filtersArg[key]);
    //   return newObj;
    // }, {});

    // 全选:‘1，2’;
    // filters.status =
    //   filters && filters.status && filters.status.indexOf(',') !== -1 ? '' : filters.status;

    const params = {
      pageNo: pagination.current,
      pageSize: pagination.pageSize,
      ...formValues,
      // ...filters,
    };
    this.fetchPriceStrategyList(params);
  };

  // 搜索重置功能
  handleFormReset = () => {
    const { form, price } = this.props;

    form.resetFields();
    const formValues = form.getFieldsValue();
    this.setState({ formValues });
    const params = price.queryData.defaultParams;
    this.fetchPriceStrategyList(params);
  };

  // 搜索功能
  handleFormSearch = e => {
    e.preventDefault();

    const { form } = this.props;

    form.validateFields((err, fieldsValue) => {
      const params = {
        name: fieldsValue.name,
        status: fieldsValue.status,
        pageNum: 1,
        pageSize: 10,
      };

      if (err) return;

      this.setState({
        formValues: { ...fieldsValue },
      });

      this.fetchPriceStrategyList(params);
    });
  };

  renderForm() {
    const {
      form: { getFieldDecorator },
      global,
    } = this.props;
    return (
      <Form onSubmit={this.handleFormSearch} layout="inline">
        <Row>
          <Col md={8} sm={24}>
            <FormItem label="价格策略名称">
              {getFieldDecorator('name', {
                initialValue: '',
              })(<Input placeholder="请输入价格策略名称" />)}
            </FormItem>
          </Col>
          <Col md={8} sm={24}>
            <FormItem label="价格策略状态">
              {getFieldDecorator('status', {
                initialValue: '',
              })(
                <Select placeholder="请选择价格策略状态" style={{ width: '100%' }}>
                  <Option value="">全部</Option>
                  {global.STATUS.map((status, key) => (
                    <Option key={`option-${key}`} value={key}>
                      {status}
                    </Option>
                  ))}
                </Select>
              )}
            </FormItem>
          </Col>
          <Col md={8} sm={24} style={{ textAlign: 'right' }}>
            <span className={styles.submitButtons}>
              <Button type="primary" htmlType="submit">
                查询
              </Button>
              <Button style={{ marginLeft: 20 }} onClick={this.handleFormReset}>
                重置
              </Button>
            </span>
          </Col>
        </Row>
      </Form>
    );
  }

  render() {
    const { price, loading } = this.props;

    return (
      <PageHeaderWrapper title="">
        <Card bordered={false}>
          <div className={styles.tableList}>
            <div className={styles.tableListForm}>{this.renderForm()}</div>
          </div>
        </Card>
        <Card bordered={false} style={{ marginTop: 15 }}>
          <ButtonAuthorized
            icon="plus"
            type="primary"
            code="CRS4.1.1"
            onClick={() => this.props.history.push('/price/create')}
          >
            新增价格策略
          </ButtonAuthorized>
          <Table
            loading={loading}
            bordered
            size="small"
            dataSource={price.queryData.list}
            columns={this.state.columns}
            style={{ marginTop: 20 }}
            pagination={{
              showSizeChanger: true,
              current: price.queryData.pageNum,
              pageSize: price.queryData.pageSize,
              total: price.queryData.totalCount,
            }}
            onChange={this.handlePageChange}
            onShowSizeChange={this.handlePageChange}
          />
        </Card>
      </PageHeaderWrapper>
    );
  }
}
