import React, { PureComponent } from 'react';
import { Radio, Button, Checkbox, Select, DatePicker, Input, message, Icon } from 'antd';
import moment from 'moment';
import { connect } from 'dva';
import MultiSelection from '@/components/MultiSelection/MultiSelection';
import { WEEK_LIST, transDefaultList, transWeeklyList } from '@/utils/dateFiliterWeekday';
import styles from './DateRules.less';
import 'moment/locale/zh-cn';

const RadioGroup = Radio.Group;
const Option = Select.Option;
const DayList = Array.from(new Array(31), (item, i) => i + 1);

@connect(({ strategy, loading }) => ({
  strategy,
  loading: loading.models.price,
}))
export default class DateRules extends PureComponent {
  render() {
    const { reservationDateRule, applyDateRule, applyDateRule2 } = this.props.strategy;
    const rulesList = [reservationDateRule, applyDateRule];

    return (
      <div className={styles.addStrategyRules}>
        {rulesList.map((item, blockIndex) => (
          <div className={`${styles.rulesBlock} ${item.name}Wrapper`} key={blockIndex}>
            <div className={(styles.rulesBlockHd, styles.blockHd)}>
              <p>
                {item.name === 'reservationDateRule'
                  ? '可预订日期时间规则: (活动日期)'
                  : '可使用日期时间规则: (入住时间)'}
              </p>
              <Checkbox
                onChange={e => this.onIsCanCustom(item.name, e)}
                checked={item.customizable}
              >
                允许酒店自定义
              </Checkbox>
            </div>
            <RadioGroup onChange={e => this.onType(item.name, e)} value={item.type}>
              <div className={styles.rulesBlockTimeType}>
                <Radio value={0}>长期</Radio>
              </div>
              <div className={styles.rulesBlockTimeType}>
                <Radio value={1}>按固定日期:</Radio>
                <DatePicker
                  disabled={item.type !== 1}
                  value={moment(item.regularDate.startDate, 'YYYY-MM-DD')}
                  onChange={(date, dateString) =>
                    this.onRegularDate(item.name, 'startDate', date, dateString)
                  }
                  ref={`${item.name}startDate`}
                />
                <DatePicker
                  disabled={item.type !== 1}
                  value={moment(item.regularDate.endDate, 'YYYY-MM-DD')}
                  onChange={(date, dateString) =>
                    this.onRegularDate(item.name, 'endDate', date, dateString)
                  }
                  ref={`${item.name}endDate`}
                />
              </div>
            </RadioGroup>
            <ul className={styles.rulesDetail}>
              <li>
                <Checkbox
                  checked={item.isUseWeekly}
                  onChange={() => this.onIsUse(item.name, 'isUseWeekly')}
                >
                  按每周:{' '}
                </Checkbox>
                <MultiSelection
                  value={transDefaultList(item.weekly)}
                  list={WEEK_LIST}
                  onChange={(list, listIndex) => this.onWeekList(item.name, listIndex)}
                />
              </li>
              <li>
                <Checkbox
                  checked={item.isUseExceptDate}
                  onChange={() => this.onIsUse(item.name, 'isUseExceptDate')}
                >
                  排除每月几号:{' '}
                </Checkbox>{' '}
                <ul className={styles.detailFilter}>
                  {item.exceptDate.map((filterDay, filterIndex) => (
                    <li key={filterDay}>
                      <Select
                        defaultValue={filterDay}
                        style={{ width: '64px', height: '28px' }}
                        onChange={val => this.onFilterList(item.name, filterIndex, val)}
                      >
                        {DayList.map(day => (
                          <Option value={day} key={day} disabled={item.exceptDate.includes(day)}>
                            {day}
                          </Option>
                        ))}
                      </Select>
                      <Button onClick={() => this.handlerDeleFilterDay(item.name, filterIndex)}>
                        删除
                      </Button>
                      {filterIndex === item.exceptDate.length - 1 ? (
                        <Button onClick={() => this.handlerAddFilterDay(item.name)}>增加</Button>
                      ) : null}
                    </li>
                  ))}
                </ul>
              </li>
              {item.name === 'reservationDateRule' ? (
                <li>
                  <Checkbox
                    checked={item.isUseTimeLimit}
                    onChange={() => this.onIsUse(item.name, 'isUseTimeLimit')}
                  >
                    限制时间段:
                  </Checkbox>
                  <ul className={styles.detailTimeRang}>
                    {item.timeLimitList.map((timeLimit, index) => (
                      <li key={index}>
                        <Input
                          id={`ref-${item.name}-${index}-startTime`}
                          placeholder="HHMMSS"
                          maxLength={6}
                          value={timeLimit.startTime}
                          onChange={e => this.onTimeLimitList(item.name, 'startTime', e, index)}
                        />
                        <Input
                          id={`ref-${item.name}-${index}-endTime`}
                          placeholder="HHMMSS"
                          maxLength={6}
                          value={timeLimit.endTime}
                          onChange={e => this.onTimeLimitList(item.name, 'endTime', e, index)}
                        />
                        {index === item.timeLimitList.length - 1 ? (
                          <div className={styles.timeRangContral}>
                            <Icon
                              type="plus-circle"
                              theme="outlined"
                              onClick={e => this.onAddLimitList(item.name)}
                            />
                            <Icon
                              type="minus-circle"
                              theme="outlined"
                              onClick={e => this.onMinusLimitList(item.name, index)}
                            />
                          </div>
                        ) : (
                          <div className={styles.timeRangContral}>
                            <Icon
                              type="minus-circle"
                              theme="outlined"
                              onClick={e => this.onMinusLimitList(item.name, index)}
                            />
                          </div>
                        )}
                      </li>
                    ))}
                  </ul>
                </li>
              ) : null}
            </ul>
          </div>
        ))}
      </div>
    );
  }

  // handleTimeDur(val) {
  //   this.dispatchDateRules('applyDateRule2', {
  //     hourCount: val,
  //   });
  // }

  // 发送改变props值的
  dispatchDateRules(blockName, payload) {
    this.props.dispatch({
      type: 'strategy/changeDateRulesVal',
      payload: {
        blockName,
        payload,
      },
    });
  }

  // 是否允许自定义
  onIsCanCustom(blockName, e) {
    const rulesBlock = this.props.strategy[blockName];

    this.dispatchDateRules(blockName, {
      customizable: rulesBlock.customizable ? 0 : 1, // 1变0 0变1
    });
  }

  // 长期还是固定日期
  onType(blockName, e) {
    const rulesBlock = this.props.strategy[blockName];

    this.dispatchDateRules(blockName, {
      type: Number(e.target.value),
    });
  }

  // 按固定日期的日期选择
  onRegularDate(blockName, type, date, dateString) {
    const rulesBlock = this.props.strategy[blockName];

    this.dispatchDateRules(blockName, {
      regularDate: {
        ...rulesBlock.regularDate,
        [type]: dateString.replace(/-/g, ''),
      },
    });
  }

  // 是否使用按每周 排除每月几号 限制时间段
  onIsUse(blockName, type) {
    const rulesBlock = this.props.strategy[blockName];

    this.dispatchDateRules(blockName, {
      [type]: !rulesBlock[type],
    });
  }

  // 按每周几
  onWeekList(blockName, listIndex) {
    const weekly = transWeeklyList(listIndex);

    this.dispatchDateRules(blockName, {
      weekly,
    });
  }

  // 选择排除每月几号
  onFilterList(blockName, filterIndex, val) {
    const rulesBlock = this.props.strategy[blockName];
    const exceptDate = rulesBlock.exceptDate.slice();

    exceptDate[filterIndex] = val;

    this.dispatchDateRules(blockName, {
      exceptDate,
    });
  }

  // 增加排除日期
  handlerAddFilterDay(blockName) {
    const rulesBlock = this.props.strategy[blockName];
    const exceptDate = rulesBlock.exceptDate.slice();
    let addDay = null;

    for (let i = 0; i < DayList.length; i++) {
      if (!exceptDate.includes(DayList[i])) {
        addDay = DayList[i];
        break;
      }
    }

    if (addDay !== null) {
      exceptDate.push(addDay);

      this.dispatchDateRules(blockName, {
        exceptDate,
      });
    } else {
      message.error('不能增加更多');
    }
  }

  // 删除排除日期
  handlerDeleFilterDay(blockName, filterIndex) {
    const rulesBlock = this.props.strategy[blockName];
    const exceptDate = rulesBlock.exceptDate.slice();

    if (exceptDate.length === 1) {
      message.error('至少保留一个');
      return false;
    }

    exceptDate.splice(filterIndex, 1);

    this.dispatchDateRules(blockName, {
      exceptDate,
    });
  }

  // // 限制时间段信息
  // onTimeLimit(blockName, type, e) {
  //   const rulesBlock = this.props.strategy[blockName];

  //   rulesBlock.timeLimit[type] = e.target.value;
  //   this.dispatchDateRules(blockName, {
  //     timeLimit: {
  //       ...rulesBlock.timeLimit,
  //       [type]: e.target.value,
  //     },
  //   });
  // }

  onTimeLimitList(blockName, type, e, index) {
    const rulesBlock = this.props.strategy[blockName];

    rulesBlock.timeLimitList[index][type] = e.target.value;

    this.dispatchDateRules(blockName, {
      timeLimitList: [...rulesBlock.timeLimitList],
    });
  }

  onAddLimitList(blockName) {
    const rulesBlock = this.props.strategy[blockName];

    rulesBlock.timeLimitList.push({
      startTime: '', // 开始日期
      endTime: '', // 结束日期
    });

    this.dispatchDateRules(blockName, {
      timeLimitList: [...rulesBlock.timeLimitList],
    });
  }

  onMinusLimitList(blockName, index) {
    const rulesBlock = this.props.strategy[blockName];

    if (rulesBlock.timeLimitList.length === 1) return;

    rulesBlock.timeLimitList.splice(index, 1);

    this.dispatchDateRules(blockName, {
      timeLimitList: [...rulesBlock.timeLimitList],
    });
  }
}
