import React, { PureComponent } from 'react';
import { connect } from 'dva';
import { Radio, Input, Checkbox, Switch, message } from 'antd';
import { checkFloatNumber } from '@/utils/validate';
import styles from './PriceChange.less';

const RadioGroup = Radio.Group;
const InputGroup = [
  {
    id: 0,
    label: '加价',
    unit: '元',
    text: '门市价+x元',
  },
  {
    id: 2,
    label: '提价',
    unit: '%',
    text: '门市价+门市价*x元',
  },
  {
    id: 1,
    label: '减价',
    unit: '元',
    text: '门市价+x元',
  },
  {
    id: 3,
    label: '折扣',
    unit: '%',
    text: '门市价+门市价*x元',
  },
];

@connect(({ strategy, loading }) => ({
  strategy,
  loading: loading.models.price,
}))
export default class PriceChange extends PureComponent {
  render() {
    const {
      type,
      customizable,
      stablePrice,
      dynamicPriceType,
      dynamicPriceValue,
      customizeRateType,
      rateCustomizable,
      rangeFrom,
      rangeTo,
      roundType,
    } = this.props.strategy.changePriceRule;
    const { isUseChangePrice } = this.props.strategy;

    return (
      <div className={`${styles.addStrategyPriceChange} priceChangeWrapper`}>
        <div className={(styles.priceChangeHd, styles.blockHd)}>
          <p>变价规则: </p>
          <Checkbox checked={customizable} onChange={e => this.onIsCanCustom(e)}>
            允许酒店自定义
          </Checkbox>
        </div>
        <RadioGroup
          onChange={e => this.onType(e)}
          value={isUseChangePrice ? type : null}
          className={styles.rulesDetail}
        >
          <div className={styles.priceRulesType}>
            <Radio value={0}>固定价</Radio>
            <div className={styles.priceRulesTypeInfo}>
              <Input
                id="ref-priceChangeStablePrice"
                value={isUseChangePrice && type === 0 ? stablePrice : null}
                onChange={e => this.onStablePrice(e)}
                onFocus={() => this.onType(0)}
              />
              <span>元</span>
            </div>
          </div>
          <div className={styles.priceRulesType}>
            <Radio value={1}>浮动价</Radio>
            <div className={(styles.priceRulesTypeInfo, styles.priceRulesFloat)}>
              <div className={styles.priceRulesTypeConfig}>
                <ul className={styles.configMain}>
                  <RadioGroup
                    onChange={e => this.onDynamicPriceType(e)}
                    value={type === 1 ? dynamicPriceType : null}
                  >
                    {InputGroup.map((item, index) => (
                      <li key={index}>
                        <Radio value={item.id}>{item.label}</Radio>
                        <Input
                          id={`ref-priceChangeDynamic-${item.id}`}
                          onFocus={() => this.onChangeFocus(item.id)}
                          value={
                            isUseChangePrice && type === 1 && dynamicPriceType === item.id
                              ? dynamicPriceValue
                              : null
                          }
                          onChange={e => this.onDynamicPriceValue(e)}
                        />
                        <span>{item.unit}</span>
                        <span className={styles.configMainText}>{item.text}</span>
                      </li>
                    ))}
                  </RadioGroup>
                </ul>
              </div>
              <Switch checked={isUseChangePrice} onChange={val => this.onIsUseChangePrice(val)} />
            </div>
          </div>
          <div className={styles.priceRulesType}>
            <Radio value={3}>基准价</Radio>
          </div>
        </RadioGroup>
        <div className={styles.customPrice}>
          <Checkbox
            onChange={e => this.isRateCustomizable(e)}
            checked={isUseChangePrice && rateCustomizable}
          >
            开启自定义价格
          </Checkbox>
          <RadioGroup
            onChange={e => this.onCustomizeRateType(e)}
            value={isUseChangePrice ? customizeRateType : null}
            className={styles.customPriceContainer}
          >
            <Radio value={0}>无限制</Radio>
            <div className={styles.customPriceRange}>
              <Radio value={1} />
              <p>区间值限制:</p>
              <Input
                value={rangeFrom}
                disabled={customizeRateType !== 1}
                id="ref-customPriceRange-f"
                placeholder="1"
                onChange={e => this.changeRange('rangeFrom', e)}
              />
              <span>-</span>
              <Input
                value={rangeTo}
                disabled={customizeRateType !== 1}
                id="ref-customPriceRange-t"
                placeholder="999"
                onChange={e => this.changeRange('rangeTo', e)}
              />
            </div>
          </RadioGroup>
        </div>
        <div className={styles.customPrice} style={{ paddingTop: 20 }}>
          <span style={{ paddingRight: 10 }}>价格尾数规则:</span>
          <RadioGroup
            onChange={e => this.onRoundTypeType(e)}
            value={isUseChangePrice ? roundType : null}
            className={styles.customPriceContainer}
          >
            <Radio value={0}>向上取整</Radio>
            <Radio value={1}>保留2位小数</Radio>
          </RadioGroup>
        </div>
      </div>
    );
  }

  // 发送改变props值的
  dispatchChangePriceChange(payload) {
    this.props.dispatch({
      type: 'strategy/changePriceChange',
      payload,
    });
  }

  // 开启自定义价格
  isRateCustomizable(e) {
    let val = e.target.checked;

    if (!this.props.strategy.isUseChangePrice) {
      return message.error('开关被关闭时不能修改');
    }

    let payload = {
      rateCustomizable: val,
    };

    let customizeRateType = this.props.strategy.changePriceRule.customizeRateType;

    if (val && (customizeRateType === null || customizeRateType === undefined)) {
      payload.customizeRateType = 0;
    }

    this.dispatchChangePriceChange(payload);
  }

  onRoundTypeType(e) {
    let val = e.target.value;

    if (!this.props.strategy.isUseChangePrice) {
      return message.error('开关被关闭时不能修改');
    }

    let payload = {
      roundType: val,
    };

    this.dispatchChangePriceChange(payload);
  }

  onCustomizeRateType(e) {
    let val = e.target.value;
    let payload = {
      customizeRateType: val,
    };

    if (!this.props.strategy.isUseChangePrice) {
      return message.error('开关被关闭时不能修改');
    }

    if (val === 0) {
      payload.rangeFrom = '';
      payload.rangeTo = '';
    }

    this.dispatchChangePriceChange(payload);
  }

  // 改变范围
  changeRange(key, e) {
    let val = e.target.value;

    if (!this.props.strategy.isUseChangePrice) {
      return message.error('开关被关闭时不能修改');
    }

    if (/\.\d{3}$/g.test(val) || Number.isNaN(Number(val))) return false;

    this.dispatchChangePriceChange({
      [key]: val,
    });
  }

  // 允许酒店自定义
  onIsCanCustom(e) {
    const { changePriceRule } = this.props.strategy;

    if (!this.props.strategy.isUseChangePrice) {
      return message.error('开关被关闭时不能修改');
    }

    this.dispatchChangePriceChange({
      customizable: changePriceRule.customizable ? 0 : 1,
    });
  }

  // 是否使用(右边的开关)
  onIsUseChangePrice(val) {
    this.props.dispatch({
      type: 'strategy/switchChangePriceChange',
      payload: {
        isUseChangePrice: val,
      },
    });
  }

  // 修改固定价格
  onStablePrice(e) {
    const { changePriceRule } = this.props.strategy;
    const val = e.target.value;

    if (!this.props.strategy.isUseChangePrice) {
      return message.error('开关被关闭时不能修改');
    }

    if (/\.\d{3}$/g.test(val) || Number.isNaN(Number(val))) return false;

    this.dispatchChangePriceChange({
      type: 0,
      stablePrice: val,
    });
  }

  // 修改浮动价格
  onDynamicPriceValue(e) {
    const { changePriceRule } = this.props.strategy;
    let val = e.target.value;

    if (!this.props.strategy.isUseChangePrice) {
      return message.error('开关被关闭时不能修改');
    }

    if (!checkFloatNumber(val)) return false;

    if ([2, 3].includes(changePriceRule.dynamicPriceType)) {
      if (Number(val) > 100) val = 100;
    }

    this.dispatchChangePriceChange({
      dynamicPriceValue: val,
    });
  }

  // 价格变化规则
  onType(val) {
    const { changePriceRule } = this.props.strategy;
    const data = {};

    if (!this.props.strategy.isUseChangePrice) {
      return message.error('开关被关闭时不能修改');
    }

    const numberVal = typeof val === 'number' ? val : Number(val.target.value);

    data.type = numberVal;

    if (numberVal === 0) {
      data.dynamicPriceType = 0;
      data.dynamicPriceValue = '';
    }

    if (numberVal === 1) {
      data.stablePrice = '';
    }

    if (numberVal === 2) {
      data.dynamicPriceType = 0;
      data.dynamicPriceValue = '';
      data.stablePrice = '';
    }

    this.dispatchChangePriceChange(data);
  }

  // 浮动价类型变化
  onDynamicPriceType(e) {
    const { changePriceRule } = this.props.strategy;

    if (!this.props.strategy.isUseChangePrice) {
      return message.error('开关被关闭时不能修改');
    }

    this.dispatchChangePriceChange({
      type: 1,
      dynamicPriceType: e.target.value,
      dynamicPriceValue: '',
    });
  }

  // 切换类型
  onChangeFocus(dynamicPriceType) {
    const { changePriceRule } = this.props.strategy;

    if (!this.props.strategy.isUseChangePrice) {
      return message.error('开关被关闭时不能修改');
    }

    if (changePriceRule.dynamicPriceType === dynamicPriceType && changePriceRule.type === 1) return;

    this.dispatchChangePriceChange({
      type: 1,
      stablePrice: '',
      dynamicPriceType,
      dynamicPriceValue: '',
    });
  }
}
