import React, { PureComponent } from 'react';
import { connect } from 'dva';
import { Checkbox, Select, Radio } from 'antd';
import styles from '../../AddStrategy.less';

const RadioGroup = Radio.Group;
const Option = Select.Option;

@connect(({ strategy, loading }) => ({
  strategy,
  loading: loading.models.price,
}))
export default class CancelRule extends PureComponent {
  render() {
    const strategy = this.props.strategy;
    let { cancelRule } = strategy;

    return (
      <div className={styles.container}>
        <div className={(styles.rulesBlockHd, styles.blockHd)}>
          <p>取消规则</p>
          <Checkbox onChange={this.onIsCanCustom} checked={cancelRule.customizable}>
            允许酒店自定义
          </Checkbox>
        </div>
        <div className={styles.containerBd}>
          <RadioGroup
            className={styles.reservationLt}
            onChange={this.handlerType}
            value={cancelRule.type}
          >
            <Radio value={2}>不可取消</Radio>
            <Radio value={1}>免费取消</Radio>
            <Radio value={3}>限时取消</Radio>
            <Select
              value={
                cancelRule.timeLimitCancelReasonType === 0
                  ? undefined
                  : cancelRule.timeLimitCancelReasonType
              }
              style={{ width: 280 }}
              disabled={cancelRule.type !== 3}
              onChange={this.handleCancelRuleReason}
            >
              <Option value={2}>入住日18点前可以免费取消</Option>
              <Option value={1}>入住日期前一天24点前可以免费取消</Option>
            </Select>
          </RadioGroup>
        </div>
      </div>
    );
  }

  onIsCanCustom = () => {
    this.props.dispatch({
      type: 'strategy/onIsCanCustom',
      payload: {
        key: 'cancelRule',
      },
    });
  };

  handlerType = e => {
    this.props.dispatch({
      type: 'strategy/changeMainVal',
      payload: {
        cancelRule: {
          ...this.props.strategy.cancelRule,
          type: Number(e.target.value),
        },
      },
    });
  };

  handleCancelRuleReason = val => {
    let { cancelRule } = this.props.strategy;

    let payload = {
      cancelRule: {
        // 取消规则
        type: 3, // 取消类型 1可取消 2不可取消
        customizable: cancelRule.customizable, // 是否可定制
        timeLimitCancelReasonType: val,
      },
    };

    this.props.dispatch({
      type: 'strategy/changeMainVal',
      payload,
    });
  };
}
