import React, { PureComponent } from 'react';
import { connect } from 'dva';
import { Checkbox } from 'antd';
import styles from '../../AddStrategy.less';

const CheckboxGroup = Checkbox.Group;
const GuestSource = ['非会员', '会员'];

@connect(({ strategy, loading }) => ({
  strategy,
  loading: loading.models.price,
}))
export default class GuestSourceRule extends PureComponent {
  render() {
    const strategy = this.props.strategy;
    let { guestSourceRule } = strategy;

    return (
      <div className={styles.container}>
        <div className={(styles.rulesBlockHd, styles.blockHd)}>
          <p>可使用客源类型规则</p>
          <Checkbox onChange={this.onIsCanCustom} checked={guestSourceRule.customizable}>
            允许酒店自定义
          </Checkbox>
        </div>
        <div className={styles.containerBd}>
          <Checkbox onChange={this.checkGuestAll} checked={guestSourceRule.guestSource.includes(0)}>
            全部
          </Checkbox>
          <CheckboxGroup
            options={GuestSource}
            value={guestSourceRule.guestSource.filter(i => i !== 0).map(i => GuestSource[i - 1])}
            onChange={val => this.onGuestSourceRule(val)}
          />
        </div>
      </div>
    );
  }

  onIsCanCustom = () => {
    this.props.dispatch({
      type: 'strategy/onIsCanCustom',
      payload: {
        key: 'guestSourceRule',
      },
    });
  };

  /**
   * 客源类型选择全部
   * @param  {[type]} e event对象
   * @return {[type]}   [description]
   */
  checkGuestAll = e => {
    const val = e.target.checked;
    let guestSource;

    if (val) {
      guestSource = [0].concat(GuestSource.map((item, i) => i + 1));
    } else {
      guestSource = [];
    }

    this.props.dispatch({
      type: 'strategy/changeMainVal',
      payload: {
        guestSourceRule: {
          ...this.props.strategy.guestSourceRule,
          guestSource,
        },
      },
    });
  };

  /**
   * 处理客源类型规则多选
   * @param  {String} val 全部 | 非会员 | 会员
   */
  onGuestSourceRule(val) {
    // 将string转为number的集合
    let guestSource = val.map(item => GuestSource.findIndex(i => i === item) + 1);

    guestSource.sort((a, b) => Number(a) - Number(b)); // 按从小到大排列

    // 有选择全部的情况
    if (guestSource.includes(1) && guestSource.includes(2))
      guestSource = [0].concat(GuestSource.map((item, i) => i + 1));

    this.props.dispatch({
      type: 'strategy/changeMainVal',
      payload: {
        guestSourceRule: {
          ...this.props.strategy.guestSourceRule,
          guestSource,
        },
      },
    });
  }
}
