import React, { PureComponent } from 'react';
import { connect } from 'dva';
import { Input, Radio } from 'antd';
import styles from '../../AddStrategy.less';

const RadioGroup = Radio.Group;

@connect(({ strategy, loading }) => ({
  strategy,
  loading: loading.models.price,
}))
export default class InventoryRule extends PureComponent {
  render() {
    const strategy = this.props.strategy;
    let { inventoryRule } = strategy;

    return (
      <div className={styles.container}>
        <div className={(styles.rulesBlockHd, styles.blockHd)}>
          <p>库存规则</p>
        </div>
        <div className={styles.containerBd}>
          <RadioGroup
            className={styles.inventoryRuleLt}
            onChange={this.handlerType}
            value={inventoryRule.type}
          >
            <Radio value={1}>共享正常库存</Radio>
            <Input
              id="ref-shareInventoryRate"
              value={inventoryRule.shareInventoryRate}
              onChange={this.setInventoryRule}
            />
            <span>%</span>
            <span className={styles.notice}>*最高占正常库存的_%</span>
          </RadioGroup>
        </div>
      </div>
    );
  }

  handlerType = e => {
    this.props.dispatch({
      type: 'strategy/changeMainVal',
      payload: {
        inventoryRule: {
          ...this.props.strategy.inventoryRule,
          type: Number(e.target.value),
        },
      },
    });
  };

  /**
   * 设置共享库存百分比
   * @param  {Object} e   event对象
   */
  setInventoryRule = e => {
    let val = e.target.value;
    const { strategy } = this.props;

    // 非数字或者有2个小数点都将被禁止输入
    if (/\./g.test(val) || Number.isNaN(Number(val))) return false;
    // 大于100则置为100
    if (Number(val) > 100) val = 100;

    this.props.dispatch({
      type: 'strategy/changeMainVal',
      payload: {
        inventoryRule: {
          ...strategy.inventoryRule,
          shareInventoryRate: Number(val),
        },
      },
    });
  };
}
