import React, { PureComponent } from 'react';
import { connect } from 'dva';
import { Checkbox, Switch, Input, Radio, message } from 'antd';
import styles from '../../AddStrategy.less';

const RadioGroup = Radio.Group;

@connect(({ strategy, loading }) => ({
  strategy,
  loading: loading.models.price,
}))
export default class LeastReservationRule extends PureComponent {
  render() {
    const strategy = this.props.strategy;
    let { leastReservationRule, isUseLeastReservation } = strategy;

    return (
      <div className={styles.container}>
        <div className={(styles.rulesBlockHd, styles.blockHd)}>
          <p>可使用起订规则</p>
          <Checkbox onChange={this.onIsCanCustom} checked={leastReservationRule.customizable}>
            允许酒店自定义
          </Checkbox>
        </div>
        <div className={(styles.containerBd, styles.leastReservation)}>
          <RadioGroup
            className={styles.reservationLt}
            onChange={e => this.handlerLeastReservationType(e)}
            value={leastReservationRule.type}
          >
            <div className={styles.leastReservationList}>
              <Radio value={1}>多间预定</Radio>
              <Input
                id="ref-leastReservation_1"
                value={leastReservationRule.continuousRoom}
                onFocus={() => this.handlerLeastReservationType(1)}
                onChange={e => this.handlerLeastReservation(e, 'continuousRoom')}
              />
              <span>间起</span>
            </div>
            <div className={styles.leastReservationList}>
              <Radio value={2}>连住预定:</Radio>
              <Input
                id="ref-leastReservation_2"
                onFocus={() => this.handlerLeastReservationType(2)}
                value={leastReservationRule.continuousDay}
                onChange={e => this.handlerLeastReservation(e, 'continuousDay')}
              />
              <span>天起</span>
            </div>
            <div className={styles.leastReservationList}>
              <Radio value={3}>提前预定:</Radio>
              <Input
                id="ref-leastReservation_3"
                onFocus={() => this.handlerLeastReservationType(3)}
                value={leastReservationRule.inAdvanceDay}
                onChange={e => this.handlerLeastReservation(e, 'inAdvanceDay')}
              />
              <span>天</span>
            </div>
          </RadioGroup>
          <Switch checked={isUseLeastReservation} onChange={this.switchLeastReservation} />
        </div>
      </div>
    );
  }

  onIsCanCustom = () => {
    this.props.dispatch({
      type: 'strategy/onIsCanCustom',
      payload: {
        key: 'leastReservationRule',
        relyOn: 'isUseLeastReservation',
      },
    });
  };

  /**
   * 处理可是用起定规则外层select [多间预定, 连住预定, 提前预定]
   * @param  {[Object, String]} val 可传event对象也可以直接传值 1 2 3
   */
  handlerLeastReservationType(val) {
    const valParam = val instanceof Object ? val.target.value : val;

    // switch没有打开时不得选择select
    if (!this.props.strategy.isUseLeastReservation) return message.error('请先开启功能');

    // 选择当前的类型
    if (valParam === this.props.strategy.leastReservationRule.type) return;

    // 选择之后重置所有房间数为0
    this.props.dispatch({
      type: 'strategy/changeMainVal',
      payload: {
        leastReservationRule: {
          customizable: this.props.strategy.leastReservationRule.customizable,
          continuousDay: 0,
          continuousRoom: 0,
          inAdvanceDay: 0,
          type: Number(valParam),
        },
      },
    });
  }

  /**
   * 处理可使用起订规则input值
   * @param  {Object} e   event对象
   * @param  {String} key 需要修改的key
   */
  handlerLeastReservation(e, key) {
    const valParam = e.target.value;

    // switch未被打开的情况下不得修改input值内容
    if (!this.props.strategy.isUseLeastReservation) return message.error('请先开启功能');

    // 只允许输入数字 不是数字则不让输入
    if (Number.isNaN(Number(valParam))) return false;

    // 修改对应值前现将所有值都重置为0
    const data = {
      customizable: this.props.strategy.leastReservationRule.customizable,
      type: this.props.strategy.leastReservationRule.type,
      continuousDay: 0,
      continuousRoom: 0,
      inAdvanceDay: 0,
      [key]: Number(valParam),
    };

    this.props.dispatch({
      type: 'strategy/changeMainVal',
      payload: {
        leastReservationRule: data,
      },
    });
  }

  /**
   * 操作可使用起定规则的开关,初始化所有数值为0
   * @param  {Boolean} boolean Switch组件传来的true或者false]
   */
  switchLeastReservation = boolean => {
    this.props.dispatch({
      type: 'strategy/changeMainVal',
      payload: {
        isUseLeastReservation: boolean,
        leastReservationRule: {
          customizable: this.props.strategy.leastReservationRule.customizable,
          continuousDay: 0,
          continuousRoom: 0,
          inAdvanceDay: 0,
          type: boolean ? 1 : null, // true打开的时候默认为select选择首个 false关闭的时候清空所有select
        },
      },
    });
  };
}
