import React, { PureComponent } from 'react';
import { connect } from 'dva';
import { Checkbox, Input } from 'antd';
import BlockSelect from '@/components/BlockSelect/index.tsx';
import { checkNumber } from '@/utils/validate';
import styles from '../../AddStrategy.less';

const CheckboxGroup = Checkbox.Group;

@connect(({ strategy, loading }) => ({
  strategy,
  loading: loading.models.price,
}))
export default class ChangeTimeRule extends PureComponent {
  render() {
    const strategy = this.props.strategy;
    let { changeTimeRule } = strategy;

    return (
      <div className={`${styles.container} ${styles.hourStyle} ${styles.changeTimeRule}`}>
        <div className={(styles.rulesBlockHd, styles.blockHd)}>
          <p>基础时长设置规则:</p>
        </div>
        <div className={styles.containerBd}>
          <div className={styles.hourRow}>
            <div className={styles.label}>初始设置：</div>
            <div className={styles.inputGroup}>
              <Input
                id="ref-changeTimeRuleStableTime"
                value={changeTimeRule.stableTime}
                onChange={e => this.handlerInputVal('stableTime', e)}
                maxLength={3}
              />
              <span>小时</span>
            </div>
          </div>
          <div className={styles.hourRow}>
            <Checkbox checked={!!changeTimeRule.customizable} onChange={this.handlerCustomizable}>
              允许自定义
            </Checkbox>
            <div className={styles.hourRow} style={{ paddingLeft: 20, paddingBottom: 0 }}>
              <span>区间值限制：</span>
              <Input
                id="ref-changeTimeRuleRangeFrom-f"
                value={changeTimeRule.rangeFrom}
                onChange={e => this.handlerInputVal('rangeFrom', e)}
                maxLength={3}
              />
              <span style={{ paddingRight: 8 }}>~</span>
              <Input
                id="ref-changeTimeRuleRangeFrom-t"
                value={changeTimeRule.rangeTo}
                onChange={e => this.handlerInputVal('rangeTo', e)}
                maxLength={3}
              />
              <span>小时</span>
            </div>
          </div>
        </div>
        <div className={(styles.rulesBlockHd, styles.blockHd)} style={{ paddingTop: 20 }}>
          <p>入住总时长限制规则:</p>
        </div>
        <div className={styles.containerBd}>
          <div className={styles.hourRow}>
            <div className={styles.label}>不超过：</div>
            <div className={styles.inputGroup}>
              <Input
                id="ref-changeTimeMaxTime"
                value={changeTimeRule.maxTime}
                onChange={e => this.handlerInputVal('maxTime', e)}
                maxLength={3}
              />
              <span>小时</span>
            </div>
          </div>
        </div>
      </div>
    );
  }

  // 发送改变props值的
  dispatchChangeTimeRule = payload => {
    this.props.dispatch({
      type: 'strategy/changeMainVal',
      payload: {
        changeTimeRule: {
          ...this.props.strategy.changeTimeRule,
          ...payload,
        },
      },
    });
  };

  handlerInputVal = (key, e) => {
    const val = e.target.value;

    if (!checkNumber(val) && val !== '') return false;

    this.dispatchChangeTimeRule({
      [key]: Number(val),
    });
  };

  handlerCustomizable = e => {
    const lastCustomizable = this.props.strategy.changeTimeRule.customizable;
    const customizable = lastCustomizable === 1 ? 0 : 1;
    const rateCustomizable = Boolean(customizable);

    this.dispatchChangeTimeRule({
      customizable,
      rateCustomizable,
    });
  };
}
