import React, { PureComponent } from 'react';
import { connect } from 'dva';
import { Checkbox, Radio, DatePicker } from 'antd';
import moment from 'moment';
import BlockSelect from '@/components/BlockSelect/index.tsx';
import styles from '../../AddStrategy.less';

const RadioGroup = Radio.Group;

@connect(({ strategy, loading }) => ({
  strategy,
  loading: loading.models.price,
}))
export default class DateRules extends PureComponent {
  render() {
    const { type } = this.props;
    const renderData = this.props.strategy[type];

    return (
      <div className={`${styles.container} ${styles.hourStyle}  ${renderData.name}Wrapper`}>
        <div className={(styles.rulesBlockHd, styles.blockHd)}>
          <p>
            {type === 'reservationDateRule'
              ? '可下单日期-时间区间规则：'
              : '可住日期-时间区间规则：'}
          </p>
          <Checkbox onChange={this.onIsCanCustom} checked={renderData.customizable}>
            允许酒店自定义
          </Checkbox>
        </div>
        <div className={styles.containerBd}>
          <div className={styles.hourRow}>
            <div className={styles.label}>日期区间：</div>
            <RadioGroup
              className={styles.radioGroup}
              onChange={this.onType}
              value={renderData.type}
            >
              <div className={styles.hourType}>
                <Radio value={0}>长期</Radio>
              </div>
              <div className={styles.hourType}>
                <Radio value={1}>按固定日期:</Radio>
                <DatePicker
                  className={styles.datePicker}
                  disabled={renderData.type !== 1}
                  value={moment(renderData.regularDate.startDate, 'YYYY-MM-DD')}
                  onChange={(date, dateString) => this.onRegularDate('startDate', dateString)}
                  style={{ marginRight: 10 }}
                  // ref={`${item.name}startDate`}
                />
                <DatePicker
                  className={styles.datePicker}
                  disabled={renderData.type !== 1}
                  value={moment(renderData.regularDate.endDate, 'YYYY-MM-DD')}
                  onChange={(date, dateString) => this.onRegularDate('endDate', dateString)}
                  // ref={`${item.name}endDate`}
                />
              </div>
            </RadioGroup>
          </div>
          <div className={styles.hourRow}>
            <div className={styles.label}>时间区间：</div>
            <div className={styles.timeLimite}>
              <BlockSelect onChange={this.handlerTimeRange} value={renderData.timeLimitList} />
            </div>
            {/* <RadioGroup
              className={styles.radioGroup}
              onChange={this.handlerIsUseTimeLimit}
              value={1}
              // value={Number(renderData.isUseTimeLimit)}
            >
              <div className={styles.hourType}>
                <Radio value={0}>24小时</Radio>
              </div>
              <div className={styles.hourType}>
                <Radio value={1}>限制时间段:</Radio>
                <BlockSelect onChange={this.handlerTimeRange} value={renderData.timeLimitList} />
              </div>
            </RadioGroup> */}
          </div>
        </div>
      </div>
    );
  }

  componentDidMount() {
    // setTimeout(() => {
    //   this.setState({
    //     timeLimitList: [
    //       { startTime: '000000', endTime: '80000' },
    //       { startTime: '120000', endTime: '200000' },
    //     ],
    //   });
    // }, 2000);
  }

  // 发送改变props值的
  dispatchDateRules = (type, payload) => {
    this.props.dispatch({
      type: 'strategy/changeDateRulesVal',
      payload: {
        blockName: type,
        payload,
      },
    });
  };

  onIsCanCustom = () => {
    const { type } = this.props;

    this.props.dispatch({
      type: 'strategy/onIsCanCustom',
      payload: {
        key: type,
      },
    });
  };

  onType = e => {
    const { type } = this.props;

    this.dispatchDateRules(type, {
      type: Number(e.target.value),
    });
  };

  handlerIsUseTimeLimit = e => {
    const { type } = this.props;

    this.dispatchDateRules(type, {
      isUseTimeLimit: !!e.target.value,
    });
  };

  onRegularDate = (timeType, dateString) => {
    const { type } = this.props;
    const rulesBlock = this.props.strategy[type];

    this.dispatchDateRules(type, {
      regularDate: {
        ...rulesBlock.regularDate,
        [timeType]: dateString.replace(/-/g, ''),
      },
    });
  };

  handlerTimeRange = (rangeList, timeLimitList) => {
    const { type } = this.props;
    const rulesBlock = this.props.strategy[type];

    this.dispatchDateRules(type, {
      timeLimitList,
    });
  };
}
