import React, { PureComponent } from 'react';
import { connect } from 'dva';
import { Checkbox, Input } from 'antd';
import moment from 'moment';
import { checkNumber, checkFloatNumber } from '@/utils/validate';
import styles from '../../AddStrategy.less';

// const RadioGroup = Radio.Group;

@connect(({ strategy, loading }) => ({
  strategy,
  loading: loading.models.price,
}))
export default class PriceChange extends PureComponent {
  render() {
    const { hourPriceChange } = this.props.strategy;

    return (
      <div className={`${styles.container} ${styles.hourStyle} ${styles.changeTimeRule}`}>
        <div className={(styles.rulesBlockHd, styles.blockHd)}>
          <p>基础价格设置规则:</p>
        </div>
        <div className={styles.containerBd}>
          <div className={styles.hourRow}>
            <div className={styles.label}>初始设置：</div>
            <div className={styles.inputGroup}>
              <Input
                id="ref-priceChangeStablePrice"
                value={hourPriceChange.stablePrice}
                onChange={e => this.handlerFloatInputVal('stablePrice', e)}
              />
              <span>元</span>
            </div>
          </div>
          <div className={styles.hourRow}>
            <Checkbox checked={!!hourPriceChange.customizable} onChange={this.handlerCustomizable}>
              允许自定义
            </Checkbox>
            <div className={styles.hourRow} style={{ paddingLeft: 20, paddingBottom: 0 }}>
              <span>区间值限制：</span>
              <Input
                id="ref-customPriceRange-f"
                value={hourPriceChange.rangeFrom}
                onChange={e => this.handlerInputVal('rangeFrom', e)}
              />
              <span style={{ paddingRight: 8 }}>~</span>
              <Input
                id="ref-customPriceRange-t"
                value={hourPriceChange.rangeTo}
                onChange={e => this.handlerInputVal('rangeTo', e)}
              />
              <span>元</span>
            </div>
          </div>
        </div>
      </div>
    );
  }

  // 发送改变props值的
  dispatchPriceChange = payload => {
    this.props.dispatch({
      type: 'strategy/changeMainVal',
      payload: {
        hourPriceChange: {
          ...this.props.strategy.hourPriceChange,
          ...payload,
        },
      },
    });
  };

  onIsCanCustom = () => {
    const { type } = this.props;

    this.props.dispatch({
      type: 'strategy/onIsCanCustom',
      payload: {
        key: type,
      },
    });
  };

  handlerFloatInputVal = (key, e) => {
    const val = e.target.value;

    if (!checkFloatNumber(val) && val !== '') return false;

    this.dispatchPriceChange({
      [key]: val,
    });
  };

  handlerInputVal = (key, e) => {
    const val = e.target.value;

    if (!checkNumber(val) && val !== '') return false;

    this.dispatchPriceChange({
      [key]: val,
    });
  };

  handlerCustomizable = e => {
    const lastCustomizable = this.props.strategy.hourPriceChange.customizable;
    const customizable = lastCustomizable === 1 ? 0 : 1;
    const rateCustomizable = Boolean(customizable);

    this.dispatchPriceChange({
      customizable,
      rateCustomizable,
    });
  };
}
