import { message } from 'antd';
import { getRateCodeDetail, createRateCode, update } from '../services/strategy';

// 默认变价规则数据
const DefaultChangePriceRule = {
  customizable: 0, // 是否可定制 0可定制 1不可定制
  type: 0, // 变价类型 0固定 1动态 2门市价
  dynamicPriceType: 0, // 0加价 1减价 2加价（百分比） 3打折
  stablePrice: '', // 固定价格
  dynamicPriceValue: '',
  rateCustomizable: true, // 是否开启自定义价
  customizeRateType: 0, // 自定义价格类型 0无限制 1范围
  rangeFrom: '', // 范围from
  rangeTo: '', // 范围to
  roundType: 0,
};

// 默认可使用起订规则数据
const DefaultLeastReservationRule = {
  type: 0, // 起订类型 1多间预订 2连住预定 3提前预定
  continuousRoom: 0, // 房间数
  continuousDay: 0, // 连住天数
  inAdvanceDay: 0, // 提前预定天数
  customizable: 0, // 是否可定制
};

const DefaultTimeLimit = {
  // 限制时间段信息
  startTime: '', // 开始日期
  endTime: '', // 结束日期
};

const GetDefaultApplyDateRule = () => ({
  name: 'applyDateRule',
  customizable: 0, // 是否可定制 0 不可 1 可制定
  type: 0, // 入住类型 '0'长期 '1'固定
  isUseWeekly: false, // 按每周
  isUseExceptDate: false, // 排除每月几号
  isUseTimeLimit: false, // 限制时间段
  regularDate: {
    // 固定日期
    startDate: new Date(), // 开始日期
    endDate: new Date(), // 结束日期
  },
  weekly: [], // 按每周：周信息 1,2,3,4,5,6,0（星期一到星期天)
  exceptDate: [1], // 排除每月几号，日期信息
  // timeLimit: {
  //   // 限制时间段信息
  //   startTime: '', // 开始日期
  //   endTime: '', // 结束日期
  // },
  timeLimitList: [
    {
      ...DefaultTimeLimit,
    },
  ].slice(),
});

// 总的默认数据
const DefaultData = {
  rateCodeId: 0, //	价格策略ID
  rateCodeName: '', // 价格策略名称
  description: '', // 价格策略概述
  status: 1, // 是否有效 0无效 1有效
  checkinType: 1, // 入住类型 2时租房 1全天房
  guestSourceRule: {
    // 客源类型规则
    guestSource: [1], // 客源类型数组 0全部 1非会员 2会员
    customizable: 0, // 是否可定制 0 不可定制 1可定制
  },
  reservationDateRule: {
    name: 'reservationDateRule',
    customizable: 0, // 是否可定制 0 不可 1 可制定
    type: 0, // 入住类型 '0'长期 '1'固定
    isUseWeekly: false, // 按每周
    isUseExceptDate: false, // 排除每月几号
    isUseTimeLimit: false, // 限制时间段
    regularDate: {
      // 固定日期
      startDate: new Date(), // 开始日期
      endDate: new Date(), // 结束日期
    },
    weekly: [], // 按每周：周信息 1,2,3,4,5,6,0（星期一到星期天)
    exceptDate: [1], // 排除每月几号，日期信息
    // timeLimit: {
    //   ...DefaultTimeLimit,
    // },
    timeLimitList: [
      {
        ...DefaultTimeLimit,
      },
    ].slice(), // 全体房是列表
  },
  applyDateRule: {
    ...GetDefaultApplyDateRule(),
  },
  isUseChangePrice: true, // 是否使用
  changePriceRule: {
    ...DefaultChangePriceRule,
  },
  isUseLeastReservation: false, // 是否使用起订规则
  leastReservationRule: {
    // 可使用起订规则
    ...DefaultLeastReservationRule,
  },
  payRule: {
    // 支付规则
    type: 0, // 1预付 0现付
    customizable: 0, // 是否可定制
  },
  cancelRule: {
    // 取消规则
    type: 2, // 取消类型 1可取消 2不可取消 3限时取消
    customizable: 0, // 是否可定制
    timeLimitCancelReasonType: 1, //  1入住日期前一天24点前可以免费取消 value={2}>入住前18点前可以免费取消
  },
  inventoryRule: {
    // 库存规则
    type: 1, // 共享库存规则 1共享正常库存
    shareInventoryRate: null, // 共享库存百分比
    customizable: 0, // 是否可定制
  },
  guaranteeRule: {
    type: 1, // 1无担保 2全天首晚担保 3全天全额担保
    customizable: 0, // 是否可定制
  },
  changeTimeRule: {
    // 钟点房特有
    stableTime: '', // int 基础时长 必填
    maxTime: '', // int 最高时长 必填
    rateCustomizable: false, // int 是否开启自定义价格 和 customizable 一致
    customizeRateType: 1, // int 是否允许自定义 0无限制 1范围  钟点肯定是1
    rangeFrom: '', // int 范围from
    rangeTo: '', // int 范围to
    customizable: 0, // 是否可定制
  },
  hourPriceChange: {
    type: 0, // 变价类型 0固定 1动态 2门市价
    dynamicPriceType: 0, // 0加价 1减价 2加价（百分比） 3打折
    rateCustomizable: false, // 是否开启自定义价 和 customizable 一致
    stablePrice: '', // 固定价格decimal
    rangeFrom: '', // int 范围from
    rangeTo: '', // int 范围to
    customizeRateType: 1, // int 是否允许自定义 0无限制 1范围  钟点肯定是1
    customizable: 0, // 是否可定制 0可定制 1不可定制
  },
};

export default {
  namespace: 'strategy',

  state: {
    ...DefaultData,
  },

  effects: {
    *createRateCode({ payload }, { call }) {
      try {
        const response = yield call(createRateCode, payload);

        return Promise.resolve({
          statue: true,
          ...response,
        });
      } catch (err) {
        return Promise.resolve({
          statue: false,
          ...err.response,
        });
      }
    },

    *update({ payload }, { call }) {
      try {
        const response = yield call(update, payload);

        return Promise.resolve({
          statue: true,
          ...response,
        });
      } catch (err) {
        return Promise.resolve({
          statue: false,
          ...err.response,
        });
      }
    },

    *fetch({ payload }, { call, put }) {
      try {
        const response = yield call(getRateCodeDetail, payload.rateCodeId);
        const hasOwnProperty = Object.prototype.hasOwnProperty;
        const res = response.data;

        const data = {
          status: res.status,
          id: res.id,
          rateCodeName: res.rateCodeName,
          checkinType: res.checkinType,
          description: res.description,
          ...res.rules,
        };

        if (data.checkinType === 2) {
          yield put({
            type: 'handlerHourRoomVal',
            payload: data,
          });
        } else if (data.checkinType === 1) {
          yield put({
            type: 'handlerAllDayRoomVal',
            payload: data,
          });
        } else {
          message.error('数据错误, 为历史遗留无效数据');

          payload.errCb && payload.errCb();
        }
      } catch (e) {
        return e.response;
      }
    },
  },

  reducers: {
    init() {
      return {
        ...JSON.parse(JSON.stringify(DefaultData)),
      };
    },

    checkinTypeInit(state, { payload }) {
      const data = {
        ...JSON.parse(JSON.stringify(DefaultData)),
      };

      data.checkinType = payload.checkinType;

      return {
        ...data,
        rateCodeName: state.rateCodeName, // 价格策略名称
        description: state.description, // 价格策略概述
      };
    },

    handlerAllDayRoomVal(state, { payload }) {
      let data = payload;

      if (data.guestSourceRule.guestSource.includes(0))
        data.guestSourceRule.guestSource = [0, 1, 2];

      // 添加名字循环时用到
      data.reservationDateRule.name = 'reservationDateRule';
      data.applyDateRule.name = 'applyDateRule';

      data.reservationDateRule.timeLimitList = data.reservationDateRule.timeLimitList || [
        { ...DefaultTimeLimit },
      ];

      // 如用户之前关闭changePriceRule的开关 后台将直接忽略这个字段
      if (hasOwnProperty.call(data, 'changePriceRule') && data.changePriceRule !== null) {
        data.isUseChangePrice = true; // 控制开关以及最终是否上传改该数据
        data.changePriceRule.roundType = data.changePriceRule.roundType || 0;
      } else {
        data.isUseChangePrice = false;
        data.changePriceRule = {
          // 之前没使用该配置的情况用默认值
          ...DefaultChangePriceRule,
        };
      }

      if (hasOwnProperty.call(data, 'leastReservationRule') && data.leastReservationRule !== null) {
        data.isUseLeastReservation = true;
      } else {
        data.isUseLeastReservation = false;
        data.leastReservationRule = {
          // 之前没使用该配置的情况用默认值
          ...DefaultLeastReservationRule,
        };
      }

      const rulesBlock = ['applyDateRule', 'reservationDateRule'];

      rulesBlock.forEach(key => {
        data[key].isUseWeekly = data[key].weekly && data[key].weekly.length !== 0;
        data[key].isUseExceptDate = data[key].exceptDate && data[key].exceptDate.length !== 0;
        data[key].weekly = data[key].isUseWeekly ? data[key].weekly : [];
        data[key].exceptDate = data[key].isUseExceptDate ? data[key].exceptDate : [1];

        if (key === 'reservationDateRule') {
          data.reservationDateRule.isUseTimeLimit =
            data[key].timeLimitList && !!data[key].timeLimitList[0].startTime;
        }

        if (!data[key].regularDate.startDate) {
          data[key].regularDate = {
            startDate: new Date(), // 开始日期
            endDate: new Date(), // 结束日期
          };
        }
      });

      return {
        ...state,
        ...data,
      };
    },

    handlerHourRoomVal(state, { payload }) {
      let data = payload;

      if (data.guestSourceRule.guestSource.includes(0))
        data.guestSourceRule.guestSource = [0, 1, 2];

      // 添加名字循环时用到
      data.reservationDateRule.name = 'reservationDateRule';
      data.applyDateRule.name = 'applyDateRule';

      data.hourPriceChange = data.changePriceRule;

      // 如用户之前关闭changePriceRule的开关 后台将直接忽略这个字段
      // 时租房必定有该数据
      // if (hasOwnProperty.call(data, 'changePriceRule') && data.changePriceRule !== null) {
      //   data.isUseChangePrice = true; // 控制开关以及最终是否上传改该数据
      // } else {
      //   data.isUseChangePrice = false;
      //   data.changePriceRule = {
      //     // 之前没使用该配置的情况用默认值
      //     ...DefaultChangePriceRule,
      //   };
      // }

      if (hasOwnProperty.call(data, 'leastReservationRule') && data.leastReservationRule !== null) {
        data.isUseLeastReservation = true;
      } else {
        data.isUseLeastReservation = false;
        data.leastReservationRule = {
          // 之前没使用该配置的情况用默认值
          ...DefaultLeastReservationRule,
        };
      }

      const rulesBlock = ['applyDateRule', 'reservationDateRule'];

      rulesBlock.forEach(key => {
        // data[key].isUseWeekly = data[key].weekly && data[key].weekly.length !== 0;
        // data[key].isUseExceptDate = data[key].exceptDate && data[key].exceptDate.length !== 0;
        // data[key].weekly = data[key].isUseWeekly ? data[key].weekly : [];
        // data[key].exceptDate = data[key].isUseExceptDate ? data[key].exceptDate : [1];

        data[key].timeLimitList = data[key].timeLimitList || [{ ...DefaultTimeLimit }];
        data[key].isUseTimeLimit = true;

        if (!data[key].regularDate.startDate) {
          data[key].regularDate = {
            startDate: new Date(), // 开始日期
            endDate: new Date(), // 结束日期
          };
        }
      });

      return {
        ...state,
        ...data,
      };
    },

    onIsCanCustom(state, { payload }) {
      let { key, relyOn } = payload;

      // 传了relyOn的时有switch的模块
      if (relyOn && !state[relyOn]) {
        message.error('请先开启功能');

        // return {
        //   ...state,
        // };
      }

      const data = {
        ...state[key],
        customizable: state[key].customizable ? 0 : 1,
      };

      return {
        ...state,
        [key]: {
          ...data,
        },
      };
    },

    // 改变普通值
    changeMainVal(state, action) {
      return {
        ...state,
        ...action.payload,
      };
    },

    // 改变DateRules内值(reservationDateRule, applyDateRule)
    changeDateRulesVal(state, action) {
      const { blockName, payload } = action.payload;

      return {
        ...state,
        [blockName]: {
          ...state[blockName],
          ...payload,
        },
      };
    },

    // 改变PriceChange内值(reservationDateRule, applyDateRule)
    changePriceChange(state, action) {
      return {
        ...state,
        changePriceRule: {
          ...state.changePriceRule,
          ...action.payload,
        },
      };
    },

    // 关闭打开PriceChange
    switchChangePriceChange(state, action) {
      return {
        ...state,
        isUseChangePrice: action.payload.isUseChangePrice,
        changePriceRule: {
          ...DefaultChangePriceRule,
        },
      };
    },

    // 暂存数据
    store(state, action) {
      return {
        ...action.payload,
      };
    },
  },
};
