import React, { Component } from 'react';
import Link from 'umi/link';
import router from 'umi/router';
import { formatMessage } from 'umi/locale';
import RenderAuthorized from '@/components/Authorized';
import Exception from '@/components/Exception';
import ComponentError from './Exception/ComponentError';

const Authorized = RenderAuthorized(['user']); // 当前角色

// export default ({ children, route, location }) => {
//   const menuList = window.localStorage.menuList
//     ? JSON.parse(localStorage.menuList).map(item => item.code)
//     : '';

//   if (route.code && menuList && menuList.indexOf(route.code) === -1) {
//     // console.log(route.code, '无权限');
//     router.replace('/exception/403');
//   } else {
//     // console.log(route.code, '有权限');
//   }

//   const noMatch = (
//     <Exception
//       type="403"
//       desc={formatMessage({ id: 'app.exception.description.403' })}
//       linkElement={Link}
//       backText={formatMessage({ id: 'app.exception.back' })}
//     />
//   );

//   return (
//     <Authorized authority="user" noMatch={noMatch}>
//       {children}
//     </Authorized>
//   );
// };

// 权限控制 加 组件的错误catch
export default class Authorize extends Component {
  constructor(props) {
    super(props);
    const menuList = window.localStorage.menuList
      ? JSON.parse(localStorage.menuList).map(item => item.code)
      : '';
    let { children, route, location } = props;
    if (route.code && menuList && menuList.indexOf(route.code) === -1) {
      router.replace('/exception/403');
    } else {
      // console.log(route.code, '有权限');
    }
    this.state = {
      hasError: false,
      info: '',
    };
  }

  componentDidCatch(error, info) {
    this.setState({ hasError: true, info: `${error.message}&&&&&&&${info.componentStack}` });
    console.warn('componentError', error, info);
  }

  render() {
    const noMatch = (
      <Exception
        type="403"
        desc={formatMessage({ id: 'app.exception.description.403' })}
        linkElement={Link}
        backText={formatMessage({ id: 'app.exception.back' })}
      />
    );
    let { children, route, location } = this.props;
    let { hasError, info } = this.state;
    return (
      <Authorized authority="user" noMatch={noMatch}>
        {/* {children} */}
        {hasError ? <ComponentError /> : children}
      </Authorized>
    );
  }
}
