import React, { Component } from 'react';
import { connect } from 'dva';
import router from 'umi/router';
import Link from 'umi/link';
import { Checkbox, Alert, Icon } from 'antd';
import Login from '@/components/Login';
import styles from './Login.less';

const { Tab, UserName, Password, Mobile, Captcha, Submit, Code } = Login;

@connect(({ login, loading }) => ({
  login,
  submitting: loading.effects['login/login'],
}))
export default class LoginPage extends Component {
  state = {
    type: 'account',
    autoLogin: true,
  };

  componentWillMount() {
    const now = Date.now();
    this.props.dispatch({
      type: 'login/getCode',
      payload: { now },
    });
  }

  onTabChange = type => {
    this.setState({ type });
    this.onChangeCode();
  };

  onGetCaptcha = () =>
    new Promise((resolve, reject) => {
      const { dispatch, login } = this.props;

      this.loginForm.validateFields(['mobile', 'code'], {}, (err, values) => {
        // debugger;
        if (err) {
          reject(err);
        } else {
          dispatch({
            type: 'login/getCaptcha',
            payload: {
              phone: values.mobile,
              token: login.token,
              code: values.code,
            },
          })
            .then(resolve)
            .catch(reject);
        }
      });
    });

  handleSubmit = (err, values) => {
    const { dispatch, login } = this.props;
    const { type } = this.state;

    if (!err) {
      if (type === 'account') {
        if (values.userName) {
          values.account = values.userName;
          delete values.userName;
        }

        dispatch({
          type: 'login/loginbByPass',
          payload: {
            ...values,
            type,
            system: 'CRS',
            token: login.token,
          },
        });
      }
      if (type === 'mobile') {
        dispatch({
          type: 'login/loginbByPhone',
          payload: {
            ...values,
            type,
            system: 'CRS',
            token: login.token,
          },
        });
      }
    }
  };

  changeAutoLogin = e => {
    this.setState({
      autoLogin: e.target.checked,
    });
  };

  onChangeCode = () => {
    const now = Date.now();
    this.props.dispatch({
      type: 'login/getCode',
      payload: { now },
    });
  };

  renderMessage = content => (
    <Alert style={{ marginBottom: 24 }} message={content} type="error" showIcon />
  );

  toResetPass = () => {
    router.push({
      pathname: '/user/resetPass',
    });
  };

  render() {
    let { toResetPass } = this;
    const { login, submitting, img } = this.props;
    const { type, autoLogin } = this.state;
    return (
      <div className={styles.main}>
        <Login
          defaultActiveKey={type}
          onTabChange={this.onTabChange}
          onSubmit={this.handleSubmit}
          ref={form => {
            this.loginForm = form;
          }}
        >
          <Tab key="account" tab="账户密码登录">
            {login.status === 'error' &&
              login.type === 'account' &&
              !submitting &&
              this.renderMessage('账户或密码错误（admin/888888）')}
            <UserName name="userName" placeholder="手机号/邮箱" />
            <Password
              name="password"
              placeholder="请输入密码"
              onPressEnter={() => this.loginForm.validateFields(this.handleSubmit)}
            />
            {/* {login.needCode ? ( */}
            <Code
              name="code"
              placeholder="请输入验证码"
              onChangeCode={this.onChangeCode}
              img={login.img}
            />
            {/* ) : null} */}
          </Tab>
          <Tab key="mobile" tab="手机号登录">
            {login.status === 'error' &&
              login.type === 'mobile' &&
              !submitting &&
              this.renderMessage('验证码错误')}
            <Mobile name="mobile" placeholder="请输入手机号" />
            <Code
              name="code"
              placeholder="请输入图形验证码"
              onChangeCode={this.onChangeCode}
              img={login.img}
            />
            <Captcha
              placeholder="请输入手机验证码"
              name="captcha"
              countDown={120}
              onGetCaptcha={this.onGetCaptcha}
            />
          </Tab>
          <div style={{ overflow: 'hidden' }}>
            {/* <Checkbox checked={autoLogin} onChange={this.changeAutoLogin}>
              自动登录
            </Checkbox> */}
            {type === 'account' ? (
              <span onClick={toResetPass} style={{ float: 'right', cursor: 'pointer' }}>
                忘记密码
              </span>
            ) : null}
          </div>
          <Submit loading={submitting}>登录</Submit>
          {/* <div className={styles.other}>
            其他登录方式
            <Icon className={styles.icon} type="alipay-circle" />
            <Icon className={styles.icon} type="taobao-circle" />
            <Icon className={styles.icon} type="weibo-circle" />
            <Link className={styles.register} to="/User/Register">
              注册账户
            </Link>
          </div> */}
        </Login>
      </div>
    );
  }
}
