import React, { Component } from 'react';
import { connect } from 'dva';
import Link from 'umi/link';
import router from 'umi/router';
import { Checkbox, Alert, Icon } from 'antd';
import Login from '@/components/Login';
import styles from './Login.less';
import { verifyMessage } from './services/login';

const { Tab, UserName, Password, Mobile, Captcha, Submit, Code } = Login;

@connect(({ login, loading }) => ({
  login,
  submitting: loading.effects['login/login'],
}))
export default class resetPass extends Component {
  state = {
    type: '1',
  };

  componentWillMount() {
    const now = Date.now();
    this.props.dispatch({
      type: 'login/getCode',
      payload: { now },
    });
  }

  onTabChange = type => {
    this.setState({ type });
    this.onChangeCode();
  };

  onGetCaptcha = () =>
    new Promise((resolve, reject) => {
      const { dispatch, login } = this.props;

      this.loginForm.validateFields(['mobile', 'code'], {}, (err, values) => {
        if (err) {
          reject(err);
        } else {
          dispatch({
            type: 'login/getCaptcha',
            payload: {
              phone: values.mobile,
              code: values.code,
              token: login.token,
            },
          })
            .then(resolve)
            .catch(reject);
        }
      });
    });

  handleSubmit = (err, values) => {
    let { mobile, captcha } = values;

    if (!err) {
      const { dispatch, login } = this.props;
      // debugger;
      verifyMessage({ phone: mobile, verificationCode: captcha })
        .then(() => {
          dispatch({
            type: 'login/saveResetpassInfo',
            payload: {
              phone: mobile,
              verificationCode: captcha,
            },
          });
          router.push({
            pathname: '/user/setNewPass',
            query: {
              type: 'forget',
            },
          });
        })
        .catch(er => {
          console.log(er);
        });
    }
  };

  onChangeCode = () => {
    const now = Date.now();
    this.props.dispatch({
      type: 'login/getCode',
      payload: { now },
    });
  };

  render() {
    const { login, submitting, img } = this.props;
    const { type } = this.state;
    return (
      <div className={styles.main}>
        <Login
          defaultActiveKey={type}
          onTabChange={this.onTabChange}
          onSubmit={this.handleSubmit}
          ref={form => {
            this.loginForm = form;
          }}
        >
          <Tab key="1" tab="重置密码">
            {login.status === 'error' &&
              login.type === 'mobile' &&
              !submitting &&
              this.renderMessage('验证码错误')}
            <Mobile name="mobile" placeholder="请输入手机号" />
            <Code
              name="code"
              placeholder="请输入图形验证码"
              onChangeCode={this.onChangeCode}
              img={login.img}
            />
            <Captcha
              name="captcha"
              placeholder="请输入手机验证码"
              countDown={120}
              onGetCaptcha={this.onGetCaptcha}
            />
          </Tab>

          <Submit loading={submitting}>下一步</Submit>
        </Login>
      </div>
    );
  }
}
