import React, { Component } from 'react';
import { connect } from 'dva';
import Link from 'umi/link';
import router from 'umi/router';
import { Input, Icon, Tabs, Button, message } from 'antd';
import Login from '@/components/Login';
import styles from './Login.less';
import { PASSWORD } from '@/constant/reg';

const TabPane = Tabs.TabPane;
@connect(({ login, loading }) => ({
  login,
  submitting: loading.effects['login/updatePass'],
}))
export default class resetPass extends Component {
  state = {
    type: 'forget', // first
    password1: '',
    password2: '',
  };

  componentWillMount() {
    let { location } = this.props;

    this.setState({
      type: location.query.type, // forget 忘记密码  first 修改密码
    });
  }

  handleSubmit = () => {
    let { dispatch } = this.props;
    let { password1, password2, type } = this.state;
    password1 = password1.trim();
    password2 = password2.trim();

    let res1 = PASSWORD.test(password1);
    let res2 = password1 === password2;
    if (!res1) {
      message.error('密码是10-20数字字母组合');
      return;
    }
    if (!res2) {
      message.error('两次输入的密码不一致');
      return;
    }
    if (type === 'first') {
      // 第一次
      dispatch({
        type: 'login/updatePass',
        payload: {
          newPassword: password1,
          system: 'CRS',
        },
      })
        .then(res => {})
        .catch(er => console.log(er));
    } else {
      let { login } = this.props;
      let { resetInfo } = login;

      dispatch({
        type: 'login/resetPass',
        payload: {
          newPassword: password1,
          ...resetInfo,
          system: 'CRS',
        },
      })
        .then(res => {})
        .catch(er => console.log(er));
    }
  };

  change = (e, key) => {
    this.setState({
      [key]: e.target.value,
    });
  };

  render() {
    const { login, submitting, img } = this.props;
    const { type, password1, password2 } = this.state;
    let { change, handleSubmit } = this;
    return (
      <div className={styles.main}>
        <Tabs className={styles.tabs} tabBarStyle={{ textAlign: 'center' }}>
          <TabPane tab="设置新密码" key="1">
            {type === 'first' ? (
              <p style={{ textAlign: 'center' }}>第一次登陆需修改账户密码</p>
            ) : null}
            <Input
              type="password"
              placeholder="10-20数字字母组合，区分大小写"
              size="large"
              value={password1}
              onChange={ev => change(ev, 'password1')}
              prefix={<Icon type="key" style={{ color: 'rgba(0,0,0,.25)' }} />}
            />
            <Input
              type="password"
              style={{ marginTop: 30 }}
              placeholder="请再次输入密码"
              onChange={ev => change(ev, 'password2')}
              size="large"
              value={password2}
              prefix={<Icon type="key" style={{ color: 'rgba(0,0,0,.25)' }} />}
            />
            <p>
              <Button
                loading={submitting}
                onClick={handleSubmit}
                size="large"
                type="primary"
                style={{ textAlign: 'center', marginTop: 30, width: '100%' }}
              >
                确定
              </Button>
            </p>
          </TabPane>
        </Tabs>
      </div>
    );
  }
}
