import { routerRedux } from 'dva/router';
import router from 'umi/router';
import { message } from 'antd';
import { fakeAccountLogin, getFakeCaptcha } from '@/services/api';
import {
  login,
  logout,
  getUserInfo,
  getCode,
  getUserMenu,
  loginByPhone,
  updatePass,
  resetPass,
  getPhoneCode,
} from '../services/login';
import { setAuthority } from '@/utils/authority';
import { getPageQuery } from '@/utils/utils';

export default {
  namespace: 'login',

  state: {
    status: undefined,
    needCode: false, // 是否需要二维码
    img: '', // 二维码图片
    token: '', // 二维码对应token 非用户token
    accountId: '',
    resetInfo: null,
  },

  effects: {
    *loginbByPass({ payload }, { call, put, select }) {
      // debugger;
      let response = '';
      const token = yield select(state => state.login.token);
      const needCode = yield select(state => state.login.needCode);
      if (needCode) {
        payload.token = token;
      }

      try {
        response = yield call(login, payload);
      } catch (error) {
        // 重新刷新验证码
        yield put({
          type: 'getCode',
          payload: {
            now: Date.now(),
          },
        });
        if (error.response && error.response.code === '6004') {
          // 五次密码错误 需要输入验证码
          //
          yield put({
            type: 'changeNeedCode',
            payload: {
              needCode: true,
            },
          });
        }
      }
      yield put({
        type: 'handleLoginSuccess',
        payload: response,
      });
    },
    *loginbByPhone({ payload }, { call, put, select }) {
      // phone verificationCode
      payload.phone = payload.mobile;
      payload.verificationCode = payload.captcha;
      try {
        let res = yield call(loginByPhone, payload);
        yield put({
          type: 'handleLoginSuccess',
          payload: res,
        });
      } catch (error) {
        console.log(error);
      }
    },
    *updatePass({ payload }, { call, put, select }) {
      // debugger;

      try {
        let res = yield call(updatePass, payload);
        yield put({
          type: 'handleLoginSuccess',
          payload: res,
        });
      } catch (error) {
        return Promise.reject(error);
      }
    },
    *resetPass({ payload }, { call, put, select }) {
      // debugger;

      try {
        let res = yield call(resetPass, payload);
        yield put({
          type: 'handleLoginSuccess',
          payload: res,
        });
      } catch (error) {
        return Promise.reject(error);
      }
    },
    *handleLoginSuccess({ payload }, { call, put, select }) {
      // Login successfully
      let response = payload;
      if (response.code === '000') {
        yield put({
          type: 'user/save',
          payload: response.data,
        });
        const { token: _token } = response.data;
        localStorage.token = _token;

        yield put({
          type: 'user/getUserInfo',
          payload: {},
        });
        // 第一次登陆强制设置新密码
        if (response.data.isForceUpdatePwd === 1) {
          router.push({
            pathname: '/user/setNewPass',
            query: {
              type: 'first',
            },
          });
          message.info('第一次登陆需修改账户密码');
          return;
        }

        // reloadAuthorized();
        const urlParams = new URL(window.location.href);

        const params = getPageQuery();
        let { redirect } = params;

        if (redirect) {
          const redirectUrlParams = new URL(redirect);
          if (redirectUrlParams.origin === urlParams.origin) {
            redirect = redirect.substr(urlParams.origin.length);
            if (redirect.startsWith('/#')) {
              redirect = redirect.substr(2);
            }
          } else {
            window.location.href = redirect;
            return;
          }
        }
        yield put(routerRedux.replace(redirect || '/'));
      }
    },
    *getCaptcha({ payload }, { call }) {
      try {
        yield call(getPhoneCode, payload);
        message.info('验证码已发，请注意查收。');
      } catch (error) {
        console.log(error);
      }
    },

    *getCode({ payload }, { call, put }) {
      // ;
      let response = {};
      try {
        response = yield call(getCode, payload);
      } catch (error) {
        console.log(error.status);
        console.log(error.response);
        // ;
      }

      if (response.code === '000') {
        //
        yield put({
          type: 'saveCode',
          payload: response.data,
        });
      }
    },
  },

  reducers: {
    changeLoginStatus(state, { payload }) {
      setAuthority(payload.currentAuthority);
      return {
        ...state,
        status: payload.status,
        type: payload.type,
      };
    },
    changeNeedCode(state, { payload }) {
      return {
        ...state,
        ...payload,
      };
    },
    saveCode(state, { payload }) {
      return {
        ...state,
        ...payload,
      };
    },
    saveResetpassInfo(state, { payload }) {
      return {
        ...state,
        resetInfo: payload,
      };
    },
  },
};
