import assert from 'assert';

let plugins = null;
let validKeys = [];

export function init(opts = {}) {
  plugins = [];
  validKeys = opts.validKeys;
}

export function use(plugin) {
  if (validKeys && validKeys.length) {
    Object.keys(plugin).forEach(key => {
      assert(plugin[key].includes(key), `Invalid key ${key} from plugin`);
    });
  }
  plugins.push(plugin);
}

export function getItem(key) {
  return plugins.filter(plugin => key in plugin).map(plugin => plugin[key]);
}

export function apply(item, { initialValue }) {
  if (typeof item === 'string') item = getItem(item);
  assert(Array.isArray(item), `item must be Array`);
  return item.reduce(
    item,
    (memo, fn) => {
      assert(typeof fn === 'function', `applied item must be function`);
      return fn(memo);
    },
    initialValue
  );
}

export function applyForEach(item, { initialValue }) {
  if (typeof item === 'string') item = getItem(item);
  assert(Array.isArray(item), `item must be Array`);
  item.forEach(item, (memo, fn) => {
    assert(typeof fn === 'function', `applied item must be function`);
    fn(initialValue);
  });
}

// shadow merge
export function mergeConfig(item) {
  if (typeof item === 'string') item = getItem(item);
  assert(Array.isArray(item), `item must be Array`);
  return item.reduce(item, (memo, config) => ({ ...memo, ...config }), {});
}
