/* eslint-disable no-console */
import moment from 'moment';

export const WEEK_LIST = ['周一', '周二', '周三', '周四', '周五', '周六', '周日'];

export const Weekly = [1, 2, 3, 4, 5, 6, 0];

export function transDefaultList(list) {
  return list.map(l => Weekly.findIndex(w => w === l));
}

export function transWeeklyList(list) {
  return list.map(item => Weekly[item]);
}

export function getDisableList(list) {
  return Weekly.filter(item => !list.includes(item));
}

export const DateFiliter = {
  handleSection(datelist) {
    const unionSet = [];

    if (!Array.isArray(datelist)) {
      return new Error('参数必须为数组');
    }

    if (datelist.length === 0) {
      return [0, 1, 2, 3, 4, 5, 6];
    }

    datelist.forEach(dateChange => {
      const startDate = dateChange[0];
      const endDate = dateChange[1];
      const days = moment(endDate).diff(moment(startDate), 'day');
      let rangeDateArr = [];
      for (let i = 0; i <= days; i++) {
        const activeDate = moment(startDate)
          .add(i, 'day')
          .format('YYYY-MM-DD');
        rangeDateArr.push(activeDate);
      }
      const rangeDate = rangeDateArr.map(date => {
        return moment(date).day();
      });
      /** 获取多个日期范围的星期值，存放于数组unionSet */
      unionSet.push(new Set([...rangeDate]));
    });
    // 获取交集
    return this.getIntersect(unionSet);
  },

  getIntersect(unionSet) {
    let tempArr = [...unionSet[0]];

    /** 获取当前重复数据，然后去重 */
    const unionSetArr = Array.from(unionSet);
    for (let i = 1; i < unionSet.length; i++) {
      let arr1 = [...tempArr];
      let arr2 = [...unionSetArr[i]];
      tempArr = this.getRepeatArr(arr1, arr2);
    }
    return tempArr;
  },

  getRepeatArr(arr1, arr2) {
    let arr = [...arr1];

    arr2.forEach(v => {
      if (!arr1.includes(v)) {
        arr.push(v);
      }
    });

    return arr;
  },
};

export function transListToStr(arrRes) {
  let str = '';
  let arr = arrRes.slice();
  arr = arr.sort();

  if (arr[0] === 0) {
    arr.shift();
    arr.push(0);
  }
  arr = transDefaultList(arr);
  str = arr.map(item => WEEK_LIST[item]).join(',');

  return str;
}
// export default DateFiliter;
