import _ from 'lodash';

/**
 * debounce模式的装饰器
 * @param  {Object} target     实例对象
 * @param  {String} name       修饰的名字
 * @param  {Objecty} descriptor 对象的属性
 * @return {Objecty}            对象的属性
 * 用法: @debounce 或者 debounce(300)
 * exp: @/components/HotelSearch/HotelSearch.js
 */

/* eslint-disable */
export function debounce(target, name, descriptor) {
  let isFn =
    typeof arguments[0] === 'object' &&
    typeof arguments[1] === 'string' &&
    typeof arguments[2] === 'object';

  if (isFn) {
    descriptor.value = _.debounce(target[name], 250);

    return descriptor;
  }

  let debounceTime = target;

  return (target, name, descriptor) => {
    descriptor.value = _.debounce(target[name], debounceTime || 250);

    return descriptor;
  };
}
/* eslint-disable */

export function tableWidthDecorator(tar) {
  let isFn = typeof tar !== 'function';

  if (isFn) {
    return function(target) {
      setTableWidth(target, !!tar);
    };
  } else {
    setTableWidth(tar, false);
  }

  function setTableWidth(target, bool) {
    let fn = target.prototype.componentDidMount;

    target.prototype.componentDidMount = function() {
      fn.call(this);

      const columns = this.columns || this.state.columns || [];

      let tableWidth = this.state.columns.reduce((a, b) => {
        let last = typeof a === 'number' ? a : a.width;

        return last + b.width;
      }, 0);

      let addWidth = bool ? 51 : 0;

      this.setState({
        tableWidth: tableWidth + addWidth || 1900,
      });
    };
  }
}
