import { authDownload, transAuthDownload } from '@/utils/fetch';

export function resolveBlob(blob, fileName) {
  const ev = document.createEvent('MouseEvents');
  const urlObject = window.URL || window;
  const save_link = document.createElement('a');

  save_link.href = urlObject.createObjectURL(blob);
  save_link.download = fileName;

  ev.initMouseEvent(
    'click',
    true,
    false,
    window,
    0,
    0,
    0,
    0,
    0,
    false,
    false,
    false,
    false,
    0,
    null
  );

  save_link.dispatchEvent(ev);
}

export function downloadUrl(imgsrc, name) {
  let image = new Image();
  // 解决跨域 Canvas 污染问题
  image.setAttribute('crossOrigin', 'anonymous');
  image.onload = function() {
    let canvas = document.createElement('canvas');
    canvas.width = image.width;
    canvas.height = image.height;
    let context = canvas.getContext('2d');
    context.drawImage(image, 0, 0, image.width, image.height);
    let url = canvas.toDataURL('image/png'); // 得到图片的base64编码数据
    let a = document.createElement('a'); // 生成一个a元素
    let event = new MouseEvent('click'); // 创建一个单击事件
    a.download = name || 'photo'; // 设置图片名称
    a.href = url; // 将生成的URL设置为a.href属性
    a.dispatchEvent(event); // 触发a的单击事件
  };

  image.src = imgsrc;
}

export function downloadFile(url, params = {}, fileName = '') {
  const contentType = params['Content-Type'];
  delete params['Content-Type'];

  return authDownload(url, {
    params,
    'Content-Type': contentType,
  })
    .then(res => {
      fileName = fileName || res.fileName;
      resolveBlob(res.data, fileName);
    })
    .catch(err => {
      console.log(err);
    });
}

export function transDownloadFile(url, params = {}, fileName = '') {
  return transAuthDownload(url, {
    params,
    type: 1,
  })
    .then(res => {
      fileName = fileName || res.fileName;
      resolveBlob(res.data, fileName);
    })
    .catch(err => {
      console.log(err);
    });
}
