const Dictionary = {};
export default Dictionary;

/**
 *
 * @param {Array} list 字典数组
 * @returns {Object}  返回key-value字典用于页面显示
 */
function getDicKV(list) {
  return list.reduce((kv, e) => {
    const tmp = kv;
    tmp[e.code] = e.name;
    return tmp;
  }, {});
}

/**
 *
 * @param {Object} kv key-value字典
 * @returns {Array}  返回字典数组
 */
function getDicList(kv) {
  return Object.keys(kv).map(e => ({ name: kv[e], code: (Number.isNaN(+e) && e) || +e }));
}

// 资金核销 渠道
Dictionary.channelKV = { 0: '全部', 1: 'CPP2', 2: '中行', 3: '建行' };
Dictionary.channel = getDicList(Dictionary.channelKV);

// 确认状态
Dictionary.confirmationKV = { 0: '全部', 1: '待确认', 2: '已确认' };
Dictionary.confirmation = getDicList(Dictionary.confirmationKV);

// 渠道
Dictionary.otaCodeKV = {
  0: '去哪儿',
  1: '携程',
  2: '飞猪',
  3: '艺龙直连',
  4: '艺龙EBK',
  5: '微信',
  6: '支付宝',
};
Dictionary.otaCode = getDicList(Dictionary.otaCodeKV);

// 对账状态
Dictionary.reconStatusKV = { 0: '待对账', 1: '成功' };
Dictionary.reconStatus = getDicList(Dictionary.reconStatusKV);

// 状态
Dictionary.summaryStatusKV = { 0: '待汇总', 1: '已汇总', 2: '关闭' };
Dictionary.summaryStatus = getDicList(Dictionary.summaryStatusKV);

// 业务类型
Dictionary.businessType = [
  { code: 1, name: '消费' },
  { code: 2, name: '退款' },
  { code: 3, name: '赔付' },
  {
    code: 4,
    name: '里程费',
  },
  { code: 5, name: '其他' },
];
Dictionary.businessTypeKV = getDicKV(Dictionary.businessType);

//
Dictionary.billStatusKV = { 0: '未处理', 1: '成功', 2: '失败' };
Dictionary.billStatus = getDicList(Dictionary.billStatusKV);

Dictionary.weeklyStatusKV = { 0: '待确认', 1: '待结算', 2: '待出款', 3: '出款成功' };
Dictionary.weeklyStatus = getDicList(Dictionary.weeklyStatusKV);

Dictionary.adjustStatusKV = { 0: '未发送', 1: '发送成功', 2: '发送失败' };
Dictionary.adjustStatus = getDicList(Dictionary.adjustStatusKV);

Dictionary.withdrawStatusKV = { 0: '待编辑', 1: '待结算', 2: '待出款', 3: '出款成功' };
Dictionary.withdrawStatus = getDicList(Dictionary.withdrawStatusKV);

// 出款管理账单状态
Dictionary.outmoneyManageKV = { 0: '待出款', 1: '出款成功' };
Dictionary.outmoneyManage = getDicList(Dictionary.outmoneyManageKV);

Dictionary.customaryTypeKV = { 1: '商户周结退款', 2: '提现退款' };
Dictionary.customaryType = getDicList(Dictionary.customaryTypeKV);

// 出款管理重处理状态
Dictionary.reprocessKV = { t: '是', f: '否' };
Dictionary.reprocess = getDicList(Dictionary.reprocessKV);

// 商户信息表列表状态
Dictionary.merchantKV = { 0: '不可用', 1: '可用' };
Dictionary.merchant = getDicList(Dictionary.merchantKV);

// 账户类型
Dictionary.accountType = [
  { code: null, name: '全部' },
  { code: 1, name: '结算账户' },
  { code: 2, name: '公司本部账户' },
];

// 账户状态
Dictionary.accountStatus = [
  { code: '', name: '全部' },
  { code: 1, name: '正常' },
  { code: 2, name: '销户' },
];

// 银行流水 方向
Dictionary.transactionType = [{ code: 1, name: '借方' }, { code: 2, name: '贷方' }];

// 匹配状态
Dictionary.matchStatusKV = { 0: 'Y', 1: 'N' };
Dictionary.matchStatus = getDicList(Dictionary.matchStatusKV);

// 银行流水 确认状态
Dictionary.confirmStatusKV = { 0: '待确认', 1: '已确认' };
Dictionary.confirmStatus = getDicList(Dictionary.confirmStatusKV);

// 审核状态
Dictionary.approveStatusKV = { 0: '待审核', 1: '审核通过', 2: '审核拒绝' };
Dictionary.approveStatus = getDicList(Dictionary.approveStatusKV);

// spa自动还款  凭证模板配类型
Dictionary.accountEntryTemplateStatusKV = { 0: '不可用', 1: '可用' };
Dictionary.accountEntryTemplateStatus = getDicList(Dictionary.accountEntryTemplateStatusKV);

// 退款 支付渠道
Dictionary.channelCodeKV = { wechat: '微信', alipay: '支付宝', xiaomi: '小米支付' };
Dictionary.channelCode = getDicList(Dictionary.channelCodeKV);

// 退款 状态
Dictionary.refundStatusKV = { 0: '退款中', 1: '退款成功', 2: '退款失败', 3: '待退款' };
Dictionary.refundStatus = getDicList(Dictionary.refundStatusKV);

// 退款 类型
Dictionary.refundTypeKV = { 1: '网银退款', 2: '无需退款' };
Dictionary.refundType = getDicList(Dictionary.refundTypeKV);

// 退款 来源
Dictionary.appCodeKV = {
  PMS_1_0: '旧版PMS',
  'PMS2.0': '新版PMS',
  'CRS1.0': '旧版CRS',
  'CRS2.0': '新版CRS',
  'OYO-APP': '无线APP',
  'OYO-APP-IOS': '苹果端APP',
  'OYO-APP-ANDROID': '安卓端APP',
  OTA: 'OTA直连',
};
Dictionary.appCode = getDicList(Dictionary.appCodeKV);

// 支付-对账单对账-差错处理-渠道
Dictionary.errorHandlingChannelKV = { 1: '支付宝', 2: '微信' };
Dictionary.errorHandlingChannel = getDicList(Dictionary.errorHandlingChannelKV);

// 支付-对账单对账-差错处理-渠道类型
Dictionary.errorHandlingTypeKV = { 1: '系统多', 2: '渠道多' };
Dictionary.errorHandlingType = getDicList(Dictionary.errorHandlingTypeKV);

// 支付-对账单对账-差错处理-渠道状态
Dictionary.errorHandlingStateKV = { 1: '待处理', 2: '已提交', 3: '已退款', 4: '已关闭' };
Dictionary.errorHandlingState = getDicList(Dictionary.errorHandlingStateKV);

// 支付掉单-支付状态
Dictionary.reFundPayStateKV = {
  0: '支付中',
  1: '交易支付成功',
  2: '支付失败',
  3: '待支付',
  4: '未付款交易超时关闭，或支付完成后全额退款',
  5: '交易结束，不可退款',
  6: '转入退款',
};
Dictionary.reFundPayState = getDicList(Dictionary.reFundPayStateKV);

// 支付掉单-补单状态
Dictionary.supplementStateKV = { 0: '待补单', 1: '补单成功', 2: '无需补单' };
Dictionary.supplementState = getDicList(Dictionary.supplementStateKV);

// 自动退款处理 - 退款来源
Dictionary.automaticRefundProcessingAppCodeKV = {
  PMS_1_0: '旧版PMS',
  'PMS2.0': '新版PMS',
  'CRS1.0': '旧版CRS',
  'CRS2.0': '新版CRS',
  'OYO-APP': '无线APP',
  'OYO-APP-IOS': '苹果端APP',
  'OYO-APP-ANDROID': '安卓端APP',
  'OYO-APP-APPLET': '小程序',
  OTA: 'OTA直连',
};
Dictionary.automaticRefundProcessingAppCode = getDicList(
  Dictionary.automaticRefundProcessingAppCodeKV
);

// 自动退款处理 - 支付渠道
Dictionary.automaticRefundProcessingChannelCodeKV = {
  alipay: '支付宝',
  wechat: '微信',
  xiaomi: '小米支付',
};
Dictionary.automaticRefundProcessingChannelCode = getDicList(
  Dictionary.automaticRefundProcessingChannelCodeKV
);

// 自动退款处理 - 状态
Dictionary.automaticRefundProcessingrefundStatusKV = {
  0: '退款中',
  1: '退款成功',
  2: '退款失败',
  3: '待退款',
};
Dictionary.automaticRefundProcessingrefundStatus = getDicList(
  Dictionary.automaticRefundProcessingrefundStatusKV
);

// 自动退款处理 - 处理状态
Dictionary.automaticRefundProcessingprocessingStateKV = { 0: '无', 1: '关闭' };
Dictionary.automaticRefundProcessingprocessingState = getDicList(
  Dictionary.automaticRefundProcessingprocessingStateKV
);

// 交易查询-渠道
Dictionary.transactionQueryChannelCodeKV = { alipay: '支付宝', wechat: '微信', xiaomi: '小米支付' };
Dictionary.transactionQueryChannelCode = getDicList(Dictionary.transactionQueryChannelCodeKV);

// 交易查询-状态
Dictionary.transactionQueryStatusKV = {
  0: '支付中',
  1: '交易支付成功',
  2: '支付失败',
  3: '待支付',
  4: '未付款交易超时关闭，或支付完成后全额退款',
  5: '交易结束，不可退款',
  6: '转入退款(微信才有)',
};
Dictionary.transactionQueryStatus = getDicList(Dictionary.transactionQueryStatusKV);
