// 基于pro2模板  request的封装，涉及下行的权限验证，业务error处理。上行toekn携带（body以及头部）,baseurl添加
import { notification, message } from 'antd';
import router from 'umi/router';
import { stringify } from 'qs';
import { getUrlParam } from '@oyo/umi-mobile-utils';
import { authInit } from '@oyo/universal-auth';
import request from './request';
// import { CRS_API_BASE_URL } from '@/services/config';
import { RESPONCE_CODE_LIST } from '../constant/responseCode';
import { typeCheck } from './utils';

const CRS_API_BASE_URL = '';
const TRANS_AUTH_GET_URL = '/api/crs/v1/common/transfer/get/token';
const TRANS_AUTH_GET_NO_URL = '/api/crs/v1/common/transfer/get';
const TRANS_AUTH_POST_URL = '/api/crs/v1/common/transfer/post/token';
const TRANS_AUTH_POST_NO_URL = '/api/crs/v1/common/transfer/post';
const TRANS_AUTH_PUT_URL = '/api/crs/v1/common/transfer/put/token';
const TRANS_AUTH_PUT_NO_URL = '/api/crs/v1/common/transfer/put';
const TRANS_AUTH_DOWNLOAD = '/api/crs/v1/common/transfer/download/token';

let baseUrl = CRS_API_BASE_URL;

// const codeList = Object.keys(RESPONCE_CODE_LIST);

const checkCode = response => {
  // if (response.netError) {

  //   notification.error({
  //     message: '接口异常',
  //     description: `code:${response.status};msg:}`,
  //   });
  //   const error = new Error('网络错误');
  //   error.response = response;
  //   error.status = response.status;
  //   throw error ;

  // }
  if (response.code === '000' || response.code === 3002) {
    // 成功
    return response;
  }

  const errortext = response.msg ? response.msg : RESPONCE_CODE_LIST[response.code];
  const text = errortext.indexOf('=') > -1 ? 'msg错误' : errortext;
  const error = new Error(text);
  error.response = response;
  error.status = 200;

  if (response.code === '401') {
    router.push('/user/login');
  }

  if (['999', '10000'].includes(response.code)) {
    notification.error({
      message: '系统出错,请稍后再试…',
      description: `错误码:${response.code}`,
      duration: 9,
    });

    throw error;
  }

  if (errortext) {
    // notification.error({
    //   message: '',
    //   description: `msg:${errortext}`,
    // });
    message.error(errortext);
  } else {
    // notification.error({
    //   message: '',
    //   description: `code:${response.code}; no_msg:未定义的code`,
    // });
    message.error(`code:${response.code}; no_msg:未定义的code`);
  }

  throw error;
};

/**
 *
 * @param {*} url
 * @param {*} option {method,params,headers}
 * @param {*} needToken
 */
function formatParamToRequest(url, option, needToken = false) {
  // console.log('formatParamToRequest:', url, option, needToken);

  let res = {};
  let _option = JSON.parse(JSON.stringify(option));
  let _url = url;

  if (!url) {
    throw new Error('fetch need url param');
  }
  if (!typeCheck('isObj', _option)) {
    throw new Error('fetch (option param must be a object)');
  }
  const { method, headers } = _option;
  if (!method) {
    _option.method = 'GET';
  }

  if (needToken && localStorage.token) {
    // if (!params) {
    //   option.params = {};
    //   option.params.token = localStorage.token;
    // } else {
    //   option.params.token = localStorage.token;
    // }
    // debugger
    if (!headers) {
      _option.headers = {};
      _option.headers.token = localStorage.token;
    } else {
      _option.headers.token = localStorage.token;
    }
  }
  if (!_option.headers) _option.headers = {};
  _option.headers.client_id = 'crs-biz-service';
  _option.headers.client_type = 'web';
  _option.headers.redirect_uri = window.location.href; // 重定向地址
  _option.headers.ticket =
    getUrlParam('ticket', window.location.href) || localStorage.getItem('token') || '';

  if (_option.baseUrl) {
    // 覆盖全局定义baseurl
    baseUrl = _option.baseUrl;
  }

  if (_option.method === 'GET' || !_option.method) {
    if (stringify(_option.params)) {
      _url = `${url}?${stringify(_option.params)}`;
    }
    res = {
      url: baseUrl + _url, // 环境判断
      headers,
      option: {
        method: 'GET',
        headers: _option.headers,
      },
    };
  } else if (_option.method === 'POST') {
    res = {
      url: baseUrl + url, // 环境判断
      option: {
        method: 'POST',
        body: {
          ..._option.params,
        },
        headers: _option.headers,
      },
    };
  } else if (_option.method === 'PUT') {
    res = {
      url: baseUrl + url, // 环境判断
      option: {
        method: 'POST',
        body: {
          ..._option.params,
        },
        headers: _option.headers,
      },
    };
  } else {
    res = {};
  }

  return res;
}

/**
 *
 * @param {*} url
 * @param {*} option {method,params,headers}
 * @param {*} needToken
 */
function _fetch(url, option, needToken, notNeedCheckode) {
  // console.log('_fetch:', url, option, needToken);
  const { url: formatUrl, option: formatOption } = formatParamToRequest(url, option, needToken);

  // 下载时不需要校验code
  if (notNeedCheckode) {
    return request(formatUrl, formatOption);
  }

  return request(formatUrl, formatOption).then(checkCode);
}

// 上行token
export function authFetch(url, option = {}) {
  return _fetch(url, option, true);
}

// 不上行token
export function fetch(url, option = {}) {
  return _fetch(url, option, false);
}

// 上行token穿透接口
export function transAuthDownload(url, option) {
  if (url === undefined) return;
  let method = option.method ? option.method.toUpperCase() : 'GET';
  let type = option.type;
  let fetchUrl = TRANS_AUTH_DOWNLOAD;

  option.params = option.params || {};

  option = {
    method,
    params: {
      map: JSON.stringify(option.params),
      type,
      url,
    },
    headers: {
      isDownLoad: true,
      'Content-Type': option['Content-Type'] || `application/vnd.ms-excel; charset=utf-8`,
    },
  };

  return _fetch(fetchUrl, option, true, true);
}

// 上行token穿透接口
export function authDownload(url, option) {
  if (url === undefined) return;

  option = {
    method: 'GET',
    params: option.params,
    headers: {
      isDownLoad: true,
      'Content-Type': option['Content-Type'] || `application/vnd.ms-excel; charset=utf-8`,
    },
  };

  return _fetch(url, option, true, true);
}

// 上行token穿透接口
export function transAuthFetch(url, option) {
  if (url === undefined) return;
  let method = option.method ? option.method.toUpperCase() : 'GET';
  let type = option.type;
  let fetchUrl;

  option.params = option.params || {};

  if (['get', 'GET'].includes(method)) {
    fetchUrl = TRANS_AUTH_GET_URL;
    option = {
      method,
      params: {
        map: JSON.stringify(option.params),
        type,
        url,
      },
    };
  } else if (method === 'PUT') {
    fetchUrl = `${TRANS_AUTH_PUT_URL}?type=${type}&url=${url}`;
  } else {
    fetchUrl = `${TRANS_AUTH_POST_URL}?type=${type}&url=${url}`;
  }

  return _fetch(fetchUrl, option, true);
}

// 上行不带token穿透接口
export function transFetch(url, option) {
  if (url === undefined) return;

  let method = option.method !== '' ? option.method.toUpperCase() : 'GET';
  let type = option.type;
  let fetchUrl;

  option.params = option.params || {};

  if (['get', 'GET'].includes(method)) {
    fetchUrl = TRANS_AUTH_GET_NO_URL;
    option = {
      method,
      params: {
        map: JSON.stringify(option.params),
        type,
        url,
      },
    };
  } else if (method === 'PUT') {
    fetchUrl = `${TRANS_AUTH_PUT_NO_URL}?type=${type}&url=${url}`;
  } else {
    fetchUrl = `${TRANS_AUTH_POST_NO_URL}?type=${type}&url=${url}`;
  }
  return _fetch(fetchUrl, option, true);
}

/**
 *
 * @param {*} url
 * @param {*} option {method,params,headers}
 * @param {*} needToken
 */
function _uploads(url, formData, needToken) {
  let headers;

  if (needToken && localStorage.token) {
    headers = {};
    headers.token = localStorage.token;
  }
  if (!headers) headers = {};
  headers.client_id = 'crs-biz-service';
  headers.client_type = 'web';
  headers.redirect_uri = window.location.href; // 重定向地址
  headers.ticket =
    getUrlParam('ticket', window.location.href) || localStorage.getItem('token') || '';

  let formatUrl = baseUrl + url;
  // let formatUrl = '/buguywguyq' + url;

  let formatOption = {
    method: 'POST',
    body: formData,
    headers,
  };

  return request(formatUrl, formatOption).then(checkCode);
}

// 上行token穿透接口
export function transAuthUpdate(url, option, key) {
  let method = 'POST';
  let { formData, params = { xxxxxx: 1 }, type } = option;
  let fetchUrl = `/api/crs/v1/common/upload/list/post/token?field=${key ||
    'files'}&type=${type}&url=${url}&map=${encodeURIComponent(JSON.stringify(params))}`;

  return _uploads(fetchUrl, formData, true);
}

// 上传新接口要求，不拼URL
export function updateWithoutSplit(url, option, key) {
  let method = 'POST';
  let { formData, params = { xxxxxx: 1 }, type } = option;
  let fetchUrl = url;

  return _uploads(fetchUrl, formData, true);
}

authInit({ request: authFetch, ssoCheckUrl: '/api/crs/v1/user' });
