const gulp = require("gulp");
const path = require("path");
const rename = require("gulp-rename");
const replace = require("gulp-replace");
const shell = require("shelljs");
const jeditor = require("gulp-json-editor");
const fs = require("fs");

module.exports = function({
  gulpArgv,
  projectName,
  processPath,
  projetPath,
  templatesPath
}) {
  // 基础模版
  gulp.task("cloneGit", function(cb) {
    if (gulpArgv.gitBranch && gulpArgv.gitBranch !== "master") {
      shell
        .cd(processPath)
        .exec(
          `git clone -b ${gulpArgv.gitBranch} ${gulpArgv.git} ${projectName}`
        );
    } else {
      shell.cd(processPath).exec(`git clone ${gulpArgv.git} ${projectName}`);
    }

    cb();
  });

  // 处理packageJson
  gulp.task("handlerPackageJson", function(cb) {
    const packagePath = path.join(projetPath, "package.json");
    const package = fs.readFileSync(packagePath, "utf-8");
    const packageJson = JSON.parse(package);
    const newPackage = {};
    let scripts = packageJson.scripts;
    let devDependencies = packageJson.devDependencies;

    if (scripts.start) {
      scripts.start2 = scripts.start;

      scripts.start =
        "export NODE_ENV=production && cd node-services && npm run start";
    } else {
      scripts.start =
        "export NODE_ENV=production && cd node-services && npm run start";
    }

    scripts = {
      ...scripts,
      buildDev:
        "cross-env LOCAL=true cross-env ENV='dev' umi build && sh ./node-services/build.sh",
      buildTest:
        "cross-env LOCAL=true cross-env ENV='test' umi build && sh ./node-services/build.sh",
      devService: "cd node-services && npm run devService",
      testService: "cd node-services && npm run testService"
    };

    if (scripts.build) {
      scripts.build = `${scripts.build} && sh ./node-services/build.sh`;
    } else {
      console.log("您的package.json中缺失build....");
      process.exit();
    }

    newPackage.scripts = scripts;

    // 没有名字加上name
    if (!packageJson.name) newPackage.name = projectName;

    if (!devDependencies["cross-env"]) {
      newPackage.devDependencies = {
        ...devDependencies,
        "cross-env": "^5.1.1"
      };
    }

    gulp
      .src(packagePath)
      .pipe(jeditor(newPackage))
      .pipe(gulp.dest(projetPath))
      .on("end", function() {
        cb();
      });
  });

  // 处理packageJson
  gulp.task("handlerDockerignore", function(cb) {
    gulp
      .src(path.join(templatesPath, ".dockerignore"))
      .pipe(gulp.dest(projetPath))
      .on("end", function() {
        cb();
      });
  });

  // 处理gitignore
  gulp.task("handlerDockerignore", async function(cb) {
    const ignoreFile = path.join(projetPath, ".gitignore");
    const gitignore = fs.readFileSync(ignoreFile);
    console.log(gitignore);
    await fs.writeFileSync(
      ignoreFile,
      `
      ${gitignore}
.node-services/dist
**/logs
**/node_modules
    `
    );

    cb();
  });

  // handlerGitignore

  gulp.task("installWeb", function(cb) {
    if (!gulpArgv.install) return cb();
    shell.cd(projetPath).exec("npm install -d");
    cb();
  });

  gulp.task("installNode", function(cb) {
    if (!gulpArgv.install) return cb();

    shell.cd(path.join(projetPath, "node-services")).exec("npm install -d");

    cb();
  });
};
